/*
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*   http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing,
* software distributed under the License is distributed on an
* "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
* KIND, either express or implied.  See the License for the
* specific language governing permissions and limitations
* under the License.
*/
import echart from "echarts";
(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['exports', 'echarts'], factory);
    } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
        // CommonJS
        factory(exports, require('echarts'));
    } else {
        // Browser globals
        factory({}, root.echarts);
    }
}(this, function (exports, echarts) {
    var log = function (msg) {
        if (typeof console !== 'undefined') {
            console && console.error && console.error(msg);
        }
    }
    if (!echarts) {
        echarts = echart
        // log('ECharts is not Loaded');
        // return;
    }
    if (!echarts.registerMap) {
        log('ECharts Map is not loaded')
        return;
    }
    echarts.registerMap('深圳',
        {
            "type": "FeatureCollection",
            "features": [
                {
                    "type": "Feature",
                    "id": "440305",
                    "geometry": {
                        "type": "MultiPolygon",
                        "coordinates": [
                            [
                                [
                                    [
                                        113.844477,
                                        22.510217
                                    ],
                                    [
                                        113.843568,
                                        22.511037
                                    ],
                                    [
                                        113.842953,
                                        22.511911
                                    ],
                                    [
                                        113.842512,
                                        22.512667
                                    ],
                                    [
                                        113.842339,
                                        22.5136
                                    ],
                                    [
                                        113.842278,
                                        22.51477
                                    ],
                                    [
                                        113.842538,
                                        22.515822
                                    ],
                                    [
                                        113.844412,
                                        22.517083
                                    ],
                                    [
                                        113.845078,
                                        22.517269
                                    ],
                                    [
                                        113.845659,
                                        22.516873
                                    ],
                                    [
                                        113.848694,
                                        22.513574
                                    ],
                                    [
                                        113.850371,
                                        22.513282
                                    ],
                                    [
                                        113.852664,
                                        22.511816
                                    ],
                                    [
                                        113.856864,
                                        22.509579
                                    ],
                                    [
                                        113.857014,
                                        22.504813
                                    ],
                                    [
                                        113.856797,
                                        22.503576
                                    ],
                                    [
                                        113.855091,
                                        22.502835
                                    ],
                                    [
                                        113.854229,
                                        22.503018
                                    ],
                                    [
                                        113.852439,
                                        22.503851
                                    ],
                                    [
                                        113.850518,
                                        22.504822
                                    ],
                                    [
                                        113.848875,
                                        22.506335
                                    ],
                                    [
                                        113.845879,
                                        22.509381
                                    ],
                                    [
                                        113.844477,
                                        22.510217
                                    ]
                                ]
                            ],
                            [
                                [
                                    [
                                        114.023509,
                                        22.581647
                                    ],
                                    [
                                        114.023311,
                                        22.581279
                                    ],
                                    [
                                        114.022859,
                                        22.580798
                                    ],
                                    [
                                        114.022718,
                                        22.580668
                                    ],
                                    [
                                        114.022648,
                                        22.580609
                                    ],
                                    [
                                        114.022446,
                                        22.580447
                                    ],
                                    [
                                        114.022234,
                                        22.580326
                                    ],
                                    [
                                        114.022151,
                                        22.580287
                                    ],
                                    [
                                        114.020112,
                                        22.579459
                                    ],
                                    [
                                        114.020077,
                                        22.579439
                                    ],
                                    [
                                        114.020029,
                                        22.579426
                                    ],
                                    [
                                        114.019898,
                                        22.579392
                                    ],
                                    [
                                        114.019614,
                                        22.579303
                                    ],
                                    [
                                        114.019506,
                                        22.579279
                                    ],
                                    [
                                        114.019291,
                                        22.579212
                                    ],
                                    [
                                        114.019034,
                                        22.579122
                                    ],
                                    [
                                        114.018923,
                                        22.579088
                                    ],
                                    [
                                        114.018869,
                                        22.579073
                                    ],
                                    [
                                        114.017249,
                                        22.57909
                                    ],
                                    [
                                        114.017041,
                                        22.579094
                                    ],
                                    [
                                        114.016973,
                                        22.579117
                                    ],
                                    [
                                        114.016923,
                                        22.579131
                                    ],
                                    [
                                        114.01684,
                                        22.579158
                                    ],
                                    [
                                        114.016719,
                                        22.579194
                                    ],
                                    [
                                        114.016653,
                                        22.57921
                                    ],
                                    [
                                        114.016607,
                                        22.579234
                                    ],
                                    [
                                        114.016551,
                                        22.579272
                                    ],
                                    [
                                        114.016433,
                                        22.57937
                                    ],
                                    [
                                        114.016344,
                                        22.579426
                                    ],
                                    [
                                        114.016311,
                                        22.579436
                                    ],
                                    [
                                        114.01626,
                                        22.579432
                                    ],
                                    [
                                        114.015004,
                                        22.579516
                                    ],
                                    [
                                        114.014876,
                                        22.579555
                                    ],
                                    [
                                        114.014676,
                                        22.579538
                                    ],
                                    [
                                        114.013671,
                                        22.579451
                                    ],
                                    [
                                        114.01237,
                                        22.579266
                                    ],
                                    [
                                        114.009969,
                                        22.578929
                                    ],
                                    [
                                        114.009461,
                                        22.578858
                                    ],
                                    [
                                        114.008166,
                                        22.577839
                                    ],
                                    [
                                        114.007958,
                                        22.57766
                                    ],
                                    [
                                        114.007761,
                                        22.577421
                                    ],
                                    [
                                        114.007592,
                                        22.577144
                                    ],
                                    [
                                        114.007372,
                                        22.576835
                                    ],
                                    [
                                        114.007191,
                                        22.576648
                                    ],
                                    [
                                        114.006727,
                                        22.576371
                                    ],
                                    [
                                        114.006635,
                                        22.576284
                                    ],
                                    [
                                        114.00645,
                                        22.576146
                                    ],
                                    [
                                        114.006273,
                                        22.576014
                                    ],
                                    [
                                        114.006157,
                                        22.575939
                                    ],
                                    [
                                        114.005553,
                                        22.575764
                                    ],
                                    [
                                        114.005377,
                                        22.5754
                                    ],
                                    [
                                        114.005269,
                                        22.575138
                                    ],
                                    [
                                        114.005093,
                                        22.572239
                                    ],
                                    [
                                        114.005079,
                                        22.572084
                                    ],
                                    [
                                        114.005048,
                                        22.571902
                                    ],
                                    [
                                        114.005043,
                                        22.571794
                                    ],
                                    [
                                        114.005035,
                                        22.571618
                                    ],
                                    [
                                        114.00502,
                                        22.571442
                                    ],
                                    [
                                        114.005057,
                                        22.571202
                                    ],
                                    [
                                        114.005123,
                                        22.5708
                                    ],
                                    [
                                        114.00515,
                                        22.570533
                                    ],
                                    [
                                        114.005194,
                                        22.570156
                                    ],
                                    [
                                        114.005238,
                                        22.569871
                                    ],
                                    [
                                        114.005282,
                                        22.569554
                                    ],
                                    [
                                        114.00534,
                                        22.569276
                                    ],
                                    [
                                        114.005354,
                                        22.56917
                                    ],
                                    [
                                        114.005371,
                                        22.568926
                                    ],
                                    [
                                        114.005384,
                                        22.568594
                                    ],
                                    [
                                        114.005398,
                                        22.568499
                                    ],
                                    [
                                        114.005399,
                                        22.568378
                                    ],
                                    [
                                        114.00542,
                                        22.568235
                                    ],
                                    [
                                        114.005399,
                                        22.568014
                                    ],
                                    [
                                        114.005376,
                                        22.567898
                                    ],
                                    [
                                        114.005252,
                                        22.567674
                                    ],
                                    [
                                        114.005026,
                                        22.567368
                                    ],
                                    [
                                        114.004755,
                                        22.567043
                                    ],
                                    [
                                        114.004551,
                                        22.566791
                                    ],
                                    [
                                        114.004364,
                                        22.566603
                                    ],
                                    [
                                        114.004121,
                                        22.566349
                                    ],
                                    [
                                        114.004063,
                                        22.566271
                                    ],
                                    [
                                        114.00396,
                                        22.566045
                                    ],
                                    [
                                        114.003836,
                                        22.565774
                                    ],
                                    [
                                        114.003756,
                                        22.565552
                                    ],
                                    [
                                        114.003486,
                                        22.564839
                                    ],
                                    [
                                        114.003414,
                                        22.564637
                                    ],
                                    [
                                        114.003339,
                                        22.563183
                                    ],
                                    [
                                        114.00337,
                                        22.563061
                                    ],
                                    [
                                        114.003419,
                                        22.562857
                                    ],
                                    [
                                        114.003477,
                                        22.562698
                                    ],
                                    [
                                        114.003601,
                                        22.562412
                                    ],
                                    [
                                        114.003676,
                                        22.562183
                                    ],
                                    [
                                        114.00372,
                                        22.562041
                                    ],
                                    [
                                        114.003764,
                                        22.561839
                                    ],
                                    [
                                        114.003792,
                                        22.561708
                                    ],
                                    [
                                        114.0038,
                                        22.561534
                                    ],
                                    [
                                        114.003822,
                                        22.561286
                                    ],
                                    [
                                        114.003844,
                                        22.561015
                                    ],
                                    [
                                        114.003866,
                                        22.560784
                                    ],
                                    [
                                        114.003902,
                                        22.560628
                                    ],
                                    [
                                        114.003938,
                                        22.560479
                                    ],
                                    [
                                        114.00404,
                                        22.560324
                                    ],
                                    [
                                        114.004107,
                                        22.560241
                                    ],
                                    [
                                        114.004297,
                                        22.560155
                                    ],
                                    [
                                        114.004341,
                                        22.560116
                                    ],
                                    [
                                        114.004492,
                                        22.559971
                                    ],
                                    [
                                        114.00463,
                                        22.559825
                                    ],
                                    [
                                        114.004705,
                                        22.559684
                                    ],
                                    [
                                        114.004793,
                                        22.559534
                                    ],
                                    [
                                        114.004879,
                                        22.559345
                                    ],
                                    [
                                        114.004959,
                                        22.559197
                                    ],
                                    [
                                        114.005011,
                                        22.559054
                                    ],
                                    [
                                        114.005042,
                                        22.558905
                                    ],
                                    [
                                        114.005064,
                                        22.558785
                                    ],
                                    [
                                        114.005157,
                                        22.558621
                                    ],
                                    [
                                        114.005216,
                                        22.558528
                                    ],
                                    [
                                        114.005331,
                                        22.5584
                                    ],
                                    [
                                        114.005384,
                                        22.558311
                                    ],
                                    [
                                        114.005406,
                                        22.558231
                                    ],
                                    [
                                        114.005434,
                                        22.558062
                                    ],
                                    [
                                        114.005434,
                                        22.557866
                                    ],
                                    [
                                        114.00542,
                                        22.55767
                                    ],
                                    [
                                        114.005433,
                                        22.557514
                                    ],
                                    [
                                        114.005456,
                                        22.557419
                                    ],
                                    [
                                        114.0055,
                                        22.557344
                                    ],
                                    [
                                        114.005511,
                                        22.556852
                                    ],
                                    [
                                        114.005499,
                                        22.556344
                                    ],
                                    [
                                        114.005207,
                                        22.556189
                                    ],
                                    [
                                        114.005127,
                                        22.556161
                                    ],
                                    [
                                        114.004815,
                                        22.556098
                                    ],
                                    [
                                        114.00439,
                                        22.556017
                                    ],
                                    [
                                        114.004013,
                                        22.555946
                                    ],
                                    [
                                        114.003499,
                                        22.555859
                                    ],
                                    [
                                        114.003157,
                                        22.555808
                                    ],
                                    [
                                        114.0029,
                                        22.555774
                                    ],
                                    [
                                        114.002696,
                                        22.555766
                                    ],
                                    [
                                        114.002478,
                                        22.555808
                                    ],
                                    [
                                        114.002185,
                                        22.555834
                                    ],
                                    [
                                        114.001937,
                                        22.555845
                                    ],
                                    [
                                        114.001719,
                                        22.555833
                                    ],
                                    [
                                        114.001542,
                                        22.555804
                                    ],
                                    [
                                        114.001369,
                                        22.555802
                                    ],
                                    [
                                        114.0012,
                                        22.555789
                                    ],
                                    [
                                        114.000814,
                                        22.555707
                                    ],
                                    [
                                        114.000141,
                                        22.555544
                                    ],
                                    [
                                        113.999674,
                                        22.555461
                                    ],
                                    [
                                        113.998529,
                                        22.555179
                                    ],
                                    [
                                        113.998024,
                                        22.555056
                                    ],
                                    [
                                        113.99774,
                                        22.554995
                                    ],
                                    [
                                        113.99758,
                                        22.554945
                                    ],
                                    [
                                        113.997542,
                                        22.554887
                                    ],
                                    [
                                        113.997541,
                                        22.554838
                                    ],
                                    [
                                        113.997638,
                                        22.554714
                                    ],
                                    [
                                        113.997776,
                                        22.554563
                                    ],
                                    [
                                        113.998033,
                                        22.554244
                                    ],
                                    [
                                        113.99822,
                                        22.554083
                                    ],
                                    [
                                        113.998367,
                                        22.553941
                                    ],
                                    [
                                        113.998419,
                                        22.553879
                                    ],
                                    [
                                        113.998389,
                                        22.553706
                                    ],
                                    [
                                        113.998353,
                                        22.553237
                                    ],
                                    [
                                        113.9983,
                                        22.552818
                                    ],
                                    [
                                        113.998272,
                                        22.55267
                                    ],
                                    [
                                        113.998237,
                                        22.552377
                                    ],
                                    [
                                        113.998198,
                                        22.552209
                                    ],
                                    [
                                        113.99817,
                                        22.552085
                                    ],
                                    [
                                        113.998228,
                                        22.551642
                                    ],
                                    [
                                        113.998286,
                                        22.551395
                                    ],
                                    [
                                        113.998316,
                                        22.551223
                                    ],
                                    [
                                        113.998344,
                                        22.551072
                                    ],
                                    [
                                        113.998367,
                                        22.550972
                                    ],
                                    [
                                        113.998543,
                                        22.550586
                                    ],
                                    [
                                        113.998645,
                                        22.550329
                                    ],
                                    [
                                        113.998747,
                                        22.550229
                                    ],
                                    [
                                        113.998849,
                                        22.550139
                                    ],
                                    [
                                        113.998973,
                                        22.550094
                                    ],
                                    [
                                        113.999106,
                                        22.550047
                                    ],
                                    [
                                        113.999332,
                                        22.549994
                                    ],
                                    [
                                        113.999559,
                                        22.549941
                                    ],
                                    [
                                        113.999697,
                                        22.5499
                                    ],
                                    [
                                        113.999791,
                                        22.549847
                                    ],
                                    [
                                        113.999879,
                                        22.549744
                                    ],
                                    [
                                        113.9999,
                                        22.549618
                                    ],
                                    [
                                        113.999892,
                                        22.549489
                                    ],
                                    [
                                        113.999785,
                                        22.549229
                                    ],
                                    [
                                        113.999711,
                                        22.549074
                                    ],
                                    [
                                        113.999617,
                                        22.548986
                                    ],
                                    [
                                        113.999559,
                                        22.548958
                                    ],
                                    [
                                        113.999075,
                                        22.548931
                                    ],
                                    [
                                        113.998747,
                                        22.548902
                                    ],
                                    [
                                        113.998521,
                                        22.548867
                                    ],
                                    [
                                        113.998264,
                                        22.548813
                                    ],
                                    [
                                        113.998055,
                                        22.548778
                                    ],
                                    [
                                        113.997892,
                                        22.54871
                                    ],
                                    [
                                        113.997731,
                                        22.548641
                                    ],
                                    [
                                        113.99766,
                                        22.548588
                                    ],
                                    [
                                        113.997616,
                                        22.548527
                                    ],
                                    [
                                        113.997544,
                                        22.548436
                                    ],
                                    [
                                        113.996405,
                                        22.546974
                                    ],
                                    [
                                        113.996272,
                                        22.546852
                                    ],
                                    [
                                        113.996228,
                                        22.54679
                                    ],
                                    [
                                        113.99625,
                                        22.546729
                                    ],
                                    [
                                        113.996294,
                                        22.546608
                                    ],
                                    [
                                        113.996689,
                                        22.545941
                                    ],
                                    [
                                        113.996747,
                                        22.54585
                                    ],
                                    [
                                        113.996921,
                                        22.545617
                                    ],
                                    [
                                        113.997009,
                                        22.545454
                                    ],
                                    [
                                        113.997119,
                                        22.545204
                                    ],
                                    [
                                        113.997207,
                                        22.545009
                                    ],
                                    [
                                        113.997221,
                                        22.544893
                                    ],
                                    [
                                        113.997169,
                                        22.544725
                                    ],
                                    [
                                        113.997045,
                                        22.544418
                                    ],
                                    [
                                        113.996937,
                                        22.544173
                                    ],
                                    [
                                        113.996827,
                                        22.543959
                                    ],
                                    [
                                        113.996777,
                                        22.543844
                                    ],
                                    [
                                        113.996738,
                                        22.543579
                                    ],
                                    [
                                        113.996702,
                                        22.543302
                                    ],
                                    [
                                        113.996716,
                                        22.543031
                                    ],
                                    [
                                        113.996716,
                                        22.5427
                                    ],
                                    [
                                        113.996738,
                                        22.542489
                                    ],
                                    [
                                        113.996755,
                                        22.542076
                                    ],
                                    [
                                        113.996791,
                                        22.541124
                                    ],
                                    [
                                        113.996796,
                                        22.540833
                                    ],
                                    [
                                        113.996804,
                                        22.540535
                                    ],
                                    [
                                        113.996791,
                                        22.540129
                                    ],
                                    [
                                        113.996747,
                                        22.539649
                                    ],
                                    [
                                        113.996733,
                                        22.539217
                                    ],
                                    [
                                        113.996709,
                                        22.538777
                                    ],
                                    [
                                        113.996711,
                                        22.538763
                                    ],
                                    [
                                        113.99672,
                                        22.538657
                                    ],
                                    [
                                        113.996725,
                                        22.538632
                                    ],
                                    [
                                        113.996807,
                                        22.538173
                                    ],
                                    [
                                        113.996891,
                                        22.537728
                                    ],
                                    [
                                        113.996946,
                                        22.537434
                                    ],
                                    [
                                        113.997189,
                                        22.535563
                                    ],
                                    [
                                        113.997334,
                                        22.535361
                                    ],
                                    [
                                        113.997403,
                                        22.535
                                    ],
                                    [
                                        113.997479,
                                        22.534603
                                    ],
                                    [
                                        113.997467,
                                        22.534515
                                    ],
                                    [
                                        113.997514,
                                        22.534418
                                    ],
                                    [
                                        113.997592,
                                        22.534002
                                    ],
                                    [
                                        113.9977,
                                        22.533416
                                    ],
                                    [
                                        113.997732,
                                        22.533249
                                    ],
                                    [
                                        113.997764,
                                        22.53307
                                    ],
                                    [
                                        113.9978,
                                        22.532862
                                    ],
                                    [
                                        113.997867,
                                        22.532493
                                    ],
                                    [
                                        113.997872,
                                        22.532398
                                    ],
                                    [
                                        113.997805,
                                        22.532404
                                    ],
                                    [
                                        113.997403,
                                        22.532491
                                    ],
                                    [
                                        113.997041,
                                        22.532581
                                    ],
                                    [
                                        113.996604,
                                        22.532684
                                    ],
                                    [
                                        113.996384,
                                        22.532735
                                    ],
                                    [
                                        113.996036,
                                        22.532819
                                    ],
                                    [
                                        113.995708,
                                        22.532892
                                    ],
                                    [
                                        113.995436,
                                        22.53296
                                    ],
                                    [
                                        113.995397,
                                        22.53287
                                    ],
                                    [
                                        113.995316,
                                        22.532695
                                    ],
                                    [
                                        113.995233,
                                        22.532451
                                    ],
                                    [
                                        113.995205,
                                        22.532356
                                    ],
                                    [
                                        113.995211,
                                        22.532345
                                    ],
                                    [
                                        113.995275,
                                        22.532322
                                    ],
                                    [
                                        113.995571,
                                        22.53224
                                    ],
                                    [
                                        113.996153,
                                        22.532071
                                    ],
                                    [
                                        113.996069,
                                        22.531811
                                    ],
                                    [
                                        113.996,
                                        22.531625
                                    ],
                                    [
                                        113.995885,
                                        22.53136
                                    ],
                                    [
                                        113.995785,
                                        22.531138
                                    ],
                                    [
                                        113.995713,
                                        22.530986
                                    ],
                                    [
                                        113.995624,
                                        22.530809
                                    ],
                                    [
                                        113.99551,
                                        22.530586
                                    ],
                                    [
                                        113.995487,
                                        22.530534
                                    ],
                                    [
                                        113.995465,
                                        22.530512
                                    ],
                                    [
                                        113.995436,
                                        22.530499
                                    ],
                                    [
                                        113.995347,
                                        22.530489
                                    ],
                                    [
                                        113.995225,
                                        22.5305
                                    ],
                                    [
                                        113.994858,
                                        22.530548
                                    ],
                                    [
                                        113.994658,
                                        22.530572
                                    ],
                                    [
                                        113.994526,
                                        22.530596
                                    ],
                                    [
                                        113.994456,
                                        22.530598
                                    ],
                                    [
                                        113.994394,
                                        22.530583
                                    ],
                                    [
                                        113.994354,
                                        22.530567
                                    ],
                                    [
                                        113.994301,
                                        22.53046
                                    ],
                                    [
                                        113.994278,
                                        22.53042
                                    ],
                                    [
                                        113.994153,
                                        22.530279
                                    ],
                                    [
                                        113.994102,
                                        22.530226
                                    ],
                                    [
                                        113.994032,
                                        22.530106
                                    ],
                                    [
                                        113.993944,
                                        22.529983
                                    ],
                                    [
                                        113.993915,
                                        22.529934
                                    ],
                                    [
                                        113.993874,
                                        22.529799
                                    ],
                                    [
                                        113.99383,
                                        22.529669
                                    ],
                                    [
                                        113.993755,
                                        22.529384
                                    ],
                                    [
                                        113.993672,
                                        22.529083
                                    ],
                                    [
                                        113.993553,
                                        22.528656
                                    ],
                                    [
                                        113.993439,
                                        22.528241
                                    ],
                                    [
                                        113.993371,
                                        22.527994
                                    ],
                                    [
                                        113.993298,
                                        22.527679
                                    ],
                                    [
                                        113.993456,
                                        22.527371
                                    ],
                                    [
                                        113.993598,
                                        22.52718
                                    ],
                                    [
                                        113.993626,
                                        22.526806
                                    ],
                                    [
                                        113.993633,
                                        22.526656
                                    ],
                                    [
                                        113.99388,
                                        22.525131
                                    ],
                                    [
                                        113.994208,
                                        22.523195
                                    ],
                                    [
                                        113.994272,
                                        22.522924
                                    ],
                                    [
                                        113.994295,
                                        22.522413
                                    ],
                                    [
                                        113.994359,
                                        22.522198
                                    ],
                                    [
                                        113.994391,
                                        22.521927
                                    ],
                                    [
                                        113.990545,
                                        22.520481
                                    ],
                                    [
                                        113.990747,
                                        22.510582
                                    ],
                                    [
                                        113.976539,
                                        22.510627
                                    ],
                                    [
                                        113.966031,
                                        22.509719
                                    ],
                                    [
                                        113.96217,
                                        22.507613
                                    ],
                                    [
                                        113.959143,
                                        22.504922
                                    ],
                                    [
                                        113.957039,
                                        22.500555
                                    ],
                                    [
                                        113.954769,
                                        22.490986
                                    ],
                                    [
                                        113.952674,
                                        22.486538
                                    ],
                                    [
                                        113.951702,
                                        22.484892
                                    ],
                                    [
                                        113.951624,
                                        22.48476
                                    ],
                                    [
                                        113.948979,
                                        22.480281
                                    ],
                                    [
                                        113.946876,
                                        22.477341
                                    ],
                                    [
                                        113.939907,
                                        22.471711
                                    ],
                                    [
                                        113.915741,
                                        22.45596
                                    ],
                                    [
                                        113.900819,
                                        22.447487
                                    ],
                                    [
                                        113.897549,
                                        22.444741
                                    ],
                                    [
                                        113.895494,
                                        22.443391
                                    ],
                                    [
                                        113.89363,
                                        22.442718
                                    ],
                                    [
                                        113.891766,
                                        22.442639
                                    ],
                                    [
                                        113.888594,
                                        22.443237
                                    ],
                                    [
                                        113.885231,
                                        22.444549
                                    ],
                                    [
                                        113.881722,
                                        22.446787
                                    ],
                                    [
                                        113.870001,
                                        22.45955
                                    ],
                                    [
                                        113.866987,
                                        22.465257
                                    ],
                                    [
                                        113.862805,
                                        22.475834
                                    ],
                                    [
                                        113.859377,
                                        22.495636
                                    ],
                                    [
                                        113.860131,
                                        22.502008
                                    ],
                                    [
                                        113.861049,
                                        22.504943
                                    ],
                                    [
                                        113.863751,
                                        22.511981
                                    ],
                                    [
                                        113.864063,
                                        22.515981
                                    ],
                                    [
                                        113.860929,
                                        22.526416
                                    ],
                                    [
                                        113.895649,
                                        22.54308
                                    ],
                                    [
                                        113.901389,
                                        22.545377
                                    ],
                                    [
                                        113.903379,
                                        22.546994
                                    ],
                                    [
                                        113.903396,
                                        22.547005
                                    ],
                                    [
                                        113.903411,
                                        22.54702
                                    ],
                                    [
                                        113.903559,
                                        22.54714
                                    ],
                                    [
                                        113.90358,
                                        22.547155
                                    ],
                                    [
                                        113.903645,
                                        22.547207
                                    ],
                                    [
                                        113.903663,
                                        22.547225
                                    ],
                                    [
                                        113.905089,
                                        22.548384
                                    ],
                                    [
                                        113.908889,
                                        22.551665
                                    ],
                                    [
                                        113.909511,
                                        22.552186
                                    ],
                                    [
                                        113.910687,
                                        22.553158
                                    ],
                                    [
                                        113.911506,
                                        22.553735
                                    ],
                                    [
                                        113.91303,
                                        22.554824
                                    ],
                                    [
                                        113.915773,
                                        22.556776
                                    ],
                                    [
                                        113.915982,
                                        22.557034
                                    ],
                                    [
                                        113.915983,
                                        22.557099
                                    ],
                                    [
                                        113.916024,
                                        22.55714
                                    ],
                                    [
                                        113.916075,
                                        22.557266
                                    ],
                                    [
                                        113.916109,
                                        22.557956
                                    ],
                                    [
                                        113.916064,
                                        22.55885
                                    ],
                                    [
                                        113.916053,
                                        22.558876
                                    ],
                                    [
                                        113.916053,
                                        22.559057
                                    ],
                                    [
                                        113.916033,
                                        22.559442
                                    ],
                                    [
                                        113.915995,
                                        22.5612
                                    ],
                                    [
                                        113.916038,
                                        22.561284
                                    ],
                                    [
                                        113.915992,
                                        22.561349
                                    ],
                                    [
                                        113.915911,
                                        22.565137
                                    ],
                                    [
                                        113.916,
                                        22.565704
                                    ],
                                    [
                                        113.91617,
                                        22.565936
                                    ],
                                    [
                                        113.917555,
                                        22.567129
                                    ],
                                    [
                                        113.918346,
                                        22.567801
                                    ],
                                    [
                                        113.921328,
                                        22.570537
                                    ],
                                    [
                                        113.921703,
                                        22.570887
                                    ],
                                    [
                                        113.92221,
                                        22.571361
                                    ],
                                    [
                                        113.922418,
                                        22.571556
                                    ],
                                    [
                                        113.922444,
                                        22.571569
                                    ],
                                    [
                                        113.922476,
                                        22.571586
                                    ],
                                    [
                                        113.922918,
                                        22.571809
                                    ],
                                    [
                                        113.923832,
                                        22.572253
                                    ],
                                    [
                                        113.926499,
                                        22.573849
                                    ],
                                    [
                                        113.926747,
                                        22.574115
                                    ],
                                    [
                                        113.926967,
                                        22.574409
                                    ],
                                    [
                                        113.927134,
                                        22.574948
                                    ],
                                    [
                                        113.927574,
                                        22.576005
                                    ],
                                    [
                                        113.928268,
                                        22.577563
                                    ],
                                    [
                                        113.929032,
                                        22.578768
                                    ],
                                    [
                                        113.929158,
                                        22.57919
                                    ],
                                    [
                                        113.929349,
                                        22.580208
                                    ],
                                    [
                                        113.929368,
                                        22.580436
                                    ],
                                    [
                                        113.929443,
                                        22.58053
                                    ],
                                    [
                                        113.929538,
                                        22.58062
                                    ],
                                    [
                                        113.929542,
                                        22.580689
                                    ],
                                    [
                                        113.929544,
                                        22.580756
                                    ],
                                    [
                                        113.92954,
                                        22.580794
                                    ],
                                    [
                                        113.929525,
                                        22.580826
                                    ],
                                    [
                                        113.929452,
                                        22.580924
                                    ],
                                    [
                                        113.92914,
                                        22.581349
                                    ],
                                    [
                                        113.929032,
                                        22.581509
                                    ],
                                    [
                                        113.92833,
                                        22.582339
                                    ],
                                    [
                                        113.928202,
                                        22.582612
                                    ],
                                    [
                                        113.926679,
                                        22.583406
                                    ],
                                    [
                                        113.924939,
                                        22.584584
                                    ],
                                    [
                                        113.92479,
                                        22.584824
                                    ],
                                    [
                                        113.924931,
                                        22.585717
                                    ],
                                    [
                                        113.924832,
                                        22.586498
                                    ],
                                    [
                                        113.924794,
                                        22.586617
                                    ],
                                    [
                                        113.924808,
                                        22.586691
                                    ],
                                    [
                                        113.924802,
                                        22.586728
                                    ],
                                    [
                                        113.924725,
                                        22.586906
                                    ],
                                    [
                                        113.924418,
                                        22.587616
                                    ],
                                    [
                                        113.924363,
                                        22.588472
                                    ],
                                    [
                                        113.924468,
                                        22.589961
                                    ],
                                    [
                                        113.924665,
                                        22.590255
                                    ],
                                    [
                                        113.926281,
                                        22.590812
                                    ],
                                    [
                                        113.928093,
                                        22.59069
                                    ],
                                    [
                                        113.928541,
                                        22.590779
                                    ],
                                    [
                                        113.928499,
                                        22.591459
                                    ],
                                    [
                                        113.928356,
                                        22.591802
                                    ],
                                    [
                                        113.928004,
                                        22.59214
                                    ],
                                    [
                                        113.927025,
                                        22.592243
                                    ],
                                    [
                                        113.926544,
                                        22.592785
                                    ],
                                    [
                                        113.926287,
                                        22.593322
                                    ],
                                    [
                                        113.926206,
                                        22.594206
                                    ],
                                    [
                                        113.925816,
                                        22.59544
                                    ],
                                    [
                                        113.924093,
                                        22.598614
                                    ],
                                    [
                                        113.923627,
                                        22.599601
                                    ],
                                    [
                                        113.923531,
                                        22.600115
                                    ],
                                    [
                                        113.924254,
                                        22.601916
                                    ],
                                    [
                                        113.925035,
                                        22.603184
                                    ],
                                    [
                                        113.926841,
                                        22.603493
                                    ],
                                    [
                                        113.927424,
                                        22.603717
                                    ],
                                    [
                                        113.927825,
                                        22.604006
                                    ],
                                    [
                                        113.928322,
                                        22.60543
                                    ],
                                    [
                                        113.928544,
                                        22.606631
                                    ],
                                    [
                                        113.928561,
                                        22.606725
                                    ],
                                    [
                                        113.928651,
                                        22.606767
                                    ],
                                    [
                                        113.929132,
                                        22.606991
                                    ],
                                    [
                                        113.929965,
                                        22.607856
                                    ],
                                    [
                                        113.930077,
                                        22.609244
                                    ],
                                    [
                                        113.93,
                                        22.609995
                                    ],
                                    [
                                        113.929977,
                                        22.610157
                                    ],
                                    [
                                        113.929972,
                                        22.610187
                                    ],
                                    [
                                        113.929965,
                                        22.610234
                                    ],
                                    [
                                        113.929948,
                                        22.610348
                                    ],
                                    [
                                        113.929563,
                                        22.611554
                                    ],
                                    [
                                        113.928843,
                                        22.612358
                                    ],
                                    [
                                        113.927557,
                                        22.61492
                                    ],
                                    [
                                        113.927543,
                                        22.614957
                                    ],
                                    [
                                        113.9275,
                                        22.615102
                                    ],
                                    [
                                        113.9275,
                                        22.6156
                                    ],
                                    [
                                        113.92962,
                                        22.618568
                                    ],
                                    [
                                        113.93024,
                                        22.619045
                                    ],
                                    [
                                        113.930454,
                                        22.619323
                                    ],
                                    [
                                        113.930692,
                                        22.621007
                                    ],
                                    [
                                        113.931259,
                                        22.623021
                                    ],
                                    [
                                        113.931166,
                                        22.623588
                                    ],
                                    [
                                        113.93035,
                                        22.62485
                                    ],
                                    [
                                        113.929786,
                                        22.625435
                                    ],
                                    [
                                        113.929288,
                                        22.626181
                                    ],
                                    [
                                        113.929142,
                                        22.626959
                                    ],
                                    [
                                        113.929163,
                                        22.627361
                                    ],
                                    [
                                        113.929301,
                                        22.627625
                                    ],
                                    [
                                        113.929755,
                                        22.628016
                                    ],
                                    [
                                        113.92991,
                                        22.628643
                                    ],
                                    [
                                        113.930167,
                                        22.629124
                                    ],
                                    [
                                        113.930159,
                                        22.629482
                                    ],
                                    [
                                        113.929993,
                                        22.630196
                                    ],
                                    [
                                        113.929464,
                                        22.630958
                                    ],
                                    [
                                        113.928934,
                                        22.631353
                                    ],
                                    [
                                        113.928918,
                                        22.631714
                                    ],
                                    [
                                        113.929344,
                                        22.633061
                                    ],
                                    [
                                        113.929862,
                                        22.63392
                                    ],
                                    [
                                        113.930173,
                                        22.634226
                                    ],
                                    [
                                        113.931414,
                                        22.634676
                                    ],
                                    [
                                        113.9315,
                                        22.634716
                                    ],
                                    [
                                        113.931564,
                                        22.634746
                                    ],
                                    [
                                        113.931588,
                                        22.634762
                                    ],
                                    [
                                        113.931652,
                                        22.634805
                                    ],
                                    [
                                        113.931664,
                                        22.634819
                                    ],
                                    [
                                        113.931831,
                                        22.635137
                                    ],
                                    [
                                        113.931862,
                                        22.635271
                                    ],
                                    [
                                        113.931863,
                                        22.635328
                                    ],
                                    [
                                        113.931865,
                                        22.635494
                                    ],
                                    [
                                        113.93235,
                                        22.63656
                                    ],
                                    [
                                        113.93395,
                                        22.63706
                                    ],
                                    [
                                        113.934813,
                                        22.637867
                                    ],
                                    [
                                        113.936013,
                                        22.638088
                                    ],
                                    [
                                        113.936319,
                                        22.638315
                                    ],
                                    [
                                        113.936585,
                                        22.638683
                                    ],
                                    [
                                        113.937016,
                                        22.641091
                                    ],
                                    [
                                        113.937647,
                                        22.643078
                                    ],
                                    [
                                        113.937709,
                                        22.643861
                                    ],
                                    [
                                        113.93766,
                                        22.644316
                                    ],
                                    [
                                        113.93745,
                                        22.64489
                                    ],
                                    [
                                        113.937525,
                                        22.645089
                                    ],
                                    [
                                        113.938414,
                                        22.645359
                                    ],
                                    [
                                        113.940348,
                                        22.646118
                                    ],
                                    [
                                        113.940518,
                                        22.64625
                                    ],
                                    [
                                        113.940771,
                                        22.64762
                                    ],
                                    [
                                        113.942076,
                                        22.649049
                                    ],
                                    [
                                        113.94294,
                                        22.649521
                                    ],
                                    [
                                        113.944034,
                                        22.650592
                                    ],
                                    [
                                        113.944708,
                                        22.650764
                                    ],
                                    [
                                        113.946719,
                                        22.65097
                                    ],
                                    [
                                        113.947957,
                                        22.651412
                                    ],
                                    [
                                        113.949403,
                                        22.652198
                                    ],
                                    [
                                        113.949977,
                                        22.652195
                                    ],
                                    [
                                        113.950394,
                                        22.651823
                                    ],
                                    [
                                        113.950852,
                                        22.650829
                                    ],
                                    [
                                        113.951901,
                                        22.650544
                                    ],
                                    [
                                        113.952901,
                                        22.650974
                                    ],
                                    [
                                        113.953731,
                                        22.650428
                                    ],
                                    [
                                        113.954064,
                                        22.649954
                                    ],
                                    [
                                        113.954701,
                                        22.649336
                                    ],
                                    [
                                        113.955102,
                                        22.649244
                                    ],
                                    [
                                        113.955264,
                                        22.649302
                                    ],
                                    [
                                        113.955687,
                                        22.65013
                                    ],
                                    [
                                        113.956545,
                                        22.650684
                                    ],
                                    [
                                        113.957607,
                                        22.651594
                                    ],
                                    [
                                        113.959099,
                                        22.652274
                                    ],
                                    [
                                        113.959993,
                                        22.652478
                                    ],
                                    [
                                        113.960363,
                                        22.652316
                                    ],
                                    [
                                        113.960614,
                                        22.651643
                                    ],
                                    [
                                        113.961149,
                                        22.651307
                                    ],
                                    [
                                        113.963145,
                                        22.651306
                                    ],
                                    [
                                        113.964344,
                                        22.65119
                                    ],
                                    [
                                        113.965302,
                                        22.651319
                                    ],
                                    [
                                        113.965801,
                                        22.651516
                                    ],
                                    [
                                        113.966024,
                                        22.651497
                                    ],
                                    [
                                        113.966456,
                                        22.651328
                                    ],
                                    [
                                        113.967084,
                                        22.650781
                                    ],
                                    [
                                        113.967852,
                                        22.648885
                                    ],
                                    [
                                        113.967964,
                                        22.647886
                                    ],
                                    [
                                        113.968547,
                                        22.645765
                                    ],
                                    [
                                        113.968736,
                                        22.644282
                                    ],
                                    [
                                        113.967523,
                                        22.643478
                                    ],
                                    [
                                        113.966726,
                                        22.642334
                                    ],
                                    [
                                        113.966593,
                                        22.641749
                                    ],
                                    [
                                        113.966626,
                                        22.640839
                                    ],
                                    [
                                        113.967455,
                                        22.64042
                                    ],
                                    [
                                        113.969014,
                                        22.640517
                                    ],
                                    [
                                        113.969638,
                                        22.640681
                                    ],
                                    [
                                        113.969882,
                                        22.640661
                                    ],
                                    [
                                        113.970044,
                                        22.640537
                                    ],
                                    [
                                        113.971469,
                                        22.63831
                                    ],
                                    [
                                        113.972302,
                                        22.637453
                                    ],
                                    [
                                        113.973279,
                                        22.637076
                                    ],
                                    [
                                        113.973666,
                                        22.636373
                                    ],
                                    [
                                        113.974731,
                                        22.636126
                                    ],
                                    [
                                        113.975398,
                                        22.636576
                                    ],
                                    [
                                        113.976192,
                                        22.637281
                                    ],
                                    [
                                        113.978029,
                                        22.637098
                                    ],
                                    [
                                        113.97845,
                                        22.636974
                                    ],
                                    [
                                        113.980019,
                                        22.637006
                                    ],
                                    [
                                        113.980253,
                                        22.636939
                                    ],
                                    [
                                        113.981226,
                                        22.63703
                                    ],
                                    [
                                        113.982116,
                                        22.637298
                                    ],
                                    [
                                        113.98236,
                                        22.63724
                                    ],
                                    [
                                        113.982771,
                                        22.63685
                                    ],
                                    [
                                        113.983618,
                                        22.636411
                                    ],
                                    [
                                        113.984501,
                                        22.63625
                                    ],
                                    [
                                        113.985958,
                                        22.63645
                                    ],
                                    [
                                        113.98684,
                                        22.636179
                                    ],
                                    [
                                        113.988879,
                                        22.634984
                                    ],
                                    [
                                        113.989989,
                                        22.634041
                                    ],
                                    [
                                        113.990491,
                                        22.633009
                                    ],
                                    [
                                        113.991225,
                                        22.631951
                                    ],
                                    [
                                        113.991814,
                                        22.631423
                                    ],
                                    [
                                        113.992403,
                                        22.631213
                                    ],
                                    [
                                        113.992521,
                                        22.631096
                                    ],
                                    [
                                        113.992622,
                                        22.630623
                                    ],
                                    [
                                        113.992449,
                                        22.629798
                                    ],
                                    [
                                        113.99316,
                                        22.628119
                                    ],
                                    [
                                        113.993333,
                                        22.626867
                                    ],
                                    [
                                        113.993612,
                                        22.626172
                                    ],
                                    [
                                        113.993775,
                                        22.625834
                                    ],
                                    [
                                        113.993918,
                                        22.62578
                                    ],
                                    [
                                        113.994424,
                                        22.626065
                                    ],
                                    [
                                        113.994856,
                                        22.626509
                                    ],
                                    [
                                        113.996565,
                                        22.626636
                                    ],
                                    [
                                        113.997366,
                                        22.626346
                                    ],
                                    [
                                        113.998131,
                                        22.625504
                                    ],
                                    [
                                        113.998849,
                                        22.62513
                                    ],
                                    [
                                        113.999205,
                                        22.625095
                                    ],
                                    [
                                        114.000318,
                                        22.625416
                                    ],
                                    [
                                        114.001034,
                                        22.625759
                                    ],
                                    [
                                        114.001737,
                                        22.625719
                                    ],
                                    [
                                        114.001924,
                                        22.625431
                                    ],
                                    [
                                        114.002572,
                                        22.623404
                                    ],
                                    [
                                        114.002546,
                                        22.622906
                                    ],
                                    [
                                        114.002651,
                                        22.622427
                                    ],
                                    [
                                        114.002811,
                                        22.622221
                                    ],
                                    [
                                        114.003532,
                                        22.621876
                                    ],
                                    [
                                        114.003937,
                                        22.621497
                                    ],
                                    [
                                        114.004319,
                                        22.620244
                                    ],
                                    [
                                        114.004881,
                                        22.619692
                                    ],
                                    [
                                        114.005187,
                                        22.619412
                                    ],
                                    [
                                        114.00555,
                                        22.619095
                                    ],
                                    [
                                        114.006139,
                                        22.618996
                                    ],
                                    [
                                        114.00682,
                                        22.619112
                                    ],
                                    [
                                        114.008801,
                                        22.615906
                                    ],
                                    [
                                        114.009081,
                                        22.613109
                                    ],
                                    [
                                        114.009109,
                                        22.611618
                                    ],
                                    [
                                        114.009301,
                                        22.611084
                                    ],
                                    [
                                        114.012861,
                                        22.60622
                                    ],
                                    [
                                        114.013299,
                                        22.605877
                                    ],
                                    [
                                        114.014363,
                                        22.605729
                                    ],
                                    [
                                        114.015751,
                                        22.604353
                                    ],
                                    [
                                        114.016049,
                                        22.603604
                                    ],
                                    [
                                        114.016068,
                                        22.603538
                                    ],
                                    [
                                        114.016122,
                                        22.603437
                                    ],
                                    [
                                        114.016128,
                                        22.603427
                                    ],
                                    [
                                        114.016152,
                                        22.603383
                                    ],
                                    [
                                        114.016244,
                                        22.603213
                                    ],
                                    [
                                        114.016603,
                                        22.602655
                                    ],
                                    [
                                        114.016612,
                                        22.602649
                                    ],
                                    [
                                        114.016653,
                                        22.602624
                                    ],
                                    [
                                        114.016785,
                                        22.602591
                                    ],
                                    [
                                        114.018987,
                                        22.602043
                                    ],
                                    [
                                        114.020835,
                                        22.601864
                                    ],
                                    [
                                        114.0219,
                                        22.602357
                                    ],
                                    [
                                        114.02318,
                                        22.599946
                                    ],
                                    [
                                        114.023488,
                                        22.598572
                                    ],
                                    [
                                        114.023648,
                                        22.597158
                                    ],
                                    [
                                        114.023207,
                                        22.595146
                                    ],
                                    [
                                        114.023741,
                                        22.593626
                                    ],
                                    [
                                        114.023901,
                                        22.593347
                                    ],
                                    [
                                        114.024737,
                                        22.592527
                                    ],
                                    [
                                        114.025394,
                                        22.592158
                                    ],
                                    [
                                        114.026043,
                                        22.591936
                                    ],
                                    [
                                        114.026338,
                                        22.590684
                                    ],
                                    [
                                        114.026359,
                                        22.590581
                                    ],
                                    [
                                        114.026377,
                                        22.590494
                                    ],
                                    [
                                        114.026382,
                                        22.590474
                                    ],
                                    [
                                        114.026399,
                                        22.590391
                                    ],
                                    [
                                        114.026421,
                                        22.590284
                                    ],
                                    [
                                        114.026376,
                                        22.589756
                                    ],
                                    [
                                        114.026292,
                                        22.589599
                                    ],
                                    [
                                        114.026285,
                                        22.589584
                                    ],
                                    [
                                        114.025873,
                                        22.589005
                                    ],
                                    [
                                        114.025217,
                                        22.587389
                                    ],
                                    [
                                        114.023942,
                                        22.582409
                                    ],
                                    [
                                        114.023509,
                                        22.581647
                                    ]
                                ]
                            ],
                            [
                                [
                                    [
                                        113.839629,
                                        22.498528
                                    ],
                                    [
                                        113.839274,
                                        22.499597
                                    ],
                                    [
                                        113.839474,
                                        22.500666
                                    ],
                                    [
                                        113.842763,
                                        22.503534
                                    ],
                                    [
                                        113.843496,
                                        22.503822
                                    ],
                                    [
                                        113.844451,
                                        22.503352
                                    ],
                                    [
                                        113.851983,
                                        22.496611
                                    ],
                                    [
                                        113.852139,
                                        22.495876
                                    ],
                                    [
                                        113.851894,
                                        22.495297
                                    ],
                                    [
                                        113.849138,
                                        22.491715
                                    ],
                                    [
                                        113.848161,
                                        22.491672
                                    ],
                                    [
                                        113.84725,
                                        22.491941
                                    ],
                                    [
                                        113.839629,
                                        22.498528
                                    ]
                                ]
                            ],
                            [
                                [
                                    [
                                        113.819933,
                                        22.396344
                                    ],
                                    [
                                        113.814185,
                                        22.397858
                                    ],
                                    [
                                        113.810158,
                                        22.399158
                                    ],
                                    [
                                        113.8073,
                                        22.400257
                                    ],
                                    [
                                        113.803992,
                                        22.402447
                                    ],
                                    [
                                        113.802424,
                                        22.403814
                                    ],
                                    [
                                        113.801844,
                                        22.404909
                                    ],
                                    [
                                        113.801784,
                                        22.406445
                                    ],
                                    [
                                        113.801368,
                                        22.407368
                                    ],
                                    [
                                        113.800623,
                                        22.407847
                                    ],
                                    [
                                        113.799393,
                                        22.408395
                                    ],
                                    [
                                        113.798207,
                                        22.408976
                                    ],
                                    [
                                        113.794525,
                                        22.410553
                                    ],
                                    [
                                        113.792239,
                                        22.411411
                                    ],
                                    [
                                        113.788201,
                                        22.412353
                                    ],
                                    [
                                        113.786694,
                                        22.413585
                                    ],
                                    [
                                        113.786278,
                                        22.41462
                                    ],
                                    [
                                        113.786278,
                                        22.415992
                                    ],
                                    [
                                        113.786859,
                                        22.417187
                                    ],
                                    [
                                        113.788219,
                                        22.418108
                                    ],
                                    [
                                        113.790021,
                                        22.418652
                                    ],
                                    [
                                        113.791624,
                                        22.418581
                                    ],
                                    [
                                        113.793123,
                                        22.418238
                                    ],
                                    [
                                        113.79411,
                                        22.417451
                                    ],
                                    [
                                        113.795002,
                                        22.416767
                                    ],
                                    [
                                        113.795921,
                                        22.416765
                                    ],
                                    [
                                        113.797315,
                                        22.417753
                                    ],
                                    [
                                        113.798303,
                                        22.419221
                                    ],
                                    [
                                        113.798571,
                                        22.42093
                                    ],
                                    [
                                        113.798901,
                                        22.42249
                                    ],
                                    [
                                        113.799715,
                                        22.423194
                                    ],
                                    [
                                        113.800902,
                                        22.423416
                                    ],
                                    [
                                        113.80229,
                                        22.423531
                                    ],
                                    [
                                        113.80369,
                                        22.423027
                                    ],
                                    [
                                        113.80449,
                                        22.421473
                                    ],
                                    [
                                        113.804539,
                                        22.419969
                                    ],
                                    [
                                        113.805093,
                                        22.418802
                                    ],
                                    [
                                        113.807015,
                                        22.418428
                                    ],
                                    [
                                        113.808687,
                                        22.418907
                                    ],
                                    [
                                        113.810505,
                                        22.420206
                                    ],
                                    [
                                        113.811241,
                                        22.420426
                                    ],
                                    [
                                        113.812168,
                                        22.420314
                                    ],
                                    [
                                        113.813432,
                                        22.419904
                                    ],
                                    [
                                        113.814281,
                                        22.419418
                                    ],
                                    [
                                        113.814878,
                                        22.418228
                                    ],
                                    [
                                        113.815466,
                                        22.417448
                                    ],
                                    [
                                        113.816246,
                                        22.416555
                                    ],
                                    [
                                        113.81706,
                                        22.415922
                                    ],
                                    [
                                        113.818393,
                                        22.412693
                                    ],
                                    [
                                        113.819128,
                                        22.410157
                                    ],
                                    [
                                        113.821388,
                                        22.407419
                                    ],
                                    [
                                        113.824184,
                                        22.404345
                                    ],
                                    [
                                        113.824781,
                                        22.401045
                                    ],
                                    [
                                        113.824381,
                                        22.397939
                                    ],
                                    [
                                        113.822732,
                                        22.396539
                                    ],
                                    [
                                        113.819933,
                                        22.396344
                                    ]
                                ]
                            ]
                        ]
                    },
                    "properties": {
                        "name": "南山区",
                        "cp": [
                            113.92943,
                            22.531221
                        ]
                    }
                },
                {
                    "type": "Feature",
                    "id": "440304",
                    "geometry": {
                        "type": "Polygon",
                        "coordinates": [
                            [
                                [
                                    114.066307,
                                    22.585671
                                ],
                                [
                                    114.066593,
                                    22.585036
                                ],
                                [
                                    114.067464,
                                    22.583932
                                ],
                                [
                                    114.068689,
                                    22.582049
                                ],
                                [
                                    114.069009,
                                    22.581218
                                ],
                                [
                                    114.069304,
                                    22.580983
                                ],
                                [
                                    114.070441,
                                    22.580055
                                ],
                                [
                                    114.070522,
                                    22.579985
                                ],
                                [
                                    114.070644,
                                    22.579942
                                ],
                                [
                                    114.070814,
                                    22.579893
                                ],
                                [
                                    114.071183,
                                    22.579844
                                ],
                                [
                                    114.071316,
                                    22.579822
                                ],
                                [
                                    114.071414,
                                    22.579777
                                ],
                                [
                                    114.071509,
                                    22.579729
                                ],
                                [
                                    114.071765,
                                    22.579608
                                ],
                                [
                                    114.071922,
                                    22.57948
                                ],
                                [
                                    114.072132,
                                    22.579286
                                ],
                                [
                                    114.072248,
                                    22.579179
                                ],
                                [
                                    114.072333,
                                    22.579066
                                ],
                                [
                                    114.072494,
                                    22.578864
                                ],
                                [
                                    114.07255,
                                    22.578743
                                ],
                                [
                                    114.07264,
                                    22.578544
                                ],
                                [
                                    114.072721,
                                    22.578413
                                ],
                                [
                                    114.07282,
                                    22.578252
                                ],
                                [
                                    114.072941,
                                    22.578101
                                ],
                                [
                                    114.074396,
                                    22.576131
                                ],
                                [
                                    114.074424,
                                    22.576026
                                ],
                                [
                                    114.074436,
                                    22.575915
                                ],
                                [
                                    114.074425,
                                    22.575768
                                ],
                                [
                                    114.074422,
                                    22.575687
                                ],
                                [
                                    114.074413,
                                    22.57552
                                ],
                                [
                                    114.07442,
                                    22.575387
                                ],
                                [
                                    114.074429,
                                    22.575304
                                ],
                                [
                                    114.074444,
                                    22.57527
                                ],
                                [
                                    114.075442,
                                    22.573406
                                ],
                                [
                                    114.075944,
                                    22.572466
                                ],
                                [
                                    114.075995,
                                    22.572373
                                ],
                                [
                                    114.076027,
                                    22.572324
                                ],
                                [
                                    114.076119,
                                    22.57222
                                ],
                                [
                                    114.076276,
                                    22.572064
                                ],
                                [
                                    114.076423,
                                    22.571923
                                ],
                                [
                                    114.07653,
                                    22.571842
                                ],
                                [
                                    114.076688,
                                    22.571739
                                ],
                                [
                                    114.076762,
                                    22.571693
                                ],
                                [
                                    114.076867,
                                    22.571625
                                ],
                                [
                                    114.076993,
                                    22.571499
                                ],
                                [
                                    114.077139,
                                    22.571326
                                ],
                                [
                                    114.077251,
                                    22.571219
                                ],
                                [
                                    114.077286,
                                    22.571168
                                ],
                                [
                                    114.077328,
                                    22.571063
                                ],
                                [
                                    114.077396,
                                    22.570895
                                ],
                                [
                                    114.077481,
                                    22.570689
                                ],
                                [
                                    114.077564,
                                    22.57047
                                ],
                                [
                                    114.077635,
                                    22.570266
                                ],
                                [
                                    114.077751,
                                    22.569966
                                ],
                                [
                                    114.077803,
                                    22.569836
                                ],
                                [
                                    114.077919,
                                    22.569561
                                ],
                                [
                                    114.077965,
                                    22.569438
                                ],
                                [
                                    114.078015,
                                    22.56938
                                ],
                                [
                                    114.078186,
                                    22.569219
                                ],
                                [
                                    114.078397,
                                    22.569016
                                ],
                                [
                                    114.078495,
                                    22.568924
                                ],
                                [
                                    114.078607,
                                    22.56885
                                ],
                                [
                                    114.078887,
                                    22.568673
                                ],
                                [
                                    114.079028,
                                    22.568567
                                ],
                                [
                                    114.079096,
                                    22.568519
                                ],
                                [
                                    114.079117,
                                    22.568517
                                ],
                                [
                                    114.079153,
                                    22.568538
                                ],
                                [
                                    114.079393,
                                    22.568705
                                ],
                                [
                                    114.079662,
                                    22.568882
                                ],
                                [
                                    114.079923,
                                    22.569056
                                ],
                                [
                                    114.080271,
                                    22.569293
                                ],
                                [
                                    114.080433,
                                    22.569393
                                ],
                                [
                                    114.080538,
                                    22.569445
                                ],
                                [
                                    114.080686,
                                    22.569497
                                ],
                                [
                                    114.08085,
                                    22.569578
                                ],
                                [
                                    114.080908,
                                    22.569568
                                ],
                                [
                                    114.080933,
                                    22.569619
                                ],
                                [
                                    114.081242,
                                    22.569769
                                ],
                                [
                                    114.081421,
                                    22.569841
                                ],
                                [
                                    114.081591,
                                    22.569903
                                ],
                                [
                                    114.081817,
                                    22.569965
                                ],
                                [
                                    114.082174,
                                    22.570069
                                ],
                                [
                                    114.08228,
                                    22.570096
                                ],
                                [
                                    114.082508,
                                    22.570159
                                ],
                                [
                                    114.082622,
                                    22.570188
                                ],
                                [
                                    114.082817,
                                    22.57021
                                ],
                                [
                                    114.083075,
                                    22.570242
                                ],
                                [
                                    114.083275,
                                    22.570264
                                ],
                                [
                                    114.083473,
                                    22.570284
                                ],
                                [
                                    114.083665,
                                    22.570292
                                ],
                                [
                                    114.083769,
                                    22.570298
                                ],
                                [
                                    114.084081,
                                    22.570304
                                ],
                                [
                                    114.084331,
                                    22.570304
                                ],
                                [
                                    114.084456,
                                    22.570309
                                ],
                                [
                                    114.084619,
                                    22.570303
                                ],
                                [
                                    114.084791,
                                    22.570277
                                ],
                                [
                                    114.085116,
                                    22.570236
                                ],
                                [
                                    114.085463,
                                    22.570188
                                ],
                                [
                                    114.085672,
                                    22.570161
                                ],
                                [
                                    114.085801,
                                    22.570148
                                ],
                                [
                                    114.086163,
                                    22.570103
                                ],
                                [
                                    114.086242,
                                    22.570088
                                ],
                                [
                                    114.08641,
                                    22.570031
                                ],
                                [
                                    114.086649,
                                    22.569956
                                ],
                                [
                                    114.087106,
                                    22.56982
                                ],
                                [
                                    114.087781,
                                    22.569619
                                ],
                                [
                                    114.087999,
                                    22.569556
                                ],
                                [
                                    114.08804,
                                    22.569578
                                ],
                                [
                                    114.088081,
                                    22.569532
                                ],
                                [
                                    114.088167,
                                    22.569495
                                ],
                                [
                                    114.088247,
                                    22.569416
                                ],
                                [
                                    114.088535,
                                    22.569171
                                ],
                                [
                                    114.088646,
                                    22.569078
                                ],
                                [
                                    114.088709,
                                    22.569037
                                ],
                                [
                                    114.088819,
                                    22.568935
                                ],
                                [
                                    114.089068,
                                    22.568689
                                ],
                                [
                                    114.089399,
                                    22.56837
                                ],
                                [
                                    114.089529,
                                    22.568249
                                ],
                                [
                                    114.08992,
                                    22.56787
                                ],
                                [
                                    114.090162,
                                    22.567638
                                ],
                                [
                                    114.090217,
                                    22.567571
                                ],
                                [
                                    114.090287,
                                    22.567475
                                ],
                                [
                                    114.090367,
                                    22.567349
                                ],
                                [
                                    114.090558,
                                    22.567061
                                ],
                                [
                                    114.090822,
                                    22.566674
                                ],
                                [
                                    114.090934,
                                    22.56668
                                ],
                                [
                                    114.090868,
                                    22.566609
                                ],
                                [
                                    114.091064,
                                    22.566319
                                ],
                                [
                                    114.09114,
                                    22.566201
                                ],
                                [
                                    114.091404,
                                    22.565793
                                ],
                                [
                                    114.091604,
                                    22.565503
                                ],
                                [
                                    114.091793,
                                    22.565191
                                ],
                                [
                                    114.091951,
                                    22.564934
                                ],
                                [
                                    114.092053,
                                    22.564749
                                ],
                                [
                                    114.092159,
                                    22.564576
                                ],
                                [
                                    114.092198,
                                    22.564515
                                ],
                                [
                                    114.092232,
                                    22.564471
                                ],
                                [
                                    114.092238,
                                    22.564462
                                ],
                                [
                                    114.092346,
                                    22.564394
                                ],
                                [
                                    114.092448,
                                    22.564344
                                ],
                                [
                                    114.092482,
                                    22.564333
                                ],
                                [
                                    114.092547,
                                    22.564334
                                ],
                                [
                                    114.092616,
                                    22.564338
                                ],
                                [
                                    114.092628,
                                    22.564336
                                ],
                                [
                                    114.092677,
                                    22.564341
                                ],
                                [
                                    114.09319,
                                    22.564326
                                ],
                                [
                                    114.093662,
                                    22.564387
                                ],
                                [
                                    114.094653,
                                    22.564538
                                ],
                                [
                                    114.095665,
                                    22.564683
                                ],
                                [
                                    114.096829,
                                    22.56491
                                ],
                                [
                                    114.098216,
                                    22.565256
                                ],
                                [
                                    114.099474,
                                    22.565566
                                ],
                                [
                                    114.100625,
                                    22.565896
                                ],
                                [
                                    114.101604,
                                    22.566261
                                ],
                                [
                                    114.103221,
                                    22.566996
                                ],
                                [
                                    114.103984,
                                    22.567714
                                ],
                                [
                                    114.104041,
                                    22.567776
                                ],
                                [
                                    114.104165,
                                    22.567827
                                ],
                                [
                                    114.104281,
                                    22.56785
                                ],
                                [
                                    114.104473,
                                    22.567887
                                ],
                                [
                                    114.104514,
                                    22.56789
                                ],
                                [
                                    114.104524,
                                    22.567872
                                ],
                                [
                                    114.104518,
                                    22.567455
                                ],
                                [
                                    114.104523,
                                    22.567017
                                ],
                                [
                                    114.104521,
                                    22.566593
                                ],
                                [
                                    114.104517,
                                    22.56614
                                ],
                                [
                                    114.104508,
                                    22.565722
                                ],
                                [
                                    114.104509,
                                    22.565474
                                ],
                                [
                                    114.104511,
                                    22.565285
                                ],
                                [
                                    114.104502,
                                    22.564899
                                ],
                                [
                                    114.104498,
                                    22.564475
                                ],
                                [
                                    114.104508,
                                    22.56422
                                ],
                                [
                                    114.104512,
                                    22.564046
                                ],
                                [
                                    114.104508,
                                    22.563748
                                ],
                                [
                                    114.104504,
                                    22.563617
                                ],
                                [
                                    114.104506,
                                    22.563216
                                ],
                                [
                                    114.104504,
                                    22.562812
                                ],
                                [
                                    114.104502,
                                    22.562489
                                ],
                                [
                                    114.104496,
                                    22.562368
                                ],
                                [
                                    114.104496,
                                    22.561921
                                ],
                                [
                                    114.104496,
                                    22.561506
                                ],
                                [
                                    114.104487,
                                    22.561174
                                ],
                                [
                                    114.104495,
                                    22.561075
                                ],
                                [
                                    114.104502,
                                    22.560685
                                ],
                                [
                                    114.104498,
                                    22.560353
                                ],
                                [
                                    114.104503,
                                    22.560243
                                ],
                                [
                                    114.104523,
                                    22.559815
                                ],
                                [
                                    114.104521,
                                    22.559395
                                ],
                                [
                                    114.104529,
                                    22.559019
                                ],
                                [
                                    114.104534,
                                    22.558701
                                ],
                                [
                                    114.104536,
                                    22.558579
                                ],
                                [
                                    114.104542,
                                    22.558166
                                ],
                                [
                                    114.104541,
                                    22.557852
                                ],
                                [
                                    114.104547,
                                    22.557726
                                ],
                                [
                                    114.104551,
                                    22.557399
                                ],
                                [
                                    114.104552,
                                    22.557291
                                ],
                                [
                                    114.104559,
                                    22.556903
                                ],
                                [
                                    114.10456,
                                    22.556561
                                ],
                                [
                                    114.10456,
                                    22.556475
                                ],
                                [
                                    114.104574,
                                    22.556168
                                ],
                                [
                                    114.104576,
                                    22.556037
                                ],
                                [
                                    114.104576,
                                    22.556013
                                ],
                                [
                                    114.104557,
                                    22.555933
                                ],
                                [
                                    114.104508,
                                    22.555845
                                ],
                                [
                                    114.104487,
                                    22.555809
                                ],
                                [
                                    114.104472,
                                    22.555779
                                ],
                                [
                                    114.104281,
                                    22.555434
                                ],
                                [
                                    114.104341,
                                    22.552936
                                ],
                                [
                                    114.10447,
                                    22.549363
                                ],
                                [
                                    114.104505,
                                    22.549327
                                ],
                                [
                                    114.104506,
                                    22.549251
                                ],
                                [
                                    114.104477,
                                    22.549163
                                ],
                                [
                                    114.10449,
                                    22.548786
                                ],
                                [
                                    114.104486,
                                    22.548663
                                ],
                                [
                                    114.104502,
                                    22.548445
                                ],
                                [
                                    114.104464,
                                    22.548114
                                ],
                                [
                                    114.104519,
                                    22.547975
                                ],
                                [
                                    114.104589,
                                    22.546031
                                ],
                                [
                                    114.104687,
                                    22.541316
                                ],
                                [
                                    114.104699,
                                    22.540773
                                ],
                                [
                                    114.104764,
                                    22.535834
                                ],
                                [
                                    114.104772,
                                    22.5352
                                ],
                                [
                                    114.104757,
                                    22.535105
                                ],
                                [
                                    114.104774,
                                    22.535038
                                ],
                                [
                                    114.104808,
                                    22.532512
                                ],
                                [
                                    114.105177,
                                    22.531626
                                ],
                                [
                                    114.10392,
                                    22.531335
                                ],
                                [
                                    114.102922,
                                    22.531218
                                ],
                                [
                                    114.101949,
                                    22.531242
                                ],
                                [
                                    114.101292,
                                    22.531436
                                ],
                                [
                                    114.10066,
                                    22.531777
                                ],
                                [
                                    114.10015,
                                    22.532191
                                ],
                                [
                                    114.099228,
                                    22.533142
                                ],
                                [
                                    114.098803,
                                    22.533502
                                ],
                                [
                                    114.098407,
                                    22.533812
                                ],
                                [
                                    114.097759,
                                    22.534173
                                ],
                                [
                                    114.097247,
                                    22.534405
                                ],
                                [
                                    114.096661,
                                    22.534478
                                ],
                                [
                                    114.095871,
                                    22.53428
                                ],
                                [
                                    114.095295,
                                    22.534087
                                ],
                                [
                                    114.094631,
                                    22.533822
                                ],
                                [
                                    114.094111,
                                    22.533571
                                ],
                                [
                                    114.093453,
                                    22.533067
                                ],
                                [
                                    114.092899,
                                    22.532545
                                ],
                                [
                                    114.092335,
                                    22.531781
                                ],
                                [
                                    114.091988,
                                    22.531204
                                ],
                                [
                                    114.091627,
                                    22.530611
                                ],
                                [
                                    114.09125,
                                    22.530067
                                ],
                                [
                                    114.090864,
                                    22.529672
                                ],
                                [
                                    114.090355,
                                    22.529317
                                ],
                                [
                                    114.089683,
                                    22.529084
                                ],
                                [
                                    114.088256,
                                    22.528711
                                ],
                                [
                                    114.087096,
                                    22.528543
                                ],
                                [
                                    114.085683,
                                    22.528417
                                ],
                                [
                                    114.084614,
                                    22.527973
                                ],
                                [
                                    114.084021,
                                    22.527553
                                ],
                                [
                                    114.083571,
                                    22.526898
                                ],
                                [
                                    114.083485,
                                    22.526113
                                ],
                                [
                                    114.083645,
                                    22.525901
                                ],
                                [
                                    114.084284,
                                    22.525053
                                ],
                                [
                                    114.08514,
                                    22.524345
                                ],
                                [
                                    114.085951,
                                    22.523878
                                ],
                                [
                                    114.088176,
                                    22.522932
                                ],
                                [
                                    114.089375,
                                    22.522123
                                ],
                                [
                                    114.089922,
                                    22.521632
                                ],
                                [
                                    114.090344,
                                    22.520993
                                ],
                                [
                                    114.090424,
                                    22.52032
                                ],
                                [
                                    114.090299,
                                    22.519429
                                ],
                                [
                                    114.089922,
                                    22.518767
                                ],
                                [
                                    114.089388,
                                    22.517975
                                ],
                                [
                                    114.089283,
                                    22.51782
                                ],
                                [
                                    114.088507,
                                    22.516826
                                ],
                                [
                                    114.087639,
                                    22.515901
                                ],
                                [
                                    114.086395,
                                    22.514861
                                ],
                                [
                                    114.084294,
                                    22.513388
                                ],
                                [
                                    114.083039,
                                    22.512701
                                ],
                                [
                                    114.082262,
                                    22.512473
                                ],
                                [
                                    114.081577,
                                    22.512426
                                ],
                                [
                                    114.080984,
                                    22.512585
                                ],
                                [
                                    114.080299,
                                    22.512996
                                ],
                                [
                                    114.079201,
                                    22.514397
                                ],
                                [
                                    114.078593,
                                    22.51484
                                ],
                                [
                                    114.078328,
                                    22.515034
                                ],
                                [
                                    114.077566,
                                    22.515411
                                ],
                                [
                                    114.077003,
                                    22.515486
                                ],
                                [
                                    114.076417,
                                    22.515373
                                ],
                                [
                                    114.07601,
                                    22.515255
                                ],
                                [
                                    114.075916,
                                    22.515228
                                ],
                                [
                                    114.075754,
                                    22.515178
                                ],
                                [
                                    114.075636,
                                    22.515141
                                ],
                                [
                                    114.075179,
                                    22.515
                                ],
                                [
                                    114.074366,
                                    22.514822
                                ],
                                [
                                    114.073434,
                                    22.514657
                                ],
                                [
                                    114.07284,
                                    22.514614
                                ],
                                [
                                    114.072114,
                                    22.514473
                                ],
                                [
                                    114.071502,
                                    22.514377
                                ],
                                [
                                    114.070951,
                                    22.51431
                                ],
                                [
                                    114.070494,
                                    22.514222
                                ],
                                [
                                    114.069805,
                                    22.514051
                                ],
                                [
                                    114.069123,
                                    22.51378
                                ],
                                [
                                    114.068256,
                                    22.513208
                                ],
                                [
                                    114.066796,
                                    22.51227
                                ],
                                [
                                    114.065367,
                                    22.511184
                                ],
                                [
                                    114.064603,
                                    22.510546
                                ],
                                [
                                    114.064091,
                                    22.50995
                                ],
                                [
                                    114.06362,
                                    22.509119
                                ],
                                [
                                    114.062981,
                                    22.507825
                                ],
                                [
                                    114.062635,
                                    22.506364
                                ],
                                [
                                    114.062556,
                                    22.505049
                                ],
                                [
                                    114.062445,
                                    22.503628
                                ],
                                [
                                    114.062321,
                                    22.502825
                                ],
                                [
                                    114.061899,
                                    22.50221
                                ],
                                [
                                    114.061358,
                                    22.501621
                                ],
                                [
                                    114.060746,
                                    22.501239
                                ],
                                [
                                    114.059979,
                                    22.500728
                                ],
                                [
                                    114.058302,
                                    22.500008
                                ],
                                [
                                    114.057076,
                                    22.499623
                                ],
                                [
                                    114.05595,
                                    22.499501
                                ],
                                [
                                    114.054713,
                                    22.49961
                                ],
                                [
                                    114.054538,
                                    22.49967
                                ],
                                [
                                    114.053793,
                                    22.499889
                                ],
                                [
                                    114.051584,
                                    22.500891
                                ],
                                [
                                    114.050585,
                                    22.501195
                                ],
                                [
                                    114.049238,
                                    22.501393
                                ],
                                [
                                    114.048428,
                                    22.501512
                                ],
                                [
                                    114.047079,
                                    22.501844
                                ],
                                [
                                    114.046012,
                                    22.502183
                                ],
                                [
                                    114.044378,
                                    22.502453
                                ],
                                [
                                    114.044379,
                                    22.502417
                                ],
                                [
                                    114.042107,
                                    22.502793
                                ],
                                [
                                    114.037662,
                                    22.503288
                                ],
                                [
                                    114.03697,
                                    22.503365
                                ],
                                [
                                    114.031872,
                                    22.504141
                                ],
                                [
                                    114.030897,
                                    22.504277
                                ],
                                [
                                    114.030079,
                                    22.504611
                                ],
                                [
                                    114.029105,
                                    22.505264
                                ],
                                [
                                    114.026634,
                                    22.507951
                                ],
                                [
                                    114.025164,
                                    22.509331
                                ],
                                [
                                    114.02405,
                                    22.509805
                                ],
                                [
                                    114.010554,
                                    22.510247
                                ],
                                [
                                    113.990747,
                                    22.510582
                                ],
                                [
                                    113.990545,
                                    22.520481
                                ],
                                [
                                    113.994391,
                                    22.521927
                                ],
                                [
                                    113.994359,
                                    22.522198
                                ],
                                [
                                    113.994295,
                                    22.522413
                                ],
                                [
                                    113.994272,
                                    22.522924
                                ],
                                [
                                    113.994208,
                                    22.523195
                                ],
                                [
                                    113.99388,
                                    22.525131
                                ],
                                [
                                    113.993633,
                                    22.526656
                                ],
                                [
                                    113.993626,
                                    22.526806
                                ],
                                [
                                    113.993598,
                                    22.52718
                                ],
                                [
                                    113.993456,
                                    22.527371
                                ],
                                [
                                    113.993298,
                                    22.527679
                                ],
                                [
                                    113.993371,
                                    22.527994
                                ],
                                [
                                    113.993439,
                                    22.528241
                                ],
                                [
                                    113.993553,
                                    22.528656
                                ],
                                [
                                    113.993672,
                                    22.529083
                                ],
                                [
                                    113.993755,
                                    22.529384
                                ],
                                [
                                    113.99383,
                                    22.529669
                                ],
                                [
                                    113.993874,
                                    22.529799
                                ],
                                [
                                    113.993915,
                                    22.529934
                                ],
                                [
                                    113.993944,
                                    22.529983
                                ],
                                [
                                    113.994032,
                                    22.530106
                                ],
                                [
                                    113.994102,
                                    22.530226
                                ],
                                [
                                    113.994153,
                                    22.530279
                                ],
                                [
                                    113.994278,
                                    22.53042
                                ],
                                [
                                    113.994301,
                                    22.53046
                                ],
                                [
                                    113.994354,
                                    22.530567
                                ],
                                [
                                    113.994394,
                                    22.530583
                                ],
                                [
                                    113.994456,
                                    22.530598
                                ],
                                [
                                    113.994526,
                                    22.530596
                                ],
                                [
                                    113.994658,
                                    22.530572
                                ],
                                [
                                    113.994858,
                                    22.530548
                                ],
                                [
                                    113.995225,
                                    22.5305
                                ],
                                [
                                    113.995347,
                                    22.530489
                                ],
                                [
                                    113.995436,
                                    22.530499
                                ],
                                [
                                    113.995465,
                                    22.530512
                                ],
                                [
                                    113.995487,
                                    22.530534
                                ],
                                [
                                    113.99551,
                                    22.530586
                                ],
                                [
                                    113.995624,
                                    22.530809
                                ],
                                [
                                    113.995713,
                                    22.530986
                                ],
                                [
                                    113.995785,
                                    22.531138
                                ],
                                [
                                    113.995885,
                                    22.53136
                                ],
                                [
                                    113.996,
                                    22.531625
                                ],
                                [
                                    113.996069,
                                    22.531811
                                ],
                                [
                                    113.996153,
                                    22.532071
                                ],
                                [
                                    113.995571,
                                    22.53224
                                ],
                                [
                                    113.995275,
                                    22.532322
                                ],
                                [
                                    113.995211,
                                    22.532345
                                ],
                                [
                                    113.995205,
                                    22.532356
                                ],
                                [
                                    113.995233,
                                    22.532451
                                ],
                                [
                                    113.995316,
                                    22.532695
                                ],
                                [
                                    113.995397,
                                    22.53287
                                ],
                                [
                                    113.995436,
                                    22.53296
                                ],
                                [
                                    113.995708,
                                    22.532892
                                ],
                                [
                                    113.996036,
                                    22.532819
                                ],
                                [
                                    113.996384,
                                    22.532735
                                ],
                                [
                                    113.996604,
                                    22.532684
                                ],
                                [
                                    113.997041,
                                    22.532581
                                ],
                                [
                                    113.997403,
                                    22.532491
                                ],
                                [
                                    113.997805,
                                    22.532404
                                ],
                                [
                                    113.997872,
                                    22.532398
                                ],
                                [
                                    113.997867,
                                    22.532493
                                ],
                                [
                                    113.9978,
                                    22.532862
                                ],
                                [
                                    113.997764,
                                    22.53307
                                ],
                                [
                                    113.997732,
                                    22.533249
                                ],
                                [
                                    113.9977,
                                    22.533416
                                ],
                                [
                                    113.997592,
                                    22.534002
                                ],
                                [
                                    113.997514,
                                    22.534418
                                ],
                                [
                                    113.997467,
                                    22.534515
                                ],
                                [
                                    113.997479,
                                    22.534603
                                ],
                                [
                                    113.997403,
                                    22.535
                                ],
                                [
                                    113.997334,
                                    22.535361
                                ],
                                [
                                    113.997189,
                                    22.535563
                                ],
                                [
                                    113.996946,
                                    22.537434
                                ],
                                [
                                    113.996891,
                                    22.537728
                                ],
                                [
                                    113.996807,
                                    22.538173
                                ],
                                [
                                    113.996725,
                                    22.538632
                                ],
                                [
                                    113.99672,
                                    22.538657
                                ],
                                [
                                    113.996711,
                                    22.538763
                                ],
                                [
                                    113.996709,
                                    22.538777
                                ],
                                [
                                    113.996733,
                                    22.539217
                                ],
                                [
                                    113.996747,
                                    22.539649
                                ],
                                [
                                    113.996791,
                                    22.540129
                                ],
                                [
                                    113.996804,
                                    22.540535
                                ],
                                [
                                    113.996796,
                                    22.540833
                                ],
                                [
                                    113.996791,
                                    22.541124
                                ],
                                [
                                    113.996755,
                                    22.542076
                                ],
                                [
                                    113.996738,
                                    22.542489
                                ],
                                [
                                    113.996716,
                                    22.5427
                                ],
                                [
                                    113.996716,
                                    22.543031
                                ],
                                [
                                    113.996702,
                                    22.543302
                                ],
                                [
                                    113.996738,
                                    22.543579
                                ],
                                [
                                    113.996777,
                                    22.543844
                                ],
                                [
                                    113.996827,
                                    22.543959
                                ],
                                [
                                    113.996937,
                                    22.544173
                                ],
                                [
                                    113.997045,
                                    22.544418
                                ],
                                [
                                    113.997169,
                                    22.544725
                                ],
                                [
                                    113.997221,
                                    22.544893
                                ],
                                [
                                    113.997207,
                                    22.545009
                                ],
                                [
                                    113.997119,
                                    22.545204
                                ],
                                [
                                    113.997009,
                                    22.545454
                                ],
                                [
                                    113.996921,
                                    22.545617
                                ],
                                [
                                    113.996747,
                                    22.54585
                                ],
                                [
                                    113.996689,
                                    22.545941
                                ],
                                [
                                    113.996294,
                                    22.546608
                                ],
                                [
                                    113.99625,
                                    22.546729
                                ],
                                [
                                    113.996228,
                                    22.54679
                                ],
                                [
                                    113.996272,
                                    22.546852
                                ],
                                [
                                    113.996405,
                                    22.546974
                                ],
                                [
                                    113.997544,
                                    22.548436
                                ],
                                [
                                    113.997616,
                                    22.548527
                                ],
                                [
                                    113.99766,
                                    22.548588
                                ],
                                [
                                    113.997731,
                                    22.548641
                                ],
                                [
                                    113.997892,
                                    22.54871
                                ],
                                [
                                    113.998055,
                                    22.548778
                                ],
                                [
                                    113.998264,
                                    22.548813
                                ],
                                [
                                    113.998521,
                                    22.548867
                                ],
                                [
                                    113.998747,
                                    22.548902
                                ],
                                [
                                    113.999075,
                                    22.548931
                                ],
                                [
                                    113.999559,
                                    22.548958
                                ],
                                [
                                    113.999617,
                                    22.548986
                                ],
                                [
                                    113.999711,
                                    22.549074
                                ],
                                [
                                    113.999785,
                                    22.549229
                                ],
                                [
                                    113.999892,
                                    22.549489
                                ],
                                [
                                    113.9999,
                                    22.549618
                                ],
                                [
                                    113.999879,
                                    22.549744
                                ],
                                [
                                    113.999791,
                                    22.549847
                                ],
                                [
                                    113.999697,
                                    22.5499
                                ],
                                [
                                    113.999559,
                                    22.549941
                                ],
                                [
                                    113.999332,
                                    22.549994
                                ],
                                [
                                    113.999106,
                                    22.550047
                                ],
                                [
                                    113.998973,
                                    22.550094
                                ],
                                [
                                    113.998849,
                                    22.550139
                                ],
                                [
                                    113.998747,
                                    22.550229
                                ],
                                [
                                    113.998645,
                                    22.550329
                                ],
                                [
                                    113.998543,
                                    22.550586
                                ],
                                [
                                    113.998367,
                                    22.550972
                                ],
                                [
                                    113.998344,
                                    22.551072
                                ],
                                [
                                    113.998316,
                                    22.551223
                                ],
                                [
                                    113.998286,
                                    22.551395
                                ],
                                [
                                    113.998228,
                                    22.551642
                                ],
                                [
                                    113.99817,
                                    22.552085
                                ],
                                [
                                    113.998198,
                                    22.552209
                                ],
                                [
                                    113.998237,
                                    22.552377
                                ],
                                [
                                    113.998272,
                                    22.55267
                                ],
                                [
                                    113.9983,
                                    22.552818
                                ],
                                [
                                    113.998353,
                                    22.553237
                                ],
                                [
                                    113.998389,
                                    22.553706
                                ],
                                [
                                    113.998419,
                                    22.553879
                                ],
                                [
                                    113.998367,
                                    22.553941
                                ],
                                [
                                    113.99822,
                                    22.554083
                                ],
                                [
                                    113.998033,
                                    22.554244
                                ],
                                [
                                    113.997776,
                                    22.554563
                                ],
                                [
                                    113.997638,
                                    22.554714
                                ],
                                [
                                    113.997541,
                                    22.554838
                                ],
                                [
                                    113.997542,
                                    22.554887
                                ],
                                [
                                    113.99758,
                                    22.554945
                                ],
                                [
                                    113.99774,
                                    22.554995
                                ],
                                [
                                    113.998024,
                                    22.555056
                                ],
                                [
                                    113.998529,
                                    22.555179
                                ],
                                [
                                    113.999674,
                                    22.555461
                                ],
                                [
                                    114.000141,
                                    22.555544
                                ],
                                [
                                    114.000814,
                                    22.555707
                                ],
                                [
                                    114.0012,
                                    22.555789
                                ],
                                [
                                    114.001369,
                                    22.555802
                                ],
                                [
                                    114.001542,
                                    22.555804
                                ],
                                [
                                    114.001719,
                                    22.555833
                                ],
                                [
                                    114.001937,
                                    22.555845
                                ],
                                [
                                    114.002185,
                                    22.555834
                                ],
                                [
                                    114.002478,
                                    22.555808
                                ],
                                [
                                    114.002696,
                                    22.555766
                                ],
                                [
                                    114.0029,
                                    22.555774
                                ],
                                [
                                    114.003157,
                                    22.555808
                                ],
                                [
                                    114.003499,
                                    22.555859
                                ],
                                [
                                    114.004013,
                                    22.555946
                                ],
                                [
                                    114.00439,
                                    22.556017
                                ],
                                [
                                    114.004815,
                                    22.556098
                                ],
                                [
                                    114.005127,
                                    22.556161
                                ],
                                [
                                    114.005207,
                                    22.556189
                                ],
                                [
                                    114.005499,
                                    22.556344
                                ],
                                [
                                    114.005511,
                                    22.556852
                                ],
                                [
                                    114.0055,
                                    22.557344
                                ],
                                [
                                    114.005456,
                                    22.557419
                                ],
                                [
                                    114.005433,
                                    22.557514
                                ],
                                [
                                    114.00542,
                                    22.55767
                                ],
                                [
                                    114.005434,
                                    22.557866
                                ],
                                [
                                    114.005434,
                                    22.558062
                                ],
                                [
                                    114.005406,
                                    22.558231
                                ],
                                [
                                    114.005384,
                                    22.558311
                                ],
                                [
                                    114.005331,
                                    22.5584
                                ],
                                [
                                    114.005216,
                                    22.558528
                                ],
                                [
                                    114.005157,
                                    22.558621
                                ],
                                [
                                    114.005064,
                                    22.558785
                                ],
                                [
                                    114.005042,
                                    22.558905
                                ],
                                [
                                    114.005011,
                                    22.559054
                                ],
                                [
                                    114.004959,
                                    22.559197
                                ],
                                [
                                    114.004879,
                                    22.559345
                                ],
                                [
                                    114.004793,
                                    22.559534
                                ],
                                [
                                    114.004705,
                                    22.559684
                                ],
                                [
                                    114.00463,
                                    22.559825
                                ],
                                [
                                    114.004492,
                                    22.559971
                                ],
                                [
                                    114.004341,
                                    22.560116
                                ],
                                [
                                    114.004297,
                                    22.560155
                                ],
                                [
                                    114.004107,
                                    22.560241
                                ],
                                [
                                    114.00404,
                                    22.560324
                                ],
                                [
                                    114.003938,
                                    22.560479
                                ],
                                [
                                    114.003902,
                                    22.560628
                                ],
                                [
                                    114.003866,
                                    22.560784
                                ],
                                [
                                    114.003844,
                                    22.561015
                                ],
                                [
                                    114.003822,
                                    22.561286
                                ],
                                [
                                    114.0038,
                                    22.561534
                                ],
                                [
                                    114.003792,
                                    22.561708
                                ],
                                [
                                    114.003764,
                                    22.561839
                                ],
                                [
                                    114.00372,
                                    22.562041
                                ],
                                [
                                    114.003676,
                                    22.562183
                                ],
                                [
                                    114.003601,
                                    22.562412
                                ],
                                [
                                    114.003477,
                                    22.562698
                                ],
                                [
                                    114.003419,
                                    22.562857
                                ],
                                [
                                    114.00337,
                                    22.563061
                                ],
                                [
                                    114.003339,
                                    22.563183
                                ],
                                [
                                    114.003414,
                                    22.564637
                                ],
                                [
                                    114.003486,
                                    22.564839
                                ],
                                [
                                    114.003756,
                                    22.565552
                                ],
                                [
                                    114.003836,
                                    22.565774
                                ],
                                [
                                    114.00396,
                                    22.566045
                                ],
                                [
                                    114.004063,
                                    22.566271
                                ],
                                [
                                    114.004121,
                                    22.566349
                                ],
                                [
                                    114.004364,
                                    22.566603
                                ],
                                [
                                    114.004551,
                                    22.566791
                                ],
                                [
                                    114.004755,
                                    22.567043
                                ],
                                [
                                    114.005026,
                                    22.567368
                                ],
                                [
                                    114.005252,
                                    22.567674
                                ],
                                [
                                    114.005376,
                                    22.567898
                                ],
                                [
                                    114.005399,
                                    22.568014
                                ],
                                [
                                    114.00542,
                                    22.568235
                                ],
                                [
                                    114.005399,
                                    22.568378
                                ],
                                [
                                    114.005398,
                                    22.568499
                                ],
                                [
                                    114.005384,
                                    22.568594
                                ],
                                [
                                    114.005371,
                                    22.568926
                                ],
                                [
                                    114.005354,
                                    22.56917
                                ],
                                [
                                    114.00534,
                                    22.569276
                                ],
                                [
                                    114.005282,
                                    22.569554
                                ],
                                [
                                    114.005238,
                                    22.569871
                                ],
                                [
                                    114.005194,
                                    22.570156
                                ],
                                [
                                    114.00515,
                                    22.570533
                                ],
                                [
                                    114.005123,
                                    22.5708
                                ],
                                [
                                    114.005057,
                                    22.571202
                                ],
                                [
                                    114.00502,
                                    22.571442
                                ],
                                [
                                    114.005035,
                                    22.571618
                                ],
                                [
                                    114.005043,
                                    22.571794
                                ],
                                [
                                    114.005048,
                                    22.571902
                                ],
                                [
                                    114.005079,
                                    22.572084
                                ],
                                [
                                    114.005093,
                                    22.572239
                                ],
                                [
                                    114.005269,
                                    22.575138
                                ],
                                [
                                    114.005377,
                                    22.5754
                                ],
                                [
                                    114.005553,
                                    22.575764
                                ],
                                [
                                    114.006157,
                                    22.575939
                                ],
                                [
                                    114.006273,
                                    22.576014
                                ],
                                [
                                    114.00645,
                                    22.576146
                                ],
                                [
                                    114.006635,
                                    22.576284
                                ],
                                [
                                    114.006727,
                                    22.576371
                                ],
                                [
                                    114.007191,
                                    22.576648
                                ],
                                [
                                    114.007372,
                                    22.576835
                                ],
                                [
                                    114.007592,
                                    22.577144
                                ],
                                [
                                    114.007761,
                                    22.577421
                                ],
                                [
                                    114.007958,
                                    22.57766
                                ],
                                [
                                    114.008166,
                                    22.577839
                                ],
                                [
                                    114.009461,
                                    22.578858
                                ],
                                [
                                    114.009969,
                                    22.578929
                                ],
                                [
                                    114.01237,
                                    22.579266
                                ],
                                [
                                    114.013671,
                                    22.579451
                                ],
                                [
                                    114.014676,
                                    22.579538
                                ],
                                [
                                    114.014876,
                                    22.579555
                                ],
                                [
                                    114.015004,
                                    22.579516
                                ],
                                [
                                    114.01626,
                                    22.579432
                                ],
                                [
                                    114.016311,
                                    22.579436
                                ],
                                [
                                    114.016344,
                                    22.579426
                                ],
                                [
                                    114.016433,
                                    22.57937
                                ],
                                [
                                    114.016551,
                                    22.579272
                                ],
                                [
                                    114.016607,
                                    22.579234
                                ],
                                [
                                    114.016653,
                                    22.57921
                                ],
                                [
                                    114.016719,
                                    22.579194
                                ],
                                [
                                    114.01684,
                                    22.579158
                                ],
                                [
                                    114.016923,
                                    22.579131
                                ],
                                [
                                    114.016973,
                                    22.579117
                                ],
                                [
                                    114.017041,
                                    22.579094
                                ],
                                [
                                    114.017249,
                                    22.57909
                                ],
                                [
                                    114.018869,
                                    22.579073
                                ],
                                [
                                    114.018923,
                                    22.579088
                                ],
                                [
                                    114.019034,
                                    22.579122
                                ],
                                [
                                    114.019291,
                                    22.579212
                                ],
                                [
                                    114.019506,
                                    22.579279
                                ],
                                [
                                    114.019614,
                                    22.579303
                                ],
                                [
                                    114.019898,
                                    22.579392
                                ],
                                [
                                    114.020029,
                                    22.579426
                                ],
                                [
                                    114.020077,
                                    22.579439
                                ],
                                [
                                    114.020112,
                                    22.579459
                                ],
                                [
                                    114.022151,
                                    22.580287
                                ],
                                [
                                    114.022234,
                                    22.580326
                                ],
                                [
                                    114.022446,
                                    22.580447
                                ],
                                [
                                    114.022648,
                                    22.580609
                                ],
                                [
                                    114.022718,
                                    22.580668
                                ],
                                [
                                    114.022859,
                                    22.580798
                                ],
                                [
                                    114.023311,
                                    22.581279
                                ],
                                [
                                    114.023509,
                                    22.581647
                                ],
                                [
                                    114.024271,
                                    22.581551
                                ],
                                [
                                    114.025531,
                                    22.581602
                                ],
                                [
                                    114.028061,
                                    22.581459
                                ],
                                [
                                    114.029117,
                                    22.581175
                                ],
                                [
                                    114.030141,
                                    22.580561
                                ],
                                [
                                    114.030323,
                                    22.580562
                                ],
                                [
                                    114.031997,
                                    22.581307
                                ],
                                [
                                    114.034303,
                                    22.582628
                                ],
                                [
                                    114.036416,
                                    22.582982
                                ],
                                [
                                    114.038205,
                                    22.58297
                                ],
                                [
                                    114.038943,
                                    22.583044
                                ],
                                [
                                    114.039465,
                                    22.583224
                                ],
                                [
                                    114.040419,
                                    22.58373
                                ],
                                [
                                    114.041096,
                                    22.583906
                                ],
                                [
                                    114.042057,
                                    22.583859
                                ],
                                [
                                    114.043095,
                                    22.583957
                                ],
                                [
                                    114.043538,
                                    22.584099
                                ],
                                [
                                    114.045318,
                                    22.584165
                                ],
                                [
                                    114.045654,
                                    22.584044
                                ],
                                [
                                    114.046389,
                                    22.58322
                                ],
                                [
                                    114.047516,
                                    22.582406
                                ],
                                [
                                    114.052556,
                                    22.581747
                                ],
                                [
                                    114.053343,
                                    22.58208
                                ],
                                [
                                    114.053533,
                                    22.582237
                                ],
                                [
                                    114.053742,
                                    22.584621
                                ],
                                [
                                    114.053877,
                                    22.584813
                                ],
                                [
                                    114.054641,
                                    22.585291
                                ],
                                [
                                    114.056376,
                                    22.586014
                                ],
                                [
                                    114.056469,
                                    22.58604
                                ],
                                [
                                    114.056562,
                                    22.586066
                                ],
                                [
                                    114.056656,
                                    22.586093
                                ],
                                [
                                    114.05771,
                                    22.586392
                                ],
                                [
                                    114.058132,
                                    22.586926
                                ],
                                [
                                    114.058831,
                                    22.587359
                                ],
                                [
                                    114.059393,
                                    22.587531
                                ],
                                [
                                    114.06212,
                                    22.586478
                                ],
                                [
                                    114.063838,
                                    22.586057
                                ],
                                [
                                    114.065572,
                                    22.585862
                                ],
                                [
                                    114.066307,
                                    22.585671
                                ]
                            ]
                        ]
                    },
                    "properties": {
                        "name": "福田区",
                        "cp": [
                            114.05096,
                            22.541009
                        ]
                    }
                },
                {
                    "type": "Feature",
                    "id": "440308",
                    "geometry": {
                        "type": "Polygon",
                        "coordinates": [
                            [
                                [
                                    114.232563,
                                    22.540043
                                ],
                                [
                                    114.231268,
                                    22.540831
                                ],
                                [
                                    114.231068,
                                    22.541213
                                ],
                                [
                                    114.23102,
                                    22.541309
                                ],
                                [
                                    114.230511,
                                    22.543042
                                ],
                                [
                                    114.230964,
                                    22.543747
                                ],
                                [
                                    114.230799,
                                    22.545741
                                ],
                                [
                                    114.230766,
                                    22.545941
                                ],
                                [
                                    114.230163,
                                    22.546588
                                ],
                                [
                                    114.22975,
                                    22.546906
                                ],
                                [
                                    114.229539,
                                    22.547099
                                ],
                                [
                                    114.229408,
                                    22.547284
                                ],
                                [
                                    114.22917,
                                    22.547848
                                ],
                                [
                                    114.2291,
                                    22.547936
                                ],
                                [
                                    114.228994,
                                    22.547989
                                ],
                                [
                                    114.228361,
                                    22.548008
                                ],
                                [
                                    114.22815,
                                    22.548017
                                ],
                                [
                                    114.227823,
                                    22.548346
                                ],
                                [
                                    114.22756,
                                    22.548481
                                ],
                                [
                                    114.227289,
                                    22.548546
                                ],
                                [
                                    114.226656,
                                    22.548784
                                ],
                                [
                                    114.226304,
                                    22.548961
                                ],
                                [
                                    114.226041,
                                    22.549296
                                ],
                                [
                                    114.225939,
                                    22.549864
                                ],
                                [
                                    114.225868,
                                    22.550081
                                ],
                                [
                                    114.225761,
                                    22.55028
                                ],
                                [
                                    114.225519,
                                    22.550484
                                ],
                                [
                                    114.225033,
                                    22.550786
                                ],
                                [
                                    114.224678,
                                    22.551023
                                ],
                                [
                                    114.22447,
                                    22.551254
                                ],
                                [
                                    114.223976,
                                    22.55179
                                ],
                                [
                                    114.223285,
                                    22.552764
                                ],
                                [
                                    114.223007,
                                    22.552983
                                ],
                                [
                                    114.222705,
                                    22.553054
                                ],
                                [
                                    114.222196,
                                    22.552999
                                ],
                                [
                                    114.221927,
                                    22.552882
                                ],
                                [
                                    114.221876,
                                    22.552545
                                ],
                                [
                                    114.221641,
                                    22.552272
                                ],
                                [
                                    114.221082,
                                    22.552076
                                ],
                                [
                                    114.22071,
                                    22.551935
                                ],
                                [
                                    114.22032,
                                    22.55189
                                ],
                                [
                                    114.219809,
                                    22.551839
                                ],
                                [
                                    114.218596,
                                    22.551723
                                ],
                                [
                                    114.218293,
                                    22.551725
                                ],
                                [
                                    114.217929,
                                    22.551778
                                ],
                                [
                                    114.217643,
                                    22.551874
                                ],
                                [
                                    114.217504,
                                    22.55195
                                ],
                                [
                                    114.217019,
                                    22.552445
                                ],
                                [
                                    114.216309,
                                    22.553269
                                ],
                                [
                                    114.215911,
                                    22.553662
                                ],
                                [
                                    114.215651,
                                    22.553814
                                ],
                                [
                                    114.215322,
                                    22.553947
                                ],
                                [
                                    114.214975,
                                    22.553991
                                ],
                                [
                                    114.214507,
                                    22.553977
                                ],
                                [
                                    114.213286,
                                    22.553739
                                ],
                                [
                                    114.212619,
                                    22.553623
                                ],
                                [
                                    114.212359,
                                    22.553606
                                ],
                                [
                                    114.212142,
                                    22.553615
                                ],
                                [
                                    114.210835,
                                    22.55383
                                ],
                                [
                                    114.209414,
                                    22.553732
                                ],
                                [
                                    114.207985,
                                    22.553596
                                ],
                                [
                                    114.207292,
                                    22.55352
                                ],
                                [
                                    114.207032,
                                    22.55353
                                ],
                                [
                                    114.206807,
                                    22.553584
                                ],
                                [
                                    114.206695,
                                    22.553663
                                ],
                                [
                                    114.206548,
                                    22.553871
                                ],
                                [
                                    114.206314,
                                    22.554331
                                ],
                                [
                                    114.206158,
                                    22.55459
                                ],
                                [
                                    114.206037,
                                    22.554673
                                ],
                                [
                                    114.205829,
                                    22.554751
                                ],
                                [
                                    114.205595,
                                    22.554734
                                ],
                                [
                                    114.205214,
                                    22.55465
                                ],
                                [
                                    114.204028,
                                    22.554192
                                ],
                                [
                                    114.20356,
                                    22.554008
                                ],
                                [
                                    114.20324,
                                    22.553933
                                ],
                                [
                                    114.203066,
                                    22.553902
                                ],
                                [
                                    114.202883,
                                    22.5539
                                ],
                                [
                                    114.203177,
                                    22.55531
                                ],
                                [
                                    114.203147,
                                    22.555413
                                ],
                                [
                                    114.203136,
                                    22.555519
                                ],
                                [
                                    114.203145,
                                    22.555571
                                ],
                                [
                                    114.203183,
                                    22.555711
                                ],
                                [
                                    114.203207,
                                    22.555813
                                ],
                                [
                                    114.203231,
                                    22.555863
                                ],
                                [
                                    114.20329,
                                    22.55595
                                ],
                                [
                                    114.203367,
                                    22.556053
                                ],
                                [
                                    114.203402,
                                    22.556119
                                ],
                                [
                                    114.203441,
                                    22.556149
                                ],
                                [
                                    114.203537,
                                    22.5562
                                ],
                                [
                                    114.203665,
                                    22.55627
                                ],
                                [
                                    114.203951,
                                    22.556407
                                ],
                                [
                                    114.204161,
                                    22.556523
                                ],
                                [
                                    114.204226,
                                    22.556558
                                ],
                                [
                                    114.204279,
                                    22.556606
                                ],
                                [
                                    114.204358,
                                    22.556698
                                ],
                                [
                                    114.20452,
                                    22.556892
                                ],
                                [
                                    114.204688,
                                    22.55708
                                ],
                                [
                                    114.204789,
                                    22.557201
                                ],
                                [
                                    114.204927,
                                    22.557347
                                ],
                                [
                                    114.204992,
                                    22.557407
                                ],
                                [
                                    114.205149,
                                    22.557572
                                ],
                                [
                                    114.205312,
                                    22.557753
                                ],
                                [
                                    114.205377,
                                    22.557815
                                ],
                                [
                                    114.20558,
                                    22.557978
                                ],
                                [
                                    114.205817,
                                    22.558181
                                ],
                                [
                                    114.206066,
                                    22.558385
                                ],
                                [
                                    114.206185,
                                    22.558482
                                ],
                                [
                                    114.206225,
                                    22.558534
                                ],
                                [
                                    114.206313,
                                    22.558653
                                ],
                                [
                                    114.206466,
                                    22.558856
                                ],
                                [
                                    114.206632,
                                    22.559091
                                ],
                                [
                                    114.20676,
                                    22.559265
                                ],
                                [
                                    114.206865,
                                    22.559404
                                ],
                                [
                                    114.206942,
                                    22.559507
                                ],
                                [
                                    114.207001,
                                    22.559628
                                ],
                                [
                                    114.207051,
                                    22.559732
                                ],
                                [
                                    114.207116,
                                    22.559871
                                ],
                                [
                                    114.207141,
                                    22.559953
                                ],
                                [
                                    114.207172,
                                    22.560063
                                ],
                                [
                                    114.207225,
                                    22.560206
                                ],
                                [
                                    114.207269,
                                    22.560333
                                ],
                                [
                                    114.207298,
                                    22.560464
                                ],
                                [
                                    114.207331,
                                    22.560682
                                ],
                                [
                                    114.207344,
                                    22.56079
                                ],
                                [
                                    114.207352,
                                    22.560862
                                ],
                                [
                                    114.207337,
                                    22.560946
                                ],
                                [
                                    114.207301,
                                    22.561166
                                ],
                                [
                                    114.20728,
                                    22.561283
                                ],
                                [
                                    114.207256,
                                    22.561409
                                ],
                                [
                                    114.20718,
                                    22.561643
                                ],
                                [
                                    114.207089,
                                    22.561944
                                ],
                                [
                                    114.207064,
                                    22.562024
                                ],
                                [
                                    114.206999,
                                    22.56212
                                ],
                                [
                                    114.20691,
                                    22.562277
                                ],
                                [
                                    114.206716,
                                    22.562605
                                ],
                                [
                                    114.206632,
                                    22.562762
                                ],
                                [
                                    114.206472,
                                    22.563041
                                ],
                                [
                                    114.206356,
                                    22.563258
                                ],
                                [
                                    114.206221,
                                    22.563493
                                ],
                                [
                                    114.206111,
                                    22.563694
                                ],
                                [
                                    114.205967,
                                    22.563971
                                ],
                                [
                                    114.205817,
                                    22.564258
                                ],
                                [
                                    114.205744,
                                    22.564435
                                ],
                                [
                                    114.205693,
                                    22.564543
                                ],
                                [
                                    114.205581,
                                    22.564764
                                ],
                                [
                                    114.205512,
                                    22.564925
                                ],
                                [
                                    114.205459,
                                    22.565042
                                ],
                                [
                                    114.205414,
                                    22.565138
                                ],
                                [
                                    114.205332,
                                    22.565266
                                ],
                                [
                                    114.205259,
                                    22.565368
                                ],
                                [
                                    114.205097,
                                    22.565611
                                ],
                                [
                                    114.204968,
                                    22.565799
                                ],
                                [
                                    114.204816,
                                    22.566015
                                ],
                                [
                                    114.204751,
                                    22.566134
                                ],
                                [
                                    114.204662,
                                    22.566261
                                ],
                                [
                                    114.204536,
                                    22.566448
                                ],
                                [
                                    114.204441,
                                    22.566591
                                ],
                                [
                                    114.204382,
                                    22.56671
                                ],
                                [
                                    114.204306,
                                    22.566849
                                ],
                                [
                                    114.204124,
                                    22.567195
                                ],
                                [
                                    114.20405,
                                    22.567334
                                ],
                                [
                                    114.203871,
                                    22.567678
                                ],
                                [
                                    114.203785,
                                    22.567846
                                ],
                                [
                                    114.203673,
                                    22.568165
                                ],
                                [
                                    114.203606,
                                    22.568371
                                ],
                                [
                                    114.203532,
                                    22.568614
                                ],
                                [
                                    114.203476,
                                    22.568839
                                ],
                                [
                                    114.203445,
                                    22.569021
                                ],
                                [
                                    114.203442,
                                    22.569179
                                ],
                                [
                                    114.203444,
                                    22.569249
                                ],
                                [
                                    114.203461,
                                    22.569306
                                ],
                                [
                                    114.203761,
                                    22.569949
                                ],
                                [
                                    114.203832,
                                    22.570001
                                ],
                                [
                                    114.204187,
                                    22.570192
                                ],
                                [
                                    114.204567,
                                    22.570372
                                ],
                                [
                                    114.204811,
                                    22.570497
                                ],
                                [
                                    114.205056,
                                    22.570621
                                ],
                                [
                                    114.205326,
                                    22.570794
                                ],
                                [
                                    114.205471,
                                    22.570898
                                ],
                                [
                                    114.205621,
                                    22.570991
                                ],
                                [
                                    114.205833,
                                    22.571132
                                ],
                                [
                                    114.205976,
                                    22.571265
                                ],
                                [
                                    114.206081,
                                    22.571364
                                ],
                                [
                                    114.206268,
                                    22.571552
                                ],
                                [
                                    114.206544,
                                    22.571811
                                ],
                                [
                                    114.206701,
                                    22.57196
                                ],
                                [
                                    114.20677,
                                    22.572024
                                ],
                                [
                                    114.206886,
                                    22.572112
                                ],
                                [
                                    114.207125,
                                    22.572287
                                ],
                                [
                                    114.207236,
                                    22.572363
                                ],
                                [
                                    114.20733,
                                    22.572442
                                ],
                                [
                                    114.207406,
                                    22.572495
                                ],
                                [
                                    114.207469,
                                    22.572541
                                ],
                                [
                                    114.207515,
                                    22.572575
                                ],
                                [
                                    114.207699,
                                    22.57265
                                ],
                                [
                                    114.20785,
                                    22.572709
                                ],
                                [
                                    114.208019,
                                    22.572761
                                ],
                                [
                                    114.208053,
                                    22.572771
                                ],
                                [
                                    114.208112,
                                    22.572756
                                ],
                                [
                                    114.210304,
                                    22.573396
                                ],
                                [
                                    114.210394,
                                    22.573447
                                ],
                                [
                                    114.210444,
                                    22.573486
                                ],
                                [
                                    114.210551,
                                    22.573517
                                ],
                                [
                                    114.210726,
                                    22.573565
                                ],
                                [
                                    114.210974,
                                    22.57363
                                ],
                                [
                                    114.21115,
                                    22.573678
                                ],
                                [
                                    114.21134,
                                    22.573722
                                ],
                                [
                                    114.211474,
                                    22.573757
                                ],
                                [
                                    114.211613,
                                    22.573798
                                ],
                                [
                                    114.211728,
                                    22.57382
                                ],
                                [
                                    114.211861,
                                    22.573843
                                ],
                                [
                                    114.212025,
                                    22.573863
                                ],
                                [
                                    114.21218,
                                    22.573881
                                ],
                                [
                                    114.212315,
                                    22.57389
                                ],
                                [
                                    114.21242,
                                    22.573912
                                ],
                                [
                                    114.212531,
                                    22.573916
                                ],
                                [
                                    114.212851,
                                    22.573924
                                ],
                                [
                                    114.213044,
                                    22.57392
                                ],
                                [
                                    114.213208,
                                    22.5739
                                ],
                                [
                                    114.213578,
                                    22.573868
                                ],
                                [
                                    114.213691,
                                    22.573858
                                ],
                                [
                                    114.213927,
                                    22.57386
                                ],
                                [
                                    114.214006,
                                    22.573861
                                ],
                                [
                                    114.214703,
                                    22.574005
                                ],
                                [
                                    114.215114,
                                    22.57412
                                ],
                                [
                                    114.215487,
                                    22.57425
                                ],
                                [
                                    114.215717,
                                    22.57436
                                ],
                                [
                                    114.217172,
                                    22.575006
                                ],
                                [
                                    114.217263,
                                    22.575032
                                ],
                                [
                                    114.217332,
                                    22.575083
                                ],
                                [
                                    114.217434,
                                    22.575164
                                ],
                                [
                                    114.217519,
                                    22.575269
                                ],
                                [
                                    114.217579,
                                    22.575333
                                ],
                                [
                                    114.217657,
                                    22.575451
                                ],
                                [
                                    114.217677,
                                    22.575486
                                ],
                                [
                                    114.217947,
                                    22.575801
                                ],
                                [
                                    114.21815,
                                    22.57608
                                ],
                                [
                                    114.218434,
                                    22.57645
                                ],
                                [
                                    114.2185,
                                    22.576548
                                ],
                                [
                                    114.218563,
                                    22.576617
                                ],
                                [
                                    114.218743,
                                    22.576737
                                ],
                                [
                                    114.21892,
                                    22.576857
                                ],
                                [
                                    114.219048,
                                    22.576943
                                ],
                                [
                                    114.219275,
                                    22.577084
                                ],
                                [
                                    114.219482,
                                    22.577216
                                ],
                                [
                                    114.219606,
                                    22.577311
                                ],
                                [
                                    114.219743,
                                    22.577401
                                ],
                                [
                                    114.219824,
                                    22.577488
                                ],
                                [
                                    114.219919,
                                    22.577606
                                ],
                                [
                                    114.219971,
                                    22.577686
                                ],
                                [
                                    114.220006,
                                    22.577782
                                ],
                                [
                                    114.220011,
                                    22.577863
                                ],
                                [
                                    114.220004,
                                    22.577996
                                ],
                                [
                                    114.21997,
                                    22.578174
                                ],
                                [
                                    114.219906,
                                    22.57831
                                ],
                                [
                                    114.21977,
                                    22.578649
                                ],
                                [
                                    114.219685,
                                    22.578909
                                ],
                                [
                                    114.219677,
                                    22.578972
                                ],
                                [
                                    114.219615,
                                    22.579142
                                ],
                                [
                                    114.219574,
                                    22.579246
                                ],
                                [
                                    114.219506,
                                    22.579339
                                ],
                                [
                                    114.219433,
                                    22.579473
                                ],
                                [
                                    114.219312,
                                    22.579625
                                ],
                                [
                                    114.219192,
                                    22.579787
                                ],
                                [
                                    114.219143,
                                    22.579845
                                ],
                                [
                                    114.219105,
                                    22.579931
                                ],
                                [
                                    114.219004,
                                    22.580125
                                ],
                                [
                                    114.21895,
                                    22.580217
                                ],
                                [
                                    114.218929,
                                    22.580289
                                ],
                                [
                                    114.218924,
                                    22.580327
                                ],
                                [
                                    114.218921,
                                    22.580341
                                ],
                                [
                                    114.218907,
                                    22.580476
                                ],
                                [
                                    114.218893,
                                    22.580599
                                ],
                                [
                                    114.218854,
                                    22.580966
                                ],
                                [
                                    114.218845,
                                    22.581043
                                ],
                                [
                                    114.218763,
                                    22.581919
                                ],
                                [
                                    114.219184,
                                    22.581691
                                ],
                                [
                                    114.219509,
                                    22.581654
                                ],
                                [
                                    114.220844,
                                    22.582522
                                ],
                                [
                                    114.221412,
                                    22.583187
                                ],
                                [
                                    114.222286,
                                    22.583734
                                ],
                                [
                                    114.224496,
                                    22.584437
                                ],
                                [
                                    114.224643,
                                    22.584645
                                ],
                                [
                                    114.224769,
                                    22.585529
                                ],
                                [
                                    114.224916,
                                    22.585863
                                ],
                                [
                                    114.227003,
                                    22.589155
                                ],
                                [
                                    114.227488,
                                    22.589779
                                ],
                                [
                                    114.228935,
                                    22.590752
                                ],
                                [
                                    114.229104,
                                    22.591294
                                ],
                                [
                                    114.229064,
                                    22.592108
                                ],
                                [
                                    114.229379,
                                    22.593304
                                ],
                                [
                                    114.229555,
                                    22.593733
                                ],
                                [
                                    114.23036,
                                    22.594836
                                ],
                                [
                                    114.23053,
                                    22.595254
                                ],
                                [
                                    114.230527,
                                    22.595295
                                ],
                                [
                                    114.230512,
                                    22.595447
                                ],
                                [
                                    114.230524,
                                    22.595874
                                ],
                                [
                                    114.230533,
                                    22.595981
                                ],
                                [
                                    114.230543,
                                    22.596066
                                ],
                                [
                                    114.230714,
                                    22.59849
                                ],
                                [
                                    114.230905,
                                    22.598836
                                ],
                                [
                                    114.231546,
                                    22.599246
                                ],
                                [
                                    114.232992,
                                    22.600732
                                ],
                                [
                                    114.233167,
                                    22.601657
                                ],
                                [
                                    114.234721,
                                    22.602414
                                ],
                                [
                                    114.235492,
                                    22.603747
                                ],
                                [
                                    114.235398,
                                    22.605182
                                ],
                                [
                                    114.234844,
                                    22.607082
                                ],
                                [
                                    114.234683,
                                    22.60739
                                ],
                                [
                                    114.234108,
                                    22.607879
                                ],
                                [
                                    114.234422,
                                    22.608837
                                ],
                                [
                                    114.23475,
                                    22.609375
                                ],
                                [
                                    114.236218,
                                    22.610707
                                ],
                                [
                                    114.236243,
                                    22.610733
                                ],
                                [
                                    114.236354,
                                    22.610845
                                ],
                                [
                                    114.236921,
                                    22.611697
                                ],
                                [
                                    114.236966,
                                    22.611743
                                ],
                                [
                                    114.237005,
                                    22.611783
                                ],
                                [
                                    114.237059,
                                    22.611833
                                ],
                                [
                                    114.237106,
                                    22.611877
                                ],
                                [
                                    114.238144,
                                    22.612844
                                ],
                                [
                                    114.240838,
                                    22.615646
                                ],
                                [
                                    114.243485,
                                    22.61607
                                ],
                                [
                                    114.244227,
                                    22.616791
                                ],
                                [
                                    114.244774,
                                    22.617587
                                ],
                                [
                                    114.245188,
                                    22.618002
                                ],
                                [
                                    114.246916,
                                    22.619022
                                ],
                                [
                                    114.247395,
                                    22.619163
                                ],
                                [
                                    114.247923,
                                    22.619456
                                ],
                                [
                                    114.249024,
                                    22.620229
                                ],
                                [
                                    114.249385,
                                    22.620321
                                ],
                                [
                                    114.250923,
                                    22.620356
                                ],
                                [
                                    114.251749,
                                    22.62028
                                ],
                                [
                                    114.252971,
                                    22.62031
                                ],
                                [
                                    114.253901,
                                    22.620145
                                ],
                                [
                                    114.254828,
                                    22.620104
                                ],
                                [
                                    114.25583,
                                    22.619738
                                ],
                                [
                                    114.257604,
                                    22.619494
                                ],
                                [
                                    114.259886,
                                    22.61887
                                ],
                                [
                                    114.262981,
                                    22.62044
                                ],
                                [
                                    114.265313,
                                    22.622558
                                ],
                                [
                                    114.265836,
                                    22.625268
                                ],
                                [
                                    114.26633,
                                    22.626272
                                ],
                                [
                                    114.266186,
                                    22.628304
                                ],
                                [
                                    114.266111,
                                    22.628416
                                ],
                                [
                                    114.265214,
                                    22.629217
                                ],
                                [
                                    114.263838,
                                    22.630181
                                ],
                                [
                                    114.263099,
                                    22.631229
                                ],
                                [
                                    114.261192,
                                    22.632463
                                ],
                                [
                                    114.259874,
                                    22.633456
                                ],
                                [
                                    114.259034,
                                    22.633895
                                ],
                                [
                                    114.258704,
                                    22.634184
                                ],
                                [
                                    114.258779,
                                    22.634914
                                ],
                                [
                                    114.258966,
                                    22.635561
                                ],
                                [
                                    114.258926,
                                    22.636551
                                ],
                                [
                                    114.259059,
                                    22.637586
                                ],
                                [
                                    114.258381,
                                    22.639178
                                ],
                                [
                                    114.257972,
                                    22.640807
                                ],
                                [
                                    114.258586,
                                    22.64147
                                ],
                                [
                                    114.259332,
                                    22.642496
                                ],
                                [
                                    114.259534,
                                    22.643075
                                ],
                                [
                                    114.259533,
                                    22.644137
                                ],
                                [
                                    114.260286,
                                    22.646415
                                ],
                                [
                                    114.260339,
                                    22.647179
                                ],
                                [
                                    114.2614,
                                    22.64865
                                ],
                                [
                                    114.262244,
                                    22.648789
                                ],
                                [
                                    114.262618,
                                    22.648949
                                ],
                                [
                                    114.263474,
                                    22.649634
                                ],
                                [
                                    114.264323,
                                    22.650538
                                ],
                                [
                                    114.266212,
                                    22.651683
                                ],
                                [
                                    114.267542,
                                    22.652623
                                ],
                                [
                                    114.269225,
                                    22.653397
                                ],
                                [
                                    114.269789,
                                    22.653829
                                ],
                                [
                                    114.271023,
                                    22.653277
                                ],
                                [
                                    114.272681,
                                    22.652228
                                ],
                                [
                                    114.273419,
                                    22.651621
                                ],
                                [
                                    114.274272,
                                    22.651135
                                ],
                                [
                                    114.274479,
                                    22.649801
                                ],
                                [
                                    114.27495,
                                    22.648846
                                ],
                                [
                                    114.275208,
                                    22.647702
                                ],
                                [
                                    114.275714,
                                    22.646773
                                ],
                                [
                                    114.276804,
                                    22.645817
                                ],
                                [
                                    114.277744,
                                    22.64532
                                ],
                                [
                                    114.278965,
                                    22.644507
                                ],
                                [
                                    114.279359,
                                    22.644401
                                ],
                                [
                                    114.280154,
                                    22.643773
                                ],
                                [
                                    114.280429,
                                    22.643412
                                ],
                                [
                                    114.28089,
                                    22.643092
                                ],
                                [
                                    114.28098,
                                    22.64303
                                ],
                                [
                                    114.281009,
                                    22.643009
                                ],
                                [
                                    114.281008,
                                    22.642948
                                ],
                                [
                                    114.281008,
                                    22.642944
                                ],
                                [
                                    114.281014,
                                    22.64291
                                ],
                                [
                                    114.281046,
                                    22.642861
                                ],
                                [
                                    114.281052,
                                    22.642851
                                ],
                                [
                                    114.281378,
                                    22.642373
                                ],
                                [
                                    114.281407,
                                    22.64236
                                ],
                                [
                                    114.281514,
                                    22.642324
                                ],
                                [
                                    114.281561,
                                    22.642309
                                ],
                                [
                                    114.281724,
                                    22.642245
                                ],
                                [
                                    114.281901,
                                    22.642165
                                ],
                                [
                                    114.282663,
                                    22.641823
                                ],
                                [
                                    114.283696,
                                    22.641111
                                ],
                                [
                                    114.284673,
                                    22.640992
                                ],
                                [
                                    114.284678,
                                    22.640991
                                ],
                                [
                                    114.284759,
                                    22.64092
                                ],
                                [
                                    114.284836,
                                    22.640891
                                ],
                                [
                                    114.285889,
                                    22.640514
                                ],
                                [
                                    114.285909,
                                    22.640358
                                ],
                                [
                                    114.28589,
                                    22.640279
                                ],
                                [
                                    114.285844,
                                    22.640177
                                ],
                                [
                                    114.285724,
                                    22.639611
                                ],
                                [
                                    114.285718,
                                    22.639566
                                ],
                                [
                                    114.285654,
                                    22.639512
                                ],
                                [
                                    114.28565,
                                    22.639434
                                ],
                                [
                                    114.285581,
                                    22.637932
                                ],
                                [
                                    114.285589,
                                    22.637869
                                ],
                                [
                                    114.28558,
                                    22.637794
                                ],
                                [
                                    114.285569,
                                    22.637739
                                ],
                                [
                                    114.285554,
                                    22.637173
                                ],
                                [
                                    114.285581,
                                    22.637111
                                ],
                                [
                                    114.285646,
                                    22.637003
                                ],
                                [
                                    114.285876,
                                    22.636726
                                ],
                                [
                                    114.286298,
                                    22.63651
                                ],
                                [
                                    114.286674,
                                    22.636192
                                ],
                                [
                                    114.287089,
                                    22.635314
                                ],
                                [
                                    114.287122,
                                    22.635244
                                ],
                                [
                                    114.287203,
                                    22.635136
                                ],
                                [
                                    114.287211,
                                    22.635058
                                ],
                                [
                                    114.287224,
                                    22.635029
                                ],
                                [
                                    114.28743,
                                    22.634594
                                ],
                                [
                                    114.287455,
                                    22.634541
                                ],
                                [
                                    114.287467,
                                    22.634509
                                ],
                                [
                                    114.287486,
                                    22.634476
                                ],
                                [
                                    114.287512,
                                    22.634419
                                ],
                                [
                                    114.287761,
                                    22.633893
                                ],
                                [
                                    114.287844,
                                    22.633718
                                ],
                                [
                                    114.288128,
                                    22.633087
                                ],
                                [
                                    114.28858,
                                    22.632474
                                ],
                                [
                                    114.289039,
                                    22.632196
                                ],
                                [
                                    114.289794,
                                    22.632155
                                ],
                                [
                                    114.290412,
                                    22.63177
                                ],
                                [
                                    114.290429,
                                    22.631759
                                ],
                                [
                                    114.290469,
                                    22.631712
                                ],
                                [
                                    114.290525,
                                    22.631647
                                ],
                                [
                                    114.290542,
                                    22.631625
                                ],
                                [
                                    114.290579,
                                    22.631531
                                ],
                                [
                                    114.29058,
                                    22.631525
                                ],
                                [
                                    114.290576,
                                    22.63147
                                ],
                                [
                                    114.290568,
                                    22.631421
                                ],
                                [
                                    114.290537,
                                    22.631348
                                ],
                                [
                                    114.290536,
                                    22.631343
                                ],
                                [
                                    114.290504,
                                    22.631246
                                ],
                                [
                                    114.29049,
                                    22.63121
                                ],
                                [
                                    114.290472,
                                    22.631164
                                ],
                                [
                                    114.290419,
                                    22.631029
                                ],
                                [
                                    114.288934,
                                    22.627289
                                ],
                                [
                                    114.28836,
                                    22.626773
                                ],
                                [
                                    114.287572,
                                    22.626439
                                ],
                                [
                                    114.287267,
                                    22.626205
                                ],
                                [
                                    114.286925,
                                    22.624282
                                ],
                                [
                                    114.28808,
                                    22.620868
                                ],
                                [
                                    114.289133,
                                    22.620684
                                ],
                                [
                                    114.290006,
                                    22.619985
                                ],
                                [
                                    114.290471,
                                    22.619421
                                ],
                                [
                                    114.290849,
                                    22.619333
                                ],
                                [
                                    114.291448,
                                    22.619506
                                ],
                                [
                                    114.291587,
                                    22.61968
                                ],
                                [
                                    114.291663,
                                    22.620584
                                ],
                                [
                                    114.291849,
                                    22.620799
                                ],
                                [
                                    114.294067,
                                    22.621279
                                ],
                                [
                                    114.294628,
                                    22.621292
                                ],
                                [
                                    114.294944,
                                    22.621025
                                ],
                                [
                                    114.295629,
                                    22.619066
                                ],
                                [
                                    114.295833,
                                    22.618869
                                ],
                                [
                                    114.296537,
                                    22.618543
                                ],
                                [
                                    114.296944,
                                    22.618582
                                ],
                                [
                                    114.297834,
                                    22.619986
                                ],
                                [
                                    114.298534,
                                    22.620836
                                ],
                                [
                                    114.298683,
                                    22.621141
                                ],
                                [
                                    114.298654,
                                    22.621273
                                ],
                                [
                                    114.302867,
                                    22.627901
                                ],
                                [
                                    114.303704,
                                    22.628498
                                ],
                                [
                                    114.303583,
                                    22.629292
                                ],
                                [
                                    114.304001,
                                    22.629789
                                ],
                                [
                                    114.304826,
                                    22.630511
                                ],
                                [
                                    114.306703,
                                    22.629837
                                ],
                                [
                                    114.306854,
                                    22.62986
                                ],
                                [
                                    114.308412,
                                    22.628973
                                ],
                                [
                                    114.310178,
                                    22.628105
                                ],
                                [
                                    114.310579,
                                    22.626159
                                ],
                                [
                                    114.31069,
                                    22.625978
                                ],
                                [
                                    114.311341,
                                    22.625453
                                ],
                                [
                                    114.312481,
                                    22.624992
                                ],
                                [
                                    114.313572,
                                    22.624333
                                ],
                                [
                                    114.315727,
                                    22.624447
                                ],
                                [
                                    114.316923,
                                    22.624384
                                ],
                                [
                                    114.318419,
                                    22.624669
                                ],
                                [
                                    114.318546,
                                    22.624772
                                ],
                                [
                                    114.318929,
                                    22.625838
                                ],
                                [
                                    114.319322,
                                    22.625987
                                ],
                                [
                                    114.319698,
                                    22.62601
                                ],
                                [
                                    114.320874,
                                    22.625691
                                ],
                                [
                                    114.321485,
                                    22.625353
                                ],
                                [
                                    114.322066,
                                    22.624856
                                ],
                                [
                                    114.322759,
                                    22.623574
                                ],
                                [
                                    114.323803,
                                    22.623045
                                ],
                                [
                                    114.324643,
                                    22.622873
                                ],
                                [
                                    114.325536,
                                    22.622967
                                ],
                                [
                                    114.328429,
                                    22.622867
                                ],
                                [
                                    114.329464,
                                    22.623407
                                ],
                                [
                                    114.330176,
                                    22.624296
                                ],
                                [
                                    114.331849,
                                    22.625988
                                ],
                                [
                                    114.33522,
                                    22.62589
                                ],
                                [
                                    114.335648,
                                    22.62553
                                ],
                                [
                                    114.338043,
                                    22.624207
                                ],
                                [
                                    114.339292,
                                    22.623357
                                ],
                                [
                                    114.339723,
                                    22.623063
                                ],
                                [
                                    114.340434,
                                    22.622092
                                ],
                                [
                                    114.340548,
                                    22.621496
                                ],
                                [
                                    114.340936,
                                    22.620759
                                ],
                                [
                                    114.341302,
                                    22.620276
                                ],
                                [
                                    114.342292,
                                    22.619586
                                ],
                                [
                                    114.343093,
                                    22.618536
                                ],
                                [
                                    114.343266,
                                    22.618137
                                ],
                                [
                                    114.343256,
                                    22.617826
                                ],
                                [
                                    114.342874,
                                    22.61771
                                ],
                                [
                                    114.342618,
                                    22.617514
                                ],
                                [
                                    114.341965,
                                    22.616638
                                ],
                                [
                                    114.341984,
                                    22.61646
                                ],
                                [
                                    114.342374,
                                    22.615754
                                ],
                                [
                                    114.342759,
                                    22.614279
                                ],
                                [
                                    114.342631,
                                    22.613383
                                ],
                                [
                                    114.33958,
                                    22.608374
                                ],
                                [
                                    114.339421,
                                    22.60792
                                ],
                                [
                                    114.338674,
                                    22.60723
                                ],
                                [
                                    114.33795,
                                    22.60586
                                ],
                                [
                                    114.337799,
                                    22.604064
                                ],
                                [
                                    114.337672,
                                    22.603466
                                ],
                                [
                                    114.337747,
                                    22.603174
                                ],
                                [
                                    114.337939,
                                    22.60292
                                ],
                                [
                                    114.339033,
                                    22.602318
                                ],
                                [
                                    114.33917,
                                    22.602373
                                ],
                                [
                                    114.343045,
                                    22.602146
                                ],
                                [
                                    114.344202,
                                    22.601869
                                ],
                                [
                                    114.344436,
                                    22.601887
                                ],
                                [
                                    114.344698,
                                    22.602041
                                ],
                                [
                                    114.344893,
                                    22.602461
                                ],
                                [
                                    114.344939,
                                    22.602511
                                ],
                                [
                                    114.345033,
                                    22.602596
                                ],
                                [
                                    114.345543,
                                    22.602862
                                ],
                                [
                                    114.346987,
                                    22.603094
                                ],
                                [
                                    114.347179,
                                    22.603126
                                ],
                                [
                                    114.348359,
                                    22.603386
                                ],
                                [
                                    114.348443,
                                    22.603376
                                ],
                                [
                                    114.348521,
                                    22.603359
                                ],
                                [
                                    114.348551,
                                    22.603353
                                ],
                                [
                                    114.348573,
                                    22.603349
                                ],
                                [
                                    114.348712,
                                    22.603327
                                ],
                                [
                                    114.349721,
                                    22.603027
                                ],
                                [
                                    114.35046,
                                    22.602589
                                ],
                                [
                                    114.350356,
                                    22.601419
                                ],
                                [
                                    114.350298,
                                    22.600615
                                ],
                                [
                                    114.350294,
                                    22.600576
                                ],
                                [
                                    114.350273,
                                    22.600422
                                ],
                                [
                                    114.350223,
                                    22.600035
                                ],
                                [
                                    114.350209,
                                    22.599871
                                ],
                                [
                                    114.350207,
                                    22.599842
                                ],
                                [
                                    114.350244,
                                    22.598847
                                ],
                                [
                                    114.350252,
                                    22.598653
                                ],
                                [
                                    114.350257,
                                    22.5985
                                ],
                                [
                                    114.350258,
                                    22.598477
                                ],
                                [
                                    114.350265,
                                    22.598448
                                ],
                                [
                                    114.350277,
                                    22.598398
                                ],
                                [
                                    114.350299,
                                    22.598311
                                ],
                                [
                                    114.350535,
                                    22.597011
                                ],
                                [
                                    114.353515,
                                    22.590011
                                ],
                                [
                                    114.347004,
                                    22.588677
                                ],
                                [
                                    114.343397,
                                    22.588337
                                ],
                                [
                                    114.337094,
                                    22.588325
                                ],
                                [
                                    114.330626,
                                    22.588899
                                ],
                                [
                                    114.325331,
                                    22.588637
                                ],
                                [
                                    114.322141,
                                    22.587374
                                ],
                                [
                                    114.319976,
                                    22.585382
                                ],
                                [
                                    114.318107,
                                    22.583241
                                ],
                                [
                                    114.31689,
                                    22.582199
                                ],
                                [
                                    114.315779,
                                    22.581408
                                ],
                                [
                                    114.311848,
                                    22.578609
                                ],
                                [
                                    114.309823,
                                    22.57612
                                ],
                                [
                                    114.308319,
                                    22.573172
                                ],
                                [
                                    114.306581,
                                    22.570513
                                ],
                                [
                                    114.304851,
                                    22.568719
                                ],
                                [
                                    114.303287,
                                    22.568083
                                ],
                                [
                                    114.300688,
                                    22.567502
                                ],
                                [
                                    114.298551,
                                    22.566633
                                ],
                                [
                                    114.296526,
                                    22.565301
                                ],
                                [
                                    114.294562,
                                    22.563738
                                ],
                                [
                                    114.292425,
                                    22.562985
                                ],
                                [
                                    114.289992,
                                    22.562808
                                ],
                                [
                                    114.286813,
                                    22.562978
                                ],
                                [
                                    114.284216,
                                    22.562975
                                ],
                                [
                                    114.280977,
                                    22.562857
                                ],
                                [
                                    114.275376,
                                    22.562274
                                ],
                                [
                                    114.261053,
                                    22.559591
                                ],
                                [
                                    114.259656,
                                    22.559204
                                ],
                                [
                                    114.258832,
                                    22.55882
                                ],
                                [
                                    114.250321,
                                    22.553282
                                ],
                                [
                                    114.24164,
                                    22.546016
                                ],
                                [
                                    114.237999,
                                    22.542936
                                ],
                                [
                                    114.235485,
                                    22.541219
                                ],
                                [
                                    114.232563,
                                    22.540043
                                ]
                            ]
                        ]
                    },
                    "properties": {
                        "name": "盐田区",
                        "cp": [
                            114.235366,
                            22.555069
                        ]
                    }
                },
                {
                    "type": "Feature",
                    "id": "440303",
                    "geometry": {
                        "type": "Polygon",
                        "coordinates": [
                            [
                                [
                                    114.105177,
                                    22.531626
                                ],
                                [
                                    114.104808,
                                    22.532512
                                ],
                                [
                                    114.104774,
                                    22.535038
                                ],
                                [
                                    114.104757,
                                    22.535105
                                ],
                                [
                                    114.104772,
                                    22.5352
                                ],
                                [
                                    114.104764,
                                    22.535834
                                ],
                                [
                                    114.104699,
                                    22.540773
                                ],
                                [
                                    114.104687,
                                    22.541316
                                ],
                                [
                                    114.104589,
                                    22.546031
                                ],
                                [
                                    114.104519,
                                    22.547975
                                ],
                                [
                                    114.104464,
                                    22.548114
                                ],
                                [
                                    114.104502,
                                    22.548445
                                ],
                                [
                                    114.104486,
                                    22.548663
                                ],
                                [
                                    114.10449,
                                    22.548786
                                ],
                                [
                                    114.104477,
                                    22.549163
                                ],
                                [
                                    114.104506,
                                    22.549251
                                ],
                                [
                                    114.104505,
                                    22.549327
                                ],
                                [
                                    114.10447,
                                    22.549363
                                ],
                                [
                                    114.104341,
                                    22.552936
                                ],
                                [
                                    114.104281,
                                    22.555434
                                ],
                                [
                                    114.104472,
                                    22.555779
                                ],
                                [
                                    114.104487,
                                    22.555809
                                ],
                                [
                                    114.104508,
                                    22.555845
                                ],
                                [
                                    114.104557,
                                    22.555933
                                ],
                                [
                                    114.104576,
                                    22.556013
                                ],
                                [
                                    114.104576,
                                    22.556037
                                ],
                                [
                                    114.104574,
                                    22.556168
                                ],
                                [
                                    114.10456,
                                    22.556475
                                ],
                                [
                                    114.10456,
                                    22.556561
                                ],
                                [
                                    114.104559,
                                    22.556903
                                ],
                                [
                                    114.104552,
                                    22.557291
                                ],
                                [
                                    114.104551,
                                    22.557399
                                ],
                                [
                                    114.104547,
                                    22.557726
                                ],
                                [
                                    114.104541,
                                    22.557852
                                ],
                                [
                                    114.104542,
                                    22.558166
                                ],
                                [
                                    114.104536,
                                    22.558579
                                ],
                                [
                                    114.104534,
                                    22.558701
                                ],
                                [
                                    114.104529,
                                    22.559019
                                ],
                                [
                                    114.104521,
                                    22.559395
                                ],
                                [
                                    114.104523,
                                    22.559815
                                ],
                                [
                                    114.104503,
                                    22.560243
                                ],
                                [
                                    114.104498,
                                    22.560353
                                ],
                                [
                                    114.104502,
                                    22.560685
                                ],
                                [
                                    114.104495,
                                    22.561075
                                ],
                                [
                                    114.104487,
                                    22.561174
                                ],
                                [
                                    114.104496,
                                    22.561506
                                ],
                                [
                                    114.104496,
                                    22.561921
                                ],
                                [
                                    114.104496,
                                    22.562368
                                ],
                                [
                                    114.104502,
                                    22.562489
                                ],
                                [
                                    114.104504,
                                    22.562812
                                ],
                                [
                                    114.104506,
                                    22.563216
                                ],
                                [
                                    114.104504,
                                    22.563617
                                ],
                                [
                                    114.104508,
                                    22.563748
                                ],
                                [
                                    114.104512,
                                    22.564046
                                ],
                                [
                                    114.104508,
                                    22.56422
                                ],
                                [
                                    114.104498,
                                    22.564475
                                ],
                                [
                                    114.104502,
                                    22.564899
                                ],
                                [
                                    114.104511,
                                    22.565285
                                ],
                                [
                                    114.104509,
                                    22.565474
                                ],
                                [
                                    114.104508,
                                    22.565722
                                ],
                                [
                                    114.104517,
                                    22.56614
                                ],
                                [
                                    114.104521,
                                    22.566593
                                ],
                                [
                                    114.104523,
                                    22.567017
                                ],
                                [
                                    114.104518,
                                    22.567455
                                ],
                                [
                                    114.104524,
                                    22.567872
                                ],
                                [
                                    114.104514,
                                    22.56789
                                ],
                                [
                                    114.104473,
                                    22.567887
                                ],
                                [
                                    114.104281,
                                    22.56785
                                ],
                                [
                                    114.104165,
                                    22.567827
                                ],
                                [
                                    114.104041,
                                    22.567776
                                ],
                                [
                                    114.103984,
                                    22.567714
                                ],
                                [
                                    114.103221,
                                    22.566996
                                ],
                                [
                                    114.101604,
                                    22.566261
                                ],
                                [
                                    114.100625,
                                    22.565896
                                ],
                                [
                                    114.099474,
                                    22.565566
                                ],
                                [
                                    114.098216,
                                    22.565256
                                ],
                                [
                                    114.096829,
                                    22.56491
                                ],
                                [
                                    114.095665,
                                    22.564683
                                ],
                                [
                                    114.094653,
                                    22.564538
                                ],
                                [
                                    114.093662,
                                    22.564387
                                ],
                                [
                                    114.09319,
                                    22.564326
                                ],
                                [
                                    114.092677,
                                    22.564341
                                ],
                                [
                                    114.092628,
                                    22.564336
                                ],
                                [
                                    114.092616,
                                    22.564338
                                ],
                                [
                                    114.092547,
                                    22.564334
                                ],
                                [
                                    114.092482,
                                    22.564333
                                ],
                                [
                                    114.092448,
                                    22.564344
                                ],
                                [
                                    114.092346,
                                    22.564394
                                ],
                                [
                                    114.092238,
                                    22.564462
                                ],
                                [
                                    114.092232,
                                    22.564471
                                ],
                                [
                                    114.092198,
                                    22.564515
                                ],
                                [
                                    114.092159,
                                    22.564576
                                ],
                                [
                                    114.092053,
                                    22.564749
                                ],
                                [
                                    114.091951,
                                    22.564934
                                ],
                                [
                                    114.091793,
                                    22.565191
                                ],
                                [
                                    114.091604,
                                    22.565503
                                ],
                                [
                                    114.091404,
                                    22.565793
                                ],
                                [
                                    114.09114,
                                    22.566201
                                ],
                                [
                                    114.091064,
                                    22.566319
                                ],
                                [
                                    114.090868,
                                    22.566609
                                ],
                                [
                                    114.090934,
                                    22.56668
                                ],
                                [
                                    114.090822,
                                    22.566674
                                ],
                                [
                                    114.090558,
                                    22.567061
                                ],
                                [
                                    114.090367,
                                    22.567349
                                ],
                                [
                                    114.090287,
                                    22.567475
                                ],
                                [
                                    114.090217,
                                    22.567571
                                ],
                                [
                                    114.090162,
                                    22.567638
                                ],
                                [
                                    114.08992,
                                    22.56787
                                ],
                                [
                                    114.089529,
                                    22.568249
                                ],
                                [
                                    114.089399,
                                    22.56837
                                ],
                                [
                                    114.089068,
                                    22.568689
                                ],
                                [
                                    114.088819,
                                    22.568935
                                ],
                                [
                                    114.088709,
                                    22.569037
                                ],
                                [
                                    114.088646,
                                    22.569078
                                ],
                                [
                                    114.088535,
                                    22.569171
                                ],
                                [
                                    114.088247,
                                    22.569416
                                ],
                                [
                                    114.088167,
                                    22.569495
                                ],
                                [
                                    114.088081,
                                    22.569532
                                ],
                                [
                                    114.08804,
                                    22.569578
                                ],
                                [
                                    114.087999,
                                    22.569556
                                ],
                                [
                                    114.087781,
                                    22.569619
                                ],
                                [
                                    114.087106,
                                    22.56982
                                ],
                                [
                                    114.086649,
                                    22.569956
                                ],
                                [
                                    114.08641,
                                    22.570031
                                ],
                                [
                                    114.086242,
                                    22.570088
                                ],
                                [
                                    114.086163,
                                    22.570103
                                ],
                                [
                                    114.085801,
                                    22.570148
                                ],
                                [
                                    114.085672,
                                    22.570161
                                ],
                                [
                                    114.085463,
                                    22.570188
                                ],
                                [
                                    114.085116,
                                    22.570236
                                ],
                                [
                                    114.084791,
                                    22.570277
                                ],
                                [
                                    114.084619,
                                    22.570303
                                ],
                                [
                                    114.084456,
                                    22.570309
                                ],
                                [
                                    114.084331,
                                    22.570304
                                ],
                                [
                                    114.084081,
                                    22.570304
                                ],
                                [
                                    114.083769,
                                    22.570298
                                ],
                                [
                                    114.083665,
                                    22.570292
                                ],
                                [
                                    114.083473,
                                    22.570284
                                ],
                                [
                                    114.083275,
                                    22.570264
                                ],
                                [
                                    114.083075,
                                    22.570242
                                ],
                                [
                                    114.082817,
                                    22.57021
                                ],
                                [
                                    114.082622,
                                    22.570188
                                ],
                                [
                                    114.082508,
                                    22.570159
                                ],
                                [
                                    114.08228,
                                    22.570096
                                ],
                                [
                                    114.082174,
                                    22.570069
                                ],
                                [
                                    114.081817,
                                    22.569965
                                ],
                                [
                                    114.081591,
                                    22.569903
                                ],
                                [
                                    114.081421,
                                    22.569841
                                ],
                                [
                                    114.081242,
                                    22.569769
                                ],
                                [
                                    114.080933,
                                    22.569619
                                ],
                                [
                                    114.080908,
                                    22.569568
                                ],
                                [
                                    114.08085,
                                    22.569578
                                ],
                                [
                                    114.080686,
                                    22.569497
                                ],
                                [
                                    114.080538,
                                    22.569445
                                ],
                                [
                                    114.080433,
                                    22.569393
                                ],
                                [
                                    114.080271,
                                    22.569293
                                ],
                                [
                                    114.079923,
                                    22.569056
                                ],
                                [
                                    114.079662,
                                    22.568882
                                ],
                                [
                                    114.079393,
                                    22.568705
                                ],
                                [
                                    114.079153,
                                    22.568538
                                ],
                                [
                                    114.079117,
                                    22.568517
                                ],
                                [
                                    114.079096,
                                    22.568519
                                ],
                                [
                                    114.079028,
                                    22.568567
                                ],
                                [
                                    114.078887,
                                    22.568673
                                ],
                                [
                                    114.078607,
                                    22.56885
                                ],
                                [
                                    114.078495,
                                    22.568924
                                ],
                                [
                                    114.078397,
                                    22.569016
                                ],
                                [
                                    114.078186,
                                    22.569219
                                ],
                                [
                                    114.078015,
                                    22.56938
                                ],
                                [
                                    114.077965,
                                    22.569438
                                ],
                                [
                                    114.077919,
                                    22.569561
                                ],
                                [
                                    114.077803,
                                    22.569836
                                ],
                                [
                                    114.077751,
                                    22.569966
                                ],
                                [
                                    114.077635,
                                    22.570266
                                ],
                                [
                                    114.077564,
                                    22.57047
                                ],
                                [
                                    114.077481,
                                    22.570689
                                ],
                                [
                                    114.077396,
                                    22.570895
                                ],
                                [
                                    114.077328,
                                    22.571063
                                ],
                                [
                                    114.077286,
                                    22.571168
                                ],
                                [
                                    114.077251,
                                    22.571219
                                ],
                                [
                                    114.077139,
                                    22.571326
                                ],
                                [
                                    114.076993,
                                    22.571499
                                ],
                                [
                                    114.076867,
                                    22.571625
                                ],
                                [
                                    114.076762,
                                    22.571693
                                ],
                                [
                                    114.076688,
                                    22.571739
                                ],
                                [
                                    114.07653,
                                    22.571842
                                ],
                                [
                                    114.076423,
                                    22.571923
                                ],
                                [
                                    114.076276,
                                    22.572064
                                ],
                                [
                                    114.076119,
                                    22.57222
                                ],
                                [
                                    114.076027,
                                    22.572324
                                ],
                                [
                                    114.075995,
                                    22.572373
                                ],
                                [
                                    114.075944,
                                    22.572466
                                ],
                                [
                                    114.075442,
                                    22.573406
                                ],
                                [
                                    114.074444,
                                    22.57527
                                ],
                                [
                                    114.074429,
                                    22.575304
                                ],
                                [
                                    114.07442,
                                    22.575387
                                ],
                                [
                                    114.074413,
                                    22.57552
                                ],
                                [
                                    114.074422,
                                    22.575687
                                ],
                                [
                                    114.074425,
                                    22.575768
                                ],
                                [
                                    114.074436,
                                    22.575915
                                ],
                                [
                                    114.074424,
                                    22.576026
                                ],
                                [
                                    114.074396,
                                    22.576131
                                ],
                                [
                                    114.072941,
                                    22.578101
                                ],
                                [
                                    114.07282,
                                    22.578252
                                ],
                                [
                                    114.072721,
                                    22.578413
                                ],
                                [
                                    114.07264,
                                    22.578544
                                ],
                                [
                                    114.07255,
                                    22.578743
                                ],
                                [
                                    114.072494,
                                    22.578864
                                ],
                                [
                                    114.072333,
                                    22.579066
                                ],
                                [
                                    114.072248,
                                    22.579179
                                ],
                                [
                                    114.072132,
                                    22.579286
                                ],
                                [
                                    114.071922,
                                    22.57948
                                ],
                                [
                                    114.071765,
                                    22.579608
                                ],
                                [
                                    114.071509,
                                    22.579729
                                ],
                                [
                                    114.071414,
                                    22.579777
                                ],
                                [
                                    114.071316,
                                    22.579822
                                ],
                                [
                                    114.071183,
                                    22.579844
                                ],
                                [
                                    114.070814,
                                    22.579893
                                ],
                                [
                                    114.070644,
                                    22.579942
                                ],
                                [
                                    114.070522,
                                    22.579985
                                ],
                                [
                                    114.070441,
                                    22.580055
                                ],
                                [
                                    114.069304,
                                    22.580983
                                ],
                                [
                                    114.069009,
                                    22.581218
                                ],
                                [
                                    114.068689,
                                    22.582049
                                ],
                                [
                                    114.067464,
                                    22.583932
                                ],
                                [
                                    114.066593,
                                    22.585036
                                ],
                                [
                                    114.066307,
                                    22.585671
                                ],
                                [
                                    114.066242,
                                    22.586446
                                ],
                                [
                                    114.066427,
                                    22.587767
                                ],
                                [
                                    114.06676,
                                    22.587997
                                ],
                                [
                                    114.067792,
                                    22.58822
                                ],
                                [
                                    114.068388,
                                    22.589547
                                ],
                                [
                                    114.069677,
                                    22.590484
                                ],
                                [
                                    114.070446,
                                    22.591161
                                ],
                                [
                                    114.070783,
                                    22.591517
                                ],
                                [
                                    114.071592,
                                    22.592746
                                ],
                                [
                                    114.073605,
                                    22.592416
                                ],
                                [
                                    114.076291,
                                    22.594081
                                ],
                                [
                                    114.076481,
                                    22.594279
                                ],
                                [
                                    114.07644,
                                    22.594435
                                ],
                                [
                                    114.076425,
                                    22.59446
                                ],
                                [
                                    114.076405,
                                    22.594494
                                ],
                                [
                                    114.076384,
                                    22.594524
                                ],
                                [
                                    114.076365,
                                    22.59456
                                ],
                                [
                                    114.076341,
                                    22.594601
                                ],
                                [
                                    114.076325,
                                    22.594627
                                ],
                                [
                                    114.075951,
                                    22.595047
                                ],
                                [
                                    114.075364,
                                    22.596361
                                ],
                                [
                                    114.07531,
                                    22.596547
                                ],
                                [
                                    114.075214,
                                    22.597194
                                ],
                                [
                                    114.075216,
                                    22.597212
                                ],
                                [
                                    114.075242,
                                    22.597386
                                ],
                                [
                                    114.075331,
                                    22.598095
                                ],
                                [
                                    114.075334,
                                    22.598101
                                ],
                                [
                                    114.075369,
                                    22.59811
                                ],
                                [
                                    114.075417,
                                    22.598111
                                ],
                                [
                                    114.075471,
                                    22.598105
                                ],
                                [
                                    114.075523,
                                    22.598098
                                ],
                                [
                                    114.076329,
                                    22.597851
                                ],
                                [
                                    114.077292,
                                    22.598071
                                ],
                                [
                                    114.078856,
                                    22.599039
                                ],
                                [
                                    114.079411,
                                    22.599596
                                ],
                                [
                                    114.081164,
                                    22.600857
                                ],
                                [
                                    114.082876,
                                    22.601197
                                ],
                                [
                                    114.083804,
                                    22.601219
                                ],
                                [
                                    114.085266,
                                    22.600967
                                ],
                                [
                                    114.086078,
                                    22.600389
                                ],
                                [
                                    114.089056,
                                    22.599067
                                ],
                                [
                                    114.089668,
                                    22.598512
                                ],
                                [
                                    114.089843,
                                    22.598586
                                ],
                                [
                                    114.090674,
                                    22.599398
                                ],
                                [
                                    114.09147,
                                    22.599906
                                ],
                                [
                                    114.09222,
                                    22.600078
                                ],
                                [
                                    114.093411,
                                    22.600147
                                ],
                                [
                                    114.095172,
                                    22.598901
                                ],
                                [
                                    114.096739,
                                    22.597389
                                ],
                                [
                                    114.097775,
                                    22.596069
                                ],
                                [
                                    114.099539,
                                    22.594177
                                ],
                                [
                                    114.099735,
                                    22.593308
                                ],
                                [
                                    114.099939,
                                    22.593058
                                ],
                                [
                                    114.100366,
                                    22.592807
                                ],
                                [
                                    114.100931,
                                    22.5927
                                ],
                                [
                                    114.102247,
                                    22.592214
                                ],
                                [
                                    114.10306,
                                    22.591685
                                ],
                                [
                                    114.103222,
                                    22.591579
                                ],
                                [
                                    114.103542,
                                    22.591372
                                ],
                                [
                                    114.103553,
                                    22.591365
                                ],
                                [
                                    114.103704,
                                    22.591266
                                ],
                                [
                                    114.105077,
                                    22.590145
                                ],
                                [
                                    114.105741,
                                    22.589396
                                ],
                                [
                                    114.105881,
                                    22.588793
                                ],
                                [
                                    114.105994,
                                    22.588302
                                ],
                                [
                                    114.106724,
                                    22.588183
                                ],
                                [
                                    114.107486,
                                    22.588193
                                ],
                                [
                                    114.108022,
                                    22.589015
                                ],
                                [
                                    114.110447,
                                    22.589194
                                ],
                                [
                                    114.111385,
                                    22.589313
                                ],
                                [
                                    114.111392,
                                    22.589314
                                ],
                                [
                                    114.111561,
                                    22.589353
                                ],
                                [
                                    114.111573,
                                    22.589357
                                ],
                                [
                                    114.112218,
                                    22.589464
                                ],
                                [
                                    114.112519,
                                    22.589649
                                ],
                                [
                                    114.112562,
                                    22.589674
                                ],
                                [
                                    114.112689,
                                    22.589744
                                ],
                                [
                                    114.112708,
                                    22.589755
                                ],
                                [
                                    114.112738,
                                    22.589772
                                ],
                                [
                                    114.112766,
                                    22.589787
                                ],
                                [
                                    114.112811,
                                    22.589811
                                ],
                                [
                                    114.112879,
                                    22.589847
                                ],
                                [
                                    114.112937,
                                    22.589878
                                ],
                                [
                                    114.114131,
                                    22.590493
                                ],
                                [
                                    114.114778,
                                    22.590676
                                ],
                                [
                                    114.114877,
                                    22.590688
                                ],
                                [
                                    114.11497,
                                    22.5907
                                ],
                                [
                                    114.114983,
                                    22.590702
                                ],
                                [
                                    114.115069,
                                    22.590714
                                ],
                                [
                                    114.115508,
                                    22.590837
                                ],
                                [
                                    114.115691,
                                    22.590902
                                ],
                                [
                                    114.117447,
                                    22.591251
                                ],
                                [
                                    114.119557,
                                    22.589983
                                ],
                                [
                                    114.119849,
                                    22.590075
                                ],
                                [
                                    114.119948,
                                    22.590107
                                ],
                                [
                                    114.119978,
                                    22.590116
                                ],
                                [
                                    114.121215,
                                    22.590506
                                ],
                                [
                                    114.121722,
                                    22.590666
                                ],
                                [
                                    114.121915,
                                    22.589584
                                ],
                                [
                                    114.122051,
                                    22.589317
                                ],
                                [
                                    114.122192,
                                    22.589041
                                ],
                                [
                                    114.122209,
                                    22.589007
                                ],
                                [
                                    114.122662,
                                    22.588988
                                ],
                                [
                                    114.122856,
                                    22.588973
                                ],
                                [
                                    114.123263,
                                    22.588939
                                ],
                                [
                                    114.123467,
                                    22.588929
                                ],
                                [
                                    114.12343,
                                    22.588161
                                ],
                                [
                                    114.123462,
                                    22.587963
                                ],
                                [
                                    114.123564,
                                    22.587968
                                ],
                                [
                                    114.123719,
                                    22.58773
                                ],
                                [
                                    114.124542,
                                    22.588289
                                ],
                                [
                                    114.124796,
                                    22.588661
                                ],
                                [
                                    114.12493,
                                    22.588682
                                ],
                                [
                                    114.12602,
                                    22.588761
                                ],
                                [
                                    114.128704,
                                    22.588944
                                ],
                                [
                                    114.129348,
                                    22.588701
                                ],
                                [
                                    114.129869,
                                    22.588308
                                ],
                                [
                                    114.130275,
                                    22.587676
                                ],
                                [
                                    114.13049,
                                    22.587318
                                ],
                                [
                                    114.130822,
                                    22.586694
                                ],
                                [
                                    114.131852,
                                    22.587407
                                ],
                                [
                                    114.133097,
                                    22.588299
                                ],
                                [
                                    114.133204,
                                    22.588735
                                ],
                                [
                                    114.13388,
                                    22.589161
                                ],
                                [
                                    114.134236,
                                    22.588814
                                ],
                                [
                                    114.13528,
                                    22.588108
                                ],
                                [
                                    114.135606,
                                    22.588144
                                ],
                                [
                                    114.136787,
                                    22.588331
                                ],
                                [
                                    114.138444,
                                    22.58874
                                ],
                                [
                                    114.139069,
                                    22.588748
                                ],
                                [
                                    114.139319,
                                    22.589018
                                ],
                                [
                                    114.13979,
                                    22.590095
                                ],
                                [
                                    114.139994,
                                    22.590331
                                ],
                                [
                                    114.141456,
                                    22.591084
                                ],
                                [
                                    114.141934,
                                    22.591243
                                ],
                                [
                                    114.143284,
                                    22.591405
                                ],
                                [
                                    114.144299,
                                    22.591268
                                ],
                                [
                                    114.145053,
                                    22.591772
                                ],
                                [
                                    114.145693,
                                    22.592358
                                ],
                                [
                                    114.145957,
                                    22.592811
                                ],
                                [
                                    114.145959,
                                    22.593802
                                ],
                                [
                                    114.145958,
                                    22.593844
                                ],
                                [
                                    114.145945,
                                    22.594116
                                ],
                                [
                                    114.145873,
                                    22.594481
                                ],
                                [
                                    114.145823,
                                    22.594669
                                ],
                                [
                                    114.145768,
                                    22.594911
                                ],
                                [
                                    114.146004,
                                    22.595483
                                ],
                                [
                                    114.14601,
                                    22.595499
                                ],
                                [
                                    114.146049,
                                    22.595533
                                ],
                                [
                                    114.146147,
                                    22.595613
                                ],
                                [
                                    114.146251,
                                    22.595698
                                ],
                                [
                                    114.146363,
                                    22.595791
                                ],
                                [
                                    114.146399,
                                    22.595822
                                ],
                                [
                                    114.146478,
                                    22.59589
                                ],
                                [
                                    114.146597,
                                    22.595994
                                ],
                                [
                                    114.146624,
                                    22.596017
                                ],
                                [
                                    114.150262,
                                    22.599342
                                ],
                                [
                                    114.151339,
                                    22.600002
                                ],
                                [
                                    114.152247,
                                    22.600358
                                ],
                                [
                                    114.152438,
                                    22.600394
                                ],
                                [
                                    114.153528,
                                    22.600911
                                ],
                                [
                                    114.15425,
                                    22.601428
                                ],
                                [
                                    114.154631,
                                    22.601454
                                ],
                                [
                                    114.154747,
                                    22.60145
                                ],
                                [
                                    114.154824,
                                    22.601445
                                ],
                                [
                                    114.157929,
                                    22.601334
                                ],
                                [
                                    114.159134,
                                    22.601195
                                ],
                                [
                                    114.159579,
                                    22.601232
                                ],
                                [
                                    114.159944,
                                    22.601389
                                ],
                                [
                                    114.160279,
                                    22.601884
                                ],
                                [
                                    114.160886,
                                    22.603346
                                ],
                                [
                                    114.161572,
                                    22.604487
                                ],
                                [
                                    114.161638,
                                    22.605271
                                ],
                                [
                                    114.163465,
                                    22.606384
                                ],
                                [
                                    114.163541,
                                    22.60644
                                ],
                                [
                                    114.16362,
                                    22.606499
                                ],
                                [
                                    114.163696,
                                    22.606555
                                ],
                                [
                                    114.163752,
                                    22.606596
                                ],
                                [
                                    114.163782,
                                    22.606619
                                ],
                                [
                                    114.163815,
                                    22.606642
                                ],
                                [
                                    114.163908,
                                    22.606709
                                ],
                                [
                                    114.163972,
                                    22.606755
                                ],
                                [
                                    114.164414,
                                    22.607122
                                ],
                                [
                                    114.164561,
                                    22.607248
                                ],
                                [
                                    114.165302,
                                    22.607886
                                ],
                                [
                                    114.165449,
                                    22.608013
                                ],
                                [
                                    114.166038,
                                    22.608519
                                ],
                                [
                                    114.166184,
                                    22.608646
                                ],
                                [
                                    114.16693,
                                    22.609288
                                ],
                                [
                                    114.167471,
                                    22.609519
                                ],
                                [
                                    114.17063,
                                    22.610244
                                ],
                                [
                                    114.172673,
                                    22.610358
                                ],
                                [
                                    114.173934,
                                    22.610991
                                ],
                                [
                                    114.175158,
                                    22.61219
                                ],
                                [
                                    114.175914,
                                    22.613807
                                ],
                                [
                                    114.176014,
                                    22.614284
                                ],
                                [
                                    114.177174,
                                    22.615588
                                ],
                                [
                                    114.17745,
                                    22.615527
                                ],
                                [
                                    114.181628,
                                    22.61599
                                ],
                                [
                                    114.181786,
                                    22.615914
                                ],
                                [
                                    114.182252,
                                    22.615341
                                ],
                                [
                                    114.183195,
                                    22.614909
                                ],
                                [
                                    114.184766,
                                    22.615289
                                ],
                                [
                                    114.186902,
                                    22.61519
                                ],
                                [
                                    114.187,
                                    22.615187
                                ],
                                [
                                    114.187096,
                                    22.615183
                                ],
                                [
                                    114.187185,
                                    22.61518
                                ],
                                [
                                    114.187194,
                                    22.61518
                                ],
                                [
                                    114.188777,
                                    22.615241
                                ],
                                [
                                    114.19169,
                                    22.616084
                                ],
                                [
                                    114.192145,
                                    22.616449
                                ],
                                [
                                    114.192406,
                                    22.61619
                                ],
                                [
                                    114.196861,
                                    22.613296
                                ],
                                [
                                    114.199387,
                                    22.609757
                                ],
                                [
                                    114.199502,
                                    22.6096
                                ],
                                [
                                    114.199765,
                                    22.609247
                                ],
                                [
                                    114.199861,
                                    22.609124
                                ],
                                [
                                    114.199882,
                                    22.609093
                                ],
                                [
                                    114.200355,
                                    22.60774
                                ],
                                [
                                    114.200348,
                                    22.607492
                                ],
                                [
                                    114.200202,
                                    22.607034
                                ],
                                [
                                    114.199242,
                                    22.606371
                                ],
                                [
                                    114.198901,
                                    22.605669
                                ],
                                [
                                    114.198702,
                                    22.604842
                                ],
                                [
                                    114.198788,
                                    22.603977
                                ],
                                [
                                    114.198742,
                                    22.60325
                                ],
                                [
                                    114.198867,
                                    22.60304
                                ],
                                [
                                    114.200081,
                                    22.602383
                                ],
                                [
                                    114.201067,
                                    22.602186
                                ],
                                [
                                    114.202343,
                                    22.601505
                                ],
                                [
                                    114.203151,
                                    22.601184
                                ],
                                [
                                    114.204079,
                                    22.601417
                                ],
                                [
                                    114.205452,
                                    22.601953
                                ],
                                [
                                    114.206973,
                                    22.601653
                                ],
                                [
                                    114.207583,
                                    22.601157
                                ],
                                [
                                    114.208871,
                                    22.599357
                                ],
                                [
                                    114.209512,
                                    22.598772
                                ],
                                [
                                    114.210086,
                                    22.598889
                                ],
                                [
                                    114.211343,
                                    22.599338
                                ],
                                [
                                    114.212641,
                                    22.599632
                                ],
                                [
                                    114.213228,
                                    22.599614
                                ],
                                [
                                    114.213842,
                                    22.599288
                                ],
                                [
                                    114.214031,
                                    22.598876
                                ],
                                [
                                    114.214085,
                                    22.59829
                                ],
                                [
                                    114.213704,
                                    22.596583
                                ],
                                [
                                    114.213677,
                                    22.59607
                                ],
                                [
                                    114.215775,
                                    22.593767
                                ],
                                [
                                    114.216158,
                                    22.593137
                                ],
                                [
                                    114.216721,
                                    22.59246
                                ],
                                [
                                    114.217485,
                                    22.591033
                                ],
                                [
                                    114.217635,
                                    22.590298
                                ],
                                [
                                    114.217754,
                                    22.590079
                                ],
                                [
                                    114.218556,
                                    22.589512
                                ],
                                [
                                    114.219021,
                                    22.588915
                                ],
                                [
                                    114.219105,
                                    22.588596
                                ],
                                [
                                    114.219037,
                                    22.587972
                                ],
                                [
                                    114.219352,
                                    22.585877
                                ],
                                [
                                    114.219593,
                                    22.585003
                                ],
                                [
                                    114.219527,
                                    22.58458
                                ],
                                [
                                    114.218891,
                                    22.583076
                                ],
                                [
                                    114.218763,
                                    22.581919
                                ],
                                [
                                    114.218845,
                                    22.581043
                                ],
                                [
                                    114.218854,
                                    22.580966
                                ],
                                [
                                    114.218893,
                                    22.580599
                                ],
                                [
                                    114.218907,
                                    22.580476
                                ],
                                [
                                    114.218921,
                                    22.580341
                                ],
                                [
                                    114.218924,
                                    22.580327
                                ],
                                [
                                    114.218929,
                                    22.580289
                                ],
                                [
                                    114.21895,
                                    22.580217
                                ],
                                [
                                    114.219004,
                                    22.580125
                                ],
                                [
                                    114.219105,
                                    22.579931
                                ],
                                [
                                    114.219143,
                                    22.579845
                                ],
                                [
                                    114.219192,
                                    22.579787
                                ],
                                [
                                    114.219312,
                                    22.579625
                                ],
                                [
                                    114.219433,
                                    22.579473
                                ],
                                [
                                    114.219506,
                                    22.579339
                                ],
                                [
                                    114.219574,
                                    22.579246
                                ],
                                [
                                    114.219615,
                                    22.579142
                                ],
                                [
                                    114.219677,
                                    22.578972
                                ],
                                [
                                    114.219685,
                                    22.578909
                                ],
                                [
                                    114.21977,
                                    22.578649
                                ],
                                [
                                    114.219906,
                                    22.57831
                                ],
                                [
                                    114.21997,
                                    22.578174
                                ],
                                [
                                    114.220004,
                                    22.577996
                                ],
                                [
                                    114.220011,
                                    22.577863
                                ],
                                [
                                    114.220006,
                                    22.577782
                                ],
                                [
                                    114.219971,
                                    22.577686
                                ],
                                [
                                    114.219919,
                                    22.577606
                                ],
                                [
                                    114.219824,
                                    22.577488
                                ],
                                [
                                    114.219743,
                                    22.577401
                                ],
                                [
                                    114.219606,
                                    22.577311
                                ],
                                [
                                    114.219482,
                                    22.577216
                                ],
                                [
                                    114.219275,
                                    22.577084
                                ],
                                [
                                    114.219048,
                                    22.576943
                                ],
                                [
                                    114.21892,
                                    22.576857
                                ],
                                [
                                    114.218743,
                                    22.576737
                                ],
                                [
                                    114.218563,
                                    22.576617
                                ],
                                [
                                    114.2185,
                                    22.576548
                                ],
                                [
                                    114.218434,
                                    22.57645
                                ],
                                [
                                    114.21815,
                                    22.57608
                                ],
                                [
                                    114.217947,
                                    22.575801
                                ],
                                [
                                    114.217677,
                                    22.575486
                                ],
                                [
                                    114.217657,
                                    22.575451
                                ],
                                [
                                    114.217579,
                                    22.575333
                                ],
                                [
                                    114.217519,
                                    22.575269
                                ],
                                [
                                    114.217434,
                                    22.575164
                                ],
                                [
                                    114.217332,
                                    22.575083
                                ],
                                [
                                    114.217263,
                                    22.575032
                                ],
                                [
                                    114.217172,
                                    22.575006
                                ],
                                [
                                    114.215717,
                                    22.57436
                                ],
                                [
                                    114.215487,
                                    22.57425
                                ],
                                [
                                    114.215114,
                                    22.57412
                                ],
                                [
                                    114.214703,
                                    22.574005
                                ],
                                [
                                    114.214006,
                                    22.573861
                                ],
                                [
                                    114.213927,
                                    22.57386
                                ],
                                [
                                    114.213691,
                                    22.573858
                                ],
                                [
                                    114.213578,
                                    22.573868
                                ],
                                [
                                    114.213208,
                                    22.5739
                                ],
                                [
                                    114.213044,
                                    22.57392
                                ],
                                [
                                    114.212851,
                                    22.573924
                                ],
                                [
                                    114.212531,
                                    22.573916
                                ],
                                [
                                    114.21242,
                                    22.573912
                                ],
                                [
                                    114.212315,
                                    22.57389
                                ],
                                [
                                    114.21218,
                                    22.573881
                                ],
                                [
                                    114.212025,
                                    22.573863
                                ],
                                [
                                    114.211861,
                                    22.573843
                                ],
                                [
                                    114.211728,
                                    22.57382
                                ],
                                [
                                    114.211613,
                                    22.573798
                                ],
                                [
                                    114.211474,
                                    22.573757
                                ],
                                [
                                    114.21134,
                                    22.573722
                                ],
                                [
                                    114.21115,
                                    22.573678
                                ],
                                [
                                    114.210974,
                                    22.57363
                                ],
                                [
                                    114.210726,
                                    22.573565
                                ],
                                [
                                    114.210551,
                                    22.573517
                                ],
                                [
                                    114.210444,
                                    22.573486
                                ],
                                [
                                    114.210394,
                                    22.573447
                                ],
                                [
                                    114.210304,
                                    22.573396
                                ],
                                [
                                    114.208112,
                                    22.572756
                                ],
                                [
                                    114.208053,
                                    22.572771
                                ],
                                [
                                    114.208019,
                                    22.572761
                                ],
                                [
                                    114.20785,
                                    22.572709
                                ],
                                [
                                    114.207699,
                                    22.57265
                                ],
                                [
                                    114.207515,
                                    22.572575
                                ],
                                [
                                    114.207469,
                                    22.572541
                                ],
                                [
                                    114.207406,
                                    22.572495
                                ],
                                [
                                    114.20733,
                                    22.572442
                                ],
                                [
                                    114.207236,
                                    22.572363
                                ],
                                [
                                    114.207125,
                                    22.572287
                                ],
                                [
                                    114.206886,
                                    22.572112
                                ],
                                [
                                    114.20677,
                                    22.572024
                                ],
                                [
                                    114.206701,
                                    22.57196
                                ],
                                [
                                    114.206544,
                                    22.571811
                                ],
                                [
                                    114.206268,
                                    22.571552
                                ],
                                [
                                    114.206081,
                                    22.571364
                                ],
                                [
                                    114.205976,
                                    22.571265
                                ],
                                [
                                    114.205833,
                                    22.571132
                                ],
                                [
                                    114.205621,
                                    22.570991
                                ],
                                [
                                    114.205471,
                                    22.570898
                                ],
                                [
                                    114.205326,
                                    22.570794
                                ],
                                [
                                    114.205056,
                                    22.570621
                                ],
                                [
                                    114.204811,
                                    22.570497
                                ],
                                [
                                    114.204567,
                                    22.570372
                                ],
                                [
                                    114.204187,
                                    22.570192
                                ],
                                [
                                    114.203832,
                                    22.570001
                                ],
                                [
                                    114.203761,
                                    22.569949
                                ],
                                [
                                    114.203461,
                                    22.569306
                                ],
                                [
                                    114.203444,
                                    22.569249
                                ],
                                [
                                    114.203442,
                                    22.569179
                                ],
                                [
                                    114.203445,
                                    22.569021
                                ],
                                [
                                    114.203476,
                                    22.568839
                                ],
                                [
                                    114.203532,
                                    22.568614
                                ],
                                [
                                    114.203606,
                                    22.568371
                                ],
                                [
                                    114.203673,
                                    22.568165
                                ],
                                [
                                    114.203785,
                                    22.567846
                                ],
                                [
                                    114.203871,
                                    22.567678
                                ],
                                [
                                    114.20405,
                                    22.567334
                                ],
                                [
                                    114.204124,
                                    22.567195
                                ],
                                [
                                    114.204306,
                                    22.566849
                                ],
                                [
                                    114.204382,
                                    22.56671
                                ],
                                [
                                    114.204441,
                                    22.566591
                                ],
                                [
                                    114.204536,
                                    22.566448
                                ],
                                [
                                    114.204662,
                                    22.566261
                                ],
                                [
                                    114.204751,
                                    22.566134
                                ],
                                [
                                    114.204816,
                                    22.566015
                                ],
                                [
                                    114.204968,
                                    22.565799
                                ],
                                [
                                    114.205097,
                                    22.565611
                                ],
                                [
                                    114.205259,
                                    22.565368
                                ],
                                [
                                    114.205332,
                                    22.565266
                                ],
                                [
                                    114.205414,
                                    22.565138
                                ],
                                [
                                    114.205459,
                                    22.565042
                                ],
                                [
                                    114.205512,
                                    22.564925
                                ],
                                [
                                    114.205581,
                                    22.564764
                                ],
                                [
                                    114.205693,
                                    22.564543
                                ],
                                [
                                    114.205744,
                                    22.564435
                                ],
                                [
                                    114.205817,
                                    22.564258
                                ],
                                [
                                    114.205967,
                                    22.563971
                                ],
                                [
                                    114.206111,
                                    22.563694
                                ],
                                [
                                    114.206221,
                                    22.563493
                                ],
                                [
                                    114.206356,
                                    22.563258
                                ],
                                [
                                    114.206472,
                                    22.563041
                                ],
                                [
                                    114.206632,
                                    22.562762
                                ],
                                [
                                    114.206716,
                                    22.562605
                                ],
                                [
                                    114.20691,
                                    22.562277
                                ],
                                [
                                    114.206999,
                                    22.56212
                                ],
                                [
                                    114.207064,
                                    22.562024
                                ],
                                [
                                    114.207089,
                                    22.561944
                                ],
                                [
                                    114.20718,
                                    22.561643
                                ],
                                [
                                    114.207256,
                                    22.561409
                                ],
                                [
                                    114.20728,
                                    22.561283
                                ],
                                [
                                    114.207301,
                                    22.561166
                                ],
                                [
                                    114.207337,
                                    22.560946
                                ],
                                [
                                    114.207352,
                                    22.560862
                                ],
                                [
                                    114.207344,
                                    22.56079
                                ],
                                [
                                    114.207331,
                                    22.560682
                                ],
                                [
                                    114.207298,
                                    22.560464
                                ],
                                [
                                    114.207269,
                                    22.560333
                                ],
                                [
                                    114.207225,
                                    22.560206
                                ],
                                [
                                    114.207172,
                                    22.560063
                                ],
                                [
                                    114.207141,
                                    22.559953
                                ],
                                [
                                    114.207116,
                                    22.559871
                                ],
                                [
                                    114.207051,
                                    22.559732
                                ],
                                [
                                    114.207001,
                                    22.559628
                                ],
                                [
                                    114.206942,
                                    22.559507
                                ],
                                [
                                    114.206865,
                                    22.559404
                                ],
                                [
                                    114.20676,
                                    22.559265
                                ],
                                [
                                    114.206632,
                                    22.559091
                                ],
                                [
                                    114.206466,
                                    22.558856
                                ],
                                [
                                    114.206313,
                                    22.558653
                                ],
                                [
                                    114.206225,
                                    22.558534
                                ],
                                [
                                    114.206185,
                                    22.558482
                                ],
                                [
                                    114.206066,
                                    22.558385
                                ],
                                [
                                    114.205817,
                                    22.558181
                                ],
                                [
                                    114.20558,
                                    22.557978
                                ],
                                [
                                    114.205377,
                                    22.557815
                                ],
                                [
                                    114.205312,
                                    22.557753
                                ],
                                [
                                    114.205149,
                                    22.557572
                                ],
                                [
                                    114.204992,
                                    22.557407
                                ],
                                [
                                    114.204927,
                                    22.557347
                                ],
                                [
                                    114.204789,
                                    22.557201
                                ],
                                [
                                    114.204688,
                                    22.55708
                                ],
                                [
                                    114.20452,
                                    22.556892
                                ],
                                [
                                    114.204358,
                                    22.556698
                                ],
                                [
                                    114.204279,
                                    22.556606
                                ],
                                [
                                    114.204226,
                                    22.556558
                                ],
                                [
                                    114.204161,
                                    22.556523
                                ],
                                [
                                    114.203951,
                                    22.556407
                                ],
                                [
                                    114.203665,
                                    22.55627
                                ],
                                [
                                    114.203537,
                                    22.5562
                                ],
                                [
                                    114.203441,
                                    22.556149
                                ],
                                [
                                    114.203402,
                                    22.556119
                                ],
                                [
                                    114.203367,
                                    22.556053
                                ],
                                [
                                    114.20329,
                                    22.55595
                                ],
                                [
                                    114.203231,
                                    22.555863
                                ],
                                [
                                    114.203207,
                                    22.555813
                                ],
                                [
                                    114.203183,
                                    22.555711
                                ],
                                [
                                    114.203145,
                                    22.555571
                                ],
                                [
                                    114.203136,
                                    22.555519
                                ],
                                [
                                    114.203147,
                                    22.555413
                                ],
                                [
                                    114.203177,
                                    22.55531
                                ],
                                [
                                    114.202883,
                                    22.5539
                                ],
                                [
                                    114.202754,
                                    22.553899
                                ],
                                [
                                    114.202521,
                                    22.55398
                                ],
                                [
                                    114.202209,
                                    22.554141
                                ],
                                [
                                    114.201941,
                                    22.554291
                                ],
                                [
                                    114.201733,
                                    22.55435
                                ],
                                [
                                    114.201586,
                                    22.554361
                                ],
                                [
                                    114.201456,
                                    22.554324
                                ],
                                [
                                    114.201352,
                                    22.554255
                                ],
                                [
                                    114.201248,
                                    22.554108
                                ],
                                [
                                    114.200893,
                                    22.553498
                                ],
                                [
                                    114.200711,
                                    22.553288
                                ],
                                [
                                    114.200521,
                                    22.553139
                                ],
                                [
                                    114.200295,
                                    22.553028
                                ],
                                [
                                    114.20007,
                                    22.55294
                                ],
                                [
                                    114.199386,
                                    22.552822
                                ],
                                [
                                    114.198875,
                                    22.552796
                                ],
                                [
                                    114.198494,
                                    22.552816
                                ],
                                [
                                    114.197897,
                                    22.552928
                                ],
                                [
                                    114.197447,
                                    22.55299
                                ],
                                [
                                    114.19723,
                                    22.553007
                                ],
                                [
                                    114.197048,
                                    22.552973
                                ],
                                [
                                    114.196823,
                                    22.552884
                                ],
                                [
                                    114.196277,
                                    22.552449
                                ],
                                [
                                    114.195706,
                                    22.551958
                                ],
                                [
                                    114.195507,
                                    22.551813
                                ],
                                [
                                    114.195212,
                                    22.551704
                                ],
                                [
                                    114.194745,
                                    22.551606
                                ],
                                [
                                    114.194537,
                                    22.551586
                                ],
                                [
                                    114.194329,
                                    22.551604
                                ],
                                [
                                    114.194139,
                                    22.551643
                                ],
                                [
                                    114.194009,
                                    22.551722
                                ],
                                [
                                    114.193767,
                                    22.551926
                                ],
                                [
                                    114.193368,
                                    22.552337
                                ],
                                [
                                    114.193109,
                                    22.552618
                                ],
                                [
                                    114.19297,
                                    22.552681
                                ],
                                [
                                    114.192814,
                                    22.552705
                                ],
                                [
                                    114.192641,
                                    22.552692
                                ],
                                [
                                    114.192468,
                                    22.552625
                                ],
                                [
                                    114.192252,
                                    22.5524
                                ],
                                [
                                    114.191966,
                                    22.552108
                                ],
                                [
                                    114.191836,
                                    22.552016
                                ],
                                [
                                    114.191715,
                                    22.551971
                                ],
                                [
                                    114.191585,
                                    22.551952
                                ],
                                [
                                    114.191438,
                                    22.551946
                                ],
                                [
                                    114.191152,
                                    22.551985
                                ],
                                [
                                    114.189139,
                                    22.552416
                                ],
                                [
                                    114.188649,
                                    22.552449
                                ],
                                [
                                    114.187848,
                                    22.552506
                                ],
                                [
                                    114.186797,
                                    22.552674
                                ],
                                [
                                    114.186595,
                                    22.552588
                                ],
                                [
                                    114.186408,
                                    22.552367
                                ],
                                [
                                    114.186202,
                                    22.552013
                                ],
                                [
                                    114.186112,
                                    22.551754
                                ],
                                [
                                    114.18613,
                                    22.551447
                                ],
                                [
                                    114.185995,
                                    22.551331
                                ],
                                [
                                    114.185918,
                                    22.551318
                                ],
                                [
                                    114.185666,
                                    22.551454
                                ],
                                [
                                    114.185301,
                                    22.551711
                                ],
                                [
                                    114.184492,
                                    22.552141
                                ],
                                [
                                    114.18271,
                                    22.552801
                                ],
                                [
                                    114.182626,
                                    22.552918
                                ],
                                [
                                    114.182754,
                                    22.553378
                                ],
                                [
                                    114.182578,
                                    22.554804
                                ],
                                [
                                    114.182573,
                                    22.555331
                                ],
                                [
                                    114.182426,
                                    22.556155
                                ],
                                [
                                    114.18232,
                                    22.556777
                                ],
                                [
                                    114.182161,
                                    22.556946
                                ],
                                [
                                    114.180945,
                                    22.557268
                                ],
                                [
                                    114.180688,
                                    22.557212
                                ],
                                [
                                    114.180412,
                                    22.557245
                                ],
                                [
                                    114.179739,
                                    22.557245
                                ],
                                [
                                    114.179168,
                                    22.557044
                                ],
                                [
                                    114.178236,
                                    22.556842
                                ],
                                [
                                    114.17726,
                                    22.556905
                                ],
                                [
                                    114.175509,
                                    22.556898
                                ],
                                [
                                    114.175138,
                                    22.557122
                                ],
                                [
                                    114.174783,
                                    22.557436
                                ],
                                [
                                    114.174439,
                                    22.55805
                                ],
                                [
                                    114.174222,
                                    22.558222
                                ],
                                [
                                    114.173964,
                                    22.558376
                                ],
                                [
                                    114.173687,
                                    22.558451
                                ],
                                [
                                    114.173305,
                                    22.558488
                                ],
                                [
                                    114.1728,
                                    22.558514
                                ],
                                [
                                    114.172317,
                                    22.558465
                                ],
                                [
                                    114.171984,
                                    22.55826
                                ],
                                [
                                    114.17158,
                                    22.557871
                                ],
                                [
                                    114.170993,
                                    22.557148
                                ],
                                [
                                    114.170581,
                                    22.556718
                                ],
                                [
                                    114.170035,
                                    22.556441
                                ],
                                [
                                    114.169522,
                                    22.55634
                                ],
                                [
                                    114.168954,
                                    22.556373
                                ],
                                [
                                    114.168534,
                                    22.556422
                                ],
                                [
                                    114.16819,
                                    22.556575
                                ],
                                [
                                    114.168033,
                                    22.557009
                                ],
                                [
                                    114.167872,
                                    22.557163
                                ],
                                [
                                    114.167412,
                                    22.55827
                                ],
                                [
                                    114.167094,
                                    22.558775
                                ],
                                [
                                    114.166675,
                                    22.559093
                                ],
                                [
                                    114.166436,
                                    22.559157
                                ],
                                [
                                    114.166078,
                                    22.559117
                                ],
                                [
                                    114.165592,
                                    22.558891
                                ],
                                [
                                    114.164436,
                                    22.557572
                                ],
                                [
                                    114.164003,
                                    22.556773
                                ],
                                [
                                    114.16342,
                                    22.556178
                                ],
                                [
                                    114.162237,
                                    22.554049
                                ],
                                [
                                    114.161077,
                                    22.552626
                                ],
                                [
                                    114.160765,
                                    22.552309
                                ],
                                [
                                    114.160592,
                                    22.552203
                                ],
                                [
                                    114.160445,
                                    22.552134
                                ],
                                [
                                    114.160176,
                                    22.552056
                                ],
                                [
                                    114.159925,
                                    22.552031
                                ],
                                [
                                    114.158349,
                                    22.552083
                                ],
                                [
                                    114.157674,
                                    22.552074
                                ],
                                [
                                    114.15738,
                                    22.552016
                                ],
                                [
                                    114.157155,
                                    22.551944
                                ],
                                [
                                    114.157008,
                                    22.551819
                                ],
                                [
                                    114.156877,
                                    22.551621
                                ],
                                [
                                    114.156774,
                                    22.551233
                                ],
                                [
                                    114.156739,
                                    22.550866
                                ],
                                [
                                    114.156782,
                                    22.54982
                                ],
                                [
                                    114.156774,
                                    22.549423
                                ],
                                [
                                    114.156722,
                                    22.548961
                                ],
                                [
                                    114.156653,
                                    22.548735
                                ],
                                [
                                    114.156583,
                                    22.548597
                                ],
                                [
                                    114.156401,
                                    22.548399
                                ],
                                [
                                    114.156185,
                                    22.548241
                                ],
                                [
                                    114.15602,
                                    22.548146
                                ],
                                [
                                    114.155787,
                                    22.548121
                                ],
                                [
                                    114.155466,
                                    22.548121
                                ],
                                [
                                    114.155293,
                                    22.548108
                                ],
                                [
                                    114.155154,
                                    22.548056
                                ],
                                [
                                    114.155076,
                                    22.548007
                                ],
                                [
                                    114.154999,
                                    22.547857
                                ],
                                [
                                    114.154895,
                                    22.547545
                                ],
                                [
                                    114.154817,
                                    22.5471
                                ],
                                [
                                    114.154747,
                                    22.54662
                                ],
                                [
                                    114.154652,
                                    22.546297
                                ],
                                [
                                    114.154618,
                                    22.546112
                                ],
                                [
                                    114.154609,
                                    22.545928
                                ],
                                [
                                    114.154643,
                                    22.545405
                                ],
                                [
                                    114.154704,
                                    22.544741
                                ],
                                [
                                    114.154764,
                                    22.544567
                                ],
                                [
                                    114.154834,
                                    22.544469
                                ],
                                [
                                    114.154972,
                                    22.544406
                                ],
                                [
                                    114.155345,
                                    22.544295
                                ],
                                [
                                    114.155829,
                                    22.544214
                                ],
                                [
                                    114.156046,
                                    22.544248
                                ],
                                [
                                    114.156098,
                                    22.544294
                                ],
                                [
                                    114.156089,
                                    22.544391
                                ],
                                [
                                    114.155951,
                                    22.544676
                                ],
                                [
                                    114.15583,
                                    22.544969
                                ],
                                [
                                    114.155856,
                                    22.545138
                                ],
                                [
                                    114.155959,
                                    22.545275
                                ],
                                [
                                    114.156167,
                                    22.545326
                                ],
                                [
                                    114.156418,
                                    22.545298
                                ],
                                [
                                    114.156617,
                                    22.545182
                                ],
                                [
                                    114.156721,
                                    22.544985
                                ],
                                [
                                    114.156773,
                                    22.544477
                                ],
                                [
                                    114.156721,
                                    22.543976
                                ],
                                [
                                    114.156661,
                                    22.543813
                                ],
                                [
                                    114.156505,
                                    22.543694
                                ],
                                [
                                    114.156029,
                                    22.543601
                                ],
                                [
                                    114.155535,
                                    22.543479
                                ],
                                [
                                    114.155301,
                                    22.543331
                                ],
                                [
                                    114.154712,
                                    22.542658
                                ],
                                [
                                    114.153751,
                                    22.541618
                                ],
                                [
                                    114.153474,
                                    22.541305
                                ],
                                [
                                    114.15331,
                                    22.540932
                                ],
                                [
                                    114.153223,
                                    22.540692
                                ],
                                [
                                    114.153206,
                                    22.540501
                                ],
                                [
                                    114.153257,
                                    22.540199
                                ],
                                [
                                    114.153483,
                                    22.539684
                                ],
                                [
                                    114.153543,
                                    22.539549
                                ],
                                [
                                    114.153526,
                                    22.539406
                                ],
                                [
                                    114.153491,
                                    22.539294
                                ],
                                [
                                    114.153387,
                                    22.539217
                                ],
                                [
                                    114.153136,
                                    22.539114
                                ],
                                [
                                    114.152089,
                                    22.538875
                                ],
                                [
                                    114.151093,
                                    22.538672
                                ],
                                [
                                    114.150495,
                                    22.538521
                                ],
                                [
                                    114.150131,
                                    22.538483
                                ],
                                [
                                    114.149889,
                                    22.538487
                                ],
                                [
                                    114.149733,
                                    22.538509
                                ],
                                [
                                    114.149647,
                                    22.538571
                                ],
                                [
                                    114.149595,
                                    22.538668
                                ],
                                [
                                    114.149482,
                                    22.538983
                                ],
                                [
                                    114.149387,
                                    22.539159
                                ],
                                [
                                    114.149257,
                                    22.539268
                                ],
                                [
                                    114.149162,
                                    22.539301
                                ],
                                [
                                    114.148893,
                                    22.53929
                                ],
                                [
                                    114.148642,
                                    22.539273
                                ],
                                [
                                    114.148452,
                                    22.539284
                                ],
                                [
                                    114.148183,
                                    22.539354
                                ],
                                [
                                    114.148044,
                                    22.539385
                                ],
                                [
                                    114.147897,
                                    22.539402
                                ],
                                [
                                    114.147768,
                                    22.539403
                                ],
                                [
                                    114.147612,
                                    22.539386
                                ],
                                [
                                    114.147421,
                                    22.539338
                                ],
                                [
                                    114.147274,
                                    22.539308
                                ],
                                [
                                    114.147118,
                                    22.539319
                                ],
                                [
                                    114.147023,
                                    22.539367
                                ],
                                [
                                    114.146936,
                                    22.539439
                                ],
                                [
                                    114.14685,
                                    22.539543
                                ],
                                [
                                    114.146711,
                                    22.539734
                                ],
                                [
                                    114.146676,
                                    22.539784
                                ],
                                [
                                    114.146529,
                                    22.539941
                                ],
                                [
                                    114.146399,
                                    22.540034
                                ],
                                [
                                    114.146252,
                                    22.540084
                                ],
                                [
                                    114.146036,
                                    22.5401
                                ],
                                [
                                    114.145741,
                                    22.540098
                                ],
                                [
                                    114.145455,
                                    22.540079
                                ],
                                [
                                    114.145169,
                                    22.540116
                                ],
                                [
                                    114.14491,
                                    22.540171
                                ],
                                [
                                    114.144373,
                                    22.540423
                                ],
                                [
                                    114.143888,
                                    22.540628
                                ],
                                [
                                    114.143489,
                                    22.540729
                                ],
                                [
                                    114.143022,
                                    22.540777
                                ],
                                [
                                    114.142511,
                                    22.540736
                                ],
                                [
                                    114.14206,
                                    22.540594
                                ],
                                [
                                    114.141627,
                                    22.540341
                                ],
                                [
                                    114.141012,
                                    22.539884
                                ],
                                [
                                    114.140241,
                                    22.53924
                                ],
                                [
                                    114.139808,
                                    22.538958
                                ],
                                [
                                    114.139401,
                                    22.538809
                                ],
                                [
                                    114.138908,
                                    22.538751
                                ],
                                [
                                    114.138353,
                                    22.538763
                                ],
                                [
                                    114.138084,
                                    22.538828
                                ],
                                [
                                    114.137461,
                                    22.538998
                                ],
                                [
                                    114.136759,
                                    22.539158
                                ],
                                [
                                    114.136335,
                                    22.539189
                                ],
                                [
                                    114.135893,
                                    22.539159
                                ],
                                [
                                    114.135503,
                                    22.539071
                                ],
                                [
                                    114.135104,
                                    22.538847
                                ],
                                [
                                    114.134698,
                                    22.538373
                                ],
                                [
                                    114.134221,
                                    22.537748
                                ],
                                [
                                    114.13377,
                                    22.537351
                                ],
                                [
                                    114.13338,
                                    22.537102
                                ],
                                [
                                    114.133025,
                                    22.536975
                                ],
                                [
                                    114.132661,
                                    22.536895
                                ],
                                [
                                    114.132326,
                                    22.53691
                                ],
                                [
                                    114.13222,
                                    22.536914
                                ],
                                [
                                    114.132064,
                                    22.536921
                                ],
                                [
                                    114.131492,
                                    22.537042
                                ],
                                [
                                    114.131059,
                                    22.537111
                                ],
                                [
                                    114.13079,
                                    22.537081
                                ],
                                [
                                    114.130478,
                                    22.537002
                                ],
                                [
                                    114.128736,
                                    22.536122
                                ],
                                [
                                    114.128095,
                                    22.535754
                                ],
                                [
                                    114.127567,
                                    22.535368
                                ],
                                [
                                    114.127124,
                                    22.534913
                                ],
                                [
                                    114.126587,
                                    22.534249
                                ],
                                [
                                    114.126206,
                                    22.533718
                                ],
                                [
                                    114.125616,
                                    22.532776
                                ],
                                [
                                    114.125357,
                                    22.532438
                                ],
                                [
                                    114.125062,
                                    22.532211
                                ],
                                [
                                    114.124698,
                                    22.532072
                                ],
                                [
                                    114.124169,
                                    22.531944
                                ],
                                [
                                    114.122549,
                                    22.531614
                                ],
                                [
                                    114.122072,
                                    22.531494
                                ],
                                [
                                    114.121725,
                                    22.531306
                                ],
                                [
                                    114.1215,
                                    22.531067
                                ],
                                [
                                    114.121326,
                                    22.530651
                                ],
                                [
                                    114.121257,
                                    22.530145
                                ],
                                [
                                    114.121214,
                                    22.529679
                                ],
                                [
                                    114.121006,
                                    22.529141
                                ],
                                [
                                    114.120962,
                                    22.529054
                                ],
                                [
                                    114.120694,
                                    22.528637
                                ],
                                [
                                    114.120494,
                                    22.528418
                                ],
                                [
                                    114.120226,
                                    22.528232
                                ],
                                [
                                    114.119567,
                                    22.527885
                                ],
                                [
                                    114.118752,
                                    22.527477
                                ],
                                [
                                    114.11818,
                                    22.52722
                                ],
                                [
                                    114.117608,
                                    22.526977
                                ],
                                [
                                    114.117274,
                                    22.526936
                                ],
                                [
                                    114.116713,
                                    22.527048
                                ],
                                [
                                    114.115635,
                                    22.52732
                                ],
                                [
                                    114.115032,
                                    22.52772
                                ],
                                [
                                    114.114737,
                                    22.528107
                                ],
                                [
                                    114.114591,
                                    22.528608
                                ],
                                [
                                    114.114601,
                                    22.529181
                                ],
                                [
                                    114.114649,
                                    22.530064
                                ],
                                [
                                    114.114768,
                                    22.531119
                                ],
                                [
                                    114.114823,
                                    22.532189
                                ],
                                [
                                    114.114842,
                                    22.532803
                                ],
                                [
                                    114.11463,
                                    22.533483
                                ],
                                [
                                    114.114268,
                                    22.533793
                                ],
                                [
                                    114.113769,
                                    22.533842
                                ],
                                [
                                    114.113372,
                                    22.53358
                                ],
                                [
                                    114.113054,
                                    22.532564
                                ],
                                [
                                    114.112716,
                                    22.532019
                                ],
                                [
                                    114.112211,
                                    22.531685
                                ],
                                [
                                    114.111554,
                                    22.531592
                                ],
                                [
                                    114.110922,
                                    22.531717
                                ],
                                [
                                    114.109584,
                                    22.532263
                                ],
                                [
                                    114.108715,
                                    22.532395
                                ],
                                [
                                    114.107912,
                                    22.532324
                                ],
                                [
                                    114.107577,
                                    22.532253
                                ],
                                [
                                    114.106988,
                                    22.532069
                                ],
                                [
                                    114.105943,
                                    22.531799
                                ],
                                [
                                    114.105177,
                                    22.531626
                                ]
                            ]
                        ]
                    },
                    "properties": {
                        "name": "罗湖区",
                        "cp": [
                            114.123885,
                            22.555341
                        ]
                    }
                },
                {
                    "type": "Feature",
                    "id": "440306",
                    "geometry": {
                        "type": "MultiPolygon",
                        "coordinates": [
                            [
                                [
                                    [
                                        113.823338,
                                        22.543809
                                    ],
                                    [
                                        113.823183,
                                        22.543825
                                    ],
                                    [
                                        113.823087,
                                        22.543947
                                    ],
                                    [
                                        113.823053,
                                        22.544077
                                    ],
                                    [
                                        113.823044,
                                        22.544266
                                    ],
                                    [
                                        113.823087,
                                        22.544361
                                    ],
                                    [
                                        113.823165,
                                        22.544433
                                    ],
                                    [
                                        113.823364,
                                        22.544532
                                    ],
                                    [
                                        113.824022,
                                        22.544746
                                    ],
                                    [
                                        113.824308,
                                        22.544851
                                    ],
                                    [
                                        113.824516,
                                        22.544845
                                    ],
                                    [
                                        113.824628,
                                        22.544825
                                    ],
                                    [
                                        113.824758,
                                        22.544703
                                    ],
                                    [
                                        113.82481,
                                        22.544477
                                    ],
                                    [
                                        113.824793,
                                        22.544304
                                    ],
                                    [
                                        113.824749,
                                        22.544195
                                    ],
                                    [
                                        113.824689,
                                        22.544117
                                    ],
                                    [
                                        113.824498,
                                        22.544027
                                    ],
                                    [
                                        113.823338,
                                        22.543809
                                    ]
                                ]
                            ],
                            [
                                [
                                    [
                                        113.751453,
                                        22.715403
                                    ],
                                    [
                                        113.762394,
                                        22.736873
                                    ],
                                    [
                                        113.769371,
                                        22.742042
                                    ],
                                    [
                                        113.775799,
                                        22.746051
                                    ],
                                    [
                                        113.778183,
                                        22.747171
                                    ],
                                    [
                                        113.780662,
                                        22.748488
                                    ],
                                    [
                                        113.78699,
                                        22.750586
                                    ],
                                    [
                                        113.789026,
                                        22.751772
                                    ],
                                    [
                                        113.79083,
                                        22.753397
                                    ],
                                    [
                                        113.792659,
                                        22.75608
                                    ],
                                    [
                                        113.793548,
                                        22.757874
                                    ],
                                    [
                                        113.793961,
                                        22.760301
                                    ],
                                    [
                                        113.794167,
                                        22.762212
                                    ],
                                    [
                                        113.793704,
                                        22.764899
                                    ],
                                    [
                                        113.79248,
                                        22.766592
                                    ],
                                    [
                                        113.791861,
                                        22.767651
                                    ],
                                    [
                                        113.791862,
                                        22.768917
                                    ],
                                    [
                                        113.792429,
                                        22.770492
                                    ],
                                    [
                                        113.793537,
                                        22.771782
                                    ],
                                    [
                                        113.795134,
                                        22.773303
                                    ],
                                    [
                                        113.796603,
                                        22.774205
                                    ],
                                    [
                                        113.798136,
                                        22.774681
                                    ],
                                    [
                                        113.799733,
                                        22.775066
                                    ],
                                    [
                                        113.80066,
                                        22.775581
                                    ],
                                    [
                                        113.801433,
                                        22.776329
                                    ],
                                    [
                                        113.801845,
                                        22.777129
                                    ],
                                    [
                                        113.801974,
                                        22.777929
                                    ],
                                    [
                                        113.801871,
                                        22.778833
                                    ],
                                    [
                                        113.801588,
                                        22.779815
                                    ],
                                    [
                                        113.800764,
                                        22.780901
                                    ],
                                    [
                                        113.800197,
                                        22.781832
                                    ],
                                    [
                                        113.800017,
                                        22.782581
                                    ],
                                    [
                                        113.800069,
                                        22.783149
                                    ],
                                    [
                                        113.800352,
                                        22.783743
                                    ],
                                    [
                                        113.80097,
                                        22.784362
                                    ],
                                    [
                                        113.802258,
                                        22.784876
                                    ],
                                    [
                                        113.802876,
                                        22.784979
                                    ],
                                    [
                                        113.803546,
                                        22.784874
                                    ],
                                    [
                                        113.804241,
                                        22.784486
                                    ],
                                    [
                                        113.805169,
                                        22.783554
                                    ],
                                    [
                                        113.80589,
                                        22.782598
                                    ],
                                    [
                                        113.806302,
                                        22.782287
                                    ],
                                    [
                                        113.806868,
                                        22.78208
                                    ],
                                    [
                                        113.807699,
                                        22.782033
                                    ],
                                    [
                                        113.809438,
                                        22.782128
                                    ],
                                    [
                                        113.810086,
                                        22.782191
                                    ],
                                    [
                                        113.810551,
                                        22.782282
                                    ],
                                    [
                                        113.811038,
                                        22.782495
                                    ],
                                    [
                                        113.812464,
                                        22.783349
                                    ],
                                    [
                                        113.813719,
                                        22.784251
                                    ],
                                    [
                                        113.814428,
                                        22.785186
                                    ],
                                    [
                                        113.814653,
                                        22.78596
                                    ],
                                    [
                                        113.814363,
                                        22.786735
                                    ],
                                    [
                                        113.813237,
                                        22.788125
                                    ],
                                    [
                                        113.812979,
                                        22.789062
                                    ],
                                    [
                                        113.81343,
                                        22.790417
                                    ],
                                    [
                                        113.814782,
                                        22.791739
                                    ],
                                    [
                                        113.816392,
                                        22.792284
                                    ],
                                    [
                                        113.818933,
                                        22.792179
                                    ],
                                    [
                                        113.819649,
                                        22.792099
                                    ],
                                    [
                                        113.819992,
                                        22.792082
                                    ],
                                    [
                                        113.820454,
                                        22.792084
                                    ],
                                    [
                                        113.820844,
                                        22.792088
                                    ],
                                    [
                                        113.821262,
                                        22.79214
                                    ],
                                    [
                                        113.821503,
                                        22.792174
                                    ],
                                    [
                                        113.821823,
                                        22.792222
                                    ],
                                    [
                                        113.822071,
                                        22.792267
                                    ],
                                    [
                                        113.822663,
                                        22.792323
                                    ],
                                    [
                                        113.823231,
                                        22.792372
                                    ],
                                    [
                                        113.823748,
                                        22.792471
                                    ],
                                    [
                                        113.82423,
                                        22.792574
                                    ],
                                    [
                                        113.824494,
                                        22.792648
                                    ],
                                    [
                                        113.824643,
                                        22.792731
                                    ],
                                    [
                                        113.824868,
                                        22.792873
                                    ],
                                    [
                                        113.824913,
                                        22.792931
                                    ],
                                    [
                                        113.826884,
                                        22.794862
                                    ],
                                    [
                                        113.828142,
                                        22.795796
                                    ],
                                    [
                                        113.830938,
                                        22.798268
                                    ],
                                    [
                                        113.831466,
                                        22.798529
                                    ],
                                    [
                                        113.831658,
                                        22.798695
                                    ],
                                    [
                                        113.831865,
                                        22.79908
                                    ],
                                    [
                                        113.832017,
                                        22.799235
                                    ],
                                    [
                                        113.832139,
                                        22.799314
                                    ],
                                    [
                                        113.832534,
                                        22.799564
                                    ],
                                    [
                                        113.832933,
                                        22.799817
                                    ],
                                    [
                                        113.834172,
                                        22.799444
                                    ],
                                    [
                                        113.834232,
                                        22.799465
                                    ],
                                    [
                                        113.83471,
                                        22.799751
                                    ],
                                    [
                                        113.835672,
                                        22.800235
                                    ],
                                    [
                                        113.836524,
                                        22.800649
                                    ],
                                    [
                                        113.837014,
                                        22.800847
                                    ],
                                    [
                                        113.837172,
                                        22.800919
                                    ],
                                    [
                                        113.837232,
                                        22.80096
                                    ],
                                    [
                                        113.837282,
                                        22.801067
                                    ],
                                    [
                                        113.837496,
                                        22.801594
                                    ],
                                    [
                                        113.837699,
                                        22.80207
                                    ],
                                    [
                                        113.838055,
                                        22.802918
                                    ],
                                    [
                                        113.838254,
                                        22.803445
                                    ],
                                    [
                                        113.838537,
                                        22.80415
                                    ],
                                    [
                                        113.838652,
                                        22.804294
                                    ],
                                    [
                                        113.838867,
                                        22.804933
                                    ],
                                    [
                                        113.838874,
                                        22.804953
                                    ],
                                    [
                                        113.838864,
                                        22.80496
                                    ],
                                    [
                                        113.839551,
                                        22.806716
                                    ],
                                    [
                                        113.839871,
                                        22.807479
                                    ],
                                    [
                                        113.840047,
                                        22.808028
                                    ],
                                    [
                                        113.84015,
                                        22.808514
                                    ],
                                    [
                                        113.840184,
                                        22.808804
                                    ],
                                    [
                                        113.840227,
                                        22.809053
                                    ],
                                    [
                                        113.840266,
                                        22.809254
                                    ],
                                    [
                                        113.840286,
                                        22.809544
                                    ],
                                    [
                                        113.840293,
                                        22.809709
                                    ],
                                    [
                                        113.840293,
                                        22.809786
                                    ],
                                    [
                                        113.840094,
                                        22.810787
                                    ],
                                    [
                                        113.840088,
                                        22.810825
                                    ],
                                    [
                                        113.839873,
                                        22.811148
                                    ],
                                    [
                                        113.839653,
                                        22.811438
                                    ],
                                    [
                                        113.839582,
                                        22.811474
                                    ],
                                    [
                                        113.839366,
                                        22.811494
                                    ],
                                    [
                                        113.839344,
                                        22.811526
                                    ],
                                    [
                                        113.839234,
                                        22.811704
                                    ],
                                    [
                                        113.838773,
                                        22.811996
                                    ],
                                    [
                                        113.838584,
                                        22.813418
                                    ],
                                    [
                                        113.838723,
                                        22.814896
                                    ],
                                    [
                                        113.838795,
                                        22.816307
                                    ],
                                    [
                                        113.838722,
                                        22.816426
                                    ],
                                    [
                                        113.838657,
                                        22.816562
                                    ],
                                    [
                                        113.838641,
                                        22.816642
                                    ],
                                    [
                                        113.838644,
                                        22.816723
                                    ],
                                    [
                                        113.838694,
                                        22.816979
                                    ],
                                    [
                                        113.838847,
                                        22.817357
                                    ],
                                    [
                                        113.838589,
                                        22.818312
                                    ],
                                    [
                                        113.838451,
                                        22.818575
                                    ],
                                    [
                                        113.838384,
                                        22.818738
                                    ],
                                    [
                                        113.838351,
                                        22.818929
                                    ],
                                    [
                                        113.838351,
                                        22.819039
                                    ],
                                    [
                                        113.838357,
                                        22.819134
                                    ],
                                    [
                                        113.838384,
                                        22.81925
                                    ],
                                    [
                                        113.838471,
                                        22.819357
                                    ],
                                    [
                                        113.838581,
                                        22.81945
                                    ],
                                    [
                                        113.838664,
                                        22.819536
                                    ],
                                    [
                                        113.838718,
                                        22.819607
                                    ],
                                    [
                                        113.838724,
                                        22.819672
                                    ],
                                    [
                                        113.83867,
                                        22.819762
                                    ],
                                    [
                                        113.838521,
                                        22.819889
                                    ],
                                    [
                                        113.8384,
                                        22.819997
                                    ],
                                    [
                                        113.838306,
                                        22.820114
                                    ],
                                    [
                                        113.838108,
                                        22.820307
                                    ],
                                    [
                                        113.83672,
                                        22.821461
                                    ],
                                    [
                                        113.836401,
                                        22.821661
                                    ],
                                    [
                                        113.836048,
                                        22.821808
                                    ],
                                    [
                                        113.83541,
                                        22.821963
                                    ],
                                    [
                                        113.834904,
                                        22.822085
                                    ],
                                    [
                                        113.834771,
                                        22.822138
                                    ],
                                    [
                                        113.834717,
                                        22.822173
                                    ],
                                    [
                                        113.8347,
                                        22.822209
                                    ],
                                    [
                                        113.834689,
                                        22.822259
                                    ],
                                    [
                                        113.834723,
                                        22.822394
                                    ],
                                    [
                                        113.834771,
                                        22.822506
                                    ],
                                    [
                                        113.834881,
                                        22.822691
                                    ],
                                    [
                                        113.834987,
                                        22.822849
                                    ],
                                    [
                                        113.835111,
                                        22.822986
                                    ],
                                    [
                                        113.835344,
                                        22.82316
                                    ],
                                    [
                                        113.835437,
                                        22.823206
                                    ],
                                    [
                                        113.835679,
                                        22.823282
                                    ],
                                    [
                                        113.836013,
                                        22.823368
                                    ],
                                    [
                                        113.836136,
                                        22.823419
                                    ],
                                    [
                                        113.836233,
                                        22.823483
                                    ],
                                    [
                                        113.836366,
                                        22.823598
                                    ],
                                    [
                                        113.836443,
                                        22.823696
                                    ],
                                    [
                                        113.83652,
                                        22.823879
                                    ],
                                    [
                                        113.836599,
                                        22.824832
                                    ],
                                    [
                                        113.836662,
                                        22.82521
                                    ],
                                    [
                                        113.836676,
                                        22.825399
                                    ],
                                    [
                                        113.836628,
                                        22.825788
                                    ],
                                    [
                                        113.836561,
                                        22.82611
                                    ],
                                    [
                                        113.836538,
                                        22.82639
                                    ],
                                    [
                                        113.836538,
                                        22.826526
                                    ],
                                    [
                                        113.836577,
                                        22.826667
                                    ],
                                    [
                                        113.83666,
                                        22.826764
                                    ],
                                    [
                                        113.836984,
                                        22.827033
                                    ],
                                    [
                                        113.837219,
                                        22.827239
                                    ],
                                    [
                                        113.837406,
                                        22.827474
                                    ],
                                    [
                                        113.838026,
                                        22.828615
                                    ],
                                    [
                                        113.838132,
                                        22.828773
                                    ],
                                    [
                                        113.838175,
                                        22.828907
                                    ],
                                    [
                                        113.838235,
                                        22.829076
                                    ],
                                    [
                                        113.838362,
                                        22.829443
                                    ],
                                    [
                                        113.838482,
                                        22.829657
                                    ],
                                    [
                                        113.838595,
                                        22.829779
                                    ],
                                    [
                                        113.838763,
                                        22.829907
                                    ],
                                    [
                                        113.839359,
                                        22.830382
                                    ],
                                    [
                                        113.839362,
                                        22.830459
                                    ],
                                    [
                                        113.839373,
                                        22.83048
                                    ],
                                    [
                                        113.83978,
                                        22.830873
                                    ],
                                    [
                                        113.840857,
                                        22.831212
                                    ],
                                    [
                                        113.8411,
                                        22.831411
                                    ],
                                    [
                                        113.841015,
                                        22.832624
                                    ],
                                    [
                                        113.841369,
                                        22.833804
                                    ],
                                    [
                                        113.841514,
                                        22.833995
                                    ],
                                    [
                                        113.842293,
                                        22.833743
                                    ],
                                    [
                                        113.842746,
                                        22.833696
                                    ],
                                    [
                                        113.845222,
                                        22.834428
                                    ],
                                    [
                                        113.845776,
                                        22.835006
                                    ],
                                    [
                                        113.846286,
                                        22.835352
                                    ],
                                    [
                                        113.848166,
                                        22.836121
                                    ],
                                    [
                                        113.849467,
                                        22.836443
                                    ],
                                    [
                                        113.850591,
                                        22.836844
                                    ],
                                    [
                                        113.851285,
                                        22.837485
                                    ],
                                    [
                                        113.851889,
                                        22.837164
                                    ],
                                    [
                                        113.853042,
                                        22.836358
                                    ],
                                    [
                                        113.853642,
                                        22.835597
                                    ],
                                    [
                                        113.854428,
                                        22.835214
                                    ],
                                    [
                                        113.856192,
                                        22.835683
                                    ],
                                    [
                                        113.856849,
                                        22.833786
                                    ],
                                    [
                                        113.85706,
                                        22.832613
                                    ],
                                    [
                                        113.857522,
                                        22.832622
                                    ],
                                    [
                                        113.859399,
                                        22.833454
                                    ],
                                    [
                                        113.859899,
                                        22.833852
                                    ],
                                    [
                                        113.860986,
                                        22.834154
                                    ],
                                    [
                                        113.861093,
                                        22.834081
                                    ],
                                    [
                                        113.86135,
                                        22.833237
                                    ],
                                    [
                                        113.861715,
                                        22.833219
                                    ],
                                    [
                                        113.861812,
                                        22.833361
                                    ],
                                    [
                                        113.861733,
                                        22.834063
                                    ],
                                    [
                                        113.86191,
                                        22.834659
                                    ],
                                    [
                                        113.862114,
                                        22.834833
                                    ],
                                    [
                                        113.862503,
                                        22.834911
                                    ],
                                    [
                                        113.863383,
                                        22.835672
                                    ],
                                    [
                                        113.863743,
                                        22.836072
                                    ],
                                    [
                                        113.863908,
                                        22.836723
                                    ],
                                    [
                                        113.864031,
                                        22.836853
                                    ],
                                    [
                                        113.864224,
                                        22.836916
                                    ],
                                    [
                                        113.864387,
                                        22.836968
                                    ],
                                    [
                                        113.865407,
                                        22.836892
                                    ],
                                    [
                                        113.866262,
                                        22.836659
                                    ],
                                    [
                                        113.866824,
                                        22.836889
                                    ],
                                    [
                                        113.867866,
                                        22.837169
                                    ],
                                    [
                                        113.868408,
                                        22.837314
                                    ],
                                    [
                                        113.870787,
                                        22.836986
                                    ],
                                    [
                                        113.871704,
                                        22.837063
                                    ],
                                    [
                                        113.871754,
                                        22.837071
                                    ],
                                    [
                                        113.871808,
                                        22.837077
                                    ],
                                    [
                                        113.871835,
                                        22.837081
                                    ],
                                    [
                                        113.871896,
                                        22.83709
                                    ],
                                    [
                                        113.871916,
                                        22.837093
                                    ],
                                    [
                                        113.871996,
                                        22.837103
                                    ],
                                    [
                                        113.872409,
                                        22.837178
                                    ],
                                    [
                                        113.872635,
                                        22.837277
                                    ],
                                    [
                                        113.872708,
                                        22.837517
                                    ],
                                    [
                                        113.872333,
                                        22.839957
                                    ],
                                    [
                                        113.872386,
                                        22.840524
                                    ],
                                    [
                                        113.872543,
                                        22.840702
                                    ],
                                    [
                                        113.872788,
                                        22.840713
                                    ],
                                    [
                                        113.873399,
                                        22.840067
                                    ],
                                    [
                                        113.873567,
                                        22.84003
                                    ],
                                    [
                                        113.873595,
                                        22.840138
                                    ],
                                    [
                                        113.871433,
                                        22.843118
                                    ],
                                    [
                                        113.870998,
                                        22.845658
                                    ],
                                    [
                                        113.871776,
                                        22.845417
                                    ],
                                    [
                                        113.873416,
                                        22.845475
                                    ],
                                    [
                                        113.873905,
                                        22.845017
                                    ],
                                    [
                                        113.87375,
                                        22.844075
                                    ],
                                    [
                                        113.873814,
                                        22.843943
                                    ],
                                    [
                                        113.873968,
                                        22.843978
                                    ],
                                    [
                                        113.874325,
                                        22.844569
                                    ],
                                    [
                                        113.874445,
                                        22.845551
                                    ],
                                    [
                                        113.875429,
                                        22.847312
                                    ],
                                    [
                                        113.876427,
                                        22.84811
                                    ],
                                    [
                                        113.877506,
                                        22.851915
                                    ],
                                    [
                                        113.878027,
                                        22.852156
                                    ],
                                    [
                                        113.878145,
                                        22.852307
                                    ],
                                    [
                                        113.878257,
                                        22.852749
                                    ],
                                    [
                                        113.878199,
                                        22.853901
                                    ],
                                    [
                                        113.87785,
                                        22.854253
                                    ],
                                    [
                                        113.877681,
                                        22.854448
                                    ],
                                    [
                                        113.878206,
                                        22.855124
                                    ],
                                    [
                                        113.878249,
                                        22.85518
                                    ],
                                    [
                                        113.878375,
                                        22.855206
                                    ],
                                    [
                                        113.879938,
                                        22.854917
                                    ],
                                    [
                                        113.879785,
                                        22.854606
                                    ],
                                    [
                                        113.878878,
                                        22.854206
                                    ],
                                    [
                                        113.878669,
                                        22.852685
                                    ],
                                    [
                                        113.878699,
                                        22.852414
                                    ],
                                    [
                                        113.879311,
                                        22.852185
                                    ],
                                    [
                                        113.880202,
                                        22.851956
                                    ],
                                    [
                                        113.880343,
                                        22.852014
                                    ],
                                    [
                                        113.880649,
                                        22.853225
                                    ],
                                    [
                                        113.880427,
                                        22.853637
                                    ],
                                    [
                                        113.880431,
                                        22.853813
                                    ],
                                    [
                                        113.880672,
                                        22.853892
                                    ],
                                    [
                                        113.881766,
                                        22.853422
                                    ],
                                    [
                                        113.881686,
                                        22.85318
                                    ],
                                    [
                                        113.881079,
                                        22.852849
                                    ],
                                    [
                                        113.880993,
                                        22.852713
                                    ],
                                    [
                                        113.880833,
                                        22.851786
                                    ],
                                    [
                                        113.881041,
                                        22.85141
                                    ],
                                    [
                                        113.88265,
                                        22.850537
                                    ],
                                    [
                                        113.882924,
                                        22.850474
                                    ],
                                    [
                                        113.883254,
                                        22.850562
                                    ],
                                    [
                                        113.883437,
                                        22.850818
                                    ],
                                    [
                                        113.883214,
                                        22.851312
                                    ],
                                    [
                                        113.882565,
                                        22.851651
                                    ],
                                    [
                                        113.88258,
                                        22.851893
                                    ],
                                    [
                                        113.882944,
                                        22.851991
                                    ],
                                    [
                                        113.8835,
                                        22.851884
                                    ],
                                    [
                                        113.883663,
                                        22.851712
                                    ],
                                    [
                                        113.883725,
                                        22.851383
                                    ],
                                    [
                                        113.884147,
                                        22.851247
                                    ],
                                    [
                                        113.884291,
                                        22.851343
                                    ],
                                    [
                                        113.884396,
                                        22.851461
                                    ],
                                    [
                                        113.884194,
                                        22.852191
                                    ],
                                    [
                                        113.884442,
                                        22.853035
                                    ],
                                    [
                                        113.884577,
                                        22.853073
                                    ],
                                    [
                                        113.88474,
                                        22.852984
                                    ],
                                    [
                                        113.885088,
                                        22.852391
                                    ],
                                    [
                                        113.885386,
                                        22.852406
                                    ],
                                    [
                                        113.885587,
                                        22.852743
                                    ],
                                    [
                                        113.886067,
                                        22.854119
                                    ],
                                    [
                                        113.886079,
                                        22.854281
                                    ],
                                    [
                                        113.884966,
                                        22.855171
                                    ],
                                    [
                                        113.885028,
                                        22.855339
                                    ],
                                    [
                                        113.885241,
                                        22.855339
                                    ],
                                    [
                                        113.885625,
                                        22.855162
                                    ],
                                    [
                                        113.886781,
                                        22.854398
                                    ],
                                    [
                                        113.887758,
                                        22.854696
                                    ],
                                    [
                                        113.88835,
                                        22.855068
                                    ],
                                    [
                                        113.888759,
                                        22.855507
                                    ],
                                    [
                                        113.888778,
                                        22.85576
                                    ],
                                    [
                                        113.888027,
                                        22.856514
                                    ],
                                    [
                                        113.887304,
                                        22.857681
                                    ],
                                    [
                                        113.886043,
                                        22.858799
                                    ],
                                    [
                                        113.885798,
                                        22.858855
                                    ],
                                    [
                                        113.885802,
                                        22.858923
                                    ],
                                    [
                                        113.886188,
                                        22.859045
                                    ],
                                    [
                                        113.887312,
                                        22.858526
                                    ],
                                    [
                                        113.888697,
                                        22.85906
                                    ],
                                    [
                                        113.88882,
                                        22.858929
                                    ],
                                    [
                                        113.889658,
                                        22.859773
                                    ],
                                    [
                                        113.890538,
                                        22.859747
                                    ],
                                    [
                                        113.890653,
                                        22.859899
                                    ],
                                    [
                                        113.890848,
                                        22.86084
                                    ],
                                    [
                                        113.890745,
                                        22.861553
                                    ],
                                    [
                                        113.891055,
                                        22.861748
                                    ],
                                    [
                                        113.89113,
                                        22.860817
                                    ],
                                    [
                                        113.890967,
                                        22.859346
                                    ],
                                    [
                                        113.890874,
                                        22.859195
                                    ],
                                    [
                                        113.890122,
                                        22.859085
                                    ],
                                    [
                                        113.889872,
                                        22.858909
                                    ],
                                    [
                                        113.889142,
                                        22.857896
                                    ],
                                    [
                                        113.889125,
                                        22.857524
                                    ],
                                    [
                                        113.889243,
                                        22.857319
                                    ],
                                    [
                                        113.889726,
                                        22.857075
                                    ],
                                    [
                                        113.891359,
                                        22.856839
                                    ],
                                    [
                                        113.891886,
                                        22.856619
                                    ],
                                    [
                                        113.892102,
                                        22.856963
                                    ],
                                    [
                                        113.892432,
                                        22.857063
                                    ],
                                    [
                                        113.89276,
                                        22.856269
                                    ],
                                    [
                                        113.892706,
                                        22.855929
                                    ],
                                    [
                                        113.892604,
                                        22.85583
                                    ],
                                    [
                                        113.89285,
                                        22.855403
                                    ],
                                    [
                                        113.893717,
                                        22.855062
                                    ],
                                    [
                                        113.89382,
                                        22.855349
                                    ],
                                    [
                                        113.894094,
                                        22.85559
                                    ],
                                    [
                                        113.894416,
                                        22.855563
                                    ],
                                    [
                                        113.894543,
                                        22.854809
                                    ],
                                    [
                                        113.894838,
                                        22.854353
                                    ],
                                    [
                                        113.89565,
                                        22.854213
                                    ],
                                    [
                                        113.896516,
                                        22.854685
                                    ],
                                    [
                                        113.897708,
                                        22.854664
                                    ],
                                    [
                                        113.898173,
                                        22.854809
                                    ],
                                    [
                                        113.898448,
                                        22.855035
                                    ],
                                    [
                                        113.89858,
                                        22.856038
                                    ],
                                    [
                                        113.899094,
                                        22.856649
                                    ],
                                    [
                                        113.89973,
                                        22.8571
                                    ],
                                    [
                                        113.89949,
                                        22.855491
                                    ],
                                    [
                                        113.89933,
                                        22.855197
                                    ],
                                    [
                                        113.898466,
                                        22.854224
                                    ],
                                    [
                                        113.898075,
                                        22.854108
                                    ],
                                    [
                                        113.896279,
                                        22.851512
                                    ],
                                    [
                                        113.895041,
                                        22.850405
                                    ],
                                    [
                                        113.894861,
                                        22.850453
                                    ],
                                    [
                                        113.894792,
                                        22.850732
                                    ],
                                    [
                                        113.894948,
                                        22.8513
                                    ],
                                    [
                                        113.894886,
                                        22.851631
                                    ],
                                    [
                                        113.89464,
                                        22.852048
                                    ],
                                    [
                                        113.893453,
                                        22.853478
                                    ],
                                    [
                                        113.89308,
                                        22.853774
                                    ],
                                    [
                                        113.892421,
                                        22.853834
                                    ],
                                    [
                                        113.891527,
                                        22.853598
                                    ],
                                    [
                                        113.891368,
                                        22.853294
                                    ],
                                    [
                                        113.891469,
                                        22.85199
                                    ],
                                    [
                                        113.891676,
                                        22.85174
                                    ],
                                    [
                                        113.892103,
                                        22.85152
                                    ],
                                    [
                                        113.892735,
                                        22.851642
                                    ],
                                    [
                                        113.892879,
                                        22.851587
                                    ],
                                    [
                                        113.89308,
                                        22.851114
                                    ],
                                    [
                                        113.892802,
                                        22.850334
                                    ],
                                    [
                                        113.892918,
                                        22.850108
                                    ],
                                    [
                                        113.893243,
                                        22.849904
                                    ],
                                    [
                                        113.893929,
                                        22.849891
                                    ],
                                    [
                                        113.894226,
                                        22.849969
                                    ],
                                    [
                                        113.894492,
                                        22.849953
                                    ],
                                    [
                                        113.894589,
                                        22.849861
                                    ],
                                    [
                                        113.894583,
                                        22.849714
                                    ],
                                    [
                                        113.894395,
                                        22.849444
                                    ],
                                    [
                                        113.89349,
                                        22.849409
                                    ],
                                    [
                                        113.892747,
                                        22.848918
                                    ],
                                    [
                                        113.892723,
                                        22.847704
                                    ],
                                    [
                                        113.892811,
                                        22.847425
                                    ],
                                    [
                                        113.893713,
                                        22.846328
                                    ],
                                    [
                                        113.893921,
                                        22.846195
                                    ],
                                    [
                                        113.894715,
                                        22.846331
                                    ],
                                    [
                                        113.895393,
                                        22.845953
                                    ],
                                    [
                                        113.89564,
                                        22.845958
                                    ],
                                    [
                                        113.895884,
                                        22.846149
                                    ],
                                    [
                                        113.896222,
                                        22.846914
                                    ],
                                    [
                                        113.896346,
                                        22.847014
                                    ],
                                    [
                                        113.896437,
                                        22.846942
                                    ],
                                    [
                                        113.896442,
                                        22.846789
                                    ],
                                    [
                                        113.896154,
                                        22.845973
                                    ],
                                    [
                                        113.896229,
                                        22.845802
                                    ],
                                    [
                                        113.896455,
                                        22.845633
                                    ],
                                    [
                                        113.896739,
                                        22.845569
                                    ],
                                    [
                                        113.897329,
                                        22.845109
                                    ],
                                    [
                                        113.897771,
                                        22.845065
                                    ],
                                    [
                                        113.898477,
                                        22.845598
                                    ],
                                    [
                                        113.898681,
                                        22.84559
                                    ],
                                    [
                                        113.89879,
                                        22.845409
                                    ],
                                    [
                                        113.898637,
                                        22.845202
                                    ],
                                    [
                                        113.898106,
                                        22.844863
                                    ],
                                    [
                                        113.897874,
                                        22.844612
                                    ],
                                    [
                                        113.897599,
                                        22.844583
                                    ],
                                    [
                                        113.897045,
                                        22.844261
                                    ],
                                    [
                                        113.897201,
                                        22.843871
                                    ],
                                    [
                                        113.898111,
                                        22.842751
                                    ],
                                    [
                                        113.899152,
                                        22.843557
                                    ],
                                    [
                                        113.900233,
                                        22.844137
                                    ],
                                    [
                                        113.900397,
                                        22.84457
                                    ],
                                    [
                                        113.900606,
                                        22.846122
                                    ],
                                    [
                                        113.90101,
                                        22.846131
                                    ],
                                    [
                                        113.900685,
                                        22.845162
                                    ],
                                    [
                                        113.900749,
                                        22.844525
                                    ],
                                    [
                                        113.901112,
                                        22.844328
                                    ],
                                    [
                                        113.902926,
                                        22.843821
                                    ],
                                    [
                                        113.903532,
                                        22.844042
                                    ],
                                    [
                                        113.905077,
                                        22.845061
                                    ],
                                    [
                                        113.905311,
                                        22.845057
                                    ],
                                    [
                                        113.905242,
                                        22.844776
                                    ],
                                    [
                                        113.904846,
                                        22.844239
                                    ],
                                    [
                                        113.904017,
                                        22.843925
                                    ],
                                    [
                                        113.903633,
                                        22.843648
                                    ],
                                    [
                                        113.903173,
                                        22.842738
                                    ],
                                    [
                                        113.903228,
                                        22.842439
                                    ],
                                    [
                                        113.903596,
                                        22.842351
                                    ],
                                    [
                                        113.90428,
                                        22.842366
                                    ],
                                    [
                                        113.905494,
                                        22.84261
                                    ],
                                    [
                                        113.905468,
                                        22.842495
                                    ],
                                    [
                                        113.904396,
                                        22.842052
                                    ],
                                    [
                                        113.904354,
                                        22.841737
                                    ],
                                    [
                                        113.904646,
                                        22.841186
                                    ],
                                    [
                                        113.904719,
                                        22.840395
                                    ],
                                    [
                                        113.904868,
                                        22.840132
                                    ],
                                    [
                                        113.906163,
                                        22.839788
                                    ],
                                    [
                                        113.906839,
                                        22.840033
                                    ],
                                    [
                                        113.910798,
                                        22.839345
                                    ],
                                    [
                                        113.911843,
                                        22.840033
                                    ],
                                    [
                                        113.912464,
                                        22.840229
                                    ],
                                    [
                                        113.912869,
                                        22.840235
                                    ],
                                    [
                                        113.913073,
                                        22.839918
                                    ],
                                    [
                                        113.913606,
                                        22.839468
                                    ],
                                    [
                                        113.91397,
                                        22.839299
                                    ],
                                    [
                                        113.914234,
                                        22.839351
                                    ],
                                    [
                                        113.914369,
                                        22.839482
                                    ],
                                    [
                                        113.914393,
                                        22.839678
                                    ],
                                    [
                                        113.914125,
                                        22.841009
                                    ],
                                    [
                                        113.914441,
                                        22.841689
                                    ],
                                    [
                                        113.914632,
                                        22.841838
                                    ],
                                    [
                                        113.914789,
                                        22.841652
                                    ],
                                    [
                                        113.914416,
                                        22.841065
                                    ],
                                    [
                                        113.914365,
                                        22.840849
                                    ],
                                    [
                                        113.914743,
                                        22.839509
                                    ],
                                    [
                                        113.914768,
                                        22.839161
                                    ],
                                    [
                                        113.916577,
                                        22.839376
                                    ],
                                    [
                                        113.91678,
                                        22.840687
                                    ],
                                    [
                                        113.917255,
                                        22.841159
                                    ],
                                    [
                                        113.917506,
                                        22.841386
                                    ],
                                    [
                                        113.918425,
                                        22.841817
                                    ],
                                    [
                                        113.918773,
                                        22.842427
                                    ],
                                    [
                                        113.919239,
                                        22.842567
                                    ],
                                    [
                                        113.919471,
                                        22.842139
                                    ],
                                    [
                                        113.919811,
                                        22.841763
                                    ],
                                    [
                                        113.920077,
                                        22.841632
                                    ],
                                    [
                                        113.920359,
                                        22.841638
                                    ],
                                    [
                                        113.920785,
                                        22.841886
                                    ],
                                    [
                                        113.921008,
                                        22.842229
                                    ],
                                    [
                                        113.922062,
                                        22.84309
                                    ],
                                    [
                                        113.922256,
                                        22.843412
                                    ],
                                    [
                                        113.923237,
                                        22.84346
                                    ],
                                    [
                                        113.923838,
                                        22.843346
                                    ],
                                    [
                                        113.924199,
                                        22.842944
                                    ],
                                    [
                                        113.924537,
                                        22.842826
                                    ],
                                    [
                                        113.925379,
                                        22.842976
                                    ],
                                    [
                                        113.925997,
                                        22.843441
                                    ],
                                    [
                                        113.926269,
                                        22.843526
                                    ],
                                    [
                                        113.926819,
                                        22.843341
                                    ],
                                    [
                                        113.92846,
                                        22.843125
                                    ],
                                    [
                                        113.929447,
                                        22.842417
                                    ],
                                    [
                                        113.929822,
                                        22.842298
                                    ],
                                    [
                                        113.930159,
                                        22.84203
                                    ],
                                    [
                                        113.931815,
                                        22.84218
                                    ],
                                    [
                                        113.933283,
                                        22.841913
                                    ],
                                    [
                                        113.934772,
                                        22.84115
                                    ],
                                    [
                                        113.934851,
                                        22.840808
                                    ],
                                    [
                                        113.934773,
                                        22.84073
                                    ],
                                    [
                                        113.933038,
                                        22.841272
                                    ],
                                    [
                                        113.932197,
                                        22.84161
                                    ],
                                    [
                                        113.931776,
                                        22.841779
                                    ],
                                    [
                                        113.930349,
                                        22.841777
                                    ],
                                    [
                                        113.929997,
                                        22.841586
                                    ],
                                    [
                                        113.929801,
                                        22.841583
                                    ],
                                    [
                                        113.929265,
                                        22.841999
                                    ],
                                    [
                                        113.928223,
                                        22.842604
                                    ],
                                    [
                                        113.92756,
                                        22.842746
                                    ],
                                    [
                                        113.927304,
                                        22.842705
                                    ],
                                    [
                                        113.926456,
                                        22.842189
                                    ],
                                    [
                                        113.925524,
                                        22.841895
                                    ],
                                    [
                                        113.925252,
                                        22.841689
                                    ],
                                    [
                                        113.923556,
                                        22.842389
                                    ],
                                    [
                                        113.922746,
                                        22.842444
                                    ],
                                    [
                                        113.922414,
                                        22.842339
                                    ],
                                    [
                                        113.920664,
                                        22.841202
                                    ],
                                    [
                                        113.92021,
                                        22.841081
                                    ],
                                    [
                                        113.919296,
                                        22.841016
                                    ],
                                    [
                                        113.919143,
                                        22.840929
                                    ],
                                    [
                                        113.918946,
                                        22.840528
                                    ],
                                    [
                                        113.919036,
                                        22.840184
                                    ],
                                    [
                                        113.919808,
                                        22.83998
                                    ],
                                    [
                                        113.920426,
                                        22.839961
                                    ],
                                    [
                                        113.920591,
                                        22.839883
                                    ],
                                    [
                                        113.920551,
                                        22.839751
                                    ],
                                    [
                                        113.919486,
                                        22.839785
                                    ],
                                    [
                                        113.917852,
                                        22.84011
                                    ],
                                    [
                                        113.917651,
                                        22.839475
                                    ],
                                    [
                                        113.917784,
                                        22.838773
                                    ],
                                    [
                                        113.917882,
                                        22.837971
                                    ],
                                    [
                                        113.918532,
                                        22.837083
                                    ],
                                    [
                                        113.918771,
                                        22.83702
                                    ],
                                    [
                                        113.920107,
                                        22.836221
                                    ],
                                    [
                                        113.922189,
                                        22.835737
                                    ],
                                    [
                                        113.922467,
                                        22.835777
                                    ],
                                    [
                                        113.922987,
                                        22.83478
                                    ],
                                    [
                                        113.922854,
                                        22.834642
                                    ],
                                    [
                                        113.922557,
                                        22.834652
                                    ],
                                    [
                                        113.921829,
                                        22.835114
                                    ],
                                    [
                                        113.921421,
                                        22.83522
                                    ],
                                    [
                                        113.919657,
                                        22.834579
                                    ],
                                    [
                                        113.919414,
                                        22.83464
                                    ],
                                    [
                                        113.919276,
                                        22.8348
                                    ],
                                    [
                                        113.919739,
                                        22.835225
                                    ],
                                    [
                                        113.920004,
                                        22.835733
                                    ],
                                    [
                                        113.918096,
                                        22.836455
                                    ],
                                    [
                                        113.917717,
                                        22.837355
                                    ],
                                    [
                                        113.916643,
                                        22.838195
                                    ],
                                    [
                                        113.916351,
                                        22.838237
                                    ],
                                    [
                                        113.916045,
                                        22.83815
                                    ],
                                    [
                                        113.915354,
                                        22.837566
                                    ],
                                    [
                                        113.914928,
                                        22.837403
                                    ],
                                    [
                                        113.913544,
                                        22.837175
                                    ],
                                    [
                                        113.912964,
                                        22.837327
                                    ],
                                    [
                                        113.912024,
                                        22.837897
                                    ],
                                    [
                                        113.911749,
                                        22.838516
                                    ],
                                    [
                                        113.911439,
                                        22.838763
                                    ],
                                    [
                                        113.909968,
                                        22.838426
                                    ],
                                    [
                                        113.908372,
                                        22.837889
                                    ],
                                    [
                                        113.907929,
                                        22.837971
                                    ],
                                    [
                                        113.906985,
                                        22.838507
                                    ],
                                    [
                                        113.906574,
                                        22.838567
                                    ],
                                    [
                                        113.906367,
                                        22.838456
                                    ],
                                    [
                                        113.90616,
                                        22.83804
                                    ],
                                    [
                                        113.906026,
                                        22.83802
                                    ],
                                    [
                                        113.904138,
                                        22.83976
                                    ],
                                    [
                                        113.903951,
                                        22.840138
                                    ],
                                    [
                                        113.902391,
                                        22.84021
                                    ],
                                    [
                                        113.902239,
                                        22.838368
                                    ],
                                    [
                                        113.904275,
                                        22.83288
                                    ],
                                    [
                                        113.905217,
                                        22.832624
                                    ],
                                    [
                                        113.906808,
                                        22.832624
                                    ],
                                    [
                                        113.907796,
                                        22.832899
                                    ],
                                    [
                                        113.908955,
                                        22.832669
                                    ],
                                    [
                                        113.909537,
                                        22.832297
                                    ],
                                    [
                                        113.910019,
                                        22.831846
                                    ],
                                    [
                                        113.910629,
                                        22.830889
                                    ],
                                    [
                                        113.910958,
                                        22.829994
                                    ],
                                    [
                                        113.91036,
                                        22.829808
                                    ],
                                    [
                                        113.910146,
                                        22.829729
                                    ],
                                    [
                                        113.909684,
                                        22.82964
                                    ],
                                    [
                                        113.909234,
                                        22.8296
                                    ],
                                    [
                                        113.908944,
                                        22.829659
                                    ],
                                    [
                                        113.908268,
                                        22.82964
                                    ],
                                    [
                                        113.907732,
                                        22.82963
                                    ],
                                    [
                                        113.907474,
                                        22.82962
                                    ],
                                    [
                                        113.906283,
                                        22.829214
                                    ],
                                    [
                                        113.906165,
                                        22.829116
                                    ],
                                    [
                                        113.905994,
                                        22.828928
                                    ],
                                    [
                                        113.905715,
                                        22.82876
                                    ],
                                    [
                                        113.905479,
                                        22.828601
                                    ],
                                    [
                                        113.9052,
                                        22.828463
                                    ],
                                    [
                                        113.904846,
                                        22.828384
                                    ],
                                    [
                                        113.904631,
                                        22.828384
                                    ],
                                    [
                                        113.90432,
                                        22.828453
                                    ],
                                    [
                                        113.904138,
                                        22.828334
                                    ],
                                    [
                                        113.903945,
                                        22.828305
                                    ],
                                    [
                                        113.903859,
                                        22.828226
                                    ],
                                    [
                                        113.903043,
                                        22.828206
                                    ],
                                    [
                                        113.902625,
                                        22.828354
                                    ],
                                    [
                                        113.902464,
                                        22.828502
                                    ],
                                    [
                                        113.902088,
                                        22.828631
                                    ],
                                    [
                                        113.901885,
                                        22.82873
                                    ],
                                    [
                                        113.90182,
                                        22.828898
                                    ],
                                    [
                                        113.901691,
                                        22.828977
                                    ],
                                    [
                                        113.901316,
                                        22.828997
                                    ],
                                    [
                                        113.901026,
                                        22.828928
                                    ],
                                    [
                                        113.900564,
                                        22.8287
                                    ],
                                    [
                                        113.900285,
                                        22.828601
                                    ],
                                    [
                                        113.899941,
                                        22.828452
                                    ],
                                    [
                                        113.899663,
                                        22.828363
                                    ],
                                    [
                                        113.899491,
                                        22.828304
                                    ],
                                    [
                                        113.899362,
                                        22.828166
                                    ],
                                    [
                                        113.899115,
                                        22.828067
                                    ],
                                    [
                                        113.898976,
                                        22.828057
                                    ],
                                    [
                                        113.8983,
                                        22.827859
                                    ],
                                    [
                                        113.897313,
                                        22.826831
                                    ],
                                    [
                                        113.897485,
                                        22.826307
                                    ],
                                    [
                                        113.897667,
                                        22.82601
                                    ],
                                    [
                                        113.897388,
                                        22.825654
                                    ],
                                    [
                                        113.897184,
                                        22.825199
                                    ],
                                    [
                                        113.897066,
                                        22.825061
                                    ],
                                    [
                                        113.89683,
                                        22.824873
                                    ],
                                    [
                                        113.896208,
                                        22.823923
                                    ],
                                    [
                                        113.89609,
                                        22.823567
                                    ],
                                    [
                                        113.896047,
                                        22.822835
                                    ],
                                    [
                                        113.895907,
                                        22.822805
                                    ],
                                    [
                                        113.895714,
                                        22.822617
                                    ],
                                    [
                                        113.895596,
                                        22.82234
                                    ],
                                    [
                                        113.895607,
                                        22.821925
                                    ],
                                    [
                                        113.895199,
                                        22.821539
                                    ],
                                    [
                                        113.895146,
                                        22.821431
                                    ],
                                    [
                                        113.895274,
                                        22.820916
                                    ],
                                    [
                                        113.895264,
                                        22.820382
                                    ],
                                    [
                                        113.895564,
                                        22.820016
                                    ],
                                    [
                                        113.895392,
                                        22.81967
                                    ],
                                    [
                                        113.895349,
                                        22.819344
                                    ],
                                    [
                                        113.895103,
                                        22.819176
                                    ],
                                    [
                                        113.894856,
                                        22.819087
                                    ],
                                    [
                                        113.894588,
                                        22.819136
                                    ],
                                    [
                                        113.894062,
                                        22.819364
                                    ],
                                    [
                                        113.894041,
                                        22.819423
                                    ],
                                    [
                                        113.894159,
                                        22.819562
                                    ],
                                    [
                                        113.894373,
                                        22.819878
                                    ],
                                    [
                                        113.894298,
                                        22.820007
                                    ],
                                    [
                                        113.894159,
                                        22.820165
                                    ],
                                    [
                                        113.894169,
                                        22.820323
                                    ],
                                    [
                                        113.894223,
                                        22.820422
                                    ],
                                    [
                                        113.894201,
                                        22.820481
                                    ],
                                    [
                                        113.894083,
                                        22.820461
                                    ],
                                    [
                                        113.893955,
                                        22.820303
                                    ],
                                    [
                                        113.89388,
                                        22.820076
                                    ],
                                    [
                                        113.89374,
                                        22.819947
                                    ],
                                    [
                                        113.893708,
                                        22.819878
                                    ],
                                    [
                                        113.893601,
                                        22.819779
                                    ],
                                    [
                                        113.893504,
                                        22.819611
                                    ],
                                    [
                                        113.893397,
                                        22.819502
                                    ],
                                    [
                                        113.892775,
                                        22.819107
                                    ],
                                    [
                                        113.891079,
                                        22.8206
                                    ],
                                    [
                                        113.891573,
                                        22.821233
                                    ],
                                    [
                                        113.892753,
                                        22.821767
                                    ],
                                    [
                                        113.89285,
                                        22.821895
                                    ],
                                    [
                                        113.892828,
                                        22.821984
                                    ],
                                    [
                                        113.892721,
                                        22.822014
                                    ],
                                    [
                                        113.891283,
                                        22.821717
                                    ],
                                    [
                                        113.89109,
                                        22.821826
                                    ],
                                    [
                                        113.891015,
                                        22.821974
                                    ],
                                    [
                                        113.891015,
                                        22.822063
                                    ],
                                    [
                                        113.890479,
                                        22.822093
                                    ],
                                    [
                                        113.890554,
                                        22.821955
                                    ],
                                    [
                                        113.890811,
                                        22.821787
                                    ],
                                    [
                                        113.890843,
                                        22.821678
                                    ],
                                    [
                                        113.890854,
                                        22.821529
                                    ],
                                    [
                                        113.89079,
                                        22.821421
                                    ],
                                    [
                                        113.890682,
                                        22.821272
                                    ],
                                    [
                                        113.890521,
                                        22.821223
                                    ],
                                    [
                                        113.890532,
                                        22.821154
                                    ],
                                    [
                                        113.890446,
                                        22.821114
                                    ],
                                    [
                                        113.890296,
                                        22.820916
                                    ],
                                    [
                                        113.890307,
                                        22.820719
                                    ],
                                    [
                                        113.890661,
                                        22.82063
                                    ],
                                    [
                                        113.890779,
                                        22.820521
                                    ],
                                    [
                                        113.890908,
                                        22.820471
                                    ],
                                    [
                                        113.890951,
                                        22.820333
                                    ],
                                    [
                                        113.890779,
                                        22.820056
                                    ],
                                    [
                                        113.890436,
                                        22.819888
                                    ],
                                    [
                                        113.8902,
                                        22.819848
                                    ],
                                    [
                                        113.889352,
                                        22.82239
                                    ],
                                    [
                                        113.889223,
                                        22.821757
                                    ],
                                    [
                                        113.889459,
                                        22.821658
                                    ],
                                    [
                                        113.889534,
                                        22.821609
                                    ],
                                    [
                                        113.889406,
                                        22.821302
                                    ],
                                    [
                                        113.889213,
                                        22.821154
                                    ],
                                    [
                                        113.889288,
                                        22.820966
                                    ],
                                    [
                                        113.889352,
                                        22.820788
                                    ],
                                    [
                                        113.889288,
                                        22.820758
                                    ],
                                    [
                                        113.889009,
                                        22.820254
                                    ],
                                    [
                                        113.889019,
                                        22.820174
                                    ],
                                    [
                                        113.889202,
                                        22.820086
                                    ],
                                    [
                                        113.889395,
                                        22.820026
                                    ],
                                    [
                                        113.889513,
                                        22.819947
                                    ],
                                    [
                                        113.889481,
                                        22.819858
                                    ],
                                    [
                                        113.889491,
                                        22.819629
                                    ],
                                    [
                                        113.889502,
                                        22.819512
                                    ],
                                    [
                                        113.889405,
                                        22.819433
                                    ],
                                    [
                                        113.889234,
                                        22.819344
                                    ],
                                    [
                                        113.888332,
                                        22.819581
                                    ],
                                    [
                                        113.888258,
                                        22.818019
                                    ],
                                    [
                                        113.888934,
                                        22.816898
                                    ],
                                    [
                                        113.887046,
                                        22.814293
                                    ],
                                    [
                                        113.887006,
                                        22.813928
                                    ],
                                    [
                                        113.886922,
                                        22.813537
                                    ],
                                    [
                                        113.886728,
                                        22.81326
                                    ],
                                    [
                                        113.886553,
                                        22.813047
                                    ],
                                    [
                                        113.886128,
                                        22.812607
                                    ],
                                    [
                                        113.885565,
                                        22.812236
                                    ],
                                    [
                                        113.885465,
                                        22.811916
                                    ],
                                    [
                                        113.885229,
                                        22.811698
                                    ],
                                    [
                                        113.884965,
                                        22.811543
                                    ],
                                    [
                                        113.8849,
                                        22.81099
                                    ],
                                    [
                                        113.884621,
                                        22.81099
                                    ],
                                    [
                                        113.884879,
                                        22.809941
                                    ],
                                    [
                                        113.884621,
                                        22.808913
                                    ],
                                    [
                                        113.883768,
                                        22.806401
                                    ],
                                    [
                                        113.883768,
                                        22.806332
                                    ],
                                    [
                                        113.883559,
                                        22.806179
                                    ],
                                    [
                                        113.883529,
                                        22.804609
                                    ],
                                    [
                                        113.883513,
                                        22.803309
                                    ],
                                    [
                                        113.882564,
                                        22.800981
                                    ],
                                    [
                                        113.882456,
                                        22.800843
                                    ],
                                    [
                                        113.882167,
                                        22.800655
                                    ],
                                    [
                                        113.882183,
                                        22.800516
                                    ],
                                    [
                                        113.881898,
                                        22.800383
                                    ],
                                    [
                                        113.881963,
                                        22.800042
                                    ],
                                    [
                                        113.88178,
                                        22.800007
                                    ],
                                    [
                                        113.881802,
                                        22.799616
                                    ],
                                    [
                                        113.881717,
                                        22.798561
                                    ],
                                    [
                                        113.881739,
                                        22.798392
                                    ],
                                    [
                                        113.881873,
                                        22.798313
                                    ],
                                    [
                                        113.881873,
                                        22.798174
                                    ],
                                    [
                                        113.881717,
                                        22.797685
                                    ],
                                    [
                                        113.881374,
                                        22.797718
                                    ],
                                    [
                                        113.880387,
                                        22.797599
                                    ],
                                    [
                                        113.8794,
                                        22.797125
                                    ],
                                    [
                                        113.878385,
                                        22.796315
                                    ],
                                    [
                                        113.877599,
                                        22.795687
                                    ],
                                    [
                                        113.877168,
                                        22.795344
                                    ],
                                    [
                                        113.874992,
                                        22.794351
                                    ],
                                    [
                                        113.874604,
                                        22.794174
                                    ],
                                    [
                                        113.874474,
                                        22.794115
                                    ],
                                    [
                                        113.872748,
                                        22.793327
                                    ],
                                    [
                                        113.868506,
                                        22.791441
                                    ],
                                    [
                                        113.86589,
                                        22.790279
                                    ],
                                    [
                                        113.864248,
                                        22.790399
                                    ],
                                    [
                                        113.864205,
                                        22.790249
                                    ],
                                    [
                                        113.863797,
                                        22.790071
                                    ],
                                    [
                                        113.863401,
                                        22.789469
                                    ],
                                    [
                                        113.862843,
                                        22.789507
                                    ],
                                    [
                                        113.862197,
                                        22.788647
                                    ],
                                    [
                                        113.861188,
                                        22.788609
                                    ],
                                    [
                                        113.861134,
                                        22.788708
                                    ],
                                    [
                                        113.860255,
                                        22.788657
                                    ],
                                    [
                                        113.859986,
                                        22.788767
                                    ],
                                    [
                                        113.859096,
                                        22.78853
                                    ],
                                    [
                                        113.857808,
                                        22.788015
                                    ],
                                    [
                                        113.858259,
                                        22.787194
                                    ],
                                    [
                                        113.858956,
                                        22.787164
                                    ],
                                    [
                                        113.858999,
                                        22.785988
                                    ],
                                    [
                                        113.859032,
                                        22.784869
                                    ],
                                    [
                                        113.858967,
                                        22.783623
                                    ],
                                    [
                                        113.859182,
                                        22.783169
                                    ],
                                    [
                                        113.859482,
                                        22.781873
                                    ],
                                    [
                                        113.860126,
                                        22.780439
                                    ],
                                    [
                                        113.860469,
                                        22.779725
                                    ],
                                    [
                                        113.860812,
                                        22.779103
                                    ],
                                    [
                                        113.860523,
                                        22.778856
                                    ],
                                    [
                                        113.860673,
                                        22.778618
                                    ],
                                    [
                                        113.860801,
                                        22.778679
                                    ],
                                    [
                                        113.860845,
                                        22.778628
                                    ],
                                    [
                                        113.861027,
                                        22.778738
                                    ],
                                    [
                                        113.861338,
                                        22.778272
                                    ],
                                    [
                                        113.861767,
                                        22.778421
                                    ],
                                    [
                                        113.861875,
                                        22.778411
                                    ],
                                    [
                                        113.862046,
                                        22.77845
                                    ],
                                    [
                                        113.862551,
                                        22.778649
                                    ],
                                    [
                                        113.862658,
                                        22.778559
                                    ],
                                    [
                                        113.862229,
                                        22.778094
                                    ],
                                    [
                                        113.86151,
                                        22.777601
                                    ],
                                    [
                                        113.861306,
                                        22.777245
                                    ],
                                    [
                                        113.860822,
                                        22.776611
                                    ],
                                    [
                                        113.860597,
                                        22.775623
                                    ],
                                    [
                                        113.860609,
                                        22.775068
                                    ],
                                    [
                                        113.860104,
                                        22.774079
                                    ],
                                    [
                                        113.860329,
                                        22.773753
                                    ],
                                    [
                                        113.860405,
                                        22.773546
                                    ],
                                    [
                                        113.860383,
                                        22.773339
                                    ],
                                    [
                                        113.860501,
                                        22.772973
                                    ],
                                    [
                                        113.860651,
                                        22.772903
                                    ],
                                    [
                                        113.860845,
                                        22.772843
                                    ],
                                    [
                                        113.861467,
                                        22.772725
                                    ],
                                    [
                                        113.862411,
                                        22.772696
                                    ],
                                    [
                                        113.863708,
                                        22.772696
                                    ],
                                    [
                                        113.863838,
                                        22.772408
                                    ],
                                    [
                                        113.863935,
                                        22.77228
                                    ],
                                    [
                                        113.863912,
                                        22.772003
                                    ],
                                    [
                                        113.863709,
                                        22.771656
                                    ],
                                    [
                                        113.863302,
                                        22.771706
                                    ],
                                    [
                                        113.863184,
                                        22.771646
                                    ],
                                    [
                                        113.863247,
                                        22.771469
                                    ],
                                    [
                                        113.863387,
                                        22.771311
                                    ],
                                    [
                                        113.863687,
                                        22.771004
                                    ],
                                    [
                                        113.863687,
                                        22.770756
                                    ],
                                    [
                                        113.863656,
                                        22.770637
                                    ],
                                    [
                                        113.863773,
                                        22.77044
                                    ],
                                    [
                                        113.863966,
                                        22.770193
                                    ],
                                    [
                                        113.864321,
                                        22.769936
                                    ],
                                    [
                                        113.864547,
                                        22.769838
                                    ],
                                    [
                                        113.864719,
                                        22.769848
                                    ],
                                    [
                                        113.864901,
                                        22.769867
                                    ],
                                    [
                                        113.865148,
                                        22.769906
                                    ],
                                    [
                                        113.865191,
                                        22.770025
                                    ],
                                    [
                                        113.865169,
                                        22.770144
                                    ],
                                    [
                                        113.865234,
                                        22.770421
                                    ],
                                    [
                                        113.865726,
                                        22.769936
                                    ],
                                    [
                                        113.865759,
                                        22.769828
                                    ],
                                    [
                                        113.865727,
                                        22.76958
                                    ],
                                    [
                                        113.865813,
                                        22.769214
                                    ],
                                    [
                                        113.865759,
                                        22.769075
                                    ],
                                    [
                                        113.865888,
                                        22.768996
                                    ],
                                    [
                                        113.86577,
                                        22.768749
                                    ],
                                    [
                                        113.865984,
                                        22.768631
                                    ],
                                    [
                                        113.866253,
                                        22.768452
                                    ],
                                    [
                                        113.866586,
                                        22.768373
                                    ],
                                    [
                                        113.868174,
                                        22.768176
                                    ],
                                    [
                                        113.868732,
                                        22.765783
                                    ],
                                    [
                                        113.868871,
                                        22.765514
                                    ],
                                    [
                                        113.869139,
                                        22.765287
                                    ],
                                    [
                                        113.869761,
                                        22.765198
                                    ],
                                    [
                                        113.869708,
                                        22.764813
                                    ],
                                    [
                                        113.869771,
                                        22.764614
                                    ],
                                    [
                                        113.869794,
                                        22.764218
                                    ],
                                    [
                                        113.871768,
                                        22.763271
                                    ],
                                    [
                                        113.872272,
                                        22.763143
                                    ],
                                    [
                                        113.872604,
                                        22.762875
                                    ],
                                    [
                                        113.873452,
                                        22.762538
                                    ],
                                    [
                                        113.873367,
                                        22.76234
                                    ],
                                    [
                                        113.874161,
                                        22.762094
                                    ],
                                    [
                                        113.873634,
                                        22.761084
                                    ],
                                    [
                                        113.873173,
                                        22.761232
                                    ],
                                    [
                                        113.872949,
                                        22.761321
                                    ],
                                    [
                                        113.872829,
                                        22.760738
                                    ],
                                    [
                                        113.873013,
                                        22.760718
                                    ],
                                    [
                                        113.873302,
                                        22.76055
                                    ],
                                    [
                                        113.874247,
                                        22.759936
                                    ],
                                    [
                                        113.875298,
                                        22.759204
                                    ],
                                    [
                                        113.875298,
                                        22.759076
                                    ],
                                    [
                                        113.875383,
                                        22.758996
                                    ],
                                    [
                                        113.875694,
                                        22.758719
                                    ],
                                    [
                                        113.876091,
                                        22.758492
                                    ],
                                    [
                                        113.876511,
                                        22.758147
                                    ],
                                    [
                                        113.876703,
                                        22.758047
                                    ],
                                    [
                                        113.876842,
                                        22.757751
                                    ],
                                    [
                                        113.87696,
                                        22.757523
                                    ],
                                    [
                                        113.877047,
                                        22.757245
                                    ],
                                    [
                                        113.877411,
                                        22.756741
                                    ],
                                    [
                                        113.877744,
                                        22.756464
                                    ],
                                    [
                                        113.878056,
                                        22.756209
                                    ],
                                    [
                                        113.878216,
                                        22.756061
                                    ],
                                    [
                                        113.878269,
                                        22.755892
                                    ],
                                    [
                                        113.878494,
                                        22.755605
                                    ],
                                    [
                                        113.878044,
                                        22.755714
                                    ],
                                    [
                                        113.877986,
                                        22.755569
                                    ],
                                    [
                                        113.877229,
                                        22.753706
                                    ],
                                    [
                                        113.877616,
                                        22.753647
                                    ],
                                    [
                                        113.877239,
                                        22.752014
                                    ],
                                    [
                                        113.877036,
                                        22.751163
                                    ],
                                    [
                                        113.877831,
                                        22.751007
                                    ],
                                    [
                                        113.877938,
                                        22.750751
                                    ],
                                    [
                                        113.878838,
                                        22.750058
                                    ],
                                    [
                                        113.879471,
                                        22.749661
                                    ],
                                    [
                                        113.879419,
                                        22.749523
                                    ],
                                    [
                                        113.879311,
                                        22.749228
                                    ],
                                    [
                                        113.879283,
                                        22.749154
                                    ],
                                    [
                                        113.879267,
                                        22.749025
                                    ],
                                    [
                                        113.879155,
                                        22.748971
                                    ],
                                    [
                                        113.879106,
                                        22.748908
                                    ],
                                    [
                                        113.879814,
                                        22.748382
                                    ],
                                    [
                                        113.879481,
                                        22.747419
                                    ],
                                    [
                                        113.879407,
                                        22.747269
                                    ],
                                    [
                                        113.879776,
                                        22.747235
                                    ],
                                    [
                                        113.879991,
                                        22.747215
                                    ],
                                    [
                                        113.880216,
                                        22.747126
                                    ],
                                    [
                                        113.880431,
                                        22.747022
                                    ],
                                    [
                                        113.880517,
                                        22.746923
                                    ],
                                    [
                                        113.880769,
                                        22.746547
                                    ],
                                    [
                                        113.880716,
                                        22.746492
                                    ],
                                    [
                                        113.880856,
                                        22.746334
                                    ],
                                    [
                                        113.881376,
                                        22.745994
                                    ],
                                    [
                                        113.881391,
                                        22.745899
                                    ],
                                    [
                                        113.881391,
                                        22.745424
                                    ],
                                    [
                                        113.881343,
                                        22.745355
                                    ],
                                    [
                                        113.881315,
                                        22.745278
                                    ],
                                    [
                                        113.88117,
                                        22.74511
                                    ],
                                    [
                                        113.881074,
                                        22.744996
                                    ],
                                    [
                                        113.880977,
                                        22.744877
                                    ],
                                    [
                                        113.880903,
                                        22.744788
                                    ],
                                    [
                                        113.880876,
                                        22.744685
                                    ],
                                    [
                                        113.880939,
                                        22.744561
                                    ],
                                    [
                                        113.881026,
                                        22.744467
                                    ],
                                    [
                                        113.881309,
                                        22.744269
                                    ],
                                    [
                                        113.881508,
                                        22.744091
                                    ],
                                    [
                                        113.881556,
                                        22.744003
                                    ],
                                    [
                                        113.881819,
                                        22.743334
                                    ],
                                    [
                                        113.881835,
                                        22.743017
                                    ],
                                    [
                                        113.881884,
                                        22.742958
                                    ],
                                    [
                                        113.88205,
                                        22.742755
                                    ],
                                    [
                                        113.882189,
                                        22.742701
                                    ],
                                    [
                                        113.882275,
                                        22.742641
                                    ],
                                    [
                                        113.882618,
                                        22.742473
                                    ],
                                    [
                                        113.882684,
                                        22.742429
                                    ],
                                    [
                                        113.882818,
                                        22.7423
                                    ],
                                    [
                                        113.883031,
                                        22.742067
                                    ],
                                    [
                                        113.883659,
                                        22.741037
                                    ],
                                    [
                                        113.883868,
                                        22.740562
                                    ],
                                    [
                                        113.884029,
                                        22.740245
                                    ],
                                    [
                                        113.883241,
                                        22.73881
                                    ],
                                    [
                                        113.883063,
                                        22.738662
                                    ],
                                    [
                                        113.882496,
                                        22.738038
                                    ],
                                    [
                                        113.882398,
                                        22.737774
                                    ],
                                    [
                                        113.882393,
                                        22.737319
                                    ],
                                    [
                                        113.882312,
                                        22.737176
                                    ],
                                    [
                                        113.882243,
                                        22.737136
                                    ],
                                    [
                                        113.882141,
                                        22.736938
                                    ],
                                    [
                                        113.882119,
                                        22.736503
                                    ],
                                    [
                                        113.882028,
                                        22.73629
                                    ],
                                    [
                                        113.881632,
                                        22.735785
                                    ],
                                    [
                                        113.881654,
                                        22.735716
                                    ],
                                    [
                                        113.881948,
                                        22.735073
                                    ],
                                    [
                                        113.882307,
                                        22.734781
                                    ],
                                    [
                                        113.882334,
                                        22.7347
                                    ],
                                    [
                                        113.882339,
                                        22.734537
                                    ],
                                    [
                                        113.882431,
                                        22.734339
                                    ],
                                    [
                                        113.88257,
                                        22.734191
                                    ],
                                    [
                                        113.882565,
                                        22.734032
                                    ],
                                    [
                                        113.882464,
                                        22.733874
                                    ],
                                    [
                                        113.882356,
                                        22.73376
                                    ],
                                    [
                                        113.88206,
                                        22.733617
                                    ],
                                    [
                                        113.881948,
                                        22.733508
                                    ],
                                    [
                                        113.881905,
                                        22.733434
                                    ],
                                    [
                                        113.88147,
                                        22.732974
                                    ],
                                    [
                                        113.881218,
                                        22.73236
                                    ],
                                    [
                                        113.881079,
                                        22.732157
                                    ],
                                    [
                                        113.880983,
                                        22.732068
                                    ],
                                    [
                                        113.880848,
                                        22.732034
                                    ],
                                    [
                                        113.880456,
                                        22.731959
                                    ],
                                    [
                                        113.88028,
                                        22.7318
                                    ],
                                    [
                                        113.880119,
                                        22.731513
                                    ],
                                    [
                                        113.879798,
                                        22.731108
                                    ],
                                    [
                                        113.879562,
                                        22.731019
                                    ],
                                    [
                                        113.878853,
                                        22.731177
                                    ],
                                    [
                                        113.878521,
                                        22.731098
                                    ],
                                    [
                                        113.878178,
                                        22.731049
                                    ],
                                    [
                                        113.877816,
                                        22.730344
                                    ],
                                    [
                                        113.87772,
                                        22.729869
                                    ],
                                    [
                                        113.877505,
                                        22.729651
                                    ],
                                    [
                                        113.877431,
                                        22.729117
                                    ],
                                    [
                                        113.877065,
                                        22.728256
                                    ],
                                    [
                                        113.877183,
                                        22.727999
                                    ],
                                    [
                                        113.877183,
                                        22.727672
                                    ],
                                    [
                                        113.877537,
                                        22.727445
                                    ],
                                    [
                                        113.877516,
                                        22.727118
                                    ],
                                    [
                                        113.877859,
                                        22.726455
                                    ],
                                    [
                                        113.87831,
                                        22.726277
                                    ],
                                    [
                                        113.878653,
                                        22.72601
                                    ],
                                    [
                                        113.878814,
                                        22.72503
                                    ],
                                    [
                                        113.878771,
                                        22.724446
                                    ],
                                    [
                                        113.878385,
                                        22.723949
                                    ],
                                    [
                                        113.878343,
                                        22.723533
                                    ],
                                    [
                                        113.878171,
                                        22.723444
                                    ],
                                    [
                                        113.878171,
                                        22.723196
                                    ],
                                    [
                                        113.878557,
                                        22.722444
                                    ],
                                    [
                                        113.878836,
                                        22.722128
                                    ],
                                    [
                                        113.879233,
                                        22.721257
                                    ],
                                    [
                                        113.879727,
                                        22.720445
                                    ],
                                    [
                                        113.880531,
                                        22.719723
                                    ],
                                    [
                                        113.881744,
                                        22.719139
                                    ],
                                    [
                                        113.881947,
                                        22.718694
                                    ],
                                    [
                                        113.88198,
                                        22.718397
                                    ],
                                    [
                                        113.882312,
                                        22.717793
                                    ],
                                    [
                                        113.882044,
                                        22.717229
                                    ],
                                    [
                                        113.882065,
                                        22.716724
                                    ],
                                    [
                                        113.881904,
                                        22.715507
                                    ],
                                    [
                                        113.879865,
                                        22.714792
                                    ],
                                    [
                                        113.878461,
                                        22.714782
                                    ],
                                    [
                                        113.878106,
                                        22.714861
                                    ],
                                    [
                                        113.877677,
                                        22.714732
                                    ],
                                    [
                                        113.876379,
                                        22.714277
                                    ],
                                    [
                                        113.875703,
                                        22.713802
                                    ],
                                    [
                                        113.875037,
                                        22.713367
                                    ],
                                    [
                                        113.875037,
                                        22.71304
                                    ],
                                    [
                                        113.874973,
                                        22.712565
                                    ],
                                    [
                                        113.875027,
                                        22.712268
                                    ],
                                    [
                                        113.875295,
                                        22.711892
                                    ],
                                    [
                                        113.875381,
                                        22.711803
                                    ],
                                    [
                                        113.875617,
                                        22.711753
                                    ],
                                    [
                                        113.876142,
                                        22.711387
                                    ],
                                    [
                                        113.87684,
                                        22.71117
                                    ],
                                    [
                                        113.876936,
                                        22.71108
                                    ],
                                    [
                                        113.876733,
                                        22.710873
                                    ],
                                    [
                                        113.876218,
                                        22.709972
                                    ],
                                    [
                                        113.875713,
                                        22.709299
                                    ],
                                    [
                                        113.874887,
                                        22.708713
                                    ],
                                    [
                                        113.874565,
                                        22.708189
                                    ],
                                    [
                                        113.874179,
                                        22.707842
                                    ],
                                    [
                                        113.874351,
                                        22.707446
                                    ],
                                    [
                                        113.874748,
                                        22.706427
                                    ],
                                    [
                                        113.875853,
                                        22.704457
                                    ],
                                    [
                                        113.876057,
                                        22.704408
                                    ],
                                    [
                                        113.876593,
                                        22.704674
                                    ],
                                    [
                                        113.876775,
                                        22.70412
                                    ],
                                    [
                                        113.876926,
                                        22.703437
                                    ],
                                    [
                                        113.876926,
                                        22.703081
                                    ],
                                    [
                                        113.877012,
                                        22.703011
                                    ],
                                    [
                                        113.877258,
                                        22.702982
                                    ],
                                    [
                                        113.877301,
                                        22.702596
                                    ],
                                    [
                                        113.877956,
                                        22.702259
                                    ],
                                    [
                                        113.878202,
                                        22.702239
                                    ],
                                    [
                                        113.878717,
                                        22.7022
                                    ],
                                    [
                                        113.879962,
                                        22.702467
                                    ],
                                    [
                                        113.88067,
                                        22.702398
                                    ],
                                    [
                                        113.880799,
                                        22.702012
                                    ],
                                    [
                                        113.881003,
                                        22.701685
                                    ],
                                    [
                                        113.880831,
                                        22.701447
                                    ],
                                    [
                                        113.880627,
                                        22.70122
                                    ],
                                    [
                                        113.880455,
                                        22.700764
                                    ],
                                    [
                                        113.880252,
                                        22.700764
                                    ],
                                    [
                                        113.879833,
                                        22.700873
                                    ],
                                    [
                                        113.879662,
                                        22.700804
                                    ],
                                    [
                                        113.878835,
                                        22.700764
                                    ],
                                    [
                                        113.878632,
                                        22.700685
                                    ],
                                    [
                                        113.878095,
                                        22.700863
                                    ],
                                    [
                                        113.877977,
                                        22.700953
                                    ],
                                    [
                                        113.877913,
                                        22.70123
                                    ],
                                    [
                                        113.877398,
                                        22.701249
                                    ],
                                    [
                                        113.877698,
                                        22.699418
                                    ],
                                    [
                                        113.878009,
                                        22.698884
                                    ],
                                    [
                                        113.878127,
                                        22.698755
                                    ],
                                    [
                                        113.878417,
                                        22.698636
                                    ],
                                    [
                                        113.878803,
                                        22.698369
                                    ],
                                    [
                                        113.878953,
                                        22.698092
                                    ],
                                    [
                                        113.879071,
                                        22.697488
                                    ],
                                    [
                                        113.879372,
                                        22.697092
                                    ],
                                    [
                                        113.87949,
                                        22.696776
                                    ],
                                    [
                                        113.879597,
                                        22.696597
                                    ],
                                    [
                                        113.879619,
                                        22.69638
                                    ],
                                    [
                                        113.879726,
                                        22.69621
                                    ],
                                    [
                                        113.879651,
                                        22.695992
                                    ],
                                    [
                                        113.879522,
                                        22.695695
                                    ],
                                    [
                                        113.879329,
                                        22.695606
                                    ],
                                    [
                                        113.879082,
                                        22.695408
                                    ],
                                    [
                                        113.878889,
                                        22.695378
                                    ],
                                    [
                                        113.878256,
                                        22.695091
                                    ],
                                    [
                                        113.878009,
                                        22.695072
                                    ],
                                    [
                                        113.877655,
                                        22.694824
                                    ],
                                    [
                                        113.877365,
                                        22.694389
                                    ],
                                    [
                                        113.876722,
                                        22.694191
                                    ],
                                    [
                                        113.876174,
                                        22.694032
                                    ],
                                    [
                                        113.875885,
                                        22.693824
                                    ],
                                    [
                                        113.875777,
                                        22.693547
                                    ],
                                    [
                                        113.875445,
                                        22.692924
                                    ],
                                    [
                                        113.875348,
                                        22.692775
                                    ],
                                    [
                                        113.875187,
                                        22.692686
                                    ],
                                    [
                                        113.874984,
                                        22.6923
                                    ],
                                    [
                                        113.874984,
                                        22.692191
                                    ],
                                    [
                                        113.874522,
                                        22.692053
                                    ],
                                    [
                                        113.874297,
                                        22.691696
                                    ],
                                    [
                                        113.874845,
                                        22.691292
                                    ],
                                    [
                                        113.875403,
                                        22.690856
                                    ],
                                    [
                                        113.875747,
                                        22.690579
                                    ],
                                    [
                                        113.876133,
                                        22.690064
                                    ],
                                    [
                                        113.876691,
                                        22.689629
                                    ],
                                    [
                                        113.877377,
                                        22.689787
                                    ],
                                    [
                                        113.87742,
                                        22.689787
                                    ],
                                    [
                                        113.878021,
                                        22.688876
                                    ],
                                    [
                                        113.878708,
                                        22.688203
                                    ],
                                    [
                                        113.879351,
                                        22.687689
                                    ],
                                    [
                                        113.879437,
                                        22.687372
                                    ],
                                    [
                                        113.879437,
                                        22.686738
                                    ],
                                    [
                                        113.879566,
                                        22.686303
                                    ],
                                    [
                                        113.879746,
                                        22.68582
                                    ],
                                    [
                                        113.879874,
                                        22.686216
                                    ],
                                    [
                                        113.880153,
                                        22.686454
                                    ],
                                    [
                                        113.880733,
                                        22.686771
                                    ],
                                    [
                                        113.880947,
                                        22.687087
                                    ],
                                    [
                                        113.881312,
                                        22.687424
                                    ],
                                    [
                                        113.881634,
                                        22.687503
                                    ],
                                    [
                                        113.881848,
                                        22.687563
                                    ],
                                    [
                                        113.882127,
                                        22.687543
                                    ],
                                    [
                                        113.882471,
                                        22.688196
                                    ],
                                    [
                                        113.8829,
                                        22.688473
                                    ],
                                    [
                                        113.883672,
                                        22.689938
                                    ],
                                    [
                                        113.889874,
                                        22.689008
                                    ],
                                    [
                                        113.891118,
                                        22.688018
                                    ],
                                    [
                                        113.892279,
                                        22.688139
                                    ],
                                    [
                                        113.892814,
                                        22.688195
                                    ],
                                    [
                                        113.893973,
                                        22.688551
                                    ],
                                    [
                                        113.894746,
                                        22.689224
                                    ],
                                    [
                                        113.897599,
                                        22.691362
                                    ],
                                    [
                                        113.89819,
                                        22.692303
                                    ],
                                    [
                                        113.897739,
                                        22.692817
                                    ],
                                    [
                                        113.896945,
                                        22.694104
                                    ],
                                    [
                                        113.898769,
                                        22.693738
                                    ],
                                    [
                                        113.899553,
                                        22.692511
                                    ],
                                    [
                                        113.899767,
                                        22.69258
                                    ],
                                    [
                                        113.899917,
                                        22.692204
                                    ],
                                    [
                                        113.900304,
                                        22.692075
                                    ],
                                    [
                                        113.901559,
                                        22.692045
                                    ],
                                    [
                                        113.902557,
                                        22.691531
                                    ],
                                    [
                                        113.903211,
                                        22.691303
                                    ],
                                    [
                                        113.904048,
                                        22.690818
                                    ],
                                    [
                                        113.904552,
                                        22.690778
                                    ],
                                    [
                                        113.904928,
                                        22.690867
                                    ],
                                    [
                                        113.905207,
                                        22.690897
                                    ],
                                    [
                                        113.90525,
                                        22.691006
                                    ],
                                    [
                                        113.90511,
                                        22.691115
                                    ],
                                    [
                                        113.905067,
                                        22.691352
                                    ],
                                    [
                                        113.905175,
                                        22.691659
                                    ],
                                    [
                                        113.905185,
                                        22.691907
                                    ],
                                    [
                                        113.905142,
                                        22.692154
                                    ],
                                    [
                                        113.904971,
                                        22.692322
                                    ],
                                    [
                                        113.904928,
                                        22.69252
                                    ],
                                    [
                                        113.904413,
                                        22.692798
                                    ],
                                    [
                                        113.90408,
                                        22.692926
                                    ],
                                    [
                                        113.903951,
                                        22.693787
                                    ],
                                    [
                                        113.90393,
                                        22.694074
                                    ],
                                    [
                                        113.903694,
                                        22.694302
                                    ],
                                    [
                                        113.903769,
                                        22.694599
                                    ],
                                    [
                                        113.903909,
                                        22.695025
                                    ],
                                    [
                                        113.903866,
                                        22.695242
                                    ],
                                    [
                                        113.903715,
                                        22.695431
                                    ],
                                    [
                                        113.903233,
                                        22.695728
                                    ],
                                    [
                                        113.902578,
                                        22.695659
                                    ],
                                    [
                                        113.90216,
                                        22.695451
                                    ],
                                    [
                                        113.901645,
                                        22.695194
                                    ],
                                    [
                                        113.901484,
                                        22.694976
                                    ],
                                    [
                                        113.900422,
                                        22.695154
                                    ],
                                    [
                                        113.901226,
                                        22.695224
                                    ],
                                    [
                                        113.901634,
                                        22.69556
                                    ],
                                    [
                                        113.90187,
                                        22.695837
                                    ],
                                    [
                                        113.902074,
                                        22.696035
                                    ],
                                    [
                                        113.902042,
                                        22.696223
                                    ],
                                    [
                                        113.902085,
                                        22.696421
                                    ],
                                    [
                                        113.901988,
                                        22.69656
                                    ],
                                    [
                                        113.901741,
                                        22.696797
                                    ],
                                    [
                                        113.901795,
                                        22.696956
                                    ],
                                    [
                                        113.902042,
                                        22.697045
                                    ],
                                    [
                                        113.902224,
                                        22.696995
                                    ],
                                    [
                                        113.902482,
                                        22.696976
                                    ],
                                    [
                                        113.902761,
                                        22.697144
                                    ],
                                    [
                                        113.902868,
                                        22.697352
                                    ],
                                    [
                                        113.903018,
                                        22.69754
                                    ],
                                    [
                                        113.903211,
                                        22.69753
                                    ],
                                    [
                                        113.903318,
                                        22.697401
                                    ],
                                    [
                                        113.903651,
                                        22.697371
                                    ],
                                    [
                                        113.903801,
                                        22.697579
                                    ],
                                    [
                                        113.903887,
                                        22.697728
                                    ],
                                    [
                                        113.904123,
                                        22.697837
                                    ],
                                    [
                                        113.906259,
                                        22.700619
                                    ],
                                    [
                                        113.905529,
                                        22.70245
                                    ],
                                    [
                                        113.905781,
                                        22.703975
                                    ],
                                    [
                                        113.905819,
                                        22.704202
                                    ],
                                    [
                                        113.906216,
                                        22.704687
                                    ],
                                    [
                                        113.906227,
                                        22.705124
                                    ],
                                    [
                                        113.907073,
                                        22.705158
                                    ],
                                    [
                                        113.911602,
                                        22.705341
                                    ],
                                    [
                                        113.912017,
                                        22.705577
                                    ],
                                    [
                                        113.912911,
                                        22.706084
                                    ],
                                    [
                                        113.913243,
                                        22.706361
                                    ],
                                    [
                                        113.913265,
                                        22.706945
                                    ],
                                    [
                                        113.913265,
                                        22.707113
                                    ],
                                    [
                                        113.913297,
                                        22.707835
                                    ],
                                    [
                                        113.913801,
                                        22.709043
                                    ],
                                    [
                                        113.913952,
                                        22.709211
                                    ],
                                    [
                                        113.914005,
                                        22.709211
                                    ],
                                    [
                                        113.914209,
                                        22.709201
                                    ],
                                    [
                                        113.914649,
                                        22.70931
                                    ],
                                    [
                                        113.915282,
                                        22.709706
                                    ],
                                    [
                                        113.915936,
                                        22.710043
                                    ],
                                    [
                                        113.915958,
                                        22.710151
                                    ],
                                    [
                                        113.916044,
                                        22.710211
                                    ],
                                    [
                                        113.916247,
                                        22.710181
                                    ],
                                    [
                                        113.916226,
                                        22.709934
                                    ],
                                    [
                                        113.916451,
                                        22.709577
                                    ],
                                    [
                                        113.916623,
                                        22.709389
                                    ],
                                    [
                                        113.916829,
                                        22.709251
                                    ],
                                    [
                                        113.917215,
                                        22.70931
                                    ],
                                    [
                                        113.917709,
                                        22.70931
                                    ],
                                    [
                                        113.918074,
                                        22.709211
                                    ],
                                    [
                                        113.918267,
                                        22.70937
                                    ],
                                    [
                                        113.918546,
                                        22.709429
                                    ],
                                    [
                                        113.919039,
                                        22.709667
                                    ],
                                    [
                                        113.919597,
                                        22.709805
                                    ],
                                    [
                                        113.920348,
                                        22.709469
                                    ],
                                    [
                                        113.920756,
                                        22.709429
                                    ],
                                    [
                                        113.920928,
                                        22.70931
                                    ],
                                    [
                                        113.921164,
                                        22.709211
                                    ],
                                    [
                                        113.921486,
                                        22.70937
                                    ],
                                    [
                                        113.922043,
                                        22.709409
                                    ],
                                    [
                                        113.922515,
                                        22.70931
                                    ],
                                    [
                                        113.923202,
                                        22.709231
                                    ],
                                    [
                                        113.923545,
                                        22.709389
                                    ],
                                    [
                                        113.923824,
                                        22.709469
                                    ],
                                    [
                                        113.924254,
                                        22.709389
                                    ],
                                    [
                                        113.924705,
                                        22.709577
                                    ],
                                    [
                                        113.924877,
                                        22.709478
                                    ],
                                    [
                                        113.925156,
                                        22.709468
                                    ],
                                    [
                                        113.925563,
                                        22.709092
                                    ],
                                    [
                                        113.925778,
                                        22.708933
                                    ],
                                    [
                                        113.92596,
                                        22.708904
                                    ],
                                    [
                                        113.926078,
                                        22.708567
                                    ],
                                    [
                                        113.926239,
                                        22.70832
                                    ],
                                    [
                                        113.927108,
                                        22.70729
                                    ],
                                    [
                                        113.927452,
                                        22.706934
                                    ],
                                    [
                                        113.927495,
                                        22.706776
                                    ],
                                    [
                                        113.927409,
                                        22.706558
                                    ],
                                    [
                                        113.927623,
                                        22.705717
                                    ],
                                    [
                                        113.927956,
                                        22.705895
                                    ],
                                    [
                                        113.928385,
                                        22.706033
                                    ],
                                    [
                                        113.928578,
                                        22.706033
                                    ],
                                    [
                                        113.928761,
                                        22.706202
                                    ],
                                    [
                                        113.928857,
                                        22.706271
                                    ],
                                    [
                                        113.929211,
                                        22.706528
                                    ],
                                    [
                                        113.929286,
                                        22.706716
                                    ],
                                    [
                                        113.929372,
                                        22.707013
                                    ],
                                    [
                                        113.929597,
                                        22.7073
                                    ],
                                    [
                                        113.929855,
                                        22.707498
                                    ],
                                    [
                                        113.930198,
                                        22.707696
                                    ],
                                    [
                                        113.930617,
                                        22.707696
                                    ],
                                    [
                                        113.931314,
                                        22.708033
                                    ],
                                    [
                                        113.931915,
                                        22.707944
                                    ],
                                    [
                                        113.932194,
                                        22.708072
                                    ],
                                    [
                                        113.932376,
                                        22.708013
                                    ],
                                    [
                                        113.933214,
                                        22.707775
                                    ],
                                    [
                                        113.933032,
                                        22.707488
                                    ],
                                    [
                                        113.933074,
                                        22.70735
                                    ],
                                    [
                                        113.933729,
                                        22.706974
                                    ],
                                    [
                                        113.934051,
                                        22.706934
                                    ],
                                    [
                                        113.934501,
                                        22.706637
                                    ],
                                    [
                                        113.935091,
                                        22.7064
                                    ],
                                    [
                                        113.935188,
                                        22.706231
                                    ],
                                    [
                                        113.935306,
                                        22.705825
                                    ],
                                    [
                                        113.935757,
                                        22.705331
                                    ],
                                    [
                                        113.935993,
                                        22.705123
                                    ],
                                    [
                                        113.936025,
                                        22.704875
                                    ],
                                    [
                                        113.936347,
                                        22.704183
                                    ],
                                    [
                                        113.936658,
                                        22.704044
                                    ],
                                    [
                                        113.936991,
                                        22.703678
                                    ],
                                    [
                                        113.937162,
                                        22.703618
                                    ],
                                    [
                                        113.937291,
                                        22.7035
                                    ],
                                    [
                                        113.93728,
                                        22.703094
                                    ],
                                    [
                                        113.937377,
                                        22.703005
                                    ],
                                    [
                                        113.937763,
                                        22.702876
                                    ],
                                    [
                                        113.938278,
                                        22.702836
                                    ],
                                    [
                                        113.938428,
                                        22.702916
                                    ],
                                    [
                                        113.938782,
                                        22.703084
                                    ],
                                    [
                                        113.939233,
                                        22.7035
                                    ],
                                    [
                                        113.939769,
                                        22.703915
                                    ],
                                    [
                                        113.940424,
                                        22.704202
                                    ],
                                    [
                                        113.940456,
                                        22.704598
                                    ],
                                    [
                                        113.940477,
                                        22.704717
                                    ],
                                    [
                                        113.940917,
                                        22.70542
                                    ],
                                    [
                                        113.941057,
                                        22.705796
                                    ],
                                    [
                                        113.941035,
                                        22.706033
                                    ],
                                    [
                                        113.940928,
                                        22.70638
                                    ],
                                    [
                                        113.94052,
                                        22.706835
                                    ],
                                    [
                                        113.940413,
                                        22.706845
                                    ],
                                    [
                                        113.939844,
                                        22.707429
                                    ],
                                    [
                                        113.938588,
                                        22.708715
                                    ],
                                    [
                                        113.940863,
                                        22.708517
                                    ],
                                    [
                                        113.942107,
                                        22.709902
                                    ],
                                    [
                                        113.94288,
                                        22.71113
                                    ],
                                    [
                                        113.946615,
                                        22.711248
                                    ],
                                    [
                                        113.947516,
                                        22.712
                                    ],
                                    [
                                        113.950521,
                                        22.714059
                                    ],
                                    [
                                        113.950735,
                                        22.714376
                                    ],
                                    [
                                        113.951121,
                                        22.715286
                                    ],
                                    [
                                        113.951593,
                                        22.71584
                                    ],
                                    [
                                        113.952151,
                                        22.717068
                                    ],
                                    [
                                        113.952495,
                                        22.718176
                                    ],
                                    [
                                        113.953138,
                                        22.717463
                                    ],
                                    [
                                        113.954683,
                                        22.717899
                                    ],
                                    [
                                        113.955756,
                                        22.716949
                                    ],
                                    [
                                        113.956572,
                                        22.718849
                                    ],
                                    [
                                        113.957945,
                                        22.717978
                                    ],
                                    [
                                        113.958159,
                                        22.717463
                                    ],
                                    [
                                        113.958202,
                                        22.717226
                                    ],
                                    [
                                        113.958589,
                                        22.716949
                                    ],
                                    [
                                        113.958761,
                                        22.716672
                                    ],
                                    [
                                        113.95876,
                                        22.716038
                                    ],
                                    [
                                        113.959146,
                                        22.71588
                                    ],
                                    [
                                        113.959576,
                                        22.715643
                                    ],
                                    [
                                        113.959747,
                                        22.715286
                                    ],
                                    [
                                        113.959919,
                                        22.71489
                                    ],
                                    [
                                        113.959876,
                                        22.714336
                                    ],
                                    [
                                        113.960348,
                                        22.714099
                                    ],
                                    [
                                        113.960691,
                                        22.714059
                                    ],
                                    [
                                        113.961249,
                                        22.714178
                                    ],
                                    [
                                        113.961206,
                                        22.714613
                                    ],
                                    [
                                        113.961551,
                                        22.715128
                                    ],
                                    [
                                        113.961636,
                                        22.715563
                                    ],
                                    [
                                        113.961979,
                                        22.715603
                                    ],
                                    [
                                        113.962537,
                                        22.715524
                                    ],
                                    [
                                        113.962751,
                                        22.715445
                                    ],
                                    [
                                        113.963223,
                                        22.714772
                                    ],
                                    [
                                        113.963481,
                                        22.714297
                                    ],
                                    [
                                        113.963738,
                                        22.713742
                                    ],
                                    [
                                        113.964339,
                                        22.713228
                                    ],
                                    [
                                        113.965026,
                                        22.71299
                                    ],
                                    [
                                        113.96567,
                                        22.712673
                                    ],
                                    [
                                        113.966313,
                                        22.712594
                                    ],
                                    [
                                        113.967001,
                                        22.712515
                                    ],
                                    [
                                        113.967472,
                                        22.712515
                                    ],
                                    [
                                        113.967859,
                                        22.712357
                                    ],
                                    [
                                        113.96803,
                                        22.711921
                                    ],
                                    [
                                        113.968459,
                                        22.711011
                                    ],
                                    [
                                        113.969618,
                                        22.710694
                                    ],
                                    [
                                        113.970263,
                                        22.7101
                                    ],
                                    [
                                        113.971034,
                                        22.710219
                                    ],
                                    [
                                        113.971293,
                                        22.710575
                                    ],
                                    [
                                        113.971678,
                                        22.710813
                                    ],
                                    [
                                        113.971721,
                                        22.711011
                                    ],
                                    [
                                        113.972021,
                                        22.711288
                                    ],
                                    [
                                        113.972321,
                                        22.711288
                                    ],
                                    [
                                        113.972708,
                                        22.711644
                                    ],
                                    [
                                        113.973351,
                                        22.711605
                                    ],
                                    [
                                        113.973952,
                                        22.711842
                                    ],
                                    [
                                        113.974725,
                                        22.711486
                                    ],
                                    [
                                        113.975541,
                                        22.711723
                                    ],
                                    [
                                        113.976184,
                                        22.71204
                                    ],
                                    [
                                        113.976484,
                                        22.712317
                                    ],
                                    [
                                        113.977257,
                                        22.712753
                                    ],
                                    [
                                        113.977859,
                                        22.712198
                                    ],
                                    [
                                        113.977986,
                                        22.711723
                                    ],
                                    [
                                        113.977986,
                                        22.710971
                                    ],
                                    [
                                        113.978201,
                                        22.710417
                                    ],
                                    [
                                        113.978072,
                                        22.710219
                                    ],
                                    [
                                        113.977729,
                                        22.709823
                                    ],
                                    [
                                        113.977428,
                                        22.709111
                                    ],
                                    [
                                        113.976871,
                                        22.709111
                                    ],
                                    [
                                        113.976956,
                                        22.708636
                                    ],
                                    [
                                        113.976399,
                                        22.707804
                                    ],
                                    [
                                        113.976742,
                                        22.707685
                                    ],
                                    [
                                        113.976742,
                                        22.707171
                                    ],
                                    [
                                        113.97627,
                                        22.706419
                                    ],
                                    [
                                        113.975454,
                                        22.703964
                                    ],
                                    [
                                        113.975454,
                                        22.703647
                                    ],
                                    [
                                        113.973781,
                                        22.70337
                                    ],
                                    [
                                        113.973652,
                                        22.701945
                                    ],
                                    [
                                        113.975799,
                                        22.702816
                                    ],
                                    [
                                        113.976441,
                                        22.702024
                                    ],
                                    [
                                        113.975883,
                                        22.701351
                                    ],
                                    [
                                        113.976957,
                                        22.701154
                                    ],
                                    [
                                        113.976786,
                                        22.700441
                                    ],
                                    [
                                        113.974769,
                                        22.700402
                                    ],
                                    [
                                        113.974769,
                                        22.699887
                                    ],
                                    [
                                        113.975026,
                                        22.699531
                                    ],
                                    [
                                        113.976142,
                                        22.699768
                                    ],
                                    [
                                        113.976743,
                                        22.700046
                                    ],
                                    [
                                        113.977215,
                                        22.699808
                                    ],
                                    [
                                        113.97803,
                                        22.699966
                                    ],
                                    [
                                        113.97803,
                                        22.69957
                                    ],
                                    [
                                        113.978373,
                                        22.699333
                                    ],
                                    [
                                        113.978588,
                                        22.699175
                                    ],
                                    [
                                        113.978803,
                                        22.698779
                                    ],
                                    [
                                        113.97979,
                                        22.698937
                                    ],
                                    [
                                        113.980047,
                                        22.698422
                                    ],
                                    [
                                        113.979918,
                                        22.697353
                                    ],
                                    [
                                        113.98009,
                                        22.696482
                                    ],
                                    [
                                        113.978288,
                                        22.696245
                                    ],
                                    [
                                        113.977858,
                                        22.697472
                                    ],
                                    [
                                        113.975627,
                                        22.696126
                                    ],
                                    [
                                        113.97597,
                                        22.695215
                                    ],
                                    [
                                        113.978545,
                                        22.695057
                                    ],
                                    [
                                        113.978288,
                                        22.693709
                                    ],
                                    [
                                        113.976829,
                                        22.693412
                                    ],
                                    [
                                        113.975911,
                                        22.693715
                                    ],
                                    [
                                        113.975436,
                                        22.693736
                                    ],
                                    [
                                        113.974533,
                                        22.693234
                                    ],
                                    [
                                        113.974919,
                                        22.692541
                                    ],
                                    [
                                        113.975455,
                                        22.692224
                                    ],
                                    [
                                        113.975756,
                                        22.691907
                                    ],
                                    [
                                        113.97434,
                                        22.69064
                                    ],
                                    [
                                        113.97537,
                                        22.689215
                                    ],
                                    [
                                        113.97449,
                                        22.688007
                                    ],
                                    [
                                        113.973889,
                                        22.686127
                                    ],
                                    [
                                        113.975477,
                                        22.686325
                                    ],
                                    [
                                        113.975627,
                                        22.68486
                                    ],
                                    [
                                        113.974919,
                                        22.683889
                                    ],
                                    [
                                        113.974608,
                                        22.683288
                                    ],
                                    [
                                        113.974232,
                                        22.682563
                                    ],
                                    [
                                        113.974576,
                                        22.680425
                                    ],
                                    [
                                        113.97275,
                                        22.680167
                                    ],
                                    [
                                        113.972471,
                                        22.680345
                                    ],
                                    [
                                        113.971034,
                                        22.679691
                                    ],
                                    [
                                        113.97039,
                                        22.679256
                                    ],
                                    [
                                        113.969789,
                                        22.678721
                                    ],
                                    [
                                        113.970347,
                                        22.678325
                                    ],
                                    [
                                        113.970712,
                                        22.677652
                                    ],
                                    [
                                        113.969752,
                                        22.677137
                                    ],
                                    [
                                        113.968866,
                                        22.676662
                                    ],
                                    [
                                        113.968479,
                                        22.675039
                                    ],
                                    [
                                        113.967492,
                                        22.67393
                                    ],
                                    [
                                        113.96702,
                                        22.67298
                                    ],
                                    [
                                        113.967793,
                                        22.672346
                                    ],
                                    [
                                        113.96805,
                                        22.670802
                                    ],
                                    [
                                        113.968308,
                                        22.670524
                                    ],
                                    [
                                        113.969981,
                                        22.669534
                                    ],
                                    [
                                        113.97057,
                                        22.668277
                                    ],
                                    [
                                        113.971355,
                                        22.666604
                                    ],
                                    [
                                        113.972857,
                                        22.664822
                                    ],
                                    [
                                        113.973415,
                                        22.664228
                                    ],
                                    [
                                        113.973114,
                                        22.663713
                                    ],
                                    [
                                        113.973458,
                                        22.663317
                                    ],
                                    [
                                        113.973286,
                                        22.662961
                                    ],
                                    [
                                        113.972814,
                                        22.662723
                                    ],
                                    [
                                        113.972814,
                                        22.662129
                                    ],
                                    [
                                        113.973028,
                                        22.661495
                                    ],
                                    [
                                        113.973329,
                                        22.661099
                                    ],
                                    [
                                        113.972943,
                                        22.660545
                                    ],
                                    [
                                        113.972556,
                                        22.659991
                                    ],
                                    [
                                        113.972642,
                                        22.659397
                                    ],
                                    [
                                        113.972428,
                                        22.659199
                                    ],
                                    [
                                        113.972084,
                                        22.658446
                                    ],
                                    [
                                        113.972642,
                                        22.657456
                                    ],
                                    [
                                        113.972385,
                                        22.657179
                                    ],
                                    [
                                        113.970454,
                                        22.655991
                                    ],
                                    [
                                        113.970454,
                                        22.655555
                                    ],
                                    [
                                        113.970282,
                                        22.655159
                                    ],
                                    [
                                        113.970411,
                                        22.653733
                                    ],
                                    [
                                        113.969767,
                                        22.653258
                                    ],
                                    [
                                        113.96908,
                                        22.652743
                                    ],
                                    [
                                        113.967492,
                                        22.652822
                                    ],
                                    [
                                        113.967321,
                                        22.652624
                                    ],
                                    [
                                        113.967492,
                                        22.65207
                                    ],
                                    [
                                        113.967535,
                                        22.651476
                                    ],
                                    [
                                        113.967084,
                                        22.650781
                                    ],
                                    [
                                        113.966456,
                                        22.651328
                                    ],
                                    [
                                        113.966024,
                                        22.651497
                                    ],
                                    [
                                        113.965801,
                                        22.651516
                                    ],
                                    [
                                        113.965302,
                                        22.651319
                                    ],
                                    [
                                        113.964344,
                                        22.65119
                                    ],
                                    [
                                        113.963145,
                                        22.651306
                                    ],
                                    [
                                        113.961149,
                                        22.651307
                                    ],
                                    [
                                        113.960614,
                                        22.651643
                                    ],
                                    [
                                        113.960363,
                                        22.652316
                                    ],
                                    [
                                        113.959993,
                                        22.652478
                                    ],
                                    [
                                        113.959099,
                                        22.652274
                                    ],
                                    [
                                        113.957607,
                                        22.651594
                                    ],
                                    [
                                        113.956545,
                                        22.650684
                                    ],
                                    [
                                        113.955687,
                                        22.65013
                                    ],
                                    [
                                        113.955264,
                                        22.649302
                                    ],
                                    [
                                        113.955102,
                                        22.649244
                                    ],
                                    [
                                        113.954701,
                                        22.649336
                                    ],
                                    [
                                        113.954064,
                                        22.649954
                                    ],
                                    [
                                        113.953731,
                                        22.650428
                                    ],
                                    [
                                        113.952901,
                                        22.650974
                                    ],
                                    [
                                        113.951901,
                                        22.650544
                                    ],
                                    [
                                        113.950852,
                                        22.650829
                                    ],
                                    [
                                        113.950394,
                                        22.651823
                                    ],
                                    [
                                        113.949977,
                                        22.652195
                                    ],
                                    [
                                        113.949403,
                                        22.652198
                                    ],
                                    [
                                        113.947957,
                                        22.651412
                                    ],
                                    [
                                        113.946719,
                                        22.65097
                                    ],
                                    [
                                        113.944708,
                                        22.650764
                                    ],
                                    [
                                        113.944034,
                                        22.650592
                                    ],
                                    [
                                        113.94294,
                                        22.649521
                                    ],
                                    [
                                        113.942076,
                                        22.649049
                                    ],
                                    [
                                        113.940771,
                                        22.64762
                                    ],
                                    [
                                        113.940518,
                                        22.64625
                                    ],
                                    [
                                        113.940348,
                                        22.646118
                                    ],
                                    [
                                        113.938414,
                                        22.645359
                                    ],
                                    [
                                        113.937525,
                                        22.645089
                                    ],
                                    [
                                        113.93745,
                                        22.64489
                                    ],
                                    [
                                        113.93766,
                                        22.644316
                                    ],
                                    [
                                        113.937709,
                                        22.643861
                                    ],
                                    [
                                        113.937647,
                                        22.643078
                                    ],
                                    [
                                        113.937016,
                                        22.641091
                                    ],
                                    [
                                        113.936585,
                                        22.638683
                                    ],
                                    [
                                        113.936319,
                                        22.638315
                                    ],
                                    [
                                        113.936013,
                                        22.638088
                                    ],
                                    [
                                        113.934813,
                                        22.637867
                                    ],
                                    [
                                        113.93395,
                                        22.63706
                                    ],
                                    [
                                        113.93235,
                                        22.63656
                                    ],
                                    [
                                        113.931865,
                                        22.635494
                                    ],
                                    [
                                        113.931863,
                                        22.635328
                                    ],
                                    [
                                        113.931862,
                                        22.635271
                                    ],
                                    [
                                        113.931831,
                                        22.635137
                                    ],
                                    [
                                        113.931664,
                                        22.634819
                                    ],
                                    [
                                        113.931652,
                                        22.634805
                                    ],
                                    [
                                        113.931588,
                                        22.634762
                                    ],
                                    [
                                        113.931564,
                                        22.634746
                                    ],
                                    [
                                        113.9315,
                                        22.634716
                                    ],
                                    [
                                        113.931414,
                                        22.634676
                                    ],
                                    [
                                        113.930173,
                                        22.634226
                                    ],
                                    [
                                        113.929862,
                                        22.63392
                                    ],
                                    [
                                        113.929344,
                                        22.633061
                                    ],
                                    [
                                        113.928918,
                                        22.631714
                                    ],
                                    [
                                        113.928934,
                                        22.631353
                                    ],
                                    [
                                        113.929464,
                                        22.630958
                                    ],
                                    [
                                        113.929993,
                                        22.630196
                                    ],
                                    [
                                        113.930159,
                                        22.629482
                                    ],
                                    [
                                        113.930167,
                                        22.629124
                                    ],
                                    [
                                        113.92991,
                                        22.628643
                                    ],
                                    [
                                        113.929755,
                                        22.628016
                                    ],
                                    [
                                        113.929301,
                                        22.627625
                                    ],
                                    [
                                        113.929163,
                                        22.627361
                                    ],
                                    [
                                        113.929142,
                                        22.626959
                                    ],
                                    [
                                        113.929288,
                                        22.626181
                                    ],
                                    [
                                        113.929786,
                                        22.625435
                                    ],
                                    [
                                        113.93035,
                                        22.62485
                                    ],
                                    [
                                        113.931166,
                                        22.623588
                                    ],
                                    [
                                        113.931259,
                                        22.623021
                                    ],
                                    [
                                        113.930692,
                                        22.621007
                                    ],
                                    [
                                        113.930454,
                                        22.619323
                                    ],
                                    [
                                        113.93024,
                                        22.619045
                                    ],
                                    [
                                        113.92962,
                                        22.618568
                                    ],
                                    [
                                        113.9275,
                                        22.6156
                                    ],
                                    [
                                        113.9275,
                                        22.615102
                                    ],
                                    [
                                        113.927543,
                                        22.614957
                                    ],
                                    [
                                        113.927557,
                                        22.61492
                                    ],
                                    [
                                        113.928843,
                                        22.612358
                                    ],
                                    [
                                        113.929563,
                                        22.611554
                                    ],
                                    [
                                        113.929948,
                                        22.610348
                                    ],
                                    [
                                        113.929965,
                                        22.610234
                                    ],
                                    [
                                        113.929972,
                                        22.610187
                                    ],
                                    [
                                        113.929977,
                                        22.610157
                                    ],
                                    [
                                        113.93,
                                        22.609995
                                    ],
                                    [
                                        113.930077,
                                        22.609244
                                    ],
                                    [
                                        113.929965,
                                        22.607856
                                    ],
                                    [
                                        113.929132,
                                        22.606991
                                    ],
                                    [
                                        113.928651,
                                        22.606767
                                    ],
                                    [
                                        113.928561,
                                        22.606725
                                    ],
                                    [
                                        113.928544,
                                        22.606631
                                    ],
                                    [
                                        113.928322,
                                        22.60543
                                    ],
                                    [
                                        113.927825,
                                        22.604006
                                    ],
                                    [
                                        113.927424,
                                        22.603717
                                    ],
                                    [
                                        113.926841,
                                        22.603493
                                    ],
                                    [
                                        113.925035,
                                        22.603184
                                    ],
                                    [
                                        113.924254,
                                        22.601916
                                    ],
                                    [
                                        113.923531,
                                        22.600115
                                    ],
                                    [
                                        113.923627,
                                        22.599601
                                    ],
                                    [
                                        113.924093,
                                        22.598614
                                    ],
                                    [
                                        113.925816,
                                        22.59544
                                    ],
                                    [
                                        113.926206,
                                        22.594206
                                    ],
                                    [
                                        113.926287,
                                        22.593322
                                    ],
                                    [
                                        113.926544,
                                        22.592785
                                    ],
                                    [
                                        113.927025,
                                        22.592243
                                    ],
                                    [
                                        113.928004,
                                        22.59214
                                    ],
                                    [
                                        113.928356,
                                        22.591802
                                    ],
                                    [
                                        113.928499,
                                        22.591459
                                    ],
                                    [
                                        113.928541,
                                        22.590779
                                    ],
                                    [
                                        113.928093,
                                        22.59069
                                    ],
                                    [
                                        113.926281,
                                        22.590812
                                    ],
                                    [
                                        113.924665,
                                        22.590255
                                    ],
                                    [
                                        113.924468,
                                        22.589961
                                    ],
                                    [
                                        113.924363,
                                        22.588472
                                    ],
                                    [
                                        113.924418,
                                        22.587616
                                    ],
                                    [
                                        113.924725,
                                        22.586906
                                    ],
                                    [
                                        113.924802,
                                        22.586728
                                    ],
                                    [
                                        113.924808,
                                        22.586691
                                    ],
                                    [
                                        113.924794,
                                        22.586617
                                    ],
                                    [
                                        113.924832,
                                        22.586498
                                    ],
                                    [
                                        113.924931,
                                        22.585717
                                    ],
                                    [
                                        113.92479,
                                        22.584824
                                    ],
                                    [
                                        113.924939,
                                        22.584584
                                    ],
                                    [
                                        113.926679,
                                        22.583406
                                    ],
                                    [
                                        113.928202,
                                        22.582612
                                    ],
                                    [
                                        113.92833,
                                        22.582339
                                    ],
                                    [
                                        113.929032,
                                        22.581509
                                    ],
                                    [
                                        113.92914,
                                        22.581349
                                    ],
                                    [
                                        113.929452,
                                        22.580924
                                    ],
                                    [
                                        113.929525,
                                        22.580826
                                    ],
                                    [
                                        113.92954,
                                        22.580794
                                    ],
                                    [
                                        113.929544,
                                        22.580756
                                    ],
                                    [
                                        113.929542,
                                        22.580689
                                    ],
                                    [
                                        113.929538,
                                        22.58062
                                    ],
                                    [
                                        113.929443,
                                        22.58053
                                    ],
                                    [
                                        113.929368,
                                        22.580436
                                    ],
                                    [
                                        113.929349,
                                        22.580208
                                    ],
                                    [
                                        113.929158,
                                        22.57919
                                    ],
                                    [
                                        113.929032,
                                        22.578768
                                    ],
                                    [
                                        113.928268,
                                        22.577563
                                    ],
                                    [
                                        113.927574,
                                        22.576005
                                    ],
                                    [
                                        113.927134,
                                        22.574948
                                    ],
                                    [
                                        113.926967,
                                        22.574409
                                    ],
                                    [
                                        113.926747,
                                        22.574115
                                    ],
                                    [
                                        113.926499,
                                        22.573849
                                    ],
                                    [
                                        113.923832,
                                        22.572253
                                    ],
                                    [
                                        113.922918,
                                        22.571809
                                    ],
                                    [
                                        113.922476,
                                        22.571586
                                    ],
                                    [
                                        113.922444,
                                        22.571569
                                    ],
                                    [
                                        113.922418,
                                        22.571556
                                    ],
                                    [
                                        113.92221,
                                        22.571361
                                    ],
                                    [
                                        113.921703,
                                        22.570887
                                    ],
                                    [
                                        113.921328,
                                        22.570537
                                    ],
                                    [
                                        113.918346,
                                        22.567801
                                    ],
                                    [
                                        113.917555,
                                        22.567129
                                    ],
                                    [
                                        113.91617,
                                        22.565936
                                    ],
                                    [
                                        113.916,
                                        22.565704
                                    ],
                                    [
                                        113.915911,
                                        22.565137
                                    ],
                                    [
                                        113.915992,
                                        22.561349
                                    ],
                                    [
                                        113.916038,
                                        22.561284
                                    ],
                                    [
                                        113.915995,
                                        22.5612
                                    ],
                                    [
                                        113.916033,
                                        22.559442
                                    ],
                                    [
                                        113.916053,
                                        22.559057
                                    ],
                                    [
                                        113.916053,
                                        22.558876
                                    ],
                                    [
                                        113.916064,
                                        22.55885
                                    ],
                                    [
                                        113.916109,
                                        22.557956
                                    ],
                                    [
                                        113.916075,
                                        22.557266
                                    ],
                                    [
                                        113.916024,
                                        22.55714
                                    ],
                                    [
                                        113.915983,
                                        22.557099
                                    ],
                                    [
                                        113.915982,
                                        22.557034
                                    ],
                                    [
                                        113.915773,
                                        22.556776
                                    ],
                                    [
                                        113.91303,
                                        22.554824
                                    ],
                                    [
                                        113.911506,
                                        22.553735
                                    ],
                                    [
                                        113.910687,
                                        22.553158
                                    ],
                                    [
                                        113.909511,
                                        22.552186
                                    ],
                                    [
                                        113.908889,
                                        22.551665
                                    ],
                                    [
                                        113.905089,
                                        22.548384
                                    ],
                                    [
                                        113.903663,
                                        22.547225
                                    ],
                                    [
                                        113.903645,
                                        22.547207
                                    ],
                                    [
                                        113.90358,
                                        22.547155
                                    ],
                                    [
                                        113.903559,
                                        22.54714
                                    ],
                                    [
                                        113.903411,
                                        22.54702
                                    ],
                                    [
                                        113.903396,
                                        22.547005
                                    ],
                                    [
                                        113.903379,
                                        22.546994
                                    ],
                                    [
                                        113.901389,
                                        22.545377
                                    ],
                                    [
                                        113.895649,
                                        22.54308
                                    ],
                                    [
                                        113.860929,
                                        22.526416
                                    ],
                                    [
                                        113.859683,
                                        22.529361
                                    ],
                                    [
                                        113.856557,
                                        22.539622
                                    ],
                                    [
                                        113.855847,
                                        22.541134
                                    ],
                                    [
                                        113.854756,
                                        22.542312
                                    ],
                                    [
                                        113.85299,
                                        22.542864
                                    ],
                                    [
                                        113.851154,
                                        22.542592
                                    ],
                                    [
                                        113.842894,
                                        22.539302
                                    ],
                                    [
                                        113.839042,
                                        22.537965
                                    ],
                                    [
                                        113.836116,
                                        22.538474
                                    ],
                                    [
                                        113.834696,
                                        22.539569
                                    ],
                                    [
                                        113.834281,
                                        22.54133
                                    ],
                                    [
                                        113.834194,
                                        22.544266
                                    ],
                                    [
                                        113.83461,
                                        22.547706
                                    ],
                                    [
                                        113.835113,
                                        22.551227
                                    ],
                                    [
                                        113.835953,
                                        22.553658
                                    ],
                                    [
                                        113.836706,
                                        22.555461
                                    ],
                                    [
                                        113.838377,
                                        22.559316
                                    ],
                                    [
                                        113.838213,
                                        22.562338
                                    ],
                                    [
                                        113.836707,
                                        22.565192
                                    ],
                                    [
                                        113.832188,
                                        22.570234
                                    ],
                                    [
                                        113.803409,
                                        22.593187
                                    ],
                                    [
                                        113.782291,
                                        22.625696
                                    ],
                                    [
                                        113.773278,
                                        22.643229
                                    ],
                                    [
                                        113.769004,
                                        22.654557
                                    ],
                                    [
                                        113.767002,
                                        22.659466
                                    ],
                                    [
                                        113.765493,
                                        22.665759
                                    ],
                                    [
                                        113.760429,
                                        22.678188
                                    ],
                                    [
                                        113.758357,
                                        22.683272
                                    ],
                                    [
                                        113.753161,
                                        22.698521
                                    ],
                                    [
                                        113.752008,
                                        22.705567
                                    ],
                                    [
                                        113.751453,
                                        22.715403
                                    ]
                                ]
                            ]
                        ]
                    },
                    "properties": {
                        "name": "宝安区",
                        "cp": [
                            113.828671,
                            22.754741
                        ]
                    }
                },
                {
                    "type": "Feature",
                    "id": "440310",
                    "geometry": {
                        "type": "Polygon",
                        "coordinates": [
                            [
                                [
                                    114.269789,
                                    22.653829
                                ],
                                [
                                    114.268118,
                                    22.656187
                                ],
                                [
                                    114.267389,
                                    22.657534
                                ],
                                [
                                    114.267281,
                                    22.659712
                                ],
                                [
                                    114.267625,
                                    22.660524
                                ],
                                [
                                    114.267194,
                                    22.661565
                                ],
                                [
                                    114.267002,
                                    22.662029
                                ],
                                [
                                    114.267276,
                                    22.663059
                                ],
                                [
                                    114.268022,
                                    22.664192
                                ],
                                [
                                    114.268011,
                                    22.664653
                                ],
                                [
                                    114.26924,
                                    22.665261
                                ],
                                [
                                    114.269132,
                                    22.665717
                                ],
                                [
                                    114.269562,
                                    22.666192
                                ],
                                [
                                    114.269953,
                                    22.666593
                                ],
                                [
                                    114.271234,
                                    22.66693
                                ],
                                [
                                    114.270854,
                                    22.667489
                                ],
                                [
                                    114.270773,
                                    22.668202
                                ],
                                [
                                    114.271671,
                                    22.668926
                                ],
                                [
                                    114.272251,
                                    22.66955
                                ],
                                [
                                    114.272422,
                                    22.669837
                                ],
                                [
                                    114.271939,
                                    22.670619
                                ],
                                [
                                    114.272755,
                                    22.672075
                                ],
                                [
                                    114.273162,
                                    22.672936
                                ],
                                [
                                    114.273355,
                                    22.673491
                                ],
                                [
                                    114.274793,
                                    22.673827
                                ],
                                [
                                    114.275308,
                                    22.673847
                                ],
                                [
                                    114.276166,
                                    22.674045
                                ],
                                [
                                    114.276746,
                                    22.674817
                                ],
                                [
                                    114.27793,
                                    22.675029
                                ],
                                [
                                    114.281273,
                                    22.675629
                                ],
                                [
                                    114.282217,
                                    22.675649
                                ],
                                [
                                    114.283162,
                                    22.675391
                                ],
                                [
                                    114.283913,
                                    22.675965
                                ],
                                [
                                    114.283816,
                                    22.676797
                                ],
                                [
                                    114.284267,
                                    22.677381
                                ],
                                [
                                    114.285082,
                                    22.678084
                                ],
                                [
                                    114.285973,
                                    22.678242
                                ],
                                [
                                    114.287626,
                                    22.67747
                                ],
                                [
                                    114.288452,
                                    22.67751
                                ],
                                [
                                    114.289751,
                                    22.677104
                                ],
                                [
                                    114.290545,
                                    22.677609
                                ],
                                [
                                    114.290952,
                                    22.678589
                                ],
                                [
                                    114.29136,
                                    22.679628
                                ],
                                [
                                    114.292336,
                                    22.680183
                                ],
                                [
                                    114.293227,
                                    22.680826
                                ],
                                [
                                    114.293366,
                                    22.68143
                                ],
                                [
                                    114.293913,
                                    22.681608
                                ],
                                [
                                    114.294482,
                                    22.68143
                                ],
                                [
                                    114.295458,
                                    22.681212
                                ],
                                [
                                    114.296553,
                                    22.680727
                                ],
                                [
                                    114.297208,
                                    22.680678
                                ],
                                [
                                    114.298999,
                                    22.681222
                                ],
                                [
                                    114.299557,
                                    22.681707
                                ],
                                [
                                    114.301087,
                                    22.683487
                                ],
                                [
                                    114.301167,
                                    22.683579
                                ],
                                [
                                    114.302079,
                                    22.684381
                                ],
                                [
                                    114.302221,
                                    22.685299
                                ],
                                [
                                    114.302412,
                                    22.685838
                                ],
                                [
                                    114.303999,
                                    22.685875
                                ],
                                [
                                    114.306354,
                                    22.685859
                                ],
                                [
                                    114.308299,
                                    22.685837
                                ],
                                [
                                    114.310287,
                                    22.685796
                                ],
                                [
                                    114.31253,
                                    22.686059
                                ],
                                [
                                    114.316099,
                                    22.686662
                                ],
                                [
                                    114.316919,
                                    22.688128
                                ],
                                [
                                    114.317122,
                                    22.688469
                                ],
                                [
                                    114.317959,
                                    22.690053
                                ],
                                [
                                    114.318569,
                                    22.691192
                                ],
                                [
                                    114.32077,
                                    22.689835
                                ],
                                [
                                    114.322873,
                                    22.68835
                                ],
                                [
                                    114.322757,
                                    22.689156
                                ],
                                [
                                    114.322668,
                                    22.690101
                                ],
                                [
                                    114.322589,
                                    22.690529
                                ],
                                [
                                    114.322562,
                                    22.691786
                                ],
                                [
                                    114.322628,
                                    22.692344
                                ],
                                [
                                    114.32264,
                                    22.69259
                                ],
                                [
                                    114.322632,
                                    22.692702
                                ],
                                [
                                    114.322733,
                                    22.693593
                                ],
                                [
                                    114.322787,
                                    22.69421
                                ],
                                [
                                    114.322814,
                                    22.694514
                                ],
                                [
                                    114.32298,
                                    22.695915
                                ],
                                [
                                    114.32305,
                                    22.696627
                                ],
                                [
                                    114.323173,
                                    22.697711
                                ],
                                [
                                    114.323194,
                                    22.697846
                                ],
                                [
                                    114.323243,
                                    22.698766
                                ],
                                [
                                    114.323388,
                                    22.699088
                                ],
                                [
                                    114.323331,
                                    22.700116
                                ],
                                [
                                    114.323487,
                                    22.700408
                                ],
                                [
                                    114.322685,
                                    22.700894
                                ],
                                [
                                    114.320604,
                                    22.702328
                                ],
                                [
                                    114.321232,
                                    22.703431
                                ],
                                [
                                    114.321358,
                                    22.703577
                                ],
                                [
                                    114.322534,
                                    22.702939
                                ],
                                [
                                    114.323269,
                                    22.702473
                                ],
                                [
                                    114.323371,
                                    22.702562
                                ],
                                [
                                    114.32351,
                                    22.702751
                                ],
                                [
                                    114.323602,
                                    22.702894
                                ],
                                [
                                    114.323693,
                                    22.702998
                                ],
                                [
                                    114.323805,
                                    22.703112
                                ],
                                [
                                    114.323913,
                                    22.70325
                                ],
                                [
                                    114.324101,
                                    22.703473
                                ],
                                [
                                    114.323916,
                                    22.704563
                                ],
                                [
                                    114.324294,
                                    22.704577
                                ],
                                [
                                    114.325076,
                                    22.704612
                                ],
                                [
                                    114.325215,
                                    22.704574
                                ],
                                [
                                    114.325778,
                                    22.704469
                                ],
                                [
                                    114.326053,
                                    22.70427
                                ],
                                [
                                    114.326837,
                                    22.705107
                                ],
                                [
                                    114.327467,
                                    22.704775
                                ],
                                [
                                    114.328084,
                                    22.704439
                                ],
                                [
                                    114.328261,
                                    22.704637
                                ],
                                [
                                    114.328358,
                                    22.705087
                                ],
                                [
                                    114.328433,
                                    22.705404
                                ],
                                [
                                    114.328593,
                                    22.706194
                                ],
                                [
                                    114.328701,
                                    22.706726
                                ],
                                [
                                    114.328946,
                                    22.707414
                                ],
                                [
                                    114.328915,
                                    22.707998
                                ],
                                [
                                    114.328829,
                                    22.708354
                                ],
                                [
                                    114.328859,
                                    22.708663
                                ],
                                [
                                    114.328754,
                                    22.709978
                                ],
                                [
                                    114.328754,
                                    22.710562
                                ],
                                [
                                    114.330643,
                                    22.710681
                                ],
                                [
                                    114.333303,
                                    22.711176
                                ],
                                [
                                    114.336094,
                                    22.711235
                                ],
                                [
                                    114.338027,
                                    22.710985
                                ],
                                [
                                    114.338971,
                                    22.711202
                                ],
                                [
                                    114.339765,
                                    22.711321
                                ],
                                [
                                    114.340344,
                                    22.711737
                                ],
                                [
                                    114.341203,
                                    22.712548
                                ],
                                [
                                    114.342511,
                                    22.712568
                                ],
                                [
                                    114.344443,
                                    22.713459
                                ],
                                [
                                    114.34543,
                                    22.712964
                                ],
                                [
                                    114.346717,
                                    22.713617
                                ],
                                [
                                    114.347837,
                                    22.713958
                                ],
                                [
                                    114.34936,
                                    22.717541
                                ],
                                [
                                    114.346013,
                                    22.72621
                                ],
                                [
                                    114.340601,
                                    22.726465
                                ],
                                [
                                    114.340708,
                                    22.726996
                                ],
                                [
                                    114.341019,
                                    22.729262
                                ],
                                [
                                    114.340923,
                                    22.732164
                                ],
                                [
                                    114.340915,
                                    22.732479
                                ],
                                [
                                    114.34088,
                                    22.733906
                                ],
                                [
                                    114.339099,
                                    22.734817
                                ],
                                [
                                    114.338626,
                                    22.736004
                                ],
                                [
                                    114.33897,
                                    22.740023
                                ],
                                [
                                    114.339045,
                                    22.740993
                                ],
                                [
                                    114.339903,
                                    22.741448
                                ],
                                [
                                    114.339925,
                                    22.742922
                                ],
                                [
                                    114.340525,
                                    22.743939
                                ],
                                [
                                    114.340075,
                                    22.746462
                                ],
                                [
                                    114.337995,
                                    22.746395
                                ],
                                [
                                    114.337705,
                                    22.746538
                                ],
                                [
                                    114.337367,
                                    22.747414
                                ],
                                [
                                    114.337502,
                                    22.747968
                                ],
                                [
                                    114.338257,
                                    22.749074
                                ],
                                [
                                    114.338868,
                                    22.749662
                                ],
                                [
                                    114.339077,
                                    22.749821
                                ],
                                [
                                    114.339319,
                                    22.750716
                                ],
                                [
                                    114.339576,
                                    22.751067
                                ],
                                [
                                    114.339768,
                                    22.751687
                                ],
                                [
                                    114.339891,
                                    22.75234
                                ],
                                [
                                    114.340176,
                                    22.753058
                                ],
                                [
                                    114.340514,
                                    22.753572
                                ],
                                [
                                    114.340675,
                                    22.754196
                                ],
                                [
                                    114.341343,
                                    22.754918
                                ],
                                [
                                    114.341842,
                                    22.754503
                                ],
                                [
                                    114.342362,
                                    22.754498
                                ],
                                [
                                    114.342985,
                                    22.754963
                                ],
                                [
                                    114.343194,
                                    22.755235
                                ],
                                [
                                    114.344715,
                                    22.755192
                                ],
                                [
                                    114.344812,
                                    22.756018
                                ],
                                [
                                    114.344559,
                                    22.756706
                                ],
                                [
                                    114.344441,
                                    22.757255
                                ],
                                [
                                    114.344522,
                                    22.757853
                                ],
                                [
                                    114.344436,
                                    22.758543
                                ],
                                [
                                    114.345439,
                                    22.758835
                                ],
                                [
                                    114.345981,
                                    22.759547
                                ],
                                [
                                    114.346099,
                                    22.75978
                                ],
                                [
                                    114.345654,
                                    22.760488
                                ],
                                [
                                    114.346553,
                                    22.76077
                                ],
                                [
                                    114.347476,
                                    22.761126
                                ],
                                [
                                    114.347481,
                                    22.761587
                                ],
                                [
                                    114.347717,
                                    22.761938
                                ],
                                [
                                    114.347835,
                                    22.762215
                                ],
                                [
                                    114.347733,
                                    22.762893
                                ],
                                [
                                    114.347706,
                                    22.762933
                                ],
                                [
                                    114.347856,
                                    22.763661
                                ],
                                [
                                    114.347953,
                                    22.763997
                                ],
                                [
                                    114.348028,
                                    22.764398
                                ],
                                [
                                    114.347867,
                                    22.765106
                                ],
                                [
                                    114.347824,
                                    22.765289
                                ],
                                [
                                    114.347926,
                                    22.765537
                                ],
                                [
                                    114.348715,
                                    22.766665
                                ],
                                [
                                    114.349016,
                                    22.767418
                                ],
                                [
                                    114.349091,
                                    22.767903
                                ],
                                [
                                    114.350657,
                                    22.768922
                                ],
                                [
                                    114.350979,
                                    22.768734
                                ],
                                [
                                    114.351891,
                                    22.768239
                                ],
                                [
                                    114.352181,
                                    22.768259
                                ],
                                [
                                    114.352846,
                                    22.767275
                                ],
                                [
                                    114.353259,
                                    22.766326
                                ],
                                [
                                    114.353457,
                                    22.765995
                                ],
                                [
                                    114.354039,
                                    22.765839
                                ],
                                [
                                    114.35541,
                                    22.765501
                                ],
                                [
                                    114.355784,
                                    22.765796
                                ],
                                [
                                    114.355969,
                                    22.764906
                                ],
                                [
                                    114.356472,
                                    22.764655
                                ],
                                [
                                    114.358681,
                                    22.763771
                                ],
                                [
                                    114.359334,
                                    22.763654
                                ],
                                [
                                    114.359913,
                                    22.763671
                                ],
                                [
                                    114.361672,
                                    22.764193
                                ],
                                [
                                    114.363173,
                                    22.765062
                                ],
                                [
                                    114.364951,
                                    22.765681
                                ],
                                [
                                    114.365632,
                                    22.766058
                                ],
                                [
                                    114.366229,
                                    22.766218
                                ],
                                [
                                    114.3668,
                                    22.766251
                                ],
                                [
                                    114.367812,
                                    22.766032
                                ],
                                [
                                    114.368129,
                                    22.765882
                                ],
                                [
                                    114.368836,
                                    22.764967
                                ],
                                [
                                    114.36923,
                                    22.764656
                                ],
                                [
                                    114.370069,
                                    22.764527
                                ],
                                [
                                    114.370835,
                                    22.764277
                                ],
                                [
                                    114.371655,
                                    22.763752
                                ],
                                [
                                    114.372186,
                                    22.763586
                                ],
                                [
                                    114.3753,
                                    22.76293
                                ],
                                [
                                    114.375457,
                                    22.762892
                                ],
                                [
                                    114.375488,
                                    22.762885
                                ],
                                [
                                    114.376627,
                                    22.762617
                                ],
                                [
                                    114.376999,
                                    22.762452
                                ],
                                [
                                    114.379641,
                                    22.760994
                                ],
                                [
                                    114.379727,
                                    22.760941
                                ],
                                [
                                    114.379809,
                                    22.760881
                                ],
                                [
                                    114.379873,
                                    22.760835
                                ],
                                [
                                    114.379948,
                                    22.760794
                                ],
                                [
                                    114.380011,
                                    22.760734
                                ],
                                [
                                    114.380083,
                                    22.76066
                                ],
                                [
                                    114.380236,
                                    22.760507
                                ],
                                [
                                    114.380356,
                                    22.760381
                                ],
                                [
                                    114.380439,
                                    22.760292
                                ],
                                [
                                    114.380538,
                                    22.760204
                                ],
                                [
                                    114.380697,
                                    22.760129
                                ],
                                [
                                    114.380811,
                                    22.76008
                                ],
                                [
                                    114.380906,
                                    22.760032
                                ],
                                [
                                    114.380998,
                                    22.76
                                ],
                                [
                                    114.38108,
                                    22.759969
                                ],
                                [
                                    114.38116,
                                    22.759948
                                ],
                                [
                                    114.381269,
                                    22.759923
                                ],
                                [
                                    114.381428,
                                    22.759896
                                ],
                                [
                                    114.381458,
                                    22.759587
                                ],
                                [
                                    114.381958,
                                    22.759584
                                ],
                                [
                                    114.38212,
                                    22.759771
                                ],
                                [
                                    114.382226,
                                    22.75975
                                ],
                                [
                                    114.382361,
                                    22.759734
                                ],
                                [
                                    114.382542,
                                    22.759733
                                ],
                                [
                                    114.382653,
                                    22.759731
                                ],
                                [
                                    114.382723,
                                    22.759725
                                ],
                                [
                                    114.382826,
                                    22.759704
                                ],
                                [
                                    114.382902,
                                    22.759694
                                ],
                                [
                                    114.382988,
                                    22.759682
                                ],
                                [
                                    114.383083,
                                    22.75967
                                ],
                                [
                                    114.383161,
                                    22.759656
                                ],
                                [
                                    114.383268,
                                    22.759649
                                ],
                                [
                                    114.383432,
                                    22.759631
                                ],
                                [
                                    114.383582,
                                    22.759618
                                ],
                                [
                                    114.383683,
                                    22.759615
                                ],
                                [
                                    114.383792,
                                    22.759613
                                ],
                                [
                                    114.383999,
                                    22.759607
                                ],
                                [
                                    114.384166,
                                    22.759608
                                ],
                                [
                                    114.384289,
                                    22.759603
                                ],
                                [
                                    114.38447,
                                    22.759595
                                ],
                                [
                                    114.384652,
                                    22.759583
                                ],
                                [
                                    114.38478,
                                    22.759571
                                ],
                                [
                                    114.385972,
                                    22.759601
                                ],
                                [
                                    114.386048,
                                    22.759616
                                ],
                                [
                                    114.386204,
                                    22.759611
                                ],
                                [
                                    114.386316,
                                    22.759598
                                ],
                                [
                                    114.386446,
                                    22.759546
                                ],
                                [
                                    114.38661,
                                    22.75947
                                ],
                                [
                                    114.386695,
                                    22.759437
                                ],
                                [
                                    114.386756,
                                    22.759402
                                ],
                                [
                                    114.386797,
                                    22.759356
                                ],
                                [
                                    114.386822,
                                    22.759266
                                ],
                                [
                                    114.386839,
                                    22.759149
                                ],
                                [
                                    114.386867,
                                    22.759066
                                ],
                                [
                                    114.38688,
                                    22.758976
                                ],
                                [
                                    114.386888,
                                    22.758847
                                ],
                                [
                                    114.38689,
                                    22.758811
                                ],
                                [
                                    114.38689,
                                    22.758802
                                ],
                                [
                                    114.386893,
                                    22.758694
                                ],
                                [
                                    114.386896,
                                    22.758619
                                ],
                                [
                                    114.38691,
                                    22.758545
                                ],
                                [
                                    114.386937,
                                    22.758464
                                ],
                                [
                                    114.38697,
                                    22.758384
                                ],
                                [
                                    114.387007,
                                    22.758333
                                ],
                                [
                                    114.387383,
                                    22.757804
                                ],
                                [
                                    114.387576,
                                    22.75753
                                ],
                                [
                                    114.387632,
                                    22.757526
                                ],
                                [
                                    114.388546,
                                    22.756928
                                ],
                                [
                                    114.393346,
                                    22.759079
                                ],
                                [
                                    114.393464,
                                    22.759136
                                ],
                                [
                                    114.393562,
                                    22.759191
                                ],
                                [
                                    114.393635,
                                    22.759231
                                ],
                                [
                                    114.393724,
                                    22.75928
                                ],
                                [
                                    114.393794,
                                    22.759329
                                ],
                                [
                                    114.393883,
                                    22.75935
                                ],
                                [
                                    114.393918,
                                    22.759366
                                ],
                                [
                                    114.393935,
                                    22.759374
                                ],
                                [
                                    114.394006,
                                    22.759409
                                ],
                                [
                                    114.394141,
                                    22.759458
                                ],
                                [
                                    114.394274,
                                    22.759515
                                ],
                                [
                                    114.394366,
                                    22.759555
                                ],
                                [
                                    114.394439,
                                    22.759594
                                ],
                                [
                                    114.394521,
                                    22.759641
                                ],
                                [
                                    114.394599,
                                    22.759685
                                ],
                                [
                                    114.394696,
                                    22.759734
                                ],
                                [
                                    114.394774,
                                    22.759767
                                ],
                                [
                                    114.394836,
                                    22.759786
                                ],
                                [
                                    114.395003,
                                    22.760382
                                ],
                                [
                                    114.394988,
                                    22.760448
                                ],
                                [
                                    114.395454,
                                    22.762583
                                ],
                                [
                                    114.395675,
                                    22.763594
                                ],
                                [
                                    114.396023,
                                    22.76519
                                ],
                                [
                                    114.396129,
                                    22.765677
                                ],
                                [
                                    114.395749,
                                    22.767228
                                ],
                                [
                                    114.395649,
                                    22.767912
                                ],
                                [
                                    114.39543,
                                    22.76864
                                ],
                                [
                                    114.395459,
                                    22.769173
                                ],
                                [
                                    114.395372,
                                    22.769631
                                ],
                                [
                                    114.395198,
                                    22.770089
                                ],
                                [
                                    114.395218,
                                    22.771118
                                ],
                                [
                                    114.395128,
                                    22.771501
                                ],
                                [
                                    114.395267,
                                    22.771584
                                ],
                                [
                                    114.395375,
                                    22.771654
                                ],
                                [
                                    114.395465,
                                    22.771718
                                ],
                                [
                                    114.39582,
                                    22.773534
                                ],
                                [
                                    114.396013,
                                    22.774356
                                ],
                                [
                                    114.396325,
                                    22.777322
                                ],
                                [
                                    114.396619,
                                    22.777616
                                ],
                                [
                                    114.398002,
                                    22.77797
                                ],
                                [
                                    114.399355,
                                    22.778854
                                ],
                                [
                                    114.401179,
                                    22.779443
                                ],
                                [
                                    114.403313,
                                    22.780601
                                ],
                                [
                                    114.404681,
                                    22.78132
                                ],
                                [
                                    114.405123,
                                    22.781257
                                ],
                                [
                                    114.405308,
                                    22.781186
                                ],
                                [
                                    114.405846,
                                    22.780719
                                ],
                                [
                                    114.40585,
                                    22.780703
                                ],
                                [
                                    114.405859,
                                    22.780642
                                ],
                                [
                                    114.405884,
                                    22.780562
                                ],
                                [
                                    114.405917,
                                    22.78049
                                ],
                                [
                                    114.405997,
                                    22.780353
                                ],
                                [
                                    114.40603,
                                    22.780266
                                ],
                                [
                                    114.406066,
                                    22.780151
                                ],
                                [
                                    114.406094,
                                    22.780053
                                ],
                                [
                                    114.406141,
                                    22.779938
                                ],
                                [
                                    114.406509,
                                    22.779432
                                ],
                                [
                                    114.406819,
                                    22.778988
                                ],
                                [
                                    114.407437,
                                    22.778508
                                ],
                                [
                                    114.408819,
                                    22.777969
                                ],
                                [
                                    114.408916,
                                    22.777989
                                ],
                                [
                                    114.409011,
                                    22.778001
                                ],
                                [
                                    114.409106,
                                    22.778008
                                ],
                                [
                                    114.409181,
                                    22.778036
                                ],
                                [
                                    114.409284,
                                    22.778053
                                ],
                                [
                                    114.409413,
                                    22.778091
                                ],
                                [
                                    114.40949,
                                    22.778109
                                ],
                                [
                                    114.409982,
                                    22.77802
                                ],
                                [
                                    114.410685,
                                    22.777875
                                ],
                                [
                                    114.410959,
                                    22.777625
                                ],
                                [
                                    114.411239,
                                    22.777299
                                ],
                                [
                                    114.411618,
                                    22.776717
                                ],
                                [
                                    114.411771,
                                    22.776238
                                ],
                                [
                                    114.412028,
                                    22.775435
                                ],
                                [
                                    114.41237,
                                    22.774741
                                ],
                                [
                                    114.413004,
                                    22.77425
                                ],
                                [
                                    114.413818,
                                    22.773776
                                ],
                                [
                                    114.4139,
                                    22.773718
                                ],
                                [
                                    114.413947,
                                    22.773663
                                ],
                                [
                                    114.414655,
                                    22.772478
                                ],
                                [
                                    114.414657,
                                    22.772331
                                ],
                                [
                                    114.414684,
                                    22.769932
                                ],
                                [
                                    114.414819,
                                    22.769533
                                ],
                                [
                                    114.41486,
                                    22.769468
                                ],
                                [
                                    114.414902,
                                    22.769419
                                ],
                                [
                                    114.414935,
                                    22.769363
                                ],
                                [
                                    114.415018,
                                    22.769274
                                ],
                                [
                                    114.415099,
                                    22.769206
                                ],
                                [
                                    114.415224,
                                    22.769109
                                ],
                                [
                                    114.415346,
                                    22.769014
                                ],
                                [
                                    114.415427,
                                    22.768934
                                ],
                                [
                                    114.41553,
                                    22.768866
                                ],
                                [
                                    114.415667,
                                    22.768773
                                ],
                                [
                                    114.415784,
                                    22.768689
                                ],
                                [
                                    114.415892,
                                    22.768576
                                ],
                                [
                                    114.415989,
                                    22.768475
                                ],
                                [
                                    114.416081,
                                    22.768386
                                ],
                                [
                                    114.416201,
                                    22.768309
                                ],
                                [
                                    114.416339,
                                    22.76821
                                ],
                                [
                                    114.416461,
                                    22.768128
                                ],
                                [
                                    114.416589,
                                    22.76804
                                ],
                                [
                                    114.416662,
                                    22.767983
                                ],
                                [
                                    114.416754,
                                    22.767923
                                ],
                                [
                                    114.416829,
                                    22.767864
                                ],
                                [
                                    114.416879,
                                    22.767824
                                ],
                                [
                                    114.416912,
                                    22.767752
                                ],
                                [
                                    114.416976,
                                    22.767661
                                ],
                                [
                                    114.417026,
                                    22.767587
                                ],
                                [
                                    114.417076,
                                    22.767522
                                ],
                                [
                                    114.417134,
                                    22.767442
                                ],
                                [
                                    114.417221,
                                    22.767353
                                ],
                                [
                                    114.417299,
                                    22.767259
                                ],
                                [
                                    114.417356,
                                    22.767199
                                ],
                                [
                                    114.417407,
                                    22.76716
                                ],
                                [
                                    114.41749,
                                    22.767114
                                ],
                                [
                                    114.417562,
                                    22.767056
                                ],
                                [
                                    114.417655,
                                    22.766996
                                ],
                                [
                                    114.417724,
                                    22.766939
                                ],
                                [
                                    114.41776,
                                    22.76691
                                ],
                                [
                                    114.417819,
                                    22.766855
                                ],
                                [
                                    114.417871,
                                    22.766776
                                ],
                                [
                                    114.417929,
                                    22.76671
                                ],
                                [
                                    114.418004,
                                    22.766659
                                ],
                                [
                                    114.418052,
                                    22.766642
                                ],
                                [
                                    114.418113,
                                    22.766584
                                ],
                                [
                                    114.418165,
                                    22.76649
                                ],
                                [
                                    114.41821,
                                    22.766416
                                ],
                                [
                                    114.418235,
                                    22.766333
                                ],
                                [
                                    114.418262,
                                    22.766234
                                ],
                                [
                                    114.418289,
                                    22.766145
                                ],
                                [
                                    114.418306,
                                    22.766059
                                ],
                                [
                                    114.418323,
                                    22.765983
                                ],
                                [
                                    114.418321,
                                    22.765894
                                ],
                                [
                                    114.418322,
                                    22.765827
                                ],
                                [
                                    114.418305,
                                    22.76577
                                ],
                                [
                                    114.418275,
                                    22.765711
                                ],
                                [
                                    114.418252,
                                    22.765683
                                ],
                                [
                                    114.418218,
                                    22.765633
                                ],
                                [
                                    114.418154,
                                    22.765583
                                ],
                                [
                                    114.418084,
                                    22.765532
                                ],
                                [
                                    114.418006,
                                    22.765472
                                ],
                                [
                                    114.417919,
                                    22.76541
                                ],
                                [
                                    114.417847,
                                    22.76535
                                ],
                                [
                                    114.41778,
                                    22.765308
                                ],
                                [
                                    114.417727,
                                    22.765262
                                ],
                                [
                                    114.417704,
                                    22.765231
                                ],
                                [
                                    114.417697,
                                    22.765187
                                ],
                                [
                                    114.41769,
                                    22.76514
                                ],
                                [
                                    114.41771,
                                    22.765095
                                ],
                                [
                                    114.417729,
                                    22.765019
                                ],
                                [
                                    114.417767,
                                    22.764931
                                ],
                                [
                                    114.417801,
                                    22.764821
                                ],
                                [
                                    114.417834,
                                    22.764713
                                ],
                                [
                                    114.417861,
                                    22.764583
                                ],
                                [
                                    114.417892,
                                    22.764493
                                ],
                                [
                                    114.41793,
                                    22.764374
                                ],
                                [
                                    114.417958,
                                    22.764275
                                ],
                                [
                                    114.417989,
                                    22.764176
                                ],
                                [
                                    114.418027,
                                    22.764073
                                ],
                                [
                                    114.418054,
                                    22.76397
                                ],
                                [
                                    114.418079,
                                    22.763869
                                ],
                                [
                                    114.418109,
                                    22.76375
                                ],
                                [
                                    114.418154,
                                    22.763622
                                ],
                                [
                                    114.418201,
                                    22.763428
                                ],
                                [
                                    114.418237,
                                    22.763312
                                ],
                                [
                                    114.418275,
                                    22.763206
                                ],
                                [
                                    114.418319,
                                    22.76304
                                ],
                                [
                                    114.418359,
                                    22.762898
                                ],
                                [
                                    114.418391,
                                    22.762813
                                ],
                                [
                                    114.418404,
                                    22.762719
                                ],
                                [
                                    114.418441,
                                    22.762608
                                ],
                                [
                                    114.41848,
                                    22.76246
                                ],
                                [
                                    114.418501,
                                    22.762361
                                ],
                                [
                                    114.418551,
                                    22.762199
                                ],
                                [
                                    114.418595,
                                    22.762076
                                ],
                                [
                                    114.418651,
                                    22.761939
                                ],
                                [
                                    114.418695,
                                    22.761841
                                ],
                                [
                                    114.419121,
                                    22.76083
                                ],
                                [
                                    114.419146,
                                    22.760769
                                ],
                                [
                                    114.419199,
                                    22.760784
                                ],
                                [
                                    114.419252,
                                    22.760787
                                ],
                                [
                                    114.419272,
                                    22.760785
                                ],
                                [
                                    114.419305,
                                    22.760799
                                ],
                                [
                                    114.419319,
                                    22.760856
                                ],
                                [
                                    114.41933,
                                    22.760935
                                ],
                                [
                                    114.419356,
                                    22.761064
                                ],
                                [
                                    114.419392,
                                    22.761154
                                ],
                                [
                                    114.419407,
                                    22.761238
                                ],
                                [
                                    114.419429,
                                    22.761304
                                ],
                                [
                                    114.419455,
                                    22.761394
                                ],
                                [
                                    114.419471,
                                    22.761467
                                ],
                                [
                                    114.419522,
                                    22.761563
                                ],
                                [
                                    114.419552,
                                    22.761606
                                ],
                                [
                                    114.419569,
                                    22.761658
                                ],
                                [
                                    114.419626,
                                    22.761731
                                ],
                                [
                                    114.419639,
                                    22.761772
                                ],
                                [
                                    114.419701,
                                    22.76187
                                ],
                                [
                                    114.419755,
                                    22.761954
                                ],
                                [
                                    114.419813,
                                    22.762021
                                ],
                                [
                                    114.419874,
                                    22.762069
                                ],
                                [
                                    114.420034,
                                    22.762141
                                ],
                                [
                                    114.420174,
                                    22.762196
                                ],
                                [
                                    114.420284,
                                    22.762229
                                ],
                                [
                                    114.420377,
                                    22.762248
                                ],
                                [
                                    114.420491,
                                    22.762261
                                ],
                                [
                                    114.42065,
                                    22.762269
                                ],
                                [
                                    114.420742,
                                    22.762268
                                ],
                                [
                                    114.420836,
                                    22.762274
                                ],
                                [
                                    114.420937,
                                    22.762275
                                ],
                                [
                                    114.421016,
                                    22.762277
                                ],
                                [
                                    114.421119,
                                    22.762283
                                ],
                                [
                                    114.421185,
                                    22.762288
                                ],
                                [
                                    114.421255,
                                    22.762282
                                ],
                                [
                                    114.421332,
                                    22.762254
                                ],
                                [
                                    114.421411,
                                    22.762222
                                ],
                                [
                                    114.421646,
                                    22.762072
                                ],
                                [
                                    114.422706,
                                    22.761393
                                ],
                                [
                                    114.4229,
                                    22.760584
                                ],
                                [
                                    114.422885,
                                    22.760491
                                ],
                                [
                                    114.422854,
                                    22.760385
                                ],
                                [
                                    114.422812,
                                    22.760278
                                ],
                                [
                                    114.42198,
                                    22.760525
                                ],
                                [
                                    114.420789,
                                    22.759854
                                ],
                                [
                                    114.421222,
                                    22.758816
                                ],
                                [
                                    114.421141,
                                    22.758781
                                ],
                                [
                                    114.421079,
                                    22.758739
                                ],
                                [
                                    114.421001,
                                    22.758695
                                ],
                                [
                                    114.420918,
                                    22.75866
                                ],
                                [
                                    114.420829,
                                    22.758627
                                ],
                                [
                                    114.420728,
                                    22.758576
                                ],
                                [
                                    114.420603,
                                    22.758513
                                ],
                                [
                                    114.420454,
                                    22.758454
                                ],
                                [
                                    114.420298,
                                    22.758373
                                ],
                                [
                                    114.420159,
                                    22.758321
                                ],
                                [
                                    114.420064,
                                    22.758276
                                ],
                                [
                                    114.419943,
                                    22.758234
                                ],
                                [
                                    114.419877,
                                    22.758215
                                ],
                                [
                                    114.419771,
                                    22.7582
                                ],
                                [
                                    114.419642,
                                    22.758182
                                ],
                                [
                                    114.419478,
                                    22.758154
                                ],
                                [
                                    114.419344,
                                    22.758146
                                ],
                                [
                                    114.419238,
                                    22.75813
                                ],
                                [
                                    114.41916,
                                    22.758113
                                ],
                                [
                                    114.419065,
                                    22.75811
                                ],
                                [
                                    114.418957,
                                    22.758106
                                ],
                                [
                                    114.418856,
                                    22.758113
                                ],
                                [
                                    114.418737,
                                    22.758122
                                ],
                                [
                                    114.418625,
                                    22.758121
                                ],
                                [
                                    114.418522,
                                    22.758112
                                ],
                                [
                                    114.418397,
                                    22.758083
                                ],
                                [
                                    114.418268,
                                    22.758072
                                ],
                                [
                                    114.418137,
                                    22.758057
                                ],
                                [
                                    114.418068,
                                    22.758044
                                ],
                                [
                                    114.417989,
                                    22.758045
                                ],
                                [
                                    114.417911,
                                    22.758037
                                ],
                                [
                                    114.417828,
                                    22.758013
                                ],
                                [
                                    114.417761,
                                    22.757981
                                ],
                                [
                                    114.41769,
                                    22.757941
                                ],
                                [
                                    114.417627,
                                    22.757904
                                ],
                                [
                                    114.417563,
                                    22.757842
                                ],
                                [
                                    114.417495,
                                    22.757766
                                ],
                                [
                                    114.417476,
                                    22.757714
                                ],
                                [
                                    114.417461,
                                    22.757651
                                ],
                                [
                                    114.417459,
                                    22.757552
                                ],
                                [
                                    114.417466,
                                    22.757471
                                ],
                                [
                                    114.417483,
                                    22.757378
                                ],
                                [
                                    114.417507,
                                    22.757309
                                ],
                                [
                                    114.417569,
                                    22.757244
                                ],
                                [
                                    114.417632,
                                    22.757214
                                ],
                                [
                                    114.417747,
                                    22.757193
                                ],
                                [
                                    114.417847,
                                    22.757179
                                ],
                                [
                                    114.417947,
                                    22.757178
                                ],
                                [
                                    114.418079,
                                    22.757182
                                ],
                                [
                                    114.418157,
                                    22.757188
                                ],
                                [
                                    114.418285,
                                    22.757174
                                ],
                                [
                                    114.418402,
                                    22.757163
                                ],
                                [
                                    114.418506,
                                    22.757162
                                ],
                                [
                                    114.418614,
                                    22.757164
                                ],
                                [
                                    114.4187,
                                    22.75717
                                ],
                                [
                                    114.418789,
                                    22.757176
                                ],
                                [
                                    114.418862,
                                    22.757181
                                ],
                                [
                                    114.418907,
                                    22.757188
                                ],
                                [
                                    114.419029,
                                    22.757168
                                ],
                                [
                                    114.419144,
                                    22.757141
                                ],
                                [
                                    114.419269,
                                    22.757115
                                ],
                                [
                                    114.419374,
                                    22.757079
                                ],
                                [
                                    114.419499,
                                    22.757051
                                ],
                                [
                                    114.419625,
                                    22.757035
                                ],
                                [
                                    114.419718,
                                    22.757018
                                ],
                                [
                                    114.419904,
                                    22.756963
                                ],
                                [
                                    114.420059,
                                    22.756925
                                ],
                                [
                                    114.420166,
                                    22.75691
                                ],
                                [
                                    114.420254,
                                    22.756898
                                ],
                                [
                                    114.420338,
                                    22.756879
                                ],
                                [
                                    114.420408,
                                    22.756871
                                ],
                                [
                                    114.4205,
                                    22.756857
                                ],
                                [
                                    114.420561,
                                    22.756831
                                ],
                                [
                                    114.420608,
                                    22.756784
                                ],
                                [
                                    114.420663,
                                    22.75669
                                ],
                                [
                                    114.420714,
                                    22.756612
                                ],
                                [
                                    114.420736,
                                    22.756534
                                ],
                                [
                                    114.420741,
                                    22.756463
                                ],
                                [
                                    114.420732,
                                    22.756353
                                ],
                                [
                                    114.420731,
                                    22.756287
                                ],
                                [
                                    114.420734,
                                    22.756202
                                ],
                                [
                                    114.420753,
                                    22.756112
                                ],
                                [
                                    114.420764,
                                    22.756004
                                ],
                                [
                                    114.420781,
                                    22.755921
                                ],
                                [
                                    114.420811,
                                    22.755865
                                ],
                                [
                                    114.420828,
                                    22.755797
                                ],
                                [
                                    114.420836,
                                    22.75565
                                ],
                                [
                                    114.420836,
                                    22.755535
                                ],
                                [
                                    114.42083,
                                    22.755438
                                ],
                                [
                                    114.420815,
                                    22.755343
                                ],
                                [
                                    114.42077,
                                    22.75444
                                ],
                                [
                                    114.420759,
                                    22.754225
                                ],
                                [
                                    114.42074,
                                    22.754169
                                ],
                                [
                                    114.420706,
                                    22.754116
                                ],
                                [
                                    114.420633,
                                    22.754004
                                ],
                                [
                                    114.420582,
                                    22.753932
                                ],
                                [
                                    114.420541,
                                    22.753888
                                ],
                                [
                                    114.418991,
                                    22.753139
                                ],
                                [
                                    114.418852,
                                    22.753049
                                ],
                                [
                                    114.418769,
                                    22.752989
                                ],
                                [
                                    114.418659,
                                    22.752942
                                ],
                                [
                                    114.418542,
                                    22.752882
                                ],
                                [
                                    114.418453,
                                    22.752847
                                ],
                                [
                                    114.418367,
                                    22.752804
                                ],
                                [
                                    114.418283,
                                    22.752785
                                ],
                                [
                                    114.418188,
                                    22.752775
                                ],
                                [
                                    114.418009,
                                    22.752765
                                ],
                                [
                                    114.417859,
                                    22.752751
                                ],
                                [
                                    114.417642,
                                    22.752732
                                ],
                                [
                                    114.417437,
                                    22.752704
                                ],
                                [
                                    114.417298,
                                    22.752684
                                ],
                                [
                                    114.417151,
                                    22.752666
                                ],
                                [
                                    114.416949,
                                    22.752644
                                ],
                                [
                                    114.416816,
                                    22.752622
                                ],
                                [
                                    114.416701,
                                    22.752587
                                ],
                                [
                                    114.41661,
                                    22.752549
                                ],
                                [
                                    114.416517,
                                    22.752534
                                ],
                                [
                                    114.416383,
                                    22.752514
                                ],
                                [
                                    114.416266,
                                    22.752503
                                ],
                                [
                                    114.416161,
                                    22.752485
                                ],
                                [
                                    114.416041,
                                    22.752461
                                ],
                                [
                                    114.415895,
                                    22.752447
                                ],
                                [
                                    114.415784,
                                    22.752446
                                ],
                                [
                                    114.415673,
                                    22.752444
                                ],
                                [
                                    114.41558,
                                    22.75244
                                ],
                                [
                                    114.415489,
                                    22.752441
                                ],
                                [
                                    114.415424,
                                    22.752437
                                ],
                                [
                                    114.415363,
                                    22.752434
                                ],
                                [
                                    114.414254,
                                    22.752385
                                ],
                                [
                                    114.414198,
                                    22.752382
                                ],
                                [
                                    114.414147,
                                    22.752356
                                ],
                                [
                                    114.414106,
                                    22.752324
                                ],
                                [
                                    114.414089,
                                    22.752252
                                ],
                                [
                                    114.414068,
                                    22.752159
                                ],
                                [
                                    114.414063,
                                    22.752071
                                ],
                                [
                                    114.414062,
                                    22.751999
                                ],
                                [
                                    114.414051,
                                    22.751931
                                ],
                                [
                                    114.414057,
                                    22.751874
                                ],
                                [
                                    114.414079,
                                    22.75182
                                ],
                                [
                                    114.414104,
                                    22.751762
                                ],
                                [
                                    114.414115,
                                    22.751731
                                ],
                                [
                                    114.414129,
                                    22.751652
                                ],
                                [
                                    114.414151,
                                    22.751576
                                ],
                                [
                                    114.414168,
                                    22.751522
                                ],
                                [
                                    114.414176,
                                    22.751459
                                ],
                                [
                                    114.414189,
                                    22.75138
                                ],
                                [
                                    114.414208,
                                    22.751304
                                ],
                                [
                                    114.414371,
                                    22.749578
                                ],
                                [
                                    114.414375,
                                    22.74951
                                ],
                                [
                                    114.414404,
                                    22.749411
                                ],
                                [
                                    114.414422,
                                    22.749357
                                ],
                                [
                                    114.414453,
                                    22.749294
                                ],
                                [
                                    114.414497,
                                    22.749173
                                ],
                                [
                                    114.414506,
                                    22.749112
                                ],
                                [
                                    114.414508,
                                    22.749016
                                ],
                                [
                                    114.414519,
                                    22.748921
                                ],
                                [
                                    114.414527,
                                    22.748849
                                ],
                                [
                                    114.414544,
                                    22.74875
                                ],
                                [
                                    114.414563,
                                    22.748664
                                ],
                                [
                                    114.414591,
                                    22.748579
                                ],
                                [
                                    114.414609,
                                    22.748451
                                ],
                                [
                                    114.414634,
                                    22.748345
                                ],
                                [
                                    114.414659,
                                    22.748215
                                ],
                                [
                                    114.414695,
                                    22.748134
                                ],
                                [
                                    114.414714,
                                    22.748051
                                ],
                                [
                                    114.414736,
                                    22.747956
                                ],
                                [
                                    114.414766,
                                    22.747826
                                ],
                                [
                                    114.414805,
                                    22.74775
                                ],
                                [
                                    114.414825,
                                    22.747667
                                ],
                                [
                                    114.414853,
                                    22.747581
                                ],
                                [
                                    114.414865,
                                    22.747469
                                ],
                                [
                                    114.414875,
                                    22.74734
                                ],
                                [
                                    114.414899,
                                    22.747258
                                ],
                                [
                                    114.415095,
                                    22.746786
                                ],
                                [
                                    114.415721,
                                    22.745882
                                ],
                                [
                                    114.415924,
                                    22.744333
                                ],
                                [
                                    114.415133,
                                    22.742154
                                ],
                                [
                                    114.414291,
                                    22.740665
                                ],
                                [
                                    114.41391,
                                    22.740162
                                ],
                                [
                                    114.413266,
                                    22.73836
                                ],
                                [
                                    114.413208,
                                    22.737694
                                ],
                                [
                                    114.413344,
                                    22.736847
                                ],
                                [
                                    114.413922,
                                    22.736248
                                ],
                                [
                                    114.412634,
                                    22.735473
                                ],
                                [
                                    114.412126,
                                    22.734907
                                ],
                                [
                                    114.411443,
                                    22.73366
                                ],
                                [
                                    114.410578,
                                    22.733078
                                ],
                                [
                                    114.40889,
                                    22.732177
                                ],
                                [
                                    114.407511,
                                    22.731094
                                ],
                                [
                                    114.40654,
                                    22.727684
                                ],
                                [
                                    114.406996,
                                    22.725707
                                ],
                                [
                                    114.405341,
                                    22.725859
                                ],
                                [
                                    114.404884,
                                    22.72541
                                ],
                                [
                                    114.403596,
                                    22.725003
                                ],
                                [
                                    114.403416,
                                    22.724598
                                ],
                                [
                                    114.403413,
                                    22.72293
                                ],
                                [
                                    114.403552,
                                    22.722608
                                ],
                                [
                                    114.404891,
                                    22.721474
                                ],
                                [
                                    114.406794,
                                    22.718807
                                ],
                                [
                                    114.407391,
                                    22.71787
                                ],
                                [
                                    114.407712,
                                    22.716123
                                ],
                                [
                                    114.408497,
                                    22.71473
                                ],
                                [
                                    114.408596,
                                    22.714399
                                ],
                                [
                                    114.409229,
                                    22.713577
                                ],
                                [
                                    114.407749,
                                    22.711227
                                ],
                                [
                                    114.411983,
                                    22.711478
                                ],
                                [
                                    114.413218,
                                    22.712186
                                ],
                                [
                                    114.413831,
                                    22.712417
                                ],
                                [
                                    114.415507,
                                    22.712602
                                ],
                                [
                                    114.416391,
                                    22.712573
                                ],
                                [
                                    114.416502,
                                    22.71243
                                ],
                                [
                                    114.41654,
                                    22.71183
                                ],
                                [
                                    114.417066,
                                    22.711649
                                ],
                                [
                                    114.4183,
                                    22.712084
                                ],
                                [
                                    114.419101,
                                    22.712498
                                ],
                                [
                                    114.420578,
                                    22.714017
                                ],
                                [
                                    114.421172,
                                    22.713145
                                ],
                                [
                                    114.421179,
                                    22.713133
                                ],
                                [
                                    114.421214,
                                    22.713066
                                ],
                                [
                                    114.421231,
                                    22.713003
                                ],
                                [
                                    114.421249,
                                    22.712967
                                ],
                                [
                                    114.421562,
                                    22.71236
                                ],
                                [
                                    114.421706,
                                    22.711667
                                ],
                                [
                                    114.422972,
                                    22.71013
                                ],
                                [
                                    114.423885,
                                    22.709398
                                ],
                                [
                                    114.425127,
                                    22.708902
                                ],
                                [
                                    114.424178,
                                    22.707818
                                ],
                                [
                                    114.423961,
                                    22.707487
                                ],
                                [
                                    114.423855,
                                    22.707122
                                ],
                                [
                                    114.423861,
                                    22.705891
                                ],
                                [
                                    114.423971,
                                    22.705522
                                ],
                                [
                                    114.42403,
                                    22.704187
                                ],
                                [
                                    114.423974,
                                    22.703247
                                ],
                                [
                                    114.424349,
                                    22.70249
                                ],
                                [
                                    114.42637,
                                    22.699932
                                ],
                                [
                                    114.430466,
                                    22.700621
                                ],
                                [
                                    114.433818,
                                    22.699811
                                ],
                                [
                                    114.436286,
                                    22.697964
                                ],
                                [
                                    114.438216,
                                    22.697096
                                ],
                                [
                                    114.439044,
                                    22.696896
                                ],
                                [
                                    114.440137,
                                    22.696815
                                ],
                                [
                                    114.440651,
                                    22.69692
                                ],
                                [
                                    114.44199,
                                    22.697567
                                ],
                                [
                                    114.442205,
                                    22.696511
                                ],
                                [
                                    114.442462,
                                    22.695849
                                ],
                                [
                                    114.443348,
                                    22.694698
                                ],
                                [
                                    114.444812,
                                    22.692442
                                ],
                                [
                                    114.445342,
                                    22.688986
                                ],
                                [
                                    114.444841,
                                    22.687686
                                ],
                                [
                                    114.442033,
                                    22.683441
                                ],
                                [
                                    114.441644,
                                    22.682549
                                ],
                                [
                                    114.441306,
                                    22.682192
                                ],
                                [
                                    114.440327,
                                    22.681927
                                ],
                                [
                                    114.438151,
                                    22.681562
                                ],
                                [
                                    114.437448,
                                    22.68154
                                ],
                                [
                                    114.436926,
                                    22.681347
                                ],
                                [
                                    114.436809,
                                    22.681221
                                ],
                                [
                                    114.436611,
                                    22.680111
                                ],
                                [
                                    114.435748,
                                    22.679197
                                ],
                                [
                                    114.435086,
                                    22.678881
                                ],
                                [
                                    114.434113,
                                    22.678156
                                ],
                                [
                                    114.432675,
                                    22.677527
                                ],
                                [
                                    114.431391,
                                    22.677257
                                ],
                                [
                                    114.430071,
                                    22.677353
                                ],
                                [
                                    114.428176,
                                    22.676751
                                ],
                                [
                                    114.427905,
                                    22.676534
                                ],
                                [
                                    114.427926,
                                    22.675636
                                ],
                                [
                                    114.428294,
                                    22.674967
                                ],
                                [
                                    114.428662,
                                    22.673944
                                ],
                                [
                                    114.428551,
                                    22.672424
                                ],
                                [
                                    114.428991,
                                    22.671573
                                ],
                                [
                                    114.429055,
                                    22.670595
                                ],
                                [
                                    114.429598,
                                    22.668761
                                ],
                                [
                                    114.430867,
                                    22.667711
                                ],
                                [
                                    114.431705,
                                    22.667796
                                ],
                                [
                                    114.432012,
                                    22.666891
                                ],
                                [
                                    114.432314,
                                    22.665551
                                ],
                                [
                                    114.432018,
                                    22.664165
                                ],
                                [
                                    114.432001,
                                    22.664089
                                ],
                                [
                                    114.431979,
                                    22.664009
                                ],
                                [
                                    114.431917,
                                    22.663882
                                ],
                                [
                                    114.43191,
                                    22.663864
                                ],
                                [
                                    114.431897,
                                    22.663841
                                ],
                                [
                                    114.43185,
                                    22.663759
                                ],
                                [
                                    114.431801,
                                    22.663668
                                ],
                                [
                                    114.431776,
                                    22.663607
                                ],
                                [
                                    114.431748,
                                    22.663541
                                ],
                                [
                                    114.431686,
                                    22.663482
                                ],
                                [
                                    114.431597,
                                    22.66341
                                ],
                                [
                                    114.43148,
                                    22.663329
                                ],
                                [
                                    114.431377,
                                    22.663272
                                ],
                                [
                                    114.431232,
                                    22.663206
                                ],
                                [
                                    114.431143,
                                    22.663173
                                ],
                                [
                                    114.430972,
                                    22.663098
                                ],
                                [
                                    114.430821,
                                    22.663044
                                ],
                                [
                                    114.430728,
                                    22.663
                                ],
                                [
                                    114.430644,
                                    22.66294
                                ],
                                [
                                    114.430607,
                                    22.662879
                                ],
                                [
                                    114.430594,
                                    22.662809
                                ],
                                [
                                    114.430603,
                                    22.66275
                                ],
                                [
                                    114.430643,
                                    22.662597
                                ],
                                [
                                    114.430701,
                                    22.662488
                                ],
                                [
                                    114.430729,
                                    22.66242
                                ],
                                [
                                    114.429623,
                                    22.661439
                                ],
                                [
                                    114.429247,
                                    22.661241
                                ],
                                [
                                    114.428936,
                                    22.660984
                                ],
                                [
                                    114.428582,
                                    22.660311
                                ],
                                [
                                    114.427734,
                                    22.659558
                                ],
                                [
                                    114.427133,
                                    22.659399
                                ],
                                [
                                    114.426822,
                                    22.658281
                                ],
                                [
                                    114.425094,
                                    22.657252
                                ],
                                [
                                    114.424945,
                                    22.656994
                                ],
                                [
                                    114.424751,
                                    22.656885
                                ],
                                [
                                    114.424247,
                                    22.656984
                                ],
                                [
                                    114.423947,
                                    22.656875
                                ],
                                [
                                    114.423485,
                                    22.656806
                                ],
                                [
                                    114.422992,
                                    22.656826
                                ],
                                [
                                    114.422059,
                                    22.656529
                                ],
                                [
                                    114.421372,
                                    22.656063
                                ],
                                [
                                    114.421222,
                                    22.655885
                                ],
                                [
                                    114.420942,
                                    22.655737
                                ],
                                [
                                    114.420857,
                                    22.655539
                                ],
                                [
                                    114.420943,
                                    22.655341
                                ],
                                [
                                    114.421007,
                                    22.655053
                                ],
                                [
                                    114.421124,
                                    22.654775
                                ],
                                [
                                    114.420975,
                                    22.654577
                                ],
                                [
                                    114.420825,
                                    22.654498
                                ],
                                [
                                    114.420063,
                                    22.654726
                                ],
                                [
                                    114.419848,
                                    22.654597
                                ],
                                [
                                    114.418894,
                                    22.653053
                                ],
                                [
                                    114.418797,
                                    22.652954
                                ],
                                [
                                    114.418647,
                                    22.652973
                                ],
                                [
                                    114.418184,
                                    22.653607
                                ],
                                [
                                    114.417724,
                                    22.653566
                                ],
                                [
                                    114.416587,
                                    22.653973
                                ],
                                [
                                    114.416222,
                                    22.653854
                                ],
                                [
                                    114.415074,
                                    22.654072
                                ],
                                [
                                    114.41487,
                                    22.654171
                                ],
                                [
                                    114.414119,
                                    22.654102
                                ],
                                [
                                    114.413862,
                                    22.65435
                                ],
                                [
                                    114.413089,
                                    22.65427
                                ],
                                [
                                    114.41295,
                                    22.654072
                                ],
                                [
                                    114.412134,
                                    22.653488
                                ],
                                [
                                    114.412091,
                                    22.652518
                                ],
                                [
                                    114.412242,
                                    22.6523
                                ],
                                [
                                    114.412274,
                                    22.652152
                                ],
                                [
                                    114.412209,
                                    22.652052
                                ],
                                [
                                    114.411577,
                                    22.651745
                                ],
                                [
                                    114.410976,
                                    22.651082
                                ],
                                [
                                    114.41074,
                                    22.650528
                                ],
                                [
                                    114.409229,
                                    22.652387
                                ],
                                [
                                    114.408258,
                                    22.652639
                                ],
                                [
                                    114.408018,
                                    22.65235
                                ],
                                [
                                    114.407635,
                                    22.652166
                                ],
                                [
                                    114.407568,
                                    22.652174
                                ],
                                [
                                    114.408451,
                                    22.651392
                                ],
                                [
                                    114.410293,
                                    22.649718
                                ],
                                [
                                    114.409066,
                                    22.649122
                                ],
                                [
                                    114.408841,
                                    22.648785
                                ],
                                [
                                    114.408895,
                                    22.648726
                                ],
                                [
                                    114.408852,
                                    22.648627
                                ],
                                [
                                    114.407865,
                                    22.648468
                                ],
                                [
                                    114.407789,
                                    22.648389
                                ],
                                [
                                    114.407477,
                                    22.648488
                                ],
                                [
                                    114.407156,
                                    22.648825
                                ],
                                [
                                    114.406706,
                                    22.649181
                                ],
                                [
                                    114.406437,
                                    22.649201
                                ],
                                [
                                    114.406116,
                                    22.648953
                                ],
                                [
                                    114.405815,
                                    22.648874
                                ],
                                [
                                    114.405492,
                                    22.648993
                                ],
                                [
                                    114.404936,
                                    22.648716
                                ],
                                [
                                    114.404827,
                                    22.648755
                                ],
                                [
                                    114.404614,
                                    22.648754
                                ],
                                [
                                    114.404206,
                                    22.648329
                                ],
                                [
                                    114.40427,
                                    22.647943
                                ],
                                [
                                    114.404174,
                                    22.647864
                                ],
                                [
                                    114.403648,
                                    22.647904
                                ],
                                [
                                    114.403509,
                                    22.647567
                                ],
                                [
                                    114.403487,
                                    22.64727
                                ],
                                [
                                    114.403241,
                                    22.647072
                                ],
                                [
                                    114.402941,
                                    22.646992
                                ],
                                [
                                    114.402662,
                                    22.646785
                                ],
                                [
                                    114.402372,
                                    22.646805
                                ],
                                [
                                    114.402104,
                                    22.646696
                                ],
                                [
                                    114.401825,
                                    22.646814
                                ],
                                [
                                    114.401181,
                                    22.646706
                                ],
                                [
                                    114.400602,
                                    22.646755
                                ],
                                [
                                    114.400226,
                                    22.646587
                                ],
                                [
                                    114.40014,
                                    22.646507
                                ],
                                [
                                    114.399851,
                                    22.646438
                                ],
                                [
                                    114.398928,
                                    22.645913
                                ],
                                [
                                    114.398359,
                                    22.645854
                                ],
                                [
                                    114.397716,
                                    22.645507
                                ],
                                [
                                    114.397265,
                                    22.645468
                                ],
                                [
                                    114.396804,
                                    22.645181
                                ],
                                [
                                    114.396675,
                                    22.644814
                                ],
                                [
                                    114.396171,
                                    22.644497
                                ],
                                [
                                    114.395785,
                                    22.643902
                                ],
                                [
                                    114.395494,
                                    22.643704
                                ],
                                [
                                    114.394314,
                                    22.643081
                                ],
                                [
                                    114.394099,
                                    22.643032
                                ],
                                [
                                    114.393563,
                                    22.643051
                                ],
                                [
                                    114.392672,
                                    22.642725
                                ],
                                [
                                    114.392157,
                                    22.642477
                                ],
                                [
                                    114.39146,
                                    22.642546
                                ],
                                [
                                    114.390988,
                                    22.642566
                                ],
                                [
                                    114.390376,
                                    22.642299
                                ],
                                [
                                    114.389861,
                                    22.64219
                                ],
                                [
                                    114.389722,
                                    22.642091
                                ],
                                [
                                    114.38969,
                                    22.641507
                                ],
                                [
                                    114.389292,
                                    22.640077
                                ],
                                [
                                    114.389604,
                                    22.639269
                                ],
                                [
                                    114.389636,
                                    22.638784
                                ],
                                [
                                    114.389818,
                                    22.638061
                                ],
                                [
                                    114.389797,
                                    22.637496
                                ],
                                [
                                    114.389967,
                                    22.637209
                                ],
                                [
                                    114.389967,
                                    22.637021
                                ],
                                [
                                    114.389861,
                                    22.636813
                                ],
                                [
                                    114.389668,
                                    22.636615
                                ],
                                [
                                    114.389271,
                                    22.636704
                                ],
                                [
                                    114.388906,
                                    22.636476
                                ],
                                [
                                    114.388702,
                                    22.636447
                                ],
                                [
                                    114.387597,
                                    22.636932
                                ],
                                [
                                    114.386986,
                                    22.637496
                                ],
                                [
                                    114.386718,
                                    22.637685
                                ],
                                [
                                    114.386052,
                                    22.637724
                                ],
                                [
                                    114.385387,
                                    22.637189
                                ],
                                [
                                    114.385173,
                                    22.637229
                                ],
                                [
                                    114.384883,
                                    22.637447
                                ],
                                [
                                    114.384497,
                                    22.637585
                                ],
                                [
                                    114.383789,
                                    22.637566
                                ],
                                [
                                    114.383284,
                                    22.637982
                                ],
                                [
                                    114.382898,
                                    22.63815
                                ],
                                [
                                    114.382587,
                                    22.638219
                                ],
                                [
                                    114.382093,
                                    22.638031
                                ],
                                [
                                    114.381933,
                                    22.637902
                                ],
                                [
                                    114.381471,
                                    22.637883
                                ],
                                [
                                    114.38101,
                                    22.63809
                                ],
                                [
                                    114.380881,
                                    22.638566
                                ],
                                [
                                    114.380957,
                                    22.639042
                                ],
                                [
                                    114.380893,
                                    22.63921
                                ],
                                [
                                    114.379895,
                                    22.64019
                                ],
                                [
                                    114.379722,
                                    22.640438
                                ],
                                [
                                    114.379519,
                                    22.640567
                                ],
                                [
                                    114.379036,
                                    22.640695
                                ],
                                [
                                    114.378275,
                                    22.641309
                                ],
                                [
                                    114.378125,
                                    22.64221
                                ],
                                [
                                    114.377717,
                                    22.642943
                                ],
                                [
                                    114.376923,
                                    22.643973
                                ],
                                [
                                    114.376644,
                                    22.644131
                                ],
                                [
                                    114.376118,
                                    22.644557
                                ],
                                [
                                    114.3757,
                                    22.644488
                                ],
                                [
                                    114.374895,
                                    22.643537
                                ],
                                [
                                    114.374595,
                                    22.643448
                                ],
                                [
                                    114.37452,
                                    22.643329
                                ],
                                [
                                    114.374133,
                                    22.642983
                                ],
                                [
                                    114.37379,
                                    22.642864
                                ],
                                [
                                    114.373597,
                                    22.642567
                                ],
                                [
                                    114.373297,
                                    22.642498
                                ],
                                [
                                    114.373179,
                                    22.642369
                                ],
                                [
                                    114.372664,
                                    22.642151
                                ],
                                [
                                    114.372417,
                                    22.641497
                                ],
                                [
                                    114.371934,
                                    22.641022
                                ],
                                [
                                    114.371494,
                                    22.641032
                                ],
                                [
                                    114.371322,
                                    22.640834
                                ],
                                [
                                    114.371365,
                                    22.640596
                                ],
                                [
                                    114.371313,
                                    22.640329
                                ],
                                [
                                    114.372107,
                                    22.639022
                                ],
                                [
                                    114.372268,
                                    22.638933
                                ],
                                [
                                    114.373856,
                                    22.638893
                                ],
                                [
                                    114.374864,
                                    22.638616
                                ],
                                [
                                    114.375036,
                                    22.638468
                                ],
                                [
                                    114.37509,
                                    22.638329
                                ],
                                [
                                    114.375079,
                                    22.638032
                                ],
                                [
                                    114.374779,
                                    22.637339
                                ],
                                [
                                    114.374403,
                                    22.636735
                                ],
                                [
                                    114.373684,
                                    22.636032
                                ],
                                [
                                    114.373321,
                                    22.635439
                                ],
                                [
                                    114.373374,
                                    22.63534
                                ],
                                [
                                    114.374619,
                                    22.634924
                                ],
                                [
                                    114.374984,
                                    22.634874
                                ],
                                [
                                    114.375145,
                                    22.634488
                                ],
                                [
                                    114.375134,
                                    22.633963
                                ],
                                [
                                    114.375445,
                                    22.633082
                                ],
                                [
                                    114.375359,
                                    22.632597
                                ],
                                [
                                    114.374716,
                                    22.632141
                                ],
                                [
                                    114.374201,
                                    22.632181
                                ],
                                [
                                    114.372817,
                                    22.632864
                                ],
                                [
                                    114.372033,
                                    22.632844
                                ],
                                [
                                    114.371218,
                                    22.631933
                                ],
                                [
                                    114.370993,
                                    22.631864
                                ],
                                [
                                    114.367527,
                                    22.632735
                                ],
                                [
                                    114.367688,
                                    22.632379
                                ],
                                [
                                    114.367849,
                                    22.631765
                                ],
                                [
                                    114.367388,
                                    22.631042
                                ],
                                [
                                    114.367409,
                                    22.630735
                                ],
                                [
                                    114.367216,
                                    22.629457
                                ],
                                [
                                    114.36698,
                                    22.629091
                                ],
                                [
                                    114.366529,
                                    22.629042
                                ],
                                [
                                    114.36639,
                                    22.628981
                                ],
                                [
                                    114.366476,
                                    22.627863
                                ],
                                [
                                    114.366433,
                                    22.627109
                                ],
                                [
                                    114.366765,
                                    22.626526
                                ],
                                [
                                    114.366658,
                                    22.626011
                                ],
                                [
                                    114.36667,
                                    22.625436
                                ],
                                [
                                    114.367024,
                                    22.624793
                                ],
                                [
                                    114.367013,
                                    22.624109
                                ],
                                [
                                    114.366895,
                                    22.623476
                                ],
                                [
                                    114.365607,
                                    22.622376
                                ],
                                [
                                    114.365189,
                                    22.622177
                                ],
                                [
                                    114.364942,
                                    22.622178
                                ],
                                [
                                    114.364513,
                                    22.622337
                                ],
                                [
                                    114.363934,
                                    22.622723
                                ],
                                [
                                    114.362925,
                                    22.623307
                                ],
                                [
                                    114.362485,
                                    22.622921
                                ],
                                [
                                    114.362271,
                                    22.622961
                                ],
                                [
                                    114.36196,
                                    22.623367
                                ],
                                [
                                    114.361777,
                                    22.623347
                                ],
                                [
                                    114.360951,
                                    22.622664
                                ],
                                [
                                    114.36005,
                                    22.623396
                                ],
                                [
                                    114.359771,
                                    22.623733
                                ],
                                [
                                    114.359556,
                                    22.623862
                                ],
                                [
                                    114.359213,
                                    22.623941
                                ],
                                [
                                    114.358387,
                                    22.623911
                                ],
                                [
                                    114.357582,
                                    22.624218
                                ],
                                [
                                    114.357625,
                                    22.624654
                                ],
                                [
                                    114.357528,
                                    22.62495
                                ],
                                [
                                    114.356917,
                                    22.625227
                                ],
                                [
                                    114.356316,
                                    22.624584
                                ],
                                [
                                    114.356198,
                                    22.624574
                                ],
                                [
                                    114.356134,
                                    22.624623
                                ],
                                [
                                    114.356134,
                                    22.625366
                                ],
                                [
                                    114.356101,
                                    22.625465
                                ],
                                [
                                    114.355029,
                                    22.626366
                                ],
                                [
                                    114.355082,
                                    22.626713
                                ],
                                [
                                    114.354728,
                                    22.627257
                                ],
                                [
                                    114.35461,
                                    22.627337
                                ],
                                [
                                    114.354385,
                                    22.627238
                                ],
                                [
                                    114.35417,
                                    22.626257
                                ],
                                [
                                    114.352765,
                                    22.626574
                                ],
                                [
                                    114.352066,
                                    22.626962
                                ],
                                [
                                    114.351798,
                                    22.628507
                                ],
                                [
                                    114.351809,
                                    22.629022
                                ],
                                [
                                    114.351712,
                                    22.629269
                                ],
                                [
                                    114.351401,
                                    22.629755
                                ],
                                [
                                    114.351144,
                                    22.630963
                                ],
                                [
                                    114.350961,
                                    22.631408
                                ],
                                [
                                    114.350854,
                                    22.631448
                                ],
                                [
                                    114.349256,
                                    22.63121
                                ],
                                [
                                    114.347657,
                                    22.630795
                                ],
                                [
                                    114.346101,
                                    22.631696
                                ],
                                [
                                    114.345683,
                                    22.631339
                                ],
                                [
                                    114.345436,
                                    22.63128
                                ],
                                [
                                    114.344556,
                                    22.63128
                                ],
                                [
                                    114.344406,
                                    22.631329
                                ],
                                [
                                    114.344331,
                                    22.63128
                                ],
                                [
                                    114.344331,
                                    22.630894
                                ],
                                [
                                    114.344706,
                                    22.630299
                                ],
                                [
                                    114.344824,
                                    22.629369
                                ],
                                [
                                    114.344964,
                                    22.629151
                                ],
                                [
                                    114.344943,
                                    22.628903
                                ],
                                [
                                    114.344867,
                                    22.628725
                                ],
                                [
                                    114.344749,
                                    22.628586
                                ],
                                [
                                    114.344406,
                                    22.628417
                                ],
                                [
                                    114.343762,
                                    22.628388
                                ],
                                [
                                    114.343644,
                                    22.628308
                                ],
                                [
                                    114.343494,
                                    22.628091
                                ],
                                [
                                    114.343612,
                                    22.627417
                                ],
                                [
                                    114.34343,
                                    22.626813
                                ],
                                [
                                    114.34343,
                                    22.626684
                                ],
                                [
                                    114.343312,
                                    22.626595
                                ],
                                [
                                    114.343183,
                                    22.626595
                                ],
                                [
                                    114.342411,
                                    22.626605
                                ],
                                [
                                    114.341938,
                                    22.626348
                                ],
                                [
                                    114.341359,
                                    22.626051
                                ],
                                [
                                    114.340994,
                                    22.625872
                                ],
                                [
                                    114.340715,
                                    22.625793
                                ],
                                [
                                    114.340436,
                                    22.625882
                                ],
                                [
                                    114.3402,
                                    22.625833
                                ],
                                [
                                    114.3399,
                                    22.625447
                                ],
                                [
                                    114.339793,
                                    22.624981
                                ],
                                [
                                    114.339803,
                                    22.624476
                                ],
                                [
                                    114.339685,
                                    22.624288
                                ],
                                [
                                    114.339632,
                                    22.623882
                                ],
                                [
                                    114.339546,
                                    22.623634
                                ],
                                [
                                    114.339406,
                                    22.623397
                                ],
                                [
                                    114.339292,
                                    22.623357
                                ],
                                [
                                    114.338043,
                                    22.624207
                                ],
                                [
                                    114.335648,
                                    22.62553
                                ],
                                [
                                    114.33522,
                                    22.62589
                                ],
                                [
                                    114.331849,
                                    22.625988
                                ],
                                [
                                    114.330176,
                                    22.624296
                                ],
                                [
                                    114.329464,
                                    22.623407
                                ],
                                [
                                    114.328429,
                                    22.622867
                                ],
                                [
                                    114.325536,
                                    22.622967
                                ],
                                [
                                    114.324643,
                                    22.622873
                                ],
                                [
                                    114.323803,
                                    22.623045
                                ],
                                [
                                    114.322759,
                                    22.623574
                                ],
                                [
                                    114.322066,
                                    22.624856
                                ],
                                [
                                    114.321485,
                                    22.625353
                                ],
                                [
                                    114.320874,
                                    22.625691
                                ],
                                [
                                    114.319698,
                                    22.62601
                                ],
                                [
                                    114.319322,
                                    22.625987
                                ],
                                [
                                    114.318929,
                                    22.625838
                                ],
                                [
                                    114.318546,
                                    22.624772
                                ],
                                [
                                    114.318419,
                                    22.624669
                                ],
                                [
                                    114.316923,
                                    22.624384
                                ],
                                [
                                    114.315727,
                                    22.624447
                                ],
                                [
                                    114.313572,
                                    22.624333
                                ],
                                [
                                    114.312481,
                                    22.624992
                                ],
                                [
                                    114.311341,
                                    22.625453
                                ],
                                [
                                    114.31069,
                                    22.625978
                                ],
                                [
                                    114.310579,
                                    22.626159
                                ],
                                [
                                    114.310178,
                                    22.628105
                                ],
                                [
                                    114.308412,
                                    22.628973
                                ],
                                [
                                    114.306854,
                                    22.62986
                                ],
                                [
                                    114.306703,
                                    22.629837
                                ],
                                [
                                    114.304826,
                                    22.630511
                                ],
                                [
                                    114.304001,
                                    22.629789
                                ],
                                [
                                    114.303583,
                                    22.629292
                                ],
                                [
                                    114.303704,
                                    22.628498
                                ],
                                [
                                    114.302867,
                                    22.627901
                                ],
                                [
                                    114.298654,
                                    22.621273
                                ],
                                [
                                    114.298683,
                                    22.621141
                                ],
                                [
                                    114.298534,
                                    22.620836
                                ],
                                [
                                    114.297834,
                                    22.619986
                                ],
                                [
                                    114.296944,
                                    22.618582
                                ],
                                [
                                    114.296537,
                                    22.618543
                                ],
                                [
                                    114.295833,
                                    22.618869
                                ],
                                [
                                    114.295629,
                                    22.619066
                                ],
                                [
                                    114.294944,
                                    22.621025
                                ],
                                [
                                    114.294628,
                                    22.621292
                                ],
                                [
                                    114.294067,
                                    22.621279
                                ],
                                [
                                    114.291849,
                                    22.620799
                                ],
                                [
                                    114.291663,
                                    22.620584
                                ],
                                [
                                    114.291587,
                                    22.61968
                                ],
                                [
                                    114.291448,
                                    22.619506
                                ],
                                [
                                    114.290849,
                                    22.619333
                                ],
                                [
                                    114.290471,
                                    22.619421
                                ],
                                [
                                    114.290006,
                                    22.619985
                                ],
                                [
                                    114.289133,
                                    22.620684
                                ],
                                [
                                    114.28808,
                                    22.620868
                                ],
                                [
                                    114.286925,
                                    22.624282
                                ],
                                [
                                    114.287267,
                                    22.626205
                                ],
                                [
                                    114.287572,
                                    22.626439
                                ],
                                [
                                    114.28836,
                                    22.626773
                                ],
                                [
                                    114.288934,
                                    22.627289
                                ],
                                [
                                    114.290419,
                                    22.631029
                                ],
                                [
                                    114.290472,
                                    22.631164
                                ],
                                [
                                    114.29049,
                                    22.63121
                                ],
                                [
                                    114.290504,
                                    22.631246
                                ],
                                [
                                    114.290536,
                                    22.631343
                                ],
                                [
                                    114.290537,
                                    22.631348
                                ],
                                [
                                    114.290568,
                                    22.631421
                                ],
                                [
                                    114.290576,
                                    22.63147
                                ],
                                [
                                    114.29058,
                                    22.631525
                                ],
                                [
                                    114.290579,
                                    22.631531
                                ],
                                [
                                    114.290542,
                                    22.631625
                                ],
                                [
                                    114.290525,
                                    22.631647
                                ],
                                [
                                    114.290469,
                                    22.631712
                                ],
                                [
                                    114.290429,
                                    22.631759
                                ],
                                [
                                    114.290412,
                                    22.63177
                                ],
                                [
                                    114.289794,
                                    22.632155
                                ],
                                [
                                    114.289039,
                                    22.632196
                                ],
                                [
                                    114.28858,
                                    22.632474
                                ],
                                [
                                    114.288128,
                                    22.633087
                                ],
                                [
                                    114.287844,
                                    22.633718
                                ],
                                [
                                    114.287761,
                                    22.633893
                                ],
                                [
                                    114.287512,
                                    22.634419
                                ],
                                [
                                    114.287486,
                                    22.634476
                                ],
                                [
                                    114.287467,
                                    22.634509
                                ],
                                [
                                    114.287455,
                                    22.634541
                                ],
                                [
                                    114.28743,
                                    22.634594
                                ],
                                [
                                    114.287224,
                                    22.635029
                                ],
                                [
                                    114.287211,
                                    22.635058
                                ],
                                [
                                    114.287203,
                                    22.635136
                                ],
                                [
                                    114.287122,
                                    22.635244
                                ],
                                [
                                    114.287089,
                                    22.635314
                                ],
                                [
                                    114.286674,
                                    22.636192
                                ],
                                [
                                    114.286298,
                                    22.63651
                                ],
                                [
                                    114.285876,
                                    22.636726
                                ],
                                [
                                    114.285646,
                                    22.637003
                                ],
                                [
                                    114.285581,
                                    22.637111
                                ],
                                [
                                    114.285554,
                                    22.637173
                                ],
                                [
                                    114.285569,
                                    22.637739
                                ],
                                [
                                    114.28558,
                                    22.637794
                                ],
                                [
                                    114.285589,
                                    22.637869
                                ],
                                [
                                    114.285581,
                                    22.637932
                                ],
                                [
                                    114.28565,
                                    22.639434
                                ],
                                [
                                    114.285654,
                                    22.639512
                                ],
                                [
                                    114.285718,
                                    22.639566
                                ],
                                [
                                    114.285724,
                                    22.639611
                                ],
                                [
                                    114.285844,
                                    22.640177
                                ],
                                [
                                    114.28589,
                                    22.640279
                                ],
                                [
                                    114.285909,
                                    22.640358
                                ],
                                [
                                    114.285889,
                                    22.640514
                                ],
                                [
                                    114.284836,
                                    22.640891
                                ],
                                [
                                    114.284759,
                                    22.64092
                                ],
                                [
                                    114.284678,
                                    22.640991
                                ],
                                [
                                    114.284673,
                                    22.640992
                                ],
                                [
                                    114.283696,
                                    22.641111
                                ],
                                [
                                    114.282663,
                                    22.641823
                                ],
                                [
                                    114.281901,
                                    22.642165
                                ],
                                [
                                    114.281724,
                                    22.642245
                                ],
                                [
                                    114.281561,
                                    22.642309
                                ],
                                [
                                    114.281514,
                                    22.642324
                                ],
                                [
                                    114.281407,
                                    22.64236
                                ],
                                [
                                    114.281378,
                                    22.642373
                                ],
                                [
                                    114.281052,
                                    22.642851
                                ],
                                [
                                    114.281046,
                                    22.642861
                                ],
                                [
                                    114.281014,
                                    22.64291
                                ],
                                [
                                    114.281008,
                                    22.642944
                                ],
                                [
                                    114.281008,
                                    22.642948
                                ],
                                [
                                    114.281009,
                                    22.643009
                                ],
                                [
                                    114.28098,
                                    22.64303
                                ],
                                [
                                    114.28089,
                                    22.643092
                                ],
                                [
                                    114.280429,
                                    22.643412
                                ],
                                [
                                    114.280154,
                                    22.643773
                                ],
                                [
                                    114.279359,
                                    22.644401
                                ],
                                [
                                    114.278965,
                                    22.644507
                                ],
                                [
                                    114.277744,
                                    22.64532
                                ],
                                [
                                    114.276804,
                                    22.645817
                                ],
                                [
                                    114.275714,
                                    22.646773
                                ],
                                [
                                    114.275208,
                                    22.647702
                                ],
                                [
                                    114.27495,
                                    22.648846
                                ],
                                [
                                    114.274479,
                                    22.649801
                                ],
                                [
                                    114.274272,
                                    22.651135
                                ],
                                [
                                    114.273419,
                                    22.651621
                                ],
                                [
                                    114.272681,
                                    22.652228
                                ],
                                [
                                    114.271023,
                                    22.653277
                                ],
                                [
                                    114.269789,
                                    22.653829
                                ]
                            ]
                        ]
                    },
                    "properties": {
                        "name": "坪山区",
                        "cp": [
                            114.338441,
                            22.69423
                        ]
                    }
                },
                {
                    "type": "Feature",
                    "id": "440311",
                    "geometry": {
                        "type": "Polygon",
                        "coordinates": [
                            [
                                [
                                    113.99086,
                                    22.800206
                                ],
                                [
                                    113.991041,
                                    22.800115
                                ],
                                [
                                    113.990878,
                                    22.79891
                                ],
                                [
                                    113.991168,
                                    22.795598
                                ],
                                [
                                    113.990961,
                                    22.794045
                                ],
                                [
                                    113.991451,
                                    22.792451
                                ],
                                [
                                    113.991743,
                                    22.791889
                                ],
                                [
                                    113.991957,
                                    22.791033
                                ],
                                [
                                    113.992176,
                                    22.79054
                                ],
                                [
                                    113.992683,
                                    22.789941
                                ],
                                [
                                    113.99287,
                                    22.788965
                                ],
                                [
                                    113.992578,
                                    22.788372
                                ],
                                [
                                    113.992509,
                                    22.787829
                                ],
                                [
                                    113.993939,
                                    22.784456
                                ],
                                [
                                    113.993976,
                                    22.783087
                                ],
                                [
                                    113.994154,
                                    22.782439
                                ],
                                [
                                    113.995423,
                                    22.780388
                                ],
                                [
                                    113.995832,
                                    22.779201
                                ],
                                [
                                    113.996161,
                                    22.778723
                                ],
                                [
                                    113.996691,
                                    22.778184
                                ],
                                [
                                    113.996874,
                                    22.777166
                                ],
                                [
                                    113.997634,
                                    22.776685
                                ],
                                [
                                    113.998433,
                                    22.776552
                                ],
                                [
                                    113.998878,
                                    22.774824
                                ],
                                [
                                    113.998895,
                                    22.774472
                                ],
                                [
                                    113.998739,
                                    22.774168
                                ],
                                [
                                    113.997154,
                                    22.772701
                                ],
                                [
                                    113.996344,
                                    22.772118
                                ],
                                [
                                    113.995853,
                                    22.771544
                                ],
                                [
                                    113.995324,
                                    22.771284
                                ],
                                [
                                    113.995361,
                                    22.770649
                                ],
                                [
                                    113.995927,
                                    22.769891
                                ],
                                [
                                    113.996182,
                                    22.768705
                                ],
                                [
                                    113.9963,
                                    22.768525
                                ],
                                [
                                    113.996976,
                                    22.768429
                                ],
                                [
                                    113.997226,
                                    22.768289
                                ],
                                [
                                    113.998338,
                                    22.76801
                                ],
                                [
                                    113.999871,
                                    22.767302
                                ],
                                [
                                    114.000292,
                                    22.767287
                                ],
                                [
                                    114.000503,
                                    22.767128
                                ],
                                [
                                    114.001028,
                                    22.766095
                                ],
                                [
                                    114.001869,
                                    22.765132
                                ],
                                [
                                    114.001882,
                                    22.764502
                                ],
                                [
                                    114.002059,
                                    22.764098
                                ],
                                [
                                    114.002695,
                                    22.763616
                                ],
                                [
                                    114.002617,
                                    22.763472
                                ],
                                [
                                    114.002483,
                                    22.762973
                                ],
                                [
                                    114.001474,
                                    22.762558
                                ],
                                [
                                    114.000638,
                                    22.762344
                                ],
                                [
                                    114.000112,
                                    22.762062
                                ],
                                [
                                    113.999887,
                                    22.761701
                                ],
                                [
                                    113.99971,
                                    22.761479
                                ],
                                [
                                    113.999324,
                                    22.761237
                                ],
                                [
                                    113.998632,
                                    22.760984
                                ],
                                [
                                    113.998508,
                                    22.76092
                                ],
                                [
                                    113.99832,
                                    22.760711
                                ],
                                [
                                    113.998159,
                                    22.760439
                                ],
                                [
                                    113.99731,
                                    22.759089
                                ],
                                [
                                    113.996736,
                                    22.758664
                                ],
                                [
                                    113.996559,
                                    22.758565
                                ],
                                [
                                    113.99628,
                                    22.758649
                                ],
                                [
                                    113.995696,
                                    22.758762
                                ],
                                [
                                    113.995427,
                                    22.758679
                                ],
                                [
                                    113.994961,
                                    22.758658
                                ],
                                [
                                    113.994312,
                                    22.758773
                                ],
                                [
                                    113.993624,
                                    22.759064
                                ],
                                [
                                    113.993249,
                                    22.758521
                                ],
                                [
                                    113.992976,
                                    22.758229
                                ],
                                [
                                    113.992788,
                                    22.757714
                                ],
                                [
                                    113.992953,
                                    22.75721
                                ],
                                [
                                    113.992985,
                                    22.756894
                                ],
                                [
                                    113.993055,
                                    22.756627
                                ],
                                [
                                    113.993167,
                                    22.756309
                                ],
                                [
                                    113.993226,
                                    22.755824
                                ],
                                [
                                    113.993194,
                                    22.755617
                                ],
                                [
                                    113.993087,
                                    22.755271
                                ],
                                [
                                    113.992867,
                                    22.754726
                                ],
                                [
                                    113.992326,
                                    22.75398
                                ],
                                [
                                    113.992932,
                                    22.753623
                                ],
                                [
                                    113.993581,
                                    22.753469
                                ],
                                [
                                    113.994069,
                                    22.753622
                                ],
                                [
                                    113.994718,
                                    22.753741
                                ],
                                [
                                    113.995099,
                                    22.753646
                                ],
                                [
                                    113.995394,
                                    22.753459
                                ],
                                [
                                    113.995931,
                                    22.753306
                                ],
                                [
                                    113.996457,
                                    22.753286
                                ],
                                [
                                    113.996628,
                                    22.753341
                                ],
                                [
                                    113.996858,
                                    22.753667
                                ],
                                [
                                    113.997039,
                                    22.753849
                                ],
                                [
                                    113.997571,
                                    22.754116
                                ],
                                [
                                    113.997673,
                                    22.754132
                                ],
                                [
                                    113.998285,
                                    22.753884
                                ],
                                [
                                    113.998709,
                                    22.753764
                                ],
                                [
                                    113.999621,
                                    22.753739
                                ],
                                [
                                    113.999696,
                                    22.75371
                                ],
                                [
                                    113.999798,
                                    22.753491
                                ],
                                [
                                    113.999888,
                                    22.75303
                                ],
                                [
                                    114.000012,
                                    22.752684
                                ],
                                [
                                    114.000162,
                                    22.752426
                                ],
                                [
                                    114.000715,
                                    22.751981
                                ],
                                [
                                    114.000881,
                                    22.751758
                                ],
                                [
                                    114.001209,
                                    22.751649
                                ],
                                [
                                    114.001455,
                                    22.75162
                                ],
                                [
                                    114.001627,
                                    22.75157
                                ],
                                [
                                    114.001879,
                                    22.751451
                                ],
                                [
                                    114.002153,
                                    22.751368
                                ],
                                [
                                    114.002577,
                                    22.751105
                                ],
                                [
                                    114.004203,
                                    22.750324
                                ],
                                [
                                    114.004337,
                                    22.750612
                                ],
                                [
                                    114.004809,
                                    22.750844
                                ],
                                [
                                    114.004831,
                                    22.750868
                                ],
                                [
                                    114.004814,
                                    22.750968
                                ],
                                [
                                    114.004734,
                                    22.751156
                                ],
                                [
                                    114.004641,
                                    22.751259
                                ],
                                [
                                    114.004465,
                                    22.751378
                                ],
                                [
                                    114.004309,
                                    22.751471
                                ],
                                [
                                    114.004159,
                                    22.751536
                                ],
                                [
                                    114.004105,
                                    22.751574
                                ],
                                [
                                    114.004089,
                                    22.75162
                                ],
                                [
                                    114.004099,
                                    22.751678
                                ],
                                [
                                    114.004143,
                                    22.751729
                                ],
                                [
                                    114.004223,
                                    22.751758
                                ],
                                [
                                    114.004315,
                                    22.751744
                                ],
                                [
                                    114.004421,
                                    22.751713
                                ],
                                [
                                    114.004486,
                                    22.751709
                                ],
                                [
                                    114.004556,
                                    22.751713
                                ],
                                [
                                    114.004594,
                                    22.751744
                                ],
                                [
                                    114.004626,
                                    22.751828
                                ],
                                [
                                    114.004711,
                                    22.751976
                                ],
                                [
                                    114.004803,
                                    22.751866
                                ],
                                [
                                    114.0049,
                                    22.751906
                                ],
                                [
                                    114.004991,
                                    22.751787
                                ],
                                [
                                    114.005071,
                                    22.751703
                                ],
                                [
                                    114.005179,
                                    22.75162
                                ],
                                [
                                    114.005324,
                                    22.751589
                                ],
                                [
                                    114.005465,
                                    22.751594
                                ],
                                [
                                    114.005569,
                                    22.75156
                                ],
                                [
                                    114.005702,
                                    22.751558
                                ],
                                [
                                    114.005772,
                                    22.751464
                                ],
                                [
                                    114.005783,
                                    22.751365
                                ],
                                [
                                    114.006142,
                                    22.750938
                                ],
                                [
                                    114.006169,
                                    22.750806
                                ],
                                [
                                    114.005164,
                                    22.749908
                                ],
                                [
                                    114.003743,
                                    22.748681
                                ],
                                [
                                    114.003812,
                                    22.748529
                                ],
                                [
                                    114.003963,
                                    22.748341
                                ],
                                [
                                    114.004156,
                                    22.748172
                                ],
                                [
                                    114.004767,
                                    22.747787
                                ],
                                [
                                    114.005345,
                                    22.747271
                                ],
                                [
                                    114.006052,
                                    22.746629
                                ],
                                [
                                    114.006177,
                                    22.746514
                                ],
                                [
                                    114.006348,
                                    22.746406
                                ],
                                [
                                    114.006536,
                                    22.74639
                                ],
                                [
                                    114.006589,
                                    22.746346
                                ],
                                [
                                    114.00666,
                                    22.746212
                                ],
                                [
                                    114.006751,
                                    22.746088
                                ],
                                [
                                    114.006896,
                                    22.745738
                                ],
                                [
                                    114.007141,
                                    22.745282
                                ],
                                [
                                    114.007378,
                                    22.745272
                                ],
                                [
                                    114.007523,
                                    22.745233
                                ],
                                [
                                    114.007673,
                                    22.745233
                                ],
                                [
                                    114.007893,
                                    22.745134
                                ],
                                [
                                    114.007985,
                                    22.745144
                                ],
                                [
                                    114.008097,
                                    22.745238
                                ],
                                [
                                    114.008104,
                                    22.745107
                                ],
                                [
                                    114.007807,
                                    22.744861
                                ],
                                [
                                    114.008241,
                                    22.744519
                                ],
                                [
                                    114.008355,
                                    22.744431
                                ],
                                [
                                    114.008542,
                                    22.744296
                                ],
                                [
                                    114.008666,
                                    22.744198
                                ],
                                [
                                    114.008869,
                                    22.744019
                                ],
                                [
                                    114.008809,
                                    22.743941
                                ],
                                [
                                    114.008762,
                                    22.743861
                                ],
                                [
                                    114.008655,
                                    22.743719
                                ],
                                [
                                    114.008557,
                                    22.74361
                                ],
                                [
                                    114.008462,
                                    22.743367
                                ],
                                [
                                    114.008467,
                                    22.743229
                                ],
                                [
                                    114.008617,
                                    22.743036
                                ],
                                [
                                    114.00875,
                                    22.742902
                                ],
                                [
                                    114.008831,
                                    22.742784
                                ],
                                [
                                    114.008862,
                                    22.742577
                                ],
                                [
                                    114.008866,
                                    22.742404
                                ],
                                [
                                    114.008862,
                                    22.742339
                                ],
                                [
                                    114.008883,
                                    22.742281
                                ],
                                [
                                    114.008989,
                                    22.742131
                                ],
                                [
                                    114.008996,
                                    22.742088
                                ],
                                [
                                    114.00898,
                                    22.741988
                                ],
                                [
                                    114.009204,
                                    22.739939
                                ],
                                [
                                    114.008507,
                                    22.738831
                                ],
                                [
                                    114.008343,
                                    22.736621
                                ],
                                [
                                    114.008346,
                                    22.736224
                                ],
                                [
                                    114.008754,
                                    22.735813
                                ],
                                [
                                    114.007399,
                                    22.735896
                                ],
                                [
                                    114.006179,
                                    22.735971
                                ],
                                [
                                    114.006175,
                                    22.736559
                                ],
                                [
                                    114.006189,
                                    22.736653
                                ],
                                [
                                    114.00598,
                                    22.736726
                                ],
                                [
                                    114.005648,
                                    22.736884
                                ],
                                [
                                    114.005369,
                                    22.737033
                                ],
                                [
                                    114.005229,
                                    22.737123
                                ],
                                [
                                    114.005063,
                                    22.737118
                                ],
                                [
                                    114.004666,
                                    22.737028
                                ],
                                [
                                    114.004182,
                                    22.736899
                                ],
                                [
                                    114.003973,
                                    22.736781
                                ],
                                [
                                    114.003781,
                                    22.736656
                                ],
                                [
                                    114.003534,
                                    22.736577
                                ],
                                [
                                    114.003463,
                                    22.736534
                                ],
                                [
                                    114.003351,
                                    22.736366
                                ],
                                [
                                    114.003099,
                                    22.735949
                                ],
                                [
                                    114.002762,
                                    22.735429
                                ],
                                [
                                    114.002564,
                                    22.735183
                                ],
                                [
                                    114.002408,
                                    22.734964
                                ],
                                [
                                    114.002327,
                                    22.734791
                                ],
                                [
                                    114.002306,
                                    22.734717
                                ],
                                [
                                    114.002231,
                                    22.734693
                                ],
                                [
                                    114.002112,
                                    22.734687
                                ],
                                [
                                    114.001968,
                                    22.734629
                                ],
                                [
                                    114.001796,
                                    22.734534
                                ],
                                [
                                    114.001678,
                                    22.734425
                                ],
                                [
                                    114.001627,
                                    22.734358
                                ],
                                [
                                    114.001397,
                                    22.734124
                                ],
                                [
                                    114.001042,
                                    22.733779
                                ],
                                [
                                    114.00095,
                                    22.733654
                                ],
                                [
                                    114.000569,
                                    22.733586
                                ],
                                [
                                    114.000184,
                                    22.733367
                                ],
                                [
                                    113.999861,
                                    22.733309
                                ],
                                [
                                    113.999668,
                                    22.733224
                                ],
                                [
                                    113.999408,
                                    22.732975
                                ],
                                [
                                    113.999209,
                                    22.732786
                                ],
                                [
                                    113.999109,
                                    22.732693
                                ],
                                [
                                    113.998774,
                                    22.732376
                                ],
                                [
                                    113.99848,
                                    22.731966
                                ],
                                [
                                    113.998362,
                                    22.731783
                                ],
                                [
                                    113.998206,
                                    22.731619
                                ],
                                [
                                    113.998019,
                                    22.731502
                                ],
                                [
                                    113.997729,
                                    22.731388
                                ],
                                [
                                    113.997583,
                                    22.731293
                                ],
                                [
                                    113.997529,
                                    22.731219
                                ],
                                [
                                    113.997476,
                                    22.731115
                                ],
                                [
                                    113.997407,
                                    22.731001
                                ],
                                [
                                    113.997037,
                                    22.730463
                                ],
                                [
                                    113.996908,
                                    22.730318
                                ],
                                [
                                    113.996504,
                                    22.730135
                                ],
                                [
                                    113.996409,
                                    22.730076
                                ],
                                [
                                    113.995882,
                                    22.729957
                                ],
                                [
                                    113.995764,
                                    22.729922
                                ],
                                [
                                    113.995662,
                                    22.729869
                                ],
                                [
                                    113.995598,
                                    22.729783
                                ],
                                [
                                    113.995507,
                                    22.729601
                                ],
                                [
                                    113.995393,
                                    22.729491
                                ],
                                [
                                    113.995238,
                                    22.729418
                                ],
                                [
                                    113.995114,
                                    22.729348
                                ],
                                [
                                    113.995046,
                                    22.729283
                                ],
                                [
                                    113.994987,
                                    22.729179
                                ],
                                [
                                    113.994884,
                                    22.728912
                                ],
                                [
                                    113.994751,
                                    22.728788
                                ],
                                [
                                    113.994595,
                                    22.728684
                                ],
                                [
                                    113.994456,
                                    22.7286
                                ],
                                [
                                    113.994236,
                                    22.728437
                                ],
                                [
                                    113.993839,
                                    22.728156
                                ],
                                [
                                    113.993345,
                                    22.72765
                                ],
                                [
                                    113.993159,
                                    22.727408
                                ],
                                [
                                    113.992964,
                                    22.727032
                                ],
                                [
                                    113.992922,
                                    22.726953
                                ],
                                [
                                    113.992696,
                                    22.726944
                                ],
                                [
                                    113.992531,
                                    22.726884
                                ],
                                [
                                    113.992349,
                                    22.726794
                                ],
                                [
                                    113.992222,
                                    22.726695
                                ],
                                [
                                    113.992099,
                                    22.726541
                                ],
                                [
                                    113.992029,
                                    22.726431
                                ],
                                [
                                    113.991966,
                                    22.726327
                                ],
                                [
                                    113.991907,
                                    22.726189
                                ],
                                [
                                    113.991891,
                                    22.726119
                                ],
                                [
                                    113.991841,
                                    22.725956
                                ],
                                [
                                    113.991772,
                                    22.725897
                                ],
                                [
                                    113.991596,
                                    22.725799
                                ],
                                [
                                    113.991552,
                                    22.725788
                                ],
                                [
                                    113.991321,
                                    22.725704
                                ],
                                [
                                    113.991166,
                                    22.72564
                                ],
                                [
                                    113.991048,
                                    22.72553
                                ],
                                [
                                    113.990989,
                                    22.725436
                                ],
                                [
                                    113.990822,
                                    22.725208
                                ],
                                [
                                    113.990705,
                                    22.72506
                                ],
                                [
                                    113.990683,
                                    22.724926
                                ],
                                [
                                    113.990699,
                                    22.724743
                                ],
                                [
                                    113.990678,
                                    22.724575
                                ],
                                [
                                    113.990416,
                                    22.724476
                                ],
                                [
                                    113.990216,
                                    22.724372
                                ],
                                [
                                    113.989776,
                                    22.7241
                                ],
                                [
                                    113.989595,
                                    22.723996
                                ],
                                [
                                    113.989267,
                                    22.723818
                                ],
                                [
                                    113.989074,
                                    22.723798
                                ],
                                [
                                    113.988854,
                                    22.723754
                                ],
                                [
                                    113.98865,
                                    22.72364
                                ],
                                [
                                    113.988044,
                                    22.723294
                                ],
                                [
                                    113.988033,
                                    22.72316
                                ],
                                [
                                    113.98799,
                                    22.722952
                                ],
                                [
                                    113.987948,
                                    22.722804
                                ],
                                [
                                    113.987936,
                                    22.722731
                                ],
                                [
                                    113.98739,
                                    22.721889
                                ],
                                [
                                    113.987256,
                                    22.72131
                                ],
                                [
                                    113.987241,
                                    22.721083
                                ],
                                [
                                    113.987202,
                                    22.721018
                                ],
                                [
                                    113.987068,
                                    22.720934
                                ],
                                [
                                    113.986945,
                                    22.720771
                                ],
                                [
                                    113.986853,
                                    22.720558
                                ],
                                [
                                    113.986548,
                                    22.719963
                                ],
                                [
                                    113.986419,
                                    22.719785
                                ],
                                [
                                    113.986222,
                                    22.719572
                                ],
                                [
                                    113.986146,
                                    22.719527
                                ],
                                [
                                    113.986097,
                                    22.719468
                                ],
                                [
                                    113.986097,
                                    22.71933
                                ],
                                [
                                    113.986039,
                                    22.719181
                                ],
                                [
                                    113.985953,
                                    22.719023
                                ],
                                [
                                    113.985851,
                                    22.718864
                                ],
                                [
                                    113.985631,
                                    22.718647
                                ],
                                [
                                    113.985422,
                                    22.718464
                                ],
                                [
                                    113.985277,
                                    22.71835
                                ],
                                [
                                    113.985084,
                                    22.718201
                                ],
                                [
                                    113.984917,
                                    22.718137
                                ],
                                [
                                    113.984712,
                                    22.718096
                                ],
                                [
                                    113.984643,
                                    22.718061
                                ],
                                [
                                    113.984557,
                                    22.717958
                                ],
                                [
                                    113.984508,
                                    22.717849
                                ],
                                [
                                    113.984369,
                                    22.717616
                                ],
                                [
                                    113.984278,
                                    22.717507
                                ],
                                [
                                    113.984111,
                                    22.71722
                                ],
                                [
                                    113.984048,
                                    22.717191
                                ],
                                [
                                    113.983639,
                                    22.717052
                                ],
                                [
                                    113.983452,
                                    22.716963
                                ],
                                [
                                    113.983094,
                                    22.716835
                                ],
                                [
                                    113.982986,
                                    22.716746
                                ],
                                [
                                    113.982691,
                                    22.716449
                                ],
                                [
                                    113.982595,
                                    22.716414
                                ],
                                [
                                    113.982403,
                                    22.716405
                                ],
                                [
                                    113.982251,
                                    22.716652
                                ],
                                [
                                    113.982049,
                                    22.716805
                                ],
                                [
                                    113.981914,
                                    22.71687
                                ],
                                [
                                    113.981796,
                                    22.716889
                                ],
                                [
                                    113.981668,
                                    22.716889
                                ],
                                [
                                    113.981517,
                                    22.71685
                                ],
                                [
                                    113.981393,
                                    22.716786
                                ],
                                [
                                    113.981286,
                                    22.716716
                                ],
                                [
                                    113.981071,
                                    22.716454
                                ],
                                [
                                    113.980953,
                                    22.716123
                                ],
                                [
                                    113.980884,
                                    22.716024
                                ],
                                [
                                    113.980749,
                                    22.71592
                                ],
                                [
                                    113.980599,
                                    22.715751
                                ],
                                [
                                    113.980531,
                                    22.715598
                                ],
                                [
                                    113.980433,
                                    22.715177
                                ],
                                [
                                    113.980402,
                                    22.715087
                                ],
                                [
                                    113.980338,
                                    22.715037
                                ],
                                [
                                    113.980188,
                                    22.714963
                                ],
                                [
                                    113.98,
                                    22.714889
                                ],
                                [
                                    113.979919,
                                    22.714815
                                ],
                                [
                                    113.979663,
                                    22.714523
                                ],
                                [
                                    113.979517,
                                    22.714305
                                ],
                                [
                                    113.979469,
                                    22.714176
                                ],
                                [
                                    113.979431,
                                    22.714122
                                ],
                                [
                                    113.979394,
                                    22.714092
                                ],
                                [
                                    113.979115,
                                    22.713993
                                ],
                                [
                                    113.978997,
                                    22.713805
                                ],
                                [
                                    113.978932,
                                    22.71378
                                ],
                                [
                                    113.978745,
                                    22.71377
                                ],
                                [
                                    113.978669,
                                    22.713736
                                ],
                                [
                                    113.978536,
                                    22.713657
                                ],
                                [
                                    113.978331,
                                    22.713449
                                ],
                                [
                                    113.978112,
                                    22.71333
                                ],
                                [
                                    113.978004,
                                    22.71329
                                ],
                                [
                                    113.97779,
                                    22.713256
                                ],
                                [
                                    113.977698,
                                    22.713216
                                ],
                                [
                                    113.977586,
                                    22.713142
                                ],
                                [
                                    113.977452,
                                    22.713028
                                ],
                                [
                                    113.977371,
                                    22.712924
                                ],
                                [
                                    113.977323,
                                    22.71284
                                ],
                                [
                                    113.977257,
                                    22.712753
                                ],
                                [
                                    113.976484,
                                    22.712317
                                ],
                                [
                                    113.976184,
                                    22.71204
                                ],
                                [
                                    113.975541,
                                    22.711723
                                ],
                                [
                                    113.974725,
                                    22.711486
                                ],
                                [
                                    113.973952,
                                    22.711842
                                ],
                                [
                                    113.973351,
                                    22.711605
                                ],
                                [
                                    113.972708,
                                    22.711644
                                ],
                                [
                                    113.972321,
                                    22.711288
                                ],
                                [
                                    113.972021,
                                    22.711288
                                ],
                                [
                                    113.971721,
                                    22.711011
                                ],
                                [
                                    113.971678,
                                    22.710813
                                ],
                                [
                                    113.971293,
                                    22.710575
                                ],
                                [
                                    113.971034,
                                    22.710219
                                ],
                                [
                                    113.970263,
                                    22.7101
                                ],
                                [
                                    113.969618,
                                    22.710694
                                ],
                                [
                                    113.968459,
                                    22.711011
                                ],
                                [
                                    113.96803,
                                    22.711921
                                ],
                                [
                                    113.967859,
                                    22.712357
                                ],
                                [
                                    113.967472,
                                    22.712515
                                ],
                                [
                                    113.967001,
                                    22.712515
                                ],
                                [
                                    113.966313,
                                    22.712594
                                ],
                                [
                                    113.96567,
                                    22.712673
                                ],
                                [
                                    113.965026,
                                    22.71299
                                ],
                                [
                                    113.964339,
                                    22.713228
                                ],
                                [
                                    113.963738,
                                    22.713742
                                ],
                                [
                                    113.963481,
                                    22.714297
                                ],
                                [
                                    113.963223,
                                    22.714772
                                ],
                                [
                                    113.962751,
                                    22.715445
                                ],
                                [
                                    113.962537,
                                    22.715524
                                ],
                                [
                                    113.961979,
                                    22.715603
                                ],
                                [
                                    113.961636,
                                    22.715563
                                ],
                                [
                                    113.961551,
                                    22.715128
                                ],
                                [
                                    113.961206,
                                    22.714613
                                ],
                                [
                                    113.961249,
                                    22.714178
                                ],
                                [
                                    113.960691,
                                    22.714059
                                ],
                                [
                                    113.960348,
                                    22.714099
                                ],
                                [
                                    113.959876,
                                    22.714336
                                ],
                                [
                                    113.959919,
                                    22.71489
                                ],
                                [
                                    113.959747,
                                    22.715286
                                ],
                                [
                                    113.959576,
                                    22.715643
                                ],
                                [
                                    113.959146,
                                    22.71588
                                ],
                                [
                                    113.95876,
                                    22.716038
                                ],
                                [
                                    113.958761,
                                    22.716672
                                ],
                                [
                                    113.958589,
                                    22.716949
                                ],
                                [
                                    113.958202,
                                    22.717226
                                ],
                                [
                                    113.958159,
                                    22.717463
                                ],
                                [
                                    113.957945,
                                    22.717978
                                ],
                                [
                                    113.956572,
                                    22.718849
                                ],
                                [
                                    113.955756,
                                    22.716949
                                ],
                                [
                                    113.954683,
                                    22.717899
                                ],
                                [
                                    113.953138,
                                    22.717463
                                ],
                                [
                                    113.952495,
                                    22.718176
                                ],
                                [
                                    113.952151,
                                    22.717068
                                ],
                                [
                                    113.951593,
                                    22.71584
                                ],
                                [
                                    113.951121,
                                    22.715286
                                ],
                                [
                                    113.950735,
                                    22.714376
                                ],
                                [
                                    113.950521,
                                    22.714059
                                ],
                                [
                                    113.947516,
                                    22.712
                                ],
                                [
                                    113.946615,
                                    22.711248
                                ],
                                [
                                    113.94288,
                                    22.71113
                                ],
                                [
                                    113.942107,
                                    22.709902
                                ],
                                [
                                    113.940863,
                                    22.708517
                                ],
                                [
                                    113.938588,
                                    22.708715
                                ],
                                [
                                    113.939844,
                                    22.707429
                                ],
                                [
                                    113.940413,
                                    22.706845
                                ],
                                [
                                    113.94052,
                                    22.706835
                                ],
                                [
                                    113.940928,
                                    22.70638
                                ],
                                [
                                    113.941035,
                                    22.706033
                                ],
                                [
                                    113.941057,
                                    22.705796
                                ],
                                [
                                    113.940917,
                                    22.70542
                                ],
                                [
                                    113.940477,
                                    22.704717
                                ],
                                [
                                    113.940456,
                                    22.704598
                                ],
                                [
                                    113.940424,
                                    22.704202
                                ],
                                [
                                    113.939769,
                                    22.703915
                                ],
                                [
                                    113.939233,
                                    22.7035
                                ],
                                [
                                    113.938782,
                                    22.703084
                                ],
                                [
                                    113.938428,
                                    22.702916
                                ],
                                [
                                    113.938278,
                                    22.702836
                                ],
                                [
                                    113.937763,
                                    22.702876
                                ],
                                [
                                    113.937377,
                                    22.703005
                                ],
                                [
                                    113.93728,
                                    22.703094
                                ],
                                [
                                    113.937291,
                                    22.7035
                                ],
                                [
                                    113.937162,
                                    22.703618
                                ],
                                [
                                    113.936991,
                                    22.703678
                                ],
                                [
                                    113.936658,
                                    22.704044
                                ],
                                [
                                    113.936347,
                                    22.704183
                                ],
                                [
                                    113.936025,
                                    22.704875
                                ],
                                [
                                    113.935993,
                                    22.705123
                                ],
                                [
                                    113.935757,
                                    22.705331
                                ],
                                [
                                    113.935306,
                                    22.705825
                                ],
                                [
                                    113.935188,
                                    22.706231
                                ],
                                [
                                    113.935091,
                                    22.7064
                                ],
                                [
                                    113.934501,
                                    22.706637
                                ],
                                [
                                    113.934051,
                                    22.706934
                                ],
                                [
                                    113.933729,
                                    22.706974
                                ],
                                [
                                    113.933074,
                                    22.70735
                                ],
                                [
                                    113.933032,
                                    22.707488
                                ],
                                [
                                    113.933214,
                                    22.707775
                                ],
                                [
                                    113.932376,
                                    22.708013
                                ],
                                [
                                    113.932194,
                                    22.708072
                                ],
                                [
                                    113.931915,
                                    22.707944
                                ],
                                [
                                    113.931314,
                                    22.708033
                                ],
                                [
                                    113.930617,
                                    22.707696
                                ],
                                [
                                    113.930198,
                                    22.707696
                                ],
                                [
                                    113.929855,
                                    22.707498
                                ],
                                [
                                    113.929597,
                                    22.7073
                                ],
                                [
                                    113.929372,
                                    22.707013
                                ],
                                [
                                    113.929286,
                                    22.706716
                                ],
                                [
                                    113.929211,
                                    22.706528
                                ],
                                [
                                    113.928857,
                                    22.706271
                                ],
                                [
                                    113.928761,
                                    22.706202
                                ],
                                [
                                    113.928578,
                                    22.706033
                                ],
                                [
                                    113.928385,
                                    22.706033
                                ],
                                [
                                    113.927956,
                                    22.705895
                                ],
                                [
                                    113.927623,
                                    22.705717
                                ],
                                [
                                    113.927409,
                                    22.706558
                                ],
                                [
                                    113.927495,
                                    22.706776
                                ],
                                [
                                    113.927452,
                                    22.706934
                                ],
                                [
                                    113.927108,
                                    22.70729
                                ],
                                [
                                    113.926239,
                                    22.70832
                                ],
                                [
                                    113.926078,
                                    22.708567
                                ],
                                [
                                    113.92596,
                                    22.708904
                                ],
                                [
                                    113.925778,
                                    22.708933
                                ],
                                [
                                    113.925563,
                                    22.709092
                                ],
                                [
                                    113.925156,
                                    22.709468
                                ],
                                [
                                    113.924877,
                                    22.709478
                                ],
                                [
                                    113.924705,
                                    22.709577
                                ],
                                [
                                    113.924254,
                                    22.709389
                                ],
                                [
                                    113.923824,
                                    22.709469
                                ],
                                [
                                    113.923545,
                                    22.709389
                                ],
                                [
                                    113.923202,
                                    22.709231
                                ],
                                [
                                    113.922515,
                                    22.70931
                                ],
                                [
                                    113.922043,
                                    22.709409
                                ],
                                [
                                    113.921486,
                                    22.70937
                                ],
                                [
                                    113.921164,
                                    22.709211
                                ],
                                [
                                    113.920928,
                                    22.70931
                                ],
                                [
                                    113.920756,
                                    22.709429
                                ],
                                [
                                    113.920348,
                                    22.709469
                                ],
                                [
                                    113.919597,
                                    22.709805
                                ],
                                [
                                    113.919039,
                                    22.709667
                                ],
                                [
                                    113.918546,
                                    22.709429
                                ],
                                [
                                    113.918267,
                                    22.70937
                                ],
                                [
                                    113.918074,
                                    22.709211
                                ],
                                [
                                    113.917709,
                                    22.70931
                                ],
                                [
                                    113.917215,
                                    22.70931
                                ],
                                [
                                    113.916829,
                                    22.709251
                                ],
                                [
                                    113.916623,
                                    22.709389
                                ],
                                [
                                    113.916451,
                                    22.709577
                                ],
                                [
                                    113.916226,
                                    22.709934
                                ],
                                [
                                    113.916247,
                                    22.710181
                                ],
                                [
                                    113.916044,
                                    22.710211
                                ],
                                [
                                    113.915958,
                                    22.710151
                                ],
                                [
                                    113.915936,
                                    22.710043
                                ],
                                [
                                    113.915282,
                                    22.709706
                                ],
                                [
                                    113.914649,
                                    22.70931
                                ],
                                [
                                    113.914209,
                                    22.709201
                                ],
                                [
                                    113.914005,
                                    22.709211
                                ],
                                [
                                    113.913952,
                                    22.709211
                                ],
                                [
                                    113.913801,
                                    22.709043
                                ],
                                [
                                    113.913297,
                                    22.707835
                                ],
                                [
                                    113.913265,
                                    22.707113
                                ],
                                [
                                    113.913265,
                                    22.706945
                                ],
                                [
                                    113.913243,
                                    22.706361
                                ],
                                [
                                    113.912911,
                                    22.706084
                                ],
                                [
                                    113.912017,
                                    22.705577
                                ],
                                [
                                    113.911602,
                                    22.705341
                                ],
                                [
                                    113.907073,
                                    22.705158
                                ],
                                [
                                    113.906227,
                                    22.705124
                                ],
                                [
                                    113.906216,
                                    22.704687
                                ],
                                [
                                    113.905819,
                                    22.704202
                                ],
                                [
                                    113.905781,
                                    22.703975
                                ],
                                [
                                    113.905529,
                                    22.70245
                                ],
                                [
                                    113.906259,
                                    22.700619
                                ],
                                [
                                    113.904123,
                                    22.697837
                                ],
                                [
                                    113.903887,
                                    22.697728
                                ],
                                [
                                    113.903801,
                                    22.697579
                                ],
                                [
                                    113.903651,
                                    22.697371
                                ],
                                [
                                    113.903318,
                                    22.697401
                                ],
                                [
                                    113.903211,
                                    22.69753
                                ],
                                [
                                    113.903018,
                                    22.69754
                                ],
                                [
                                    113.902868,
                                    22.697352
                                ],
                                [
                                    113.902761,
                                    22.697144
                                ],
                                [
                                    113.902482,
                                    22.696976
                                ],
                                [
                                    113.902224,
                                    22.696995
                                ],
                                [
                                    113.902042,
                                    22.697045
                                ],
                                [
                                    113.901795,
                                    22.696956
                                ],
                                [
                                    113.901741,
                                    22.696797
                                ],
                                [
                                    113.901988,
                                    22.69656
                                ],
                                [
                                    113.902085,
                                    22.696421
                                ],
                                [
                                    113.902042,
                                    22.696223
                                ],
                                [
                                    113.902074,
                                    22.696035
                                ],
                                [
                                    113.90187,
                                    22.695837
                                ],
                                [
                                    113.901634,
                                    22.69556
                                ],
                                [
                                    113.901226,
                                    22.695224
                                ],
                                [
                                    113.900422,
                                    22.695154
                                ],
                                [
                                    113.901484,
                                    22.694976
                                ],
                                [
                                    113.901645,
                                    22.695194
                                ],
                                [
                                    113.90216,
                                    22.695451
                                ],
                                [
                                    113.902578,
                                    22.695659
                                ],
                                [
                                    113.903233,
                                    22.695728
                                ],
                                [
                                    113.903715,
                                    22.695431
                                ],
                                [
                                    113.903866,
                                    22.695242
                                ],
                                [
                                    113.903909,
                                    22.695025
                                ],
                                [
                                    113.903769,
                                    22.694599
                                ],
                                [
                                    113.903694,
                                    22.694302
                                ],
                                [
                                    113.90393,
                                    22.694074
                                ],
                                [
                                    113.903951,
                                    22.693787
                                ],
                                [
                                    113.90408,
                                    22.692926
                                ],
                                [
                                    113.904413,
                                    22.692798
                                ],
                                [
                                    113.904928,
                                    22.69252
                                ],
                                [
                                    113.904971,
                                    22.692322
                                ],
                                [
                                    113.905142,
                                    22.692154
                                ],
                                [
                                    113.905185,
                                    22.691907
                                ],
                                [
                                    113.905175,
                                    22.691659
                                ],
                                [
                                    113.905067,
                                    22.691352
                                ],
                                [
                                    113.90511,
                                    22.691115
                                ],
                                [
                                    113.90525,
                                    22.691006
                                ],
                                [
                                    113.905207,
                                    22.690897
                                ],
                                [
                                    113.904928,
                                    22.690867
                                ],
                                [
                                    113.904552,
                                    22.690778
                                ],
                                [
                                    113.904048,
                                    22.690818
                                ],
                                [
                                    113.903211,
                                    22.691303
                                ],
                                [
                                    113.902557,
                                    22.691531
                                ],
                                [
                                    113.901559,
                                    22.692045
                                ],
                                [
                                    113.900304,
                                    22.692075
                                ],
                                [
                                    113.899917,
                                    22.692204
                                ],
                                [
                                    113.899767,
                                    22.69258
                                ],
                                [
                                    113.899553,
                                    22.692511
                                ],
                                [
                                    113.898769,
                                    22.693738
                                ],
                                [
                                    113.896945,
                                    22.694104
                                ],
                                [
                                    113.897739,
                                    22.692817
                                ],
                                [
                                    113.89819,
                                    22.692303
                                ],
                                [
                                    113.897599,
                                    22.691362
                                ],
                                [
                                    113.894746,
                                    22.689224
                                ],
                                [
                                    113.893973,
                                    22.688551
                                ],
                                [
                                    113.892814,
                                    22.688195
                                ],
                                [
                                    113.892279,
                                    22.688139
                                ],
                                [
                                    113.891118,
                                    22.688018
                                ],
                                [
                                    113.889874,
                                    22.689008
                                ],
                                [
                                    113.883672,
                                    22.689938
                                ],
                                [
                                    113.8829,
                                    22.688473
                                ],
                                [
                                    113.882471,
                                    22.688196
                                ],
                                [
                                    113.882127,
                                    22.687543
                                ],
                                [
                                    113.881848,
                                    22.687563
                                ],
                                [
                                    113.881634,
                                    22.687503
                                ],
                                [
                                    113.881312,
                                    22.687424
                                ],
                                [
                                    113.880947,
                                    22.687087
                                ],
                                [
                                    113.880733,
                                    22.686771
                                ],
                                [
                                    113.880153,
                                    22.686454
                                ],
                                [
                                    113.879874,
                                    22.686216
                                ],
                                [
                                    113.879746,
                                    22.68582
                                ],
                                [
                                    113.879566,
                                    22.686303
                                ],
                                [
                                    113.879437,
                                    22.686738
                                ],
                                [
                                    113.879437,
                                    22.687372
                                ],
                                [
                                    113.879351,
                                    22.687689
                                ],
                                [
                                    113.878708,
                                    22.688203
                                ],
                                [
                                    113.878021,
                                    22.688876
                                ],
                                [
                                    113.87742,
                                    22.689787
                                ],
                                [
                                    113.877377,
                                    22.689787
                                ],
                                [
                                    113.876691,
                                    22.689629
                                ],
                                [
                                    113.876133,
                                    22.690064
                                ],
                                [
                                    113.875747,
                                    22.690579
                                ],
                                [
                                    113.875403,
                                    22.690856
                                ],
                                [
                                    113.874845,
                                    22.691292
                                ],
                                [
                                    113.874297,
                                    22.691696
                                ],
                                [
                                    113.874522,
                                    22.692053
                                ],
                                [
                                    113.874984,
                                    22.692191
                                ],
                                [
                                    113.874984,
                                    22.6923
                                ],
                                [
                                    113.875187,
                                    22.692686
                                ],
                                [
                                    113.875348,
                                    22.692775
                                ],
                                [
                                    113.875445,
                                    22.692924
                                ],
                                [
                                    113.875777,
                                    22.693547
                                ],
                                [
                                    113.875885,
                                    22.693824
                                ],
                                [
                                    113.876174,
                                    22.694032
                                ],
                                [
                                    113.876722,
                                    22.694191
                                ],
                                [
                                    113.877365,
                                    22.694389
                                ],
                                [
                                    113.877655,
                                    22.694824
                                ],
                                [
                                    113.878009,
                                    22.695072
                                ],
                                [
                                    113.878256,
                                    22.695091
                                ],
                                [
                                    113.878889,
                                    22.695378
                                ],
                                [
                                    113.879082,
                                    22.695408
                                ],
                                [
                                    113.879329,
                                    22.695606
                                ],
                                [
                                    113.879522,
                                    22.695695
                                ],
                                [
                                    113.879651,
                                    22.695992
                                ],
                                [
                                    113.879726,
                                    22.69621
                                ],
                                [
                                    113.879619,
                                    22.69638
                                ],
                                [
                                    113.879597,
                                    22.696597
                                ],
                                [
                                    113.87949,
                                    22.696776
                                ],
                                [
                                    113.879372,
                                    22.697092
                                ],
                                [
                                    113.879071,
                                    22.697488
                                ],
                                [
                                    113.878953,
                                    22.698092
                                ],
                                [
                                    113.878803,
                                    22.698369
                                ],
                                [
                                    113.878417,
                                    22.698636
                                ],
                                [
                                    113.878127,
                                    22.698755
                                ],
                                [
                                    113.878009,
                                    22.698884
                                ],
                                [
                                    113.877698,
                                    22.699418
                                ],
                                [
                                    113.877398,
                                    22.701249
                                ],
                                [
                                    113.877913,
                                    22.70123
                                ],
                                [
                                    113.877977,
                                    22.700953
                                ],
                                [
                                    113.878095,
                                    22.700863
                                ],
                                [
                                    113.878632,
                                    22.700685
                                ],
                                [
                                    113.878835,
                                    22.700764
                                ],
                                [
                                    113.879662,
                                    22.700804
                                ],
                                [
                                    113.879833,
                                    22.700873
                                ],
                                [
                                    113.880252,
                                    22.700764
                                ],
                                [
                                    113.880455,
                                    22.700764
                                ],
                                [
                                    113.880627,
                                    22.70122
                                ],
                                [
                                    113.880831,
                                    22.701447
                                ],
                                [
                                    113.881003,
                                    22.701685
                                ],
                                [
                                    113.880799,
                                    22.702012
                                ],
                                [
                                    113.88067,
                                    22.702398
                                ],
                                [
                                    113.879962,
                                    22.702467
                                ],
                                [
                                    113.878717,
                                    22.7022
                                ],
                                [
                                    113.878202,
                                    22.702239
                                ],
                                [
                                    113.877956,
                                    22.702259
                                ],
                                [
                                    113.877301,
                                    22.702596
                                ],
                                [
                                    113.877258,
                                    22.702982
                                ],
                                [
                                    113.877012,
                                    22.703011
                                ],
                                [
                                    113.876926,
                                    22.703081
                                ],
                                [
                                    113.876926,
                                    22.703437
                                ],
                                [
                                    113.876775,
                                    22.70412
                                ],
                                [
                                    113.876593,
                                    22.704674
                                ],
                                [
                                    113.876057,
                                    22.704408
                                ],
                                [
                                    113.875853,
                                    22.704457
                                ],
                                [
                                    113.874748,
                                    22.706427
                                ],
                                [
                                    113.874351,
                                    22.707446
                                ],
                                [
                                    113.874179,
                                    22.707842
                                ],
                                [
                                    113.874565,
                                    22.708189
                                ],
                                [
                                    113.874887,
                                    22.708713
                                ],
                                [
                                    113.875713,
                                    22.709299
                                ],
                                [
                                    113.876218,
                                    22.709972
                                ],
                                [
                                    113.876733,
                                    22.710873
                                ],
                                [
                                    113.876936,
                                    22.71108
                                ],
                                [
                                    113.87684,
                                    22.71117
                                ],
                                [
                                    113.876142,
                                    22.711387
                                ],
                                [
                                    113.875617,
                                    22.711753
                                ],
                                [
                                    113.875381,
                                    22.711803
                                ],
                                [
                                    113.875295,
                                    22.711892
                                ],
                                [
                                    113.875027,
                                    22.712268
                                ],
                                [
                                    113.874973,
                                    22.712565
                                ],
                                [
                                    113.875037,
                                    22.71304
                                ],
                                [
                                    113.875037,
                                    22.713367
                                ],
                                [
                                    113.875703,
                                    22.713802
                                ],
                                [
                                    113.876379,
                                    22.714277
                                ],
                                [
                                    113.877677,
                                    22.714732
                                ],
                                [
                                    113.878106,
                                    22.714861
                                ],
                                [
                                    113.878461,
                                    22.714782
                                ],
                                [
                                    113.879865,
                                    22.714792
                                ],
                                [
                                    113.881904,
                                    22.715507
                                ],
                                [
                                    113.882065,
                                    22.716724
                                ],
                                [
                                    113.882044,
                                    22.717229
                                ],
                                [
                                    113.882312,
                                    22.717793
                                ],
                                [
                                    113.88198,
                                    22.718397
                                ],
                                [
                                    113.881947,
                                    22.718694
                                ],
                                [
                                    113.881744,
                                    22.719139
                                ],
                                [
                                    113.880531,
                                    22.719723
                                ],
                                [
                                    113.879727,
                                    22.720445
                                ],
                                [
                                    113.879233,
                                    22.721257
                                ],
                                [
                                    113.878836,
                                    22.722128
                                ],
                                [
                                    113.878557,
                                    22.722444
                                ],
                                [
                                    113.878171,
                                    22.723196
                                ],
                                [
                                    113.878171,
                                    22.723444
                                ],
                                [
                                    113.878343,
                                    22.723533
                                ],
                                [
                                    113.878385,
                                    22.723949
                                ],
                                [
                                    113.878771,
                                    22.724446
                                ],
                                [
                                    113.878814,
                                    22.72503
                                ],
                                [
                                    113.878653,
                                    22.72601
                                ],
                                [
                                    113.87831,
                                    22.726277
                                ],
                                [
                                    113.877859,
                                    22.726455
                                ],
                                [
                                    113.877516,
                                    22.727118
                                ],
                                [
                                    113.877537,
                                    22.727445
                                ],
                                [
                                    113.877183,
                                    22.727672
                                ],
                                [
                                    113.877183,
                                    22.727999
                                ],
                                [
                                    113.877065,
                                    22.728256
                                ],
                                [
                                    113.877431,
                                    22.729117
                                ],
                                [
                                    113.877505,
                                    22.729651
                                ],
                                [
                                    113.87772,
                                    22.729869
                                ],
                                [
                                    113.877816,
                                    22.730344
                                ],
                                [
                                    113.878178,
                                    22.731049
                                ],
                                [
                                    113.878521,
                                    22.731098
                                ],
                                [
                                    113.878853,
                                    22.731177
                                ],
                                [
                                    113.879562,
                                    22.731019
                                ],
                                [
                                    113.879798,
                                    22.731108
                                ],
                                [
                                    113.880119,
                                    22.731513
                                ],
                                [
                                    113.88028,
                                    22.7318
                                ],
                                [
                                    113.880456,
                                    22.731959
                                ],
                                [
                                    113.880848,
                                    22.732034
                                ],
                                [
                                    113.880983,
                                    22.732068
                                ],
                                [
                                    113.881079,
                                    22.732157
                                ],
                                [
                                    113.881218,
                                    22.73236
                                ],
                                [
                                    113.88147,
                                    22.732974
                                ],
                                [
                                    113.881905,
                                    22.733434
                                ],
                                [
                                    113.881948,
                                    22.733508
                                ],
                                [
                                    113.88206,
                                    22.733617
                                ],
                                [
                                    113.882356,
                                    22.73376
                                ],
                                [
                                    113.882464,
                                    22.733874
                                ],
                                [
                                    113.882565,
                                    22.734032
                                ],
                                [
                                    113.88257,
                                    22.734191
                                ],
                                [
                                    113.882431,
                                    22.734339
                                ],
                                [
                                    113.882339,
                                    22.734537
                                ],
                                [
                                    113.882334,
                                    22.7347
                                ],
                                [
                                    113.882307,
                                    22.734781
                                ],
                                [
                                    113.881948,
                                    22.735073
                                ],
                                [
                                    113.881654,
                                    22.735716
                                ],
                                [
                                    113.881632,
                                    22.735785
                                ],
                                [
                                    113.882028,
                                    22.73629
                                ],
                                [
                                    113.882119,
                                    22.736503
                                ],
                                [
                                    113.882141,
                                    22.736938
                                ],
                                [
                                    113.882243,
                                    22.737136
                                ],
                                [
                                    113.882312,
                                    22.737176
                                ],
                                [
                                    113.882393,
                                    22.737319
                                ],
                                [
                                    113.882398,
                                    22.737774
                                ],
                                [
                                    113.882496,
                                    22.738038
                                ],
                                [
                                    113.883063,
                                    22.738662
                                ],
                                [
                                    113.883241,
                                    22.73881
                                ],
                                [
                                    113.884029,
                                    22.740245
                                ],
                                [
                                    113.883868,
                                    22.740562
                                ],
                                [
                                    113.883659,
                                    22.741037
                                ],
                                [
                                    113.883031,
                                    22.742067
                                ],
                                [
                                    113.882818,
                                    22.7423
                                ],
                                [
                                    113.882684,
                                    22.742429
                                ],
                                [
                                    113.882618,
                                    22.742473
                                ],
                                [
                                    113.882275,
                                    22.742641
                                ],
                                [
                                    113.882189,
                                    22.742701
                                ],
                                [
                                    113.88205,
                                    22.742755
                                ],
                                [
                                    113.881884,
                                    22.742958
                                ],
                                [
                                    113.881835,
                                    22.743017
                                ],
                                [
                                    113.881819,
                                    22.743334
                                ],
                                [
                                    113.881556,
                                    22.744003
                                ],
                                [
                                    113.881508,
                                    22.744091
                                ],
                                [
                                    113.881309,
                                    22.744269
                                ],
                                [
                                    113.881026,
                                    22.744467
                                ],
                                [
                                    113.880939,
                                    22.744561
                                ],
                                [
                                    113.880876,
                                    22.744685
                                ],
                                [
                                    113.880903,
                                    22.744788
                                ],
                                [
                                    113.880977,
                                    22.744877
                                ],
                                [
                                    113.881074,
                                    22.744996
                                ],
                                [
                                    113.88117,
                                    22.74511
                                ],
                                [
                                    113.881315,
                                    22.745278
                                ],
                                [
                                    113.881343,
                                    22.745355
                                ],
                                [
                                    113.881391,
                                    22.745424
                                ],
                                [
                                    113.881391,
                                    22.745899
                                ],
                                [
                                    113.881376,
                                    22.745994
                                ],
                                [
                                    113.880856,
                                    22.746334
                                ],
                                [
                                    113.880716,
                                    22.746492
                                ],
                                [
                                    113.880769,
                                    22.746547
                                ],
                                [
                                    113.880517,
                                    22.746923
                                ],
                                [
                                    113.880431,
                                    22.747022
                                ],
                                [
                                    113.880216,
                                    22.747126
                                ],
                                [
                                    113.879991,
                                    22.747215
                                ],
                                [
                                    113.879776,
                                    22.747235
                                ],
                                [
                                    113.879407,
                                    22.747269
                                ],
                                [
                                    113.879481,
                                    22.747419
                                ],
                                [
                                    113.879814,
                                    22.748382
                                ],
                                [
                                    113.879106,
                                    22.748908
                                ],
                                [
                                    113.879155,
                                    22.748971
                                ],
                                [
                                    113.879267,
                                    22.749025
                                ],
                                [
                                    113.879283,
                                    22.749154
                                ],
                                [
                                    113.879311,
                                    22.749228
                                ],
                                [
                                    113.879419,
                                    22.749523
                                ],
                                [
                                    113.879471,
                                    22.749661
                                ],
                                [
                                    113.878838,
                                    22.750058
                                ],
                                [
                                    113.877938,
                                    22.750751
                                ],
                                [
                                    113.877831,
                                    22.751007
                                ],
                                [
                                    113.877036,
                                    22.751163
                                ],
                                [
                                    113.877239,
                                    22.752014
                                ],
                                [
                                    113.877616,
                                    22.753647
                                ],
                                [
                                    113.877229,
                                    22.753706
                                ],
                                [
                                    113.877986,
                                    22.755569
                                ],
                                [
                                    113.878044,
                                    22.755714
                                ],
                                [
                                    113.878494,
                                    22.755605
                                ],
                                [
                                    113.878269,
                                    22.755892
                                ],
                                [
                                    113.878216,
                                    22.756061
                                ],
                                [
                                    113.878056,
                                    22.756209
                                ],
                                [
                                    113.877744,
                                    22.756464
                                ],
                                [
                                    113.877411,
                                    22.756741
                                ],
                                [
                                    113.877047,
                                    22.757245
                                ],
                                [
                                    113.87696,
                                    22.757523
                                ],
                                [
                                    113.876842,
                                    22.757751
                                ],
                                [
                                    113.876703,
                                    22.758047
                                ],
                                [
                                    113.876511,
                                    22.758147
                                ],
                                [
                                    113.876091,
                                    22.758492
                                ],
                                [
                                    113.875694,
                                    22.758719
                                ],
                                [
                                    113.875383,
                                    22.758996
                                ],
                                [
                                    113.875298,
                                    22.759076
                                ],
                                [
                                    113.875298,
                                    22.759204
                                ],
                                [
                                    113.874247,
                                    22.759936
                                ],
                                [
                                    113.873302,
                                    22.76055
                                ],
                                [
                                    113.873013,
                                    22.760718
                                ],
                                [
                                    113.872829,
                                    22.760738
                                ],
                                [
                                    113.872949,
                                    22.761321
                                ],
                                [
                                    113.873173,
                                    22.761232
                                ],
                                [
                                    113.873634,
                                    22.761084
                                ],
                                [
                                    113.874161,
                                    22.762094
                                ],
                                [
                                    113.873367,
                                    22.76234
                                ],
                                [
                                    113.873452,
                                    22.762538
                                ],
                                [
                                    113.872604,
                                    22.762875
                                ],
                                [
                                    113.872272,
                                    22.763143
                                ],
                                [
                                    113.871768,
                                    22.763271
                                ],
                                [
                                    113.869794,
                                    22.764218
                                ],
                                [
                                    113.869771,
                                    22.764614
                                ],
                                [
                                    113.869708,
                                    22.764813
                                ],
                                [
                                    113.869761,
                                    22.765198
                                ],
                                [
                                    113.869139,
                                    22.765287
                                ],
                                [
                                    113.868871,
                                    22.765514
                                ],
                                [
                                    113.868732,
                                    22.765783
                                ],
                                [
                                    113.868174,
                                    22.768176
                                ],
                                [
                                    113.866586,
                                    22.768373
                                ],
                                [
                                    113.866253,
                                    22.768452
                                ],
                                [
                                    113.865984,
                                    22.768631
                                ],
                                [
                                    113.86577,
                                    22.768749
                                ],
                                [
                                    113.865888,
                                    22.768996
                                ],
                                [
                                    113.865759,
                                    22.769075
                                ],
                                [
                                    113.865813,
                                    22.769214
                                ],
                                [
                                    113.865727,
                                    22.76958
                                ],
                                [
                                    113.865759,
                                    22.769828
                                ],
                                [
                                    113.865726,
                                    22.769936
                                ],
                                [
                                    113.865234,
                                    22.770421
                                ],
                                [
                                    113.865169,
                                    22.770144
                                ],
                                [
                                    113.865191,
                                    22.770025
                                ],
                                [
                                    113.865148,
                                    22.769906
                                ],
                                [
                                    113.864901,
                                    22.769867
                                ],
                                [
                                    113.864719,
                                    22.769848
                                ],
                                [
                                    113.864547,
                                    22.769838
                                ],
                                [
                                    113.864321,
                                    22.769936
                                ],
                                [
                                    113.863966,
                                    22.770193
                                ],
                                [
                                    113.863773,
                                    22.77044
                                ],
                                [
                                    113.863656,
                                    22.770637
                                ],
                                [
                                    113.863687,
                                    22.770756
                                ],
                                [
                                    113.863687,
                                    22.771004
                                ],
                                [
                                    113.863387,
                                    22.771311
                                ],
                                [
                                    113.863247,
                                    22.771469
                                ],
                                [
                                    113.863184,
                                    22.771646
                                ],
                                [
                                    113.863302,
                                    22.771706
                                ],
                                [
                                    113.863709,
                                    22.771656
                                ],
                                [
                                    113.863912,
                                    22.772003
                                ],
                                [
                                    113.863935,
                                    22.77228
                                ],
                                [
                                    113.863838,
                                    22.772408
                                ],
                                [
                                    113.863708,
                                    22.772696
                                ],
                                [
                                    113.862411,
                                    22.772696
                                ],
                                [
                                    113.861467,
                                    22.772725
                                ],
                                [
                                    113.860845,
                                    22.772843
                                ],
                                [
                                    113.860651,
                                    22.772903
                                ],
                                [
                                    113.860501,
                                    22.772973
                                ],
                                [
                                    113.860383,
                                    22.773339
                                ],
                                [
                                    113.860405,
                                    22.773546
                                ],
                                [
                                    113.860329,
                                    22.773753
                                ],
                                [
                                    113.860104,
                                    22.774079
                                ],
                                [
                                    113.860609,
                                    22.775068
                                ],
                                [
                                    113.860597,
                                    22.775623
                                ],
                                [
                                    113.860822,
                                    22.776611
                                ],
                                [
                                    113.861306,
                                    22.777245
                                ],
                                [
                                    113.86151,
                                    22.777601
                                ],
                                [
                                    113.862229,
                                    22.778094
                                ],
                                [
                                    113.862658,
                                    22.778559
                                ],
                                [
                                    113.862551,
                                    22.778649
                                ],
                                [
                                    113.862046,
                                    22.77845
                                ],
                                [
                                    113.861875,
                                    22.778411
                                ],
                                [
                                    113.861767,
                                    22.778421
                                ],
                                [
                                    113.861338,
                                    22.778272
                                ],
                                [
                                    113.861027,
                                    22.778738
                                ],
                                [
                                    113.860845,
                                    22.778628
                                ],
                                [
                                    113.860801,
                                    22.778679
                                ],
                                [
                                    113.860673,
                                    22.778618
                                ],
                                [
                                    113.860523,
                                    22.778856
                                ],
                                [
                                    113.860812,
                                    22.779103
                                ],
                                [
                                    113.860469,
                                    22.779725
                                ],
                                [
                                    113.860126,
                                    22.780439
                                ],
                                [
                                    113.859482,
                                    22.781873
                                ],
                                [
                                    113.859182,
                                    22.783169
                                ],
                                [
                                    113.858967,
                                    22.783623
                                ],
                                [
                                    113.859032,
                                    22.784869
                                ],
                                [
                                    113.858999,
                                    22.785988
                                ],
                                [
                                    113.858956,
                                    22.787164
                                ],
                                [
                                    113.858259,
                                    22.787194
                                ],
                                [
                                    113.857808,
                                    22.788015
                                ],
                                [
                                    113.859096,
                                    22.78853
                                ],
                                [
                                    113.859986,
                                    22.788767
                                ],
                                [
                                    113.860255,
                                    22.788657
                                ],
                                [
                                    113.861134,
                                    22.788708
                                ],
                                [
                                    113.861188,
                                    22.788609
                                ],
                                [
                                    113.862197,
                                    22.788647
                                ],
                                [
                                    113.862843,
                                    22.789507
                                ],
                                [
                                    113.863401,
                                    22.789469
                                ],
                                [
                                    113.863797,
                                    22.790071
                                ],
                                [
                                    113.864205,
                                    22.790249
                                ],
                                [
                                    113.864248,
                                    22.790399
                                ],
                                [
                                    113.86589,
                                    22.790279
                                ],
                                [
                                    113.868506,
                                    22.791441
                                ],
                                [
                                    113.872748,
                                    22.793327
                                ],
                                [
                                    113.874474,
                                    22.794115
                                ],
                                [
                                    113.874604,
                                    22.794174
                                ],
                                [
                                    113.874992,
                                    22.794351
                                ],
                                [
                                    113.877168,
                                    22.795344
                                ],
                                [
                                    113.877599,
                                    22.795687
                                ],
                                [
                                    113.878385,
                                    22.796315
                                ],
                                [
                                    113.8794,
                                    22.797125
                                ],
                                [
                                    113.880387,
                                    22.797599
                                ],
                                [
                                    113.881374,
                                    22.797718
                                ],
                                [
                                    113.881717,
                                    22.797685
                                ],
                                [
                                    113.881873,
                                    22.798174
                                ],
                                [
                                    113.881873,
                                    22.798313
                                ],
                                [
                                    113.881739,
                                    22.798392
                                ],
                                [
                                    113.881717,
                                    22.798561
                                ],
                                [
                                    113.881802,
                                    22.799616
                                ],
                                [
                                    113.88178,
                                    22.800007
                                ],
                                [
                                    113.881963,
                                    22.800042
                                ],
                                [
                                    113.881898,
                                    22.800383
                                ],
                                [
                                    113.882183,
                                    22.800516
                                ],
                                [
                                    113.882167,
                                    22.800655
                                ],
                                [
                                    113.882456,
                                    22.800843
                                ],
                                [
                                    113.882564,
                                    22.800981
                                ],
                                [
                                    113.883513,
                                    22.803309
                                ],
                                [
                                    113.883529,
                                    22.804609
                                ],
                                [
                                    113.883559,
                                    22.806179
                                ],
                                [
                                    113.883768,
                                    22.806332
                                ],
                                [
                                    113.883768,
                                    22.806401
                                ],
                                [
                                    113.884621,
                                    22.808913
                                ],
                                [
                                    113.884879,
                                    22.809941
                                ],
                                [
                                    113.884621,
                                    22.81099
                                ],
                                [
                                    113.8849,
                                    22.81099
                                ],
                                [
                                    113.884965,
                                    22.811543
                                ],
                                [
                                    113.885229,
                                    22.811698
                                ],
                                [
                                    113.885465,
                                    22.811916
                                ],
                                [
                                    113.885565,
                                    22.812236
                                ],
                                [
                                    113.886128,
                                    22.812607
                                ],
                                [
                                    113.886553,
                                    22.813047
                                ],
                                [
                                    113.886728,
                                    22.81326
                                ],
                                [
                                    113.886922,
                                    22.813537
                                ],
                                [
                                    113.887006,
                                    22.813928
                                ],
                                [
                                    113.887046,
                                    22.814293
                                ],
                                [
                                    113.888934,
                                    22.816898
                                ],
                                [
                                    113.888258,
                                    22.818019
                                ],
                                [
                                    113.888332,
                                    22.819581
                                ],
                                [
                                    113.889234,
                                    22.819344
                                ],
                                [
                                    113.889405,
                                    22.819433
                                ],
                                [
                                    113.889502,
                                    22.819512
                                ],
                                [
                                    113.889491,
                                    22.819629
                                ],
                                [
                                    113.889481,
                                    22.819858
                                ],
                                [
                                    113.889513,
                                    22.819947
                                ],
                                [
                                    113.889395,
                                    22.820026
                                ],
                                [
                                    113.889202,
                                    22.820086
                                ],
                                [
                                    113.889019,
                                    22.820174
                                ],
                                [
                                    113.889009,
                                    22.820254
                                ],
                                [
                                    113.889288,
                                    22.820758
                                ],
                                [
                                    113.889352,
                                    22.820788
                                ],
                                [
                                    113.889288,
                                    22.820966
                                ],
                                [
                                    113.889213,
                                    22.821154
                                ],
                                [
                                    113.889406,
                                    22.821302
                                ],
                                [
                                    113.889534,
                                    22.821609
                                ],
                                [
                                    113.889459,
                                    22.821658
                                ],
                                [
                                    113.889223,
                                    22.821757
                                ],
                                [
                                    113.889352,
                                    22.82239
                                ],
                                [
                                    113.8902,
                                    22.819848
                                ],
                                [
                                    113.890436,
                                    22.819888
                                ],
                                [
                                    113.890779,
                                    22.820056
                                ],
                                [
                                    113.890951,
                                    22.820333
                                ],
                                [
                                    113.890908,
                                    22.820471
                                ],
                                [
                                    113.890779,
                                    22.820521
                                ],
                                [
                                    113.890661,
                                    22.82063
                                ],
                                [
                                    113.890307,
                                    22.820719
                                ],
                                [
                                    113.890296,
                                    22.820916
                                ],
                                [
                                    113.890446,
                                    22.821114
                                ],
                                [
                                    113.890532,
                                    22.821154
                                ],
                                [
                                    113.890521,
                                    22.821223
                                ],
                                [
                                    113.890682,
                                    22.821272
                                ],
                                [
                                    113.89079,
                                    22.821421
                                ],
                                [
                                    113.890854,
                                    22.821529
                                ],
                                [
                                    113.890843,
                                    22.821678
                                ],
                                [
                                    113.890811,
                                    22.821787
                                ],
                                [
                                    113.890554,
                                    22.821955
                                ],
                                [
                                    113.890479,
                                    22.822093
                                ],
                                [
                                    113.891015,
                                    22.822063
                                ],
                                [
                                    113.891015,
                                    22.821974
                                ],
                                [
                                    113.89109,
                                    22.821826
                                ],
                                [
                                    113.891283,
                                    22.821717
                                ],
                                [
                                    113.892721,
                                    22.822014
                                ],
                                [
                                    113.892828,
                                    22.821984
                                ],
                                [
                                    113.89285,
                                    22.821895
                                ],
                                [
                                    113.892753,
                                    22.821767
                                ],
                                [
                                    113.891573,
                                    22.821233
                                ],
                                [
                                    113.891079,
                                    22.8206
                                ],
                                [
                                    113.892775,
                                    22.819107
                                ],
                                [
                                    113.893397,
                                    22.819502
                                ],
                                [
                                    113.893504,
                                    22.819611
                                ],
                                [
                                    113.893601,
                                    22.819779
                                ],
                                [
                                    113.893708,
                                    22.819878
                                ],
                                [
                                    113.89374,
                                    22.819947
                                ],
                                [
                                    113.89388,
                                    22.820076
                                ],
                                [
                                    113.893955,
                                    22.820303
                                ],
                                [
                                    113.894083,
                                    22.820461
                                ],
                                [
                                    113.894201,
                                    22.820481
                                ],
                                [
                                    113.894223,
                                    22.820422
                                ],
                                [
                                    113.894169,
                                    22.820323
                                ],
                                [
                                    113.894159,
                                    22.820165
                                ],
                                [
                                    113.894298,
                                    22.820007
                                ],
                                [
                                    113.894373,
                                    22.819878
                                ],
                                [
                                    113.894159,
                                    22.819562
                                ],
                                [
                                    113.894041,
                                    22.819423
                                ],
                                [
                                    113.894062,
                                    22.819364
                                ],
                                [
                                    113.894588,
                                    22.819136
                                ],
                                [
                                    113.894856,
                                    22.819087
                                ],
                                [
                                    113.895103,
                                    22.819176
                                ],
                                [
                                    113.895349,
                                    22.819344
                                ],
                                [
                                    113.895392,
                                    22.81967
                                ],
                                [
                                    113.895564,
                                    22.820016
                                ],
                                [
                                    113.895264,
                                    22.820382
                                ],
                                [
                                    113.895274,
                                    22.820916
                                ],
                                [
                                    113.895146,
                                    22.821431
                                ],
                                [
                                    113.895199,
                                    22.821539
                                ],
                                [
                                    113.895607,
                                    22.821925
                                ],
                                [
                                    113.895596,
                                    22.82234
                                ],
                                [
                                    113.895714,
                                    22.822617
                                ],
                                [
                                    113.895907,
                                    22.822805
                                ],
                                [
                                    113.896047,
                                    22.822835
                                ],
                                [
                                    113.89609,
                                    22.823567
                                ],
                                [
                                    113.896208,
                                    22.823923
                                ],
                                [
                                    113.89683,
                                    22.824873
                                ],
                                [
                                    113.897066,
                                    22.825061
                                ],
                                [
                                    113.897184,
                                    22.825199
                                ],
                                [
                                    113.897388,
                                    22.825654
                                ],
                                [
                                    113.897667,
                                    22.82601
                                ],
                                [
                                    113.897485,
                                    22.826307
                                ],
                                [
                                    113.897313,
                                    22.826831
                                ],
                                [
                                    113.8983,
                                    22.827859
                                ],
                                [
                                    113.898976,
                                    22.828057
                                ],
                                [
                                    113.899115,
                                    22.828067
                                ],
                                [
                                    113.899362,
                                    22.828166
                                ],
                                [
                                    113.899491,
                                    22.828304
                                ],
                                [
                                    113.899663,
                                    22.828363
                                ],
                                [
                                    113.899941,
                                    22.828452
                                ],
                                [
                                    113.900285,
                                    22.828601
                                ],
                                [
                                    113.900564,
                                    22.8287
                                ],
                                [
                                    113.901026,
                                    22.828928
                                ],
                                [
                                    113.901316,
                                    22.828997
                                ],
                                [
                                    113.901691,
                                    22.828977
                                ],
                                [
                                    113.90182,
                                    22.828898
                                ],
                                [
                                    113.901885,
                                    22.82873
                                ],
                                [
                                    113.902088,
                                    22.828631
                                ],
                                [
                                    113.902464,
                                    22.828502
                                ],
                                [
                                    113.902625,
                                    22.828354
                                ],
                                [
                                    113.903043,
                                    22.828206
                                ],
                                [
                                    113.903859,
                                    22.828226
                                ],
                                [
                                    113.903945,
                                    22.828305
                                ],
                                [
                                    113.904138,
                                    22.828334
                                ],
                                [
                                    113.90432,
                                    22.828453
                                ],
                                [
                                    113.904631,
                                    22.828384
                                ],
                                [
                                    113.904846,
                                    22.828384
                                ],
                                [
                                    113.9052,
                                    22.828463
                                ],
                                [
                                    113.905479,
                                    22.828601
                                ],
                                [
                                    113.905715,
                                    22.82876
                                ],
                                [
                                    113.905994,
                                    22.828928
                                ],
                                [
                                    113.906165,
                                    22.829116
                                ],
                                [
                                    113.906283,
                                    22.829214
                                ],
                                [
                                    113.907474,
                                    22.82962
                                ],
                                [
                                    113.907732,
                                    22.82963
                                ],
                                [
                                    113.908268,
                                    22.82964
                                ],
                                [
                                    113.908944,
                                    22.829659
                                ],
                                [
                                    113.909234,
                                    22.8296
                                ],
                                [
                                    113.909684,
                                    22.82964
                                ],
                                [
                                    113.910146,
                                    22.829729
                                ],
                                [
                                    113.91036,
                                    22.829808
                                ],
                                [
                                    113.910958,
                                    22.829994
                                ],
                                [
                                    113.912524,
                                    22.830178
                                ],
                                [
                                    113.913694,
                                    22.830132
                                ],
                                [
                                    113.914279,
                                    22.830108
                                ],
                                [
                                    113.914432,
                                    22.830047
                                ],
                                [
                                    113.914676,
                                    22.829684
                                ],
                                [
                                    113.915536,
                                    22.829034
                                ],
                                [
                                    113.915832,
                                    22.829241
                                ],
                                [
                                    113.916448,
                                    22.83004
                                ],
                                [
                                    113.916763,
                                    22.830251
                                ],
                                [
                                    113.918098,
                                    22.830728
                                ],
                                [
                                    113.920652,
                                    22.831312
                                ],
                                [
                                    113.921893,
                                    22.831248
                                ],
                                [
                                    113.92281,
                                    22.830956
                                ],
                                [
                                    113.924522,
                                    22.830579
                                ],
                                [
                                    113.925299,
                                    22.830869
                                ],
                                [
                                    113.927379,
                                    22.831368
                                ],
                                [
                                    113.928114,
                                    22.831739
                                ],
                                [
                                    113.929489,
                                    22.832011
                                ],
                                [
                                    113.931288,
                                    22.831921
                                ],
                                [
                                    113.935135,
                                    22.83245
                                ],
                                [
                                    113.936692,
                                    22.832534
                                ],
                                [
                                    113.937684,
                                    22.832806
                                ],
                                [
                                    113.937823,
                                    22.832713
                                ],
                                [
                                    113.937671,
                                    22.831748
                                ],
                                [
                                    113.93761,
                                    22.831487
                                ],
                                [
                                    113.937367,
                                    22.831232
                                ],
                                [
                                    113.937368,
                                    22.831112
                                ],
                                [
                                    113.938015,
                                    22.830876
                                ],
                                [
                                    113.939168,
                                    22.830678
                                ],
                                [
                                    113.939286,
                                    22.830518
                                ],
                                [
                                    113.939574,
                                    22.829568
                                ],
                                [
                                    113.939763,
                                    22.829301
                                ],
                                [
                                    113.94128,
                                    22.828808
                                ],
                                [
                                    113.941989,
                                    22.828931
                                ],
                                [
                                    113.942769,
                                    22.828817
                                ],
                                [
                                    113.943513,
                                    22.828267
                                ],
                                [
                                    113.943749,
                                    22.827875
                                ],
                                [
                                    113.944096,
                                    22.827695
                                ],
                                [
                                    113.946899,
                                    22.827488
                                ],
                                [
                                    113.947595,
                                    22.827183
                                ],
                                [
                                    113.947881,
                                    22.826863
                                ],
                                [
                                    113.948029,
                                    22.825157
                                ],
                                [
                                    113.949247,
                                    22.823663
                                ],
                                [
                                    113.950219,
                                    22.823069
                                ],
                                [
                                    113.950504,
                                    22.822704
                                ],
                                [
                                    113.952589,
                                    22.822191
                                ],
                                [
                                    113.954651,
                                    22.821031
                                ],
                                [
                                    113.955259,
                                    22.820331
                                ],
                                [
                                    113.95558,
                                    22.819641
                                ],
                                [
                                    113.95492,
                                    22.818701
                                ],
                                [
                                    113.955812,
                                    22.81743
                                ],
                                [
                                    113.954979,
                                    22.815053
                                ],
                                [
                                    113.956518,
                                    22.814313
                                ],
                                [
                                    113.956971,
                                    22.814005
                                ],
                                [
                                    113.957135,
                                    22.81444
                                ],
                                [
                                    113.957351,
                                    22.814676
                                ],
                                [
                                    113.958212,
                                    22.814614
                                ],
                                [
                                    113.958638,
                                    22.814454
                                ],
                                [
                                    113.958891,
                                    22.814254
                                ],
                                [
                                    113.958898,
                                    22.813633
                                ],
                                [
                                    113.959066,
                                    22.813409
                                ],
                                [
                                    113.96055,
                                    22.81313
                                ],
                                [
                                    113.961394,
                                    22.813367
                                ],
                                [
                                    113.963094,
                                    22.814609
                                ],
                                [
                                    113.964318,
                                    22.815641
                                ],
                                [
                                    113.964762,
                                    22.815844
                                ],
                                [
                                    113.965173,
                                    22.814912
                                ],
                                [
                                    113.965146,
                                    22.814725
                                ],
                                [
                                    113.964772,
                                    22.814203
                                ],
                                [
                                    113.964867,
                                    22.813414
                                ],
                                [
                                    113.966103,
                                    22.812431
                                ],
                                [
                                    113.967258,
                                    22.812096
                                ],
                                [
                                    113.968169,
                                    22.812057
                                ],
                                [
                                    113.968569,
                                    22.812179
                                ],
                                [
                                    113.969117,
                                    22.812888
                                ],
                                [
                                    113.969466,
                                    22.812986
                                ],
                                [
                                    113.970057,
                                    22.812906
                                ],
                                [
                                    113.97122,
                                    22.812437
                                ],
                                [
                                    113.972348,
                                    22.812498
                                ],
                                [
                                    113.972429,
                                    22.812453
                                ],
                                [
                                    113.972511,
                                    22.812393
                                ],
                                [
                                    113.972585,
                                    22.812338
                                ],
                                [
                                    113.972871,
                                    22.812078
                                ],
                                [
                                    113.973444,
                                    22.811068
                                ],
                                [
                                    113.973739,
                                    22.810722
                                ],
                                [
                                    113.974202,
                                    22.81057
                                ],
                                [
                                    113.975723,
                                    22.810416
                                ],
                                [
                                    113.976374,
                                    22.81008
                                ],
                                [
                                    113.9766,
                                    22.809846
                                ],
                                [
                                    113.976975,
                                    22.809098
                                ],
                                [
                                    113.977034,
                                    22.807892
                                ],
                                [
                                    113.977175,
                                    22.807371
                                ],
                                [
                                    113.978401,
                                    22.806512
                                ],
                                [
                                    113.976174,
                                    22.805661
                                ],
                                [
                                    113.975826,
                                    22.805581
                                ],
                                [
                                    113.974843,
                                    22.80561
                                ],
                                [
                                    113.974203,
                                    22.80544
                                ],
                                [
                                    113.973533,
                                    22.804936
                                ],
                                [
                                    113.972725,
                                    22.803826
                                ],
                                [
                                    113.972266,
                                    22.802256
                                ],
                                [
                                    113.972387,
                                    22.801775
                                ],
                                [
                                    113.973126,
                                    22.800281
                                ],
                                [
                                    113.974996,
                                    22.798437
                                ],
                                [
                                    113.974788,
                                    22.797806
                                ],
                                [
                                    113.975169,
                                    22.797659
                                ],
                                [
                                    113.975497,
                                    22.797953
                                ],
                                [
                                    113.975766,
                                    22.798343
                                ],
                                [
                                    113.975757,
                                    22.799216
                                ],
                                [
                                    113.974922,
                                    22.801376
                                ],
                                [
                                    113.974894,
                                    22.801521
                                ],
                                [
                                    113.975104,
                                    22.801662
                                ],
                                [
                                    113.975826,
                                    22.801655
                                ],
                                [
                                    113.975976,
                                    22.801556
                                ],
                                [
                                    113.97627,
                                    22.800258
                                ],
                                [
                                    113.976418,
                                    22.800159
                                ],
                                [
                                    113.976666,
                                    22.800193
                                ],
                                [
                                    113.976817,
                                    22.800311
                                ],
                                [
                                    113.976875,
                                    22.800612
                                ],
                                [
                                    113.977766,
                                    22.800792
                                ],
                                [
                                    113.977752,
                                    22.800641
                                ],
                                [
                                    113.977328,
                                    22.800061
                                ],
                                [
                                    113.977198,
                                    22.799375
                                ],
                                [
                                    113.97725,
                                    22.799085
                                ],
                                [
                                    113.977522,
                                    22.798957
                                ],
                                [
                                    113.977843,
                                    22.799121
                                ],
                                [
                                    113.978661,
                                    22.800026
                                ],
                                [
                                    113.978679,
                                    22.80022
                                ],
                                [
                                    113.978401,
                                    22.800919
                                ],
                                [
                                    113.978529,
                                    22.801335
                                ],
                                [
                                    113.978854,
                                    22.801284
                                ],
                                [
                                    113.97922,
                                    22.800687
                                ],
                                [
                                    113.979943,
                                    22.800821
                                ],
                                [
                                    113.982021,
                                    22.802005
                                ],
                                [
                                    113.982525,
                                    22.802743
                                ],
                                [
                                    113.983484,
                                    22.802878
                                ],
                                [
                                    113.984145,
                                    22.803633
                                ],
                                [
                                    113.984359,
                                    22.803753
                                ],
                                [
                                    113.984586,
                                    22.803641
                                ],
                                [
                                    113.984596,
                                    22.803555
                                ],
                                [
                                    113.984467,
                                    22.802184
                                ],
                                [
                                    113.984096,
                                    22.800752
                                ],
                                [
                                    113.983807,
                                    22.800705
                                ],
                                [
                                    113.983323,
                                    22.800995
                                ],
                                [
                                    113.982237,
                                    22.800818
                                ],
                                [
                                    113.981128,
                                    22.800883
                                ],
                                [
                                    113.980791,
                                    22.800559
                                ],
                                [
                                    113.980581,
                                    22.80005
                                ],
                                [
                                    113.98059,
                                    22.799786
                                ],
                                [
                                    113.980706,
                                    22.79963
                                ],
                                [
                                    113.980923,
                                    22.799733
                                ],
                                [
                                    113.982493,
                                    22.799893
                                ],
                                [
                                    113.984466,
                                    22.800293
                                ],
                                [
                                    113.99086,
                                    22.800206
                                ]
                            ]
                        ]
                    },
                    "properties": {
                        "name": "光明区",
                        "cp": [
                            113.935895,
                            22.748816
                        ]
                    }
                },
                {
                    "type": "Feature",
                    "id": "440307",
                    "geometry": {
                        "type": "MultiPolygon",
                        "coordinates": [
                            [
                                [
                                    [
                                        114.339292,
                                        22.623357
                                    ],
                                    [
                                        114.339406,
                                        22.623397
                                    ],
                                    [
                                        114.339546,
                                        22.623634
                                    ],
                                    [
                                        114.339632,
                                        22.623882
                                    ],
                                    [
                                        114.339685,
                                        22.624288
                                    ],
                                    [
                                        114.339803,
                                        22.624476
                                    ],
                                    [
                                        114.339793,
                                        22.624981
                                    ],
                                    [
                                        114.3399,
                                        22.625447
                                    ],
                                    [
                                        114.3402,
                                        22.625833
                                    ],
                                    [
                                        114.340436,
                                        22.625882
                                    ],
                                    [
                                        114.340715,
                                        22.625793
                                    ],
                                    [
                                        114.340994,
                                        22.625872
                                    ],
                                    [
                                        114.341359,
                                        22.626051
                                    ],
                                    [
                                        114.341938,
                                        22.626348
                                    ],
                                    [
                                        114.342411,
                                        22.626605
                                    ],
                                    [
                                        114.343183,
                                        22.626595
                                    ],
                                    [
                                        114.343312,
                                        22.626595
                                    ],
                                    [
                                        114.34343,
                                        22.626684
                                    ],
                                    [
                                        114.34343,
                                        22.626813
                                    ],
                                    [
                                        114.343612,
                                        22.627417
                                    ],
                                    [
                                        114.343494,
                                        22.628091
                                    ],
                                    [
                                        114.343644,
                                        22.628308
                                    ],
                                    [
                                        114.343762,
                                        22.628388
                                    ],
                                    [
                                        114.344406,
                                        22.628417
                                    ],
                                    [
                                        114.344749,
                                        22.628586
                                    ],
                                    [
                                        114.344867,
                                        22.628725
                                    ],
                                    [
                                        114.344943,
                                        22.628903
                                    ],
                                    [
                                        114.344964,
                                        22.629151
                                    ],
                                    [
                                        114.344824,
                                        22.629369
                                    ],
                                    [
                                        114.344706,
                                        22.630299
                                    ],
                                    [
                                        114.344331,
                                        22.630894
                                    ],
                                    [
                                        114.344331,
                                        22.63128
                                    ],
                                    [
                                        114.344406,
                                        22.631329
                                    ],
                                    [
                                        114.344556,
                                        22.63128
                                    ],
                                    [
                                        114.345436,
                                        22.63128
                                    ],
                                    [
                                        114.345683,
                                        22.631339
                                    ],
                                    [
                                        114.346101,
                                        22.631696
                                    ],
                                    [
                                        114.347657,
                                        22.630795
                                    ],
                                    [
                                        114.349256,
                                        22.63121
                                    ],
                                    [
                                        114.350854,
                                        22.631448
                                    ],
                                    [
                                        114.350961,
                                        22.631408
                                    ],
                                    [
                                        114.351144,
                                        22.630963
                                    ],
                                    [
                                        114.351401,
                                        22.629755
                                    ],
                                    [
                                        114.351712,
                                        22.629269
                                    ],
                                    [
                                        114.351809,
                                        22.629022
                                    ],
                                    [
                                        114.351798,
                                        22.628507
                                    ],
                                    [
                                        114.352066,
                                        22.626962
                                    ],
                                    [
                                        114.352765,
                                        22.626574
                                    ],
                                    [
                                        114.35417,
                                        22.626257
                                    ],
                                    [
                                        114.354385,
                                        22.627238
                                    ],
                                    [
                                        114.35461,
                                        22.627337
                                    ],
                                    [
                                        114.354728,
                                        22.627257
                                    ],
                                    [
                                        114.355082,
                                        22.626713
                                    ],
                                    [
                                        114.355029,
                                        22.626366
                                    ],
                                    [
                                        114.356101,
                                        22.625465
                                    ],
                                    [
                                        114.356134,
                                        22.625366
                                    ],
                                    [
                                        114.356134,
                                        22.624623
                                    ],
                                    [
                                        114.356198,
                                        22.624574
                                    ],
                                    [
                                        114.356316,
                                        22.624584
                                    ],
                                    [
                                        114.356917,
                                        22.625227
                                    ],
                                    [
                                        114.357528,
                                        22.62495
                                    ],
                                    [
                                        114.357625,
                                        22.624654
                                    ],
                                    [
                                        114.357582,
                                        22.624218
                                    ],
                                    [
                                        114.358387,
                                        22.623911
                                    ],
                                    [
                                        114.359213,
                                        22.623941
                                    ],
                                    [
                                        114.359556,
                                        22.623862
                                    ],
                                    [
                                        114.359771,
                                        22.623733
                                    ],
                                    [
                                        114.36005,
                                        22.623396
                                    ],
                                    [
                                        114.360951,
                                        22.622664
                                    ],
                                    [
                                        114.361777,
                                        22.623347
                                    ],
                                    [
                                        114.36196,
                                        22.623367
                                    ],
                                    [
                                        114.362271,
                                        22.622961
                                    ],
                                    [
                                        114.362485,
                                        22.622921
                                    ],
                                    [
                                        114.362925,
                                        22.623307
                                    ],
                                    [
                                        114.363934,
                                        22.622723
                                    ],
                                    [
                                        114.364513,
                                        22.622337
                                    ],
                                    [
                                        114.364942,
                                        22.622178
                                    ],
                                    [
                                        114.365189,
                                        22.622177
                                    ],
                                    [
                                        114.365607,
                                        22.622376
                                    ],
                                    [
                                        114.366895,
                                        22.623476
                                    ],
                                    [
                                        114.367013,
                                        22.624109
                                    ],
                                    [
                                        114.367024,
                                        22.624793
                                    ],
                                    [
                                        114.36667,
                                        22.625436
                                    ],
                                    [
                                        114.366658,
                                        22.626011
                                    ],
                                    [
                                        114.366765,
                                        22.626526
                                    ],
                                    [
                                        114.366433,
                                        22.627109
                                    ],
                                    [
                                        114.366476,
                                        22.627863
                                    ],
                                    [
                                        114.36639,
                                        22.628981
                                    ],
                                    [
                                        114.366529,
                                        22.629042
                                    ],
                                    [
                                        114.36698,
                                        22.629091
                                    ],
                                    [
                                        114.367216,
                                        22.629457
                                    ],
                                    [
                                        114.367409,
                                        22.630735
                                    ],
                                    [
                                        114.367388,
                                        22.631042
                                    ],
                                    [
                                        114.367849,
                                        22.631765
                                    ],
                                    [
                                        114.367688,
                                        22.632379
                                    ],
                                    [
                                        114.367527,
                                        22.632735
                                    ],
                                    [
                                        114.370993,
                                        22.631864
                                    ],
                                    [
                                        114.371218,
                                        22.631933
                                    ],
                                    [
                                        114.372033,
                                        22.632844
                                    ],
                                    [
                                        114.372817,
                                        22.632864
                                    ],
                                    [
                                        114.374201,
                                        22.632181
                                    ],
                                    [
                                        114.374716,
                                        22.632141
                                    ],
                                    [
                                        114.375359,
                                        22.632597
                                    ],
                                    [
                                        114.375445,
                                        22.633082
                                    ],
                                    [
                                        114.375134,
                                        22.633963
                                    ],
                                    [
                                        114.375145,
                                        22.634488
                                    ],
                                    [
                                        114.374984,
                                        22.634874
                                    ],
                                    [
                                        114.374619,
                                        22.634924
                                    ],
                                    [
                                        114.373374,
                                        22.63534
                                    ],
                                    [
                                        114.373321,
                                        22.635439
                                    ],
                                    [
                                        114.373684,
                                        22.636032
                                    ],
                                    [
                                        114.374403,
                                        22.636735
                                    ],
                                    [
                                        114.374779,
                                        22.637339
                                    ],
                                    [
                                        114.375079,
                                        22.638032
                                    ],
                                    [
                                        114.37509,
                                        22.638329
                                    ],
                                    [
                                        114.375036,
                                        22.638468
                                    ],
                                    [
                                        114.374864,
                                        22.638616
                                    ],
                                    [
                                        114.373856,
                                        22.638893
                                    ],
                                    [
                                        114.372268,
                                        22.638933
                                    ],
                                    [
                                        114.372107,
                                        22.639022
                                    ],
                                    [
                                        114.371313,
                                        22.640329
                                    ],
                                    [
                                        114.371365,
                                        22.640596
                                    ],
                                    [
                                        114.371322,
                                        22.640834
                                    ],
                                    [
                                        114.371494,
                                        22.641032
                                    ],
                                    [
                                        114.371934,
                                        22.641022
                                    ],
                                    [
                                        114.372417,
                                        22.641497
                                    ],
                                    [
                                        114.372664,
                                        22.642151
                                    ],
                                    [
                                        114.373179,
                                        22.642369
                                    ],
                                    [
                                        114.373297,
                                        22.642498
                                    ],
                                    [
                                        114.373597,
                                        22.642567
                                    ],
                                    [
                                        114.37379,
                                        22.642864
                                    ],
                                    [
                                        114.374133,
                                        22.642983
                                    ],
                                    [
                                        114.37452,
                                        22.643329
                                    ],
                                    [
                                        114.374595,
                                        22.643448
                                    ],
                                    [
                                        114.374895,
                                        22.643537
                                    ],
                                    [
                                        114.3757,
                                        22.644488
                                    ],
                                    [
                                        114.376118,
                                        22.644557
                                    ],
                                    [
                                        114.376644,
                                        22.644131
                                    ],
                                    [
                                        114.376923,
                                        22.643973
                                    ],
                                    [
                                        114.377717,
                                        22.642943
                                    ],
                                    [
                                        114.378125,
                                        22.64221
                                    ],
                                    [
                                        114.378275,
                                        22.641309
                                    ],
                                    [
                                        114.379036,
                                        22.640695
                                    ],
                                    [
                                        114.379519,
                                        22.640567
                                    ],
                                    [
                                        114.379722,
                                        22.640438
                                    ],
                                    [
                                        114.379895,
                                        22.64019
                                    ],
                                    [
                                        114.380893,
                                        22.63921
                                    ],
                                    [
                                        114.380957,
                                        22.639042
                                    ],
                                    [
                                        114.380881,
                                        22.638566
                                    ],
                                    [
                                        114.38101,
                                        22.63809
                                    ],
                                    [
                                        114.381471,
                                        22.637883
                                    ],
                                    [
                                        114.381933,
                                        22.637902
                                    ],
                                    [
                                        114.382093,
                                        22.638031
                                    ],
                                    [
                                        114.382587,
                                        22.638219
                                    ],
                                    [
                                        114.382898,
                                        22.63815
                                    ],
                                    [
                                        114.383284,
                                        22.637982
                                    ],
                                    [
                                        114.383789,
                                        22.637566
                                    ],
                                    [
                                        114.384497,
                                        22.637585
                                    ],
                                    [
                                        114.384883,
                                        22.637447
                                    ],
                                    [
                                        114.385173,
                                        22.637229
                                    ],
                                    [
                                        114.385387,
                                        22.637189
                                    ],
                                    [
                                        114.386052,
                                        22.637724
                                    ],
                                    [
                                        114.386718,
                                        22.637685
                                    ],
                                    [
                                        114.386986,
                                        22.637496
                                    ],
                                    [
                                        114.387597,
                                        22.636932
                                    ],
                                    [
                                        114.388702,
                                        22.636447
                                    ],
                                    [
                                        114.388906,
                                        22.636476
                                    ],
                                    [
                                        114.389271,
                                        22.636704
                                    ],
                                    [
                                        114.389668,
                                        22.636615
                                    ],
                                    [
                                        114.389861,
                                        22.636813
                                    ],
                                    [
                                        114.389967,
                                        22.637021
                                    ],
                                    [
                                        114.389967,
                                        22.637209
                                    ],
                                    [
                                        114.389797,
                                        22.637496
                                    ],
                                    [
                                        114.389818,
                                        22.638061
                                    ],
                                    [
                                        114.389636,
                                        22.638784
                                    ],
                                    [
                                        114.389604,
                                        22.639269
                                    ],
                                    [
                                        114.389292,
                                        22.640077
                                    ],
                                    [
                                        114.38969,
                                        22.641507
                                    ],
                                    [
                                        114.389722,
                                        22.642091
                                    ],
                                    [
                                        114.389861,
                                        22.64219
                                    ],
                                    [
                                        114.390376,
                                        22.642299
                                    ],
                                    [
                                        114.390988,
                                        22.642566
                                    ],
                                    [
                                        114.39146,
                                        22.642546
                                    ],
                                    [
                                        114.392157,
                                        22.642477
                                    ],
                                    [
                                        114.392672,
                                        22.642725
                                    ],
                                    [
                                        114.393563,
                                        22.643051
                                    ],
                                    [
                                        114.394099,
                                        22.643032
                                    ],
                                    [
                                        114.394314,
                                        22.643081
                                    ],
                                    [
                                        114.395494,
                                        22.643704
                                    ],
                                    [
                                        114.395785,
                                        22.643902
                                    ],
                                    [
                                        114.396171,
                                        22.644497
                                    ],
                                    [
                                        114.396675,
                                        22.644814
                                    ],
                                    [
                                        114.396804,
                                        22.645181
                                    ],
                                    [
                                        114.397265,
                                        22.645468
                                    ],
                                    [
                                        114.397716,
                                        22.645507
                                    ],
                                    [
                                        114.398359,
                                        22.645854
                                    ],
                                    [
                                        114.398928,
                                        22.645913
                                    ],
                                    [
                                        114.399851,
                                        22.646438
                                    ],
                                    [
                                        114.40014,
                                        22.646507
                                    ],
                                    [
                                        114.400226,
                                        22.646587
                                    ],
                                    [
                                        114.400602,
                                        22.646755
                                    ],
                                    [
                                        114.401181,
                                        22.646706
                                    ],
                                    [
                                        114.401825,
                                        22.646814
                                    ],
                                    [
                                        114.402104,
                                        22.646696
                                    ],
                                    [
                                        114.402372,
                                        22.646805
                                    ],
                                    [
                                        114.402662,
                                        22.646785
                                    ],
                                    [
                                        114.402941,
                                        22.646992
                                    ],
                                    [
                                        114.403241,
                                        22.647072
                                    ],
                                    [
                                        114.403487,
                                        22.64727
                                    ],
                                    [
                                        114.403509,
                                        22.647567
                                    ],
                                    [
                                        114.403648,
                                        22.647904
                                    ],
                                    [
                                        114.404174,
                                        22.647864
                                    ],
                                    [
                                        114.40427,
                                        22.647943
                                    ],
                                    [
                                        114.404206,
                                        22.648329
                                    ],
                                    [
                                        114.404614,
                                        22.648754
                                    ],
                                    [
                                        114.404827,
                                        22.648755
                                    ],
                                    [
                                        114.404936,
                                        22.648716
                                    ],
                                    [
                                        114.405492,
                                        22.648993
                                    ],
                                    [
                                        114.405815,
                                        22.648874
                                    ],
                                    [
                                        114.406116,
                                        22.648953
                                    ],
                                    [
                                        114.406437,
                                        22.649201
                                    ],
                                    [
                                        114.406706,
                                        22.649181
                                    ],
                                    [
                                        114.407156,
                                        22.648825
                                    ],
                                    [
                                        114.407477,
                                        22.648488
                                    ],
                                    [
                                        114.407789,
                                        22.648389
                                    ],
                                    [
                                        114.407865,
                                        22.648468
                                    ],
                                    [
                                        114.408852,
                                        22.648627
                                    ],
                                    [
                                        114.408895,
                                        22.648726
                                    ],
                                    [
                                        114.408841,
                                        22.648785
                                    ],
                                    [
                                        114.409066,
                                        22.649122
                                    ],
                                    [
                                        114.410293,
                                        22.649718
                                    ],
                                    [
                                        114.408451,
                                        22.651392
                                    ],
                                    [
                                        114.407568,
                                        22.652174
                                    ],
                                    [
                                        114.407635,
                                        22.652166
                                    ],
                                    [
                                        114.408018,
                                        22.65235
                                    ],
                                    [
                                        114.408258,
                                        22.652639
                                    ],
                                    [
                                        114.409229,
                                        22.652387
                                    ],
                                    [
                                        114.41074,
                                        22.650528
                                    ],
                                    [
                                        114.410976,
                                        22.651082
                                    ],
                                    [
                                        114.411577,
                                        22.651745
                                    ],
                                    [
                                        114.412209,
                                        22.652052
                                    ],
                                    [
                                        114.412274,
                                        22.652152
                                    ],
                                    [
                                        114.412242,
                                        22.6523
                                    ],
                                    [
                                        114.412091,
                                        22.652518
                                    ],
                                    [
                                        114.412134,
                                        22.653488
                                    ],
                                    [
                                        114.41295,
                                        22.654072
                                    ],
                                    [
                                        114.413089,
                                        22.65427
                                    ],
                                    [
                                        114.413862,
                                        22.65435
                                    ],
                                    [
                                        114.414119,
                                        22.654102
                                    ],
                                    [
                                        114.41487,
                                        22.654171
                                    ],
                                    [
                                        114.415074,
                                        22.654072
                                    ],
                                    [
                                        114.416222,
                                        22.653854
                                    ],
                                    [
                                        114.416587,
                                        22.653973
                                    ],
                                    [
                                        114.417724,
                                        22.653566
                                    ],
                                    [
                                        114.418184,
                                        22.653607
                                    ],
                                    [
                                        114.418647,
                                        22.652973
                                    ],
                                    [
                                        114.418797,
                                        22.652954
                                    ],
                                    [
                                        114.418894,
                                        22.653053
                                    ],
                                    [
                                        114.419848,
                                        22.654597
                                    ],
                                    [
                                        114.420063,
                                        22.654726
                                    ],
                                    [
                                        114.420825,
                                        22.654498
                                    ],
                                    [
                                        114.420975,
                                        22.654577
                                    ],
                                    [
                                        114.421124,
                                        22.654775
                                    ],
                                    [
                                        114.421007,
                                        22.655053
                                    ],
                                    [
                                        114.420943,
                                        22.655341
                                    ],
                                    [
                                        114.420857,
                                        22.655539
                                    ],
                                    [
                                        114.420942,
                                        22.655737
                                    ],
                                    [
                                        114.421222,
                                        22.655885
                                    ],
                                    [
                                        114.421372,
                                        22.656063
                                    ],
                                    [
                                        114.422059,
                                        22.656529
                                    ],
                                    [
                                        114.422992,
                                        22.656826
                                    ],
                                    [
                                        114.423485,
                                        22.656806
                                    ],
                                    [
                                        114.423947,
                                        22.656875
                                    ],
                                    [
                                        114.424247,
                                        22.656984
                                    ],
                                    [
                                        114.424751,
                                        22.656885
                                    ],
                                    [
                                        114.424945,
                                        22.656994
                                    ],
                                    [
                                        114.425094,
                                        22.657252
                                    ],
                                    [
                                        114.426822,
                                        22.658281
                                    ],
                                    [
                                        114.427133,
                                        22.659399
                                    ],
                                    [
                                        114.427734,
                                        22.659558
                                    ],
                                    [
                                        114.428582,
                                        22.660311
                                    ],
                                    [
                                        114.428936,
                                        22.660984
                                    ],
                                    [
                                        114.429247,
                                        22.661241
                                    ],
                                    [
                                        114.429623,
                                        22.661439
                                    ],
                                    [
                                        114.430729,
                                        22.66242
                                    ],
                                    [
                                        114.43077,
                                        22.662308
                                    ],
                                    [
                                        114.430806,
                                        22.662229
                                    ],
                                    [
                                        114.430874,
                                        22.662122
                                    ],
                                    [
                                        114.430934,
                                        22.662015
                                    ],
                                    [
                                        114.430974,
                                        22.661903
                                    ],
                                    [
                                        114.43101,
                                        22.661826
                                    ],
                                    [
                                        114.431043,
                                        22.661777
                                    ],
                                    [
                                        114.431136,
                                        22.661686
                                    ],
                                    [
                                        114.431204,
                                        22.661622
                                    ],
                                    [
                                        114.431273,
                                        22.661548
                                    ],
                                    [
                                        114.431377,
                                        22.661448
                                    ],
                                    [
                                        114.431446,
                                        22.661391
                                    ],
                                    [
                                        114.431499,
                                        22.661351
                                    ],
                                    [
                                        114.431567,
                                        22.661313
                                    ],
                                    [
                                        114.431619,
                                        22.661274
                                    ],
                                    [
                                        114.431716,
                                        22.661189
                                    ],
                                    [
                                        114.431785,
                                        22.661127
                                    ],
                                    [
                                        114.431867,
                                        22.661027
                                    ],
                                    [
                                        114.431915,
                                        22.660964
                                    ],
                                    [
                                        114.431946,
                                        22.660931
                                    ],
                                    [
                                        114.431988,
                                        22.660916
                                    ],
                                    [
                                        114.432079,
                                        22.660917
                                    ],
                                    [
                                        114.43213,
                                        22.66092
                                    ],
                                    [
                                        114.432209,
                                        22.660937
                                    ],
                                    [
                                        114.432279,
                                        22.660974
                                    ],
                                    [
                                        114.432369,
                                        22.661034
                                    ],
                                    [
                                        114.432441,
                                        22.66111
                                    ],
                                    [
                                        114.432513,
                                        22.661174
                                    ],
                                    [
                                        114.432606,
                                        22.66123
                                    ],
                                    [
                                        114.432723,
                                        22.661292
                                    ],
                                    [
                                        114.432798,
                                        22.66133
                                    ],
                                    [
                                        114.433874,
                                        22.661734
                                    ],
                                    [
                                        114.43395,
                                        22.661756
                                    ],
                                    [
                                        114.434016,
                                        22.661776
                                    ],
                                    [
                                        114.434091,
                                        22.66178
                                    ],
                                    [
                                        114.434162,
                                        22.661772
                                    ],
                                    [
                                        114.434244,
                                        22.661769
                                    ],
                                    [
                                        114.434326,
                                        22.661756
                                    ],
                                    [
                                        114.434408,
                                        22.661737
                                    ],
                                    [
                                        114.434479,
                                        22.661729
                                    ],
                                    [
                                        114.434549,
                                        22.66171
                                    ],
                                    [
                                        114.434621,
                                        22.661677
                                    ],
                                    [
                                        114.434699,
                                        22.661665
                                    ],
                                    [
                                        114.434789,
                                        22.661657
                                    ],
                                    [
                                        114.434884,
                                        22.661659
                                    ],
                                    [
                                        114.434976,
                                        22.661662
                                    ],
                                    [
                                        114.435103,
                                        22.661662
                                    ],
                                    [
                                        114.435231,
                                        22.661666
                                    ],
                                    [
                                        114.435314,
                                        22.661667
                                    ],
                                    [
                                        114.435404,
                                        22.661678
                                    ],
                                    [
                                        114.435483,
                                        22.66169
                                    ],
                                    [
                                        114.43557,
                                        22.661712
                                    ],
                                    [
                                        114.435662,
                                        22.661745
                                    ],
                                    [
                                        114.435748,
                                        22.661796
                                    ],
                                    [
                                        114.435839,
                                        22.661853
                                    ],
                                    [
                                        114.435939,
                                        22.661914
                                    ],
                                    [
                                        114.436092,
                                        22.662026
                                    ],
                                    [
                                        114.436223,
                                        22.662119
                                    ],
                                    [
                                        114.43634,
                                        22.662222
                                    ],
                                    [
                                        114.436486,
                                        22.662337
                                    ],
                                    [
                                        114.436576,
                                        22.662412
                                    ],
                                    [
                                        114.436666,
                                        22.662482
                                    ],
                                    [
                                        114.436784,
                                        22.662544
                                    ],
                                    [
                                        114.436862,
                                        22.662563
                                    ],
                                    [
                                        114.438563,
                                        22.663008
                                    ],
                                    [
                                        114.438655,
                                        22.663043
                                    ],
                                    [
                                        114.438752,
                                        22.663054
                                    ],
                                    [
                                        114.440093,
                                        22.66334
                                    ],
                                    [
                                        114.440197,
                                        22.663355
                                    ],
                                    [
                                        114.440333,
                                        22.663364
                                    ],
                                    [
                                        114.440416,
                                        22.663371
                                    ],
                                    [
                                        114.440509,
                                        22.663391
                                    ],
                                    [
                                        114.440625,
                                        22.66342
                                    ],
                                    [
                                        114.440776,
                                        22.663438
                                    ],
                                    [
                                        114.440879,
                                        22.663451
                                    ],
                                    [
                                        114.440976,
                                        22.663467
                                    ],
                                    [
                                        114.441101,
                                        22.663485
                                    ],
                                    [
                                        114.441212,
                                        22.663498
                                    ],
                                    [
                                        114.441343,
                                        22.663505
                                    ],
                                    [
                                        114.441477,
                                        22.663511
                                    ],
                                    [
                                        114.441621,
                                        22.663508
                                    ],
                                    [
                                        114.441743,
                                        22.663513
                                    ],
                                    [
                                        114.441884,
                                        22.66351
                                    ],
                                    [
                                        114.442084,
                                        22.663524
                                    ],
                                    [
                                        114.44226,
                                        22.663536
                                    ],
                                    [
                                        114.442376,
                                        22.663542
                                    ],
                                    [
                                        114.442465,
                                        22.663553
                                    ],
                                    [
                                        114.442544,
                                        22.663563
                                    ],
                                    [
                                        114.442648,
                                        22.663589
                                    ],
                                    [
                                        114.442732,
                                        22.663608
                                    ],
                                    [
                                        114.442801,
                                        22.663634
                                    ],
                                    [
                                        114.442868,
                                        22.663678
                                    ],
                                    [
                                        114.442923,
                                        22.663739
                                    ],
                                    [
                                        114.442983,
                                        22.663819
                                    ],
                                    [
                                        114.443008,
                                        22.663854
                                    ],
                                    [
                                        114.443061,
                                        22.66392
                                    ],
                                    [
                                        114.443104,
                                        22.66399
                                    ],
                                    [
                                        114.443124,
                                        22.664027
                                    ],
                                    [
                                        114.443136,
                                        22.664049
                                    ],
                                    [
                                        114.446433,
                                        22.664871
                                    ],
                                    [
                                        114.44749,
                                        22.665218
                                    ],
                                    [
                                        114.448609,
                                        22.665326
                                    ],
                                    [
                                        114.44973,
                                        22.665311
                                    ],
                                    [
                                        114.450446,
                                        22.666196
                                    ],
                                    [
                                        114.450443,
                                        22.667572
                                    ],
                                    [
                                        114.451246,
                                        22.668362
                                    ],
                                    [
                                        114.451957,
                                        22.669218
                                    ],
                                    [
                                        114.453043,
                                        22.669861
                                    ],
                                    [
                                        114.453415,
                                        22.669963
                                    ],
                                    [
                                        114.45633,
                                        22.669726
                                    ],
                                    [
                                        114.458202,
                                        22.669113
                                    ],
                                    [
                                        114.459445,
                                        22.668199
                                    ],
                                    [
                                        114.460183,
                                        22.667789
                                    ],
                                    [
                                        114.465322,
                                        22.667559
                                    ],
                                    [
                                        114.466778,
                                        22.667642
                                    ],
                                    [
                                        114.469139,
                                        22.667132
                                    ],
                                    [
                                        114.469745,
                                        22.666788
                                    ],
                                    [
                                        114.471514,
                                        22.666236
                                    ],
                                    [
                                        114.471796,
                                        22.665949
                                    ],
                                    [
                                        114.471954,
                                        22.665339
                                    ],
                                    [
                                        114.472363,
                                        22.664601
                                    ],
                                    [
                                        114.47328,
                                        22.664294
                                    ],
                                    [
                                        114.473698,
                                        22.664023
                                    ],
                                    [
                                        114.473789,
                                        22.663958
                                    ],
                                    [
                                        114.473918,
                                        22.663833
                                    ],
                                    [
                                        114.473954,
                                        22.663791
                                    ],
                                    [
                                        114.473987,
                                        22.663767
                                    ],
                                    [
                                        114.474014,
                                        22.663756
                                    ],
                                    [
                                        114.47405,
                                        22.663731
                                    ],
                                    [
                                        114.474102,
                                        22.663705
                                    ],
                                    [
                                        114.475584,
                                        22.662969
                                    ],
                                    [
                                        114.475715,
                                        22.662901
                                    ],
                                    [
                                        114.475766,
                                        22.662879
                                    ],
                                    [
                                        114.475814,
                                        22.662863
                                    ],
                                    [
                                        114.475879,
                                        22.662848
                                    ],
                                    [
                                        114.475952,
                                        22.662836
                                    ],
                                    [
                                        114.476046,
                                        22.662828
                                    ],
                                    [
                                        114.476224,
                                        22.662814
                                    ],
                                    [
                                        114.476337,
                                        22.662809
                                    ],
                                    [
                                        114.476403,
                                        22.662801
                                    ],
                                    [
                                        114.476467,
                                        22.662793
                                    ],
                                    [
                                        114.476547,
                                        22.662785
                                    ],
                                    [
                                        114.476618,
                                        22.662774
                                    ],
                                    [
                                        114.476679,
                                        22.66276
                                    ],
                                    [
                                        114.476758,
                                        22.662736
                                    ],
                                    [
                                        114.476811,
                                        22.662714
                                    ],
                                    [
                                        114.476893,
                                        22.662686
                                    ],
                                    [
                                        114.476972,
                                        22.662651
                                    ],
                                    [
                                        114.477038,
                                        22.662624
                                    ],
                                    [
                                        114.477095,
                                        22.662596
                                    ],
                                    [
                                        114.477161,
                                        22.662552
                                    ],
                                    [
                                        114.477251,
                                        22.662489
                                    ],
                                    [
                                        114.477314,
                                        22.66245
                                    ],
                                    [
                                        114.477361,
                                        22.662408
                                    ],
                                    [
                                        114.477434,
                                        22.662334
                                    ],
                                    [
                                        114.477497,
                                        22.662281
                                    ],
                                    [
                                        114.477561,
                                        22.662221
                                    ],
                                    [
                                        114.477621,
                                        22.662165
                                    ],
                                    [
                                        114.477636,
                                        22.662138
                                    ],
                                    [
                                        114.477665,
                                        22.662093
                                    ],
                                    [
                                        114.477695,
                                        22.662055
                                    ],
                                    [
                                        114.477742,
                                        22.662013
                                    ],
                                    [
                                        114.4778,
                                        22.661957
                                    ],
                                    [
                                        114.477853,
                                        22.661915
                                    ],
                                    [
                                        114.477901,
                                        22.661877
                                    ],
                                    [
                                        114.477948,
                                        22.661846
                                    ],
                                    [
                                        114.47802,
                                        22.661818
                                    ],
                                    [
                                        114.478074,
                                        22.661807
                                    ],
                                    [
                                        114.478107,
                                        22.661801
                                    ],
                                    [
                                        114.478132,
                                        22.661806
                                    ],
                                    [
                                        114.478177,
                                        22.661825
                                    ],
                                    [
                                        114.478251,
                                        22.661875
                                    ],
                                    [
                                        114.479939,
                                        22.662778
                                    ],
                                    [
                                        114.479981,
                                        22.662801
                                    ],
                                    [
                                        114.480034,
                                        22.66284
                                    ],
                                    [
                                        114.480097,
                                        22.662888
                                    ],
                                    [
                                        114.480148,
                                        22.662936
                                    ],
                                    [
                                        114.480169,
                                        22.662981
                                    ],
                                    [
                                        114.480192,
                                        22.663061
                                    ],
                                    [
                                        114.480203,
                                        22.663126
                                    ],
                                    [
                                        114.480211,
                                        22.663271
                                    ],
                                    [
                                        114.480229,
                                        22.663361
                                    ],
                                    [
                                        114.480254,
                                        22.663443
                                    ],
                                    [
                                        114.480279,
                                        22.663567
                                    ],
                                    [
                                        114.480301,
                                        22.663662
                                    ],
                                    [
                                        114.480315,
                                        22.66375
                                    ],
                                    [
                                        114.480322,
                                        22.663773
                                    ],
                                    [
                                        114.480333,
                                        22.663816
                                    ],
                                    [
                                        114.480376,
                                        22.663966
                                    ],
                                    [
                                        114.48039,
                                        22.664004
                                    ],
                                    [
                                        114.480392,
                                        22.664011
                                    ],
                                    [
                                        114.48054,
                                        22.664297
                                    ],
                                    [
                                        114.48077,
                                        22.664481
                                    ],
                                    [
                                        114.481065,
                                        22.664938
                                    ],
                                    [
                                        114.481984,
                                        22.66815
                                    ],
                                    [
                                        114.482078,
                                        22.668257
                                    ],
                                    [
                                        114.483949,
                                        22.668229
                                    ],
                                    [
                                        114.485491,
                                        22.668525
                                    ],
                                    [
                                        114.487488,
                                        22.669153
                                    ],
                                    [
                                        114.488141,
                                        22.669191
                                    ],
                                    [
                                        114.489179,
                                        22.669076
                                    ],
                                    [
                                        114.490384,
                                        22.669456
                                    ],
                                    [
                                        114.49205,
                                        22.669812
                                    ],
                                    [
                                        114.493368,
                                        22.669926
                                    ],
                                    [
                                        114.493856,
                                        22.669878
                                    ],
                                    [
                                        114.494294,
                                        22.669689
                                    ],
                                    [
                                        114.495283,
                                        22.668836
                                    ],
                                    [
                                        114.498404,
                                        22.669144
                                    ],
                                    [
                                        114.500292,
                                        22.668926
                                    ],
                                    [
                                        114.503954,
                                        22.668914
                                    ],
                                    [
                                        114.504639,
                                        22.668781
                                    ],
                                    [
                                        114.504648,
                                        22.668778
                                    ],
                                    [
                                        114.504708,
                                        22.668759
                                    ],
                                    [
                                        114.504773,
                                        22.668741
                                    ],
                                    [
                                        114.504813,
                                        22.668729
                                    ],
                                    [
                                        114.504884,
                                        22.668714
                                    ],
                                    [
                                        114.504929,
                                        22.66871
                                    ],
                                    [
                                        114.504964,
                                        22.668708
                                    ],
                                    [
                                        114.505023,
                                        22.668691
                                    ],
                                    [
                                        114.505836,
                                        22.668473
                                    ],
                                    [
                                        114.505896,
                                        22.668447
                                    ],
                                    [
                                        114.50596,
                                        22.668409
                                    ],
                                    [
                                        114.506021,
                                        22.668367
                                    ],
                                    [
                                        114.506075,
                                        22.66832
                                    ],
                                    [
                                        114.506128,
                                        22.668267
                                    ],
                                    [
                                        114.506161,
                                        22.668224
                                    ],
                                    [
                                        114.506192,
                                        22.668189
                                    ],
                                    [
                                        114.506235,
                                        22.668153
                                    ],
                                    [
                                        114.506291,
                                        22.668109
                                    ],
                                    [
                                        114.506329,
                                        22.668077
                                    ],
                                    [
                                        114.506374,
                                        22.66804
                                    ],
                                    [
                                        114.506433,
                                        22.667986
                                    ],
                                    [
                                        114.506482,
                                        22.667946
                                    ],
                                    [
                                        114.506516,
                                        22.667911
                                    ],
                                    [
                                        114.506555,
                                        22.667875
                                    ],
                                    [
                                        114.506599,
                                        22.667839
                                    ],
                                    [
                                        114.506627,
                                        22.667815
                                    ],
                                    [
                                        114.506653,
                                        22.667789
                                    ],
                                    [
                                        114.506689,
                                        22.667759
                                    ],
                                    [
                                        114.506721,
                                        22.667733
                                    ],
                                    [
                                        114.506774,
                                        22.667702
                                    ],
                                    [
                                        114.506814,
                                        22.667662
                                    ],
                                    [
                                        114.506852,
                                        22.667626
                                    ],
                                    [
                                        114.5069,
                                        22.667591
                                    ],
                                    [
                                        114.50695,
                                        22.667553
                                    ],
                                    [
                                        114.506993,
                                        22.667517
                                    ],
                                    [
                                        114.507026,
                                        22.667488
                                    ],
                                    [
                                        114.507088,
                                        22.667433
                                    ],
                                    [
                                        114.507148,
                                        22.667379
                                    ],
                                    [
                                        114.507204,
                                        22.667328
                                    ],
                                    [
                                        114.507266,
                                        22.667272
                                    ],
                                    [
                                        114.507312,
                                        22.667233
                                    ],
                                    [
                                        114.507369,
                                        22.667188
                                    ],
                                    [
                                        114.507409,
                                        22.667148
                                    ],
                                    [
                                        114.507446,
                                        22.667101
                                    ],
                                    [
                                        114.507481,
                                        22.667056
                                    ],
                                    [
                                        114.507525,
                                        22.667001
                                    ],
                                    [
                                        114.50757,
                                        22.666954
                                    ],
                                    [
                                        114.507606,
                                        22.666927
                                    ],
                                    [
                                        114.507675,
                                        22.666889
                                    ],
                                    [
                                        114.507743,
                                        22.666848
                                    ],
                                    [
                                        114.507814,
                                        22.666799
                                    ],
                                    [
                                        114.507882,
                                        22.666759
                                    ],
                                    [
                                        114.507946,
                                        22.666712
                                    ],
                                    [
                                        114.50804,
                                        22.666646
                                    ],
                                    [
                                        114.508106,
                                        22.666601
                                    ],
                                    [
                                        114.508171,
                                        22.666555
                                    ],
                                    [
                                        114.508245,
                                        22.666502
                                    ],
                                    [
                                        114.508301,
                                        22.666455
                                    ],
                                    [
                                        114.508386,
                                        22.6664
                                    ],
                                    [
                                        114.508444,
                                        22.666351
                                    ],
                                    [
                                        114.508523,
                                        22.666304
                                    ],
                                    [
                                        114.50861,
                                        22.666254
                                    ],
                                    [
                                        114.508679,
                                        22.666212
                                    ],
                                    [
                                        114.508747,
                                        22.666172
                                    ],
                                    [
                                        114.508807,
                                        22.666139
                                    ],
                                    [
                                        114.508858,
                                        22.666101
                                    ],
                                    [
                                        114.508935,
                                        22.666048
                                    ],
                                    [
                                        114.508998,
                                        22.66601
                                    ],
                                    [
                                        114.509059,
                                        22.665979
                                    ],
                                    [
                                        114.509118,
                                        22.665947
                                    ],
                                    [
                                        114.509205,
                                        22.6659
                                    ],
                                    [
                                        114.509274,
                                        22.665876
                                    ],
                                    [
                                        114.509328,
                                        22.665863
                                    ],
                                    [
                                        114.509414,
                                        22.665856
                                    ],
                                    [
                                        114.509469,
                                        22.665861
                                    ],
                                    [
                                        114.509529,
                                        22.66587
                                    ],
                                    [
                                        114.509584,
                                        22.665887
                                    ],
                                    [
                                        114.509641,
                                        22.665903
                                    ],
                                    [
                                        114.5097,
                                        22.665918
                                    ],
                                    [
                                        114.509742,
                                        22.66593
                                    ],
                                    [
                                        114.509826,
                                        22.665937
                                    ],
                                    [
                                        114.50993,
                                        22.665932
                                    ],
                                    [
                                        114.510023,
                                        22.665915
                                    ],
                                    [
                                        114.510111,
                                        22.6659
                                    ],
                                    [
                                        114.510185,
                                        22.665886
                                    ],
                                    [
                                        114.510269,
                                        22.665864
                                    ],
                                    [
                                        114.51034,
                                        22.665849
                                    ],
                                    [
                                        114.510401,
                                        22.665836
                                    ],
                                    [
                                        114.510508,
                                        22.665817
                                    ],
                                    [
                                        114.510594,
                                        22.665791
                                    ],
                                    [
                                        114.510657,
                                        22.665763
                                    ],
                                    [
                                        114.510733,
                                        22.66573
                                    ],
                                    [
                                        114.510792,
                                        22.665701
                                    ],
                                    [
                                        114.510849,
                                        22.665668
                                    ],
                                    [
                                        114.510901,
                                        22.665617
                                    ],
                                    [
                                        114.510956,
                                        22.665568
                                    ],
                                    [
                                        114.51101,
                                        22.665524
                                    ],
                                    [
                                        114.511057,
                                        22.665481
                                    ],
                                    [
                                        114.511108,
                                        22.665435
                                    ],
                                    [
                                        114.511139,
                                        22.665392
                                    ],
                                    [
                                        114.511175,
                                        22.665368
                                    ],
                                    [
                                        114.511211,
                                        22.66535
                                    ],
                                    [
                                        114.511268,
                                        22.665297
                                    ],
                                    [
                                        114.511322,
                                        22.66525
                                    ],
                                    [
                                        114.511368,
                                        22.665201
                                    ],
                                    [
                                        114.511415,
                                        22.665127
                                    ],
                                    [
                                        114.511463,
                                        22.665053
                                    ],
                                    [
                                        114.511513,
                                        22.664995
                                    ],
                                    [
                                        114.511539,
                                        22.664948
                                    ],
                                    [
                                        114.511554,
                                        22.664871
                                    ],
                                    [
                                        114.511622,
                                        22.664819
                                    ],
                                    [
                                        114.511673,
                                        22.664787
                                    ],
                                    [
                                        114.511703,
                                        22.664747
                                    ],
                                    [
                                        114.511731,
                                        22.664709
                                    ],
                                    [
                                        114.511763,
                                        22.664673
                                    ],
                                    [
                                        114.511796,
                                        22.664622
                                    ],
                                    [
                                        114.511834,
                                        22.664582
                                    ],
                                    [
                                        114.511884,
                                        22.664517
                                    ],
                                    [
                                        114.511915,
                                        22.664472
                                    ],
                                    [
                                        114.511961,
                                        22.664401
                                    ],
                                    [
                                        114.511989,
                                        22.66434
                                    ],
                                    [
                                        114.51202,
                                        22.664275
                                    ],
                                    [
                                        114.512043,
                                        22.664212
                                    ],
                                    [
                                        114.512065,
                                        22.664147
                                    ],
                                    [
                                        114.512091,
                                        22.664079
                                    ],
                                    [
                                        114.512105,
                                        22.664028
                                    ],
                                    [
                                        114.512115,
                                        22.663996
                                    ],
                                    [
                                        114.512144,
                                        22.663936
                                    ],
                                    [
                                        114.512178,
                                        22.663873
                                    ],
                                    [
                                        114.514487,
                                        22.660748
                                    ],
                                    [
                                        114.513527,
                                        22.659996
                                    ],
                                    [
                                        114.512272,
                                        22.658573
                                    ],
                                    [
                                        114.512186,
                                        22.658313
                                    ],
                                    [
                                        114.511978,
                                        22.657693
                                    ],
                                    [
                                        114.512229,
                                        22.656433
                                    ],
                                    [
                                        114.513068,
                                        22.655719
                                    ],
                                    [
                                        114.513985,
                                        22.655423
                                    ],
                                    [
                                        114.515239,
                                        22.655502
                                    ],
                                    [
                                        114.529791,
                                        22.657192
                                    ],
                                    [
                                        114.545844,
                                        22.656228
                                    ],
                                    [
                                        114.553211,
                                        22.656212
                                    ],
                                    [
                                        114.565848,
                                        22.65774
                                    ],
                                    [
                                        114.576819,
                                        22.660829
                                    ],
                                    [
                                        114.580252,
                                        22.661496
                                    ],
                                    [
                                        114.587457,
                                        22.660819
                                    ],
                                    [
                                        114.593581,
                                        22.660145
                                    ],
                                    [
                                        114.599108,
                                        22.658129
                                    ],
                                    [
                                        114.602883,
                                        22.655277
                                    ],
                                    [
                                        114.604644,
                                        22.651585
                                    ],
                                    [
                                        114.605234,
                                        22.647138
                                    ],
                                    [
                                        114.604644,
                                        22.643026
                                    ],
                                    [
                                        114.603134,
                                        22.638748
                                    ],
                                    [
                                        114.600538,
                                        22.634804
                                    ],
                                    [
                                        114.595757,
                                        22.626375
                                    ],
                                    [
                                        114.592989,
                                        22.621173
                                    ],
                                    [
                                        114.589805,
                                        22.617064
                                    ],
                                    [
                                        114.5867,
                                        22.612872
                                    ],
                                    [
                                        114.583353,
                                        22.610357
                                    ],
                                    [
                                        114.578073,
                                        22.60684
                                    ],
                                    [
                                        114.572291,
                                        22.602692
                                    ],
                                    [
                                        114.565255,
                                        22.59381
                                    ],
                                    [
                                        114.561409,
                                        22.588113
                                    ],
                                    [
                                        114.559061,
                                        22.583251
                                    ],
                                    [
                                        114.558896,
                                        22.576372
                                    ],
                                    [
                                        114.559736,
                                        22.573182
                                    ],
                                    [
                                        114.562412,
                                        22.568311
                                    ],
                                    [
                                        114.565089,
                                        22.56428
                                    ],
                                    [
                                        114.568103,
                                        22.560753
                                    ],
                                    [
                                        114.57254,
                                        22.55781
                                    ],
                                    [
                                        114.574888,
                                        22.555711
                                    ],
                                    [
                                        114.578572,
                                        22.553608
                                    ],
                                    [
                                        114.583514,
                                        22.551674
                                    ],
                                    [
                                        114.589628,
                                        22.54974
                                    ],
                                    [
                                        114.595162,
                                        22.548479
                                    ],
                                    [
                                        114.599353,
                                        22.547974
                                    ],
                                    [
                                        114.605142,
                                        22.547514
                                    ],
                                    [
                                        114.609421,
                                        22.547431
                                    ],
                                    [
                                        114.612017,
                                        22.546424
                                    ],
                                    [
                                        114.614536,
                                        22.545169
                                    ],
                                    [
                                        114.616298,
                                        22.542819
                                    ],
                                    [
                                        114.618061,
                                        22.538962
                                    ],
                                    [
                                        114.619572,
                                        22.534266
                                    ],
                                    [
                                        114.620918,
                                        22.530828
                                    ],
                                    [
                                        114.62461,
                                        22.524958
                                    ],
                                    [
                                        114.627042,
                                        22.519928
                                    ],
                                    [
                                        114.628389,
                                        22.513637
                                    ],
                                    [
                                        114.628466,
                                        22.508772
                                    ],
                                    [
                                        114.627797,
                                        22.502983
                                    ],
                                    [
                                        114.625781,
                                        22.498368
                                    ],
                                    [
                                        114.619317,
                                        22.488926
                                    ],
                                    [
                                        114.616547,
                                        22.485736
                                    ],
                                    [
                                        114.611432,
                                        22.482042
                                    ],
                                    [
                                        114.597171,
                                        22.477009
                                    ],
                                    [
                                        114.585434,
                                        22.473408
                                    ],
                                    [
                                        114.566426,
                                        22.468439
                                    ],
                                    [
                                        114.562865,
                                        22.467941
                                    ],
                                    [
                                        114.559097,
                                        22.467907
                                    ],
                                    [
                                        114.555079,
                                        22.467579
                                    ],
                                    [
                                        114.551312,
                                        22.466579
                                    ],
                                    [
                                        114.549226,
                                        22.465747
                                    ],
                                    [
                                        114.546421,
                                        22.462461
                                    ],
                                    [
                                        114.544914,
                                        22.460073
                                    ],
                                    [
                                        114.543079,
                                        22.456009
                                    ],
                                    [
                                        114.53927,
                                        22.449246
                                    ],
                                    [
                                        114.535341,
                                        22.445146
                                    ],
                                    [
                                        114.531326,
                                        22.442724
                                    ],
                                    [
                                        114.525434,
                                        22.440581
                                    ],
                                    [
                                        114.517656,
                                        22.43943
                                    ],
                                    [
                                        114.506956,
                                        22.438581
                                    ],
                                    [
                                        114.500772,
                                        22.439941
                                    ],
                                    [
                                        114.494172,
                                        22.441974
                                    ],
                                    [
                                        114.489821,
                                        22.443665
                                    ],
                                    [
                                        114.485228,
                                        22.446699
                                    ],
                                    [
                                        114.480289,
                                        22.452919
                                    ],
                                    [
                                        114.476699,
                                        22.459135
                                    ],
                                    [
                                        114.474441,
                                        22.46451
                                    ],
                                    [
                                        114.469674,
                                        22.485366
                                    ],
                                    [
                                        114.468169,
                                        22.491409
                                    ],
                                    [
                                        114.468091,
                                        22.495101
                                    ],
                                    [
                                        114.469095,
                                        22.501978
                                    ],
                                    [
                                        114.469926,
                                        22.507638
                                    ],
                                    [
                                        114.471519,
                                        22.513506
                                    ],
                                    [
                                        114.472099,
                                        22.518453
                                    ],
                                    [
                                        114.471935,
                                        22.522227
                                    ],
                                    [
                                        114.470265,
                                        22.526846
                                    ],
                                    [
                                        114.467591,
                                        22.533354
                                    ],
                                    [
                                        114.464493,
                                        22.537809
                                    ],
                                    [
                                        114.458054,
                                        22.545037
                                    ],
                                    [
                                        114.454296,
                                        22.548657
                                    ],
                                    [
                                        114.449196,
                                        22.553532
                                    ],
                                    [
                                        114.444511,
                                        22.556896
                                    ],
                                    [
                                        114.439738,
                                        22.560007
                                    ],
                                    [
                                        114.437139,
                                        22.562613
                                    ],
                                    [
                                        114.43597,
                                        22.564544
                                    ],
                                    [
                                        114.434713,
                                        22.566601
                                    ],
                                    [
                                        114.433457,
                                        22.57088
                                    ],
                                    [
                                        114.432036,
                                        22.576837
                                    ],
                                    [
                                        114.430693,
                                        22.583382
                                    ],
                                    [
                                        114.427183,
                                        22.588796
                                    ],
                                    [
                                        114.422571,
                                        22.592744
                                    ],
                                    [
                                        114.41612,
                                        22.596858
                                    ],
                                    [
                                        114.410508,
                                        22.599545
                                    ],
                                    [
                                        114.404634,
                                        22.601474
                                    ],
                                    [
                                        114.401197,
                                        22.602396
                                    ],
                                    [
                                        114.398342,
                                        22.602858
                                    ],
                                    [
                                        114.388861,
                                        22.602935
                                    ],
                                    [
                                        114.381896,
                                        22.601502
                                    ],
                                    [
                                        114.378447,
                                        22.600102
                                    ],
                                    [
                                        114.374851,
                                        22.598643
                                    ],
                                    [
                                        114.370402,
                                        22.596456
                                    ],
                                    [
                                        114.364102,
                                        22.593384
                                    ],
                                    [
                                        114.359522,
                                        22.591573
                                    ],
                                    [
                                        114.353515,
                                        22.590011
                                    ],
                                    [
                                        114.350535,
                                        22.597011
                                    ],
                                    [
                                        114.350299,
                                        22.598311
                                    ],
                                    [
                                        114.350277,
                                        22.598398
                                    ],
                                    [
                                        114.350265,
                                        22.598448
                                    ],
                                    [
                                        114.350258,
                                        22.598477
                                    ],
                                    [
                                        114.350257,
                                        22.5985
                                    ],
                                    [
                                        114.350252,
                                        22.598653
                                    ],
                                    [
                                        114.350244,
                                        22.598847
                                    ],
                                    [
                                        114.350207,
                                        22.599842
                                    ],
                                    [
                                        114.350209,
                                        22.599871
                                    ],
                                    [
                                        114.350223,
                                        22.600035
                                    ],
                                    [
                                        114.350273,
                                        22.600422
                                    ],
                                    [
                                        114.350294,
                                        22.600576
                                    ],
                                    [
                                        114.350298,
                                        22.600615
                                    ],
                                    [
                                        114.350356,
                                        22.601419
                                    ],
                                    [
                                        114.35046,
                                        22.602589
                                    ],
                                    [
                                        114.349721,
                                        22.603027
                                    ],
                                    [
                                        114.348712,
                                        22.603327
                                    ],
                                    [
                                        114.348573,
                                        22.603349
                                    ],
                                    [
                                        114.348551,
                                        22.603353
                                    ],
                                    [
                                        114.348521,
                                        22.603359
                                    ],
                                    [
                                        114.348443,
                                        22.603376
                                    ],
                                    [
                                        114.348359,
                                        22.603386
                                    ],
                                    [
                                        114.347179,
                                        22.603126
                                    ],
                                    [
                                        114.346987,
                                        22.603094
                                    ],
                                    [
                                        114.345543,
                                        22.602862
                                    ],
                                    [
                                        114.345033,
                                        22.602596
                                    ],
                                    [
                                        114.344939,
                                        22.602511
                                    ],
                                    [
                                        114.344893,
                                        22.602461
                                    ],
                                    [
                                        114.344698,
                                        22.602041
                                    ],
                                    [
                                        114.344436,
                                        22.601887
                                    ],
                                    [
                                        114.344202,
                                        22.601869
                                    ],
                                    [
                                        114.343045,
                                        22.602146
                                    ],
                                    [
                                        114.33917,
                                        22.602373
                                    ],
                                    [
                                        114.339033,
                                        22.602318
                                    ],
                                    [
                                        114.337939,
                                        22.60292
                                    ],
                                    [
                                        114.337747,
                                        22.603174
                                    ],
                                    [
                                        114.337672,
                                        22.603466
                                    ],
                                    [
                                        114.337799,
                                        22.604064
                                    ],
                                    [
                                        114.33795,
                                        22.60586
                                    ],
                                    [
                                        114.338674,
                                        22.60723
                                    ],
                                    [
                                        114.339421,
                                        22.60792
                                    ],
                                    [
                                        114.33958,
                                        22.608374
                                    ],
                                    [
                                        114.342631,
                                        22.613383
                                    ],
                                    [
                                        114.342759,
                                        22.614279
                                    ],
                                    [
                                        114.342374,
                                        22.615754
                                    ],
                                    [
                                        114.341984,
                                        22.61646
                                    ],
                                    [
                                        114.341965,
                                        22.616638
                                    ],
                                    [
                                        114.342618,
                                        22.617514
                                    ],
                                    [
                                        114.342874,
                                        22.61771
                                    ],
                                    [
                                        114.343256,
                                        22.617826
                                    ],
                                    [
                                        114.343266,
                                        22.618137
                                    ],
                                    [
                                        114.343093,
                                        22.618536
                                    ],
                                    [
                                        114.342292,
                                        22.619586
                                    ],
                                    [
                                        114.341302,
                                        22.620276
                                    ],
                                    [
                                        114.340936,
                                        22.620759
                                    ],
                                    [
                                        114.340548,
                                        22.621496
                                    ],
                                    [
                                        114.340434,
                                        22.622092
                                    ],
                                    [
                                        114.339723,
                                        22.623063
                                    ],
                                    [
                                        114.339292,
                                        22.623357
                                    ]
                                ]
                            ],
                            [
                                [
                                    [
                                        114.355784,
                                        22.765796
                                    ],
                                    [
                                        114.35541,
                                        22.765501
                                    ],
                                    [
                                        114.354039,
                                        22.765839
                                    ],
                                    [
                                        114.353457,
                                        22.765995
                                    ],
                                    [
                                        114.353259,
                                        22.766326
                                    ],
                                    [
                                        114.352846,
                                        22.767275
                                    ],
                                    [
                                        114.352181,
                                        22.768259
                                    ],
                                    [
                                        114.351891,
                                        22.768239
                                    ],
                                    [
                                        114.350979,
                                        22.768734
                                    ],
                                    [
                                        114.350657,
                                        22.768922
                                    ],
                                    [
                                        114.349091,
                                        22.767903
                                    ],
                                    [
                                        114.349016,
                                        22.767418
                                    ],
                                    [
                                        114.348715,
                                        22.766665
                                    ],
                                    [
                                        114.347926,
                                        22.765537
                                    ],
                                    [
                                        114.347824,
                                        22.765289
                                    ],
                                    [
                                        114.347867,
                                        22.765106
                                    ],
                                    [
                                        114.348028,
                                        22.764398
                                    ],
                                    [
                                        114.347953,
                                        22.763997
                                    ],
                                    [
                                        114.347856,
                                        22.763661
                                    ],
                                    [
                                        114.347706,
                                        22.762933
                                    ],
                                    [
                                        114.347733,
                                        22.762893
                                    ],
                                    [
                                        114.347835,
                                        22.762215
                                    ],
                                    [
                                        114.347717,
                                        22.761938
                                    ],
                                    [
                                        114.347481,
                                        22.761587
                                    ],
                                    [
                                        114.347476,
                                        22.761126
                                    ],
                                    [
                                        114.346553,
                                        22.76077
                                    ],
                                    [
                                        114.345654,
                                        22.760488
                                    ],
                                    [
                                        114.346099,
                                        22.75978
                                    ],
                                    [
                                        114.345981,
                                        22.759547
                                    ],
                                    [
                                        114.345439,
                                        22.758835
                                    ],
                                    [
                                        114.344436,
                                        22.758543
                                    ],
                                    [
                                        114.344522,
                                        22.757853
                                    ],
                                    [
                                        114.344441,
                                        22.757255
                                    ],
                                    [
                                        114.344559,
                                        22.756706
                                    ],
                                    [
                                        114.344812,
                                        22.756018
                                    ],
                                    [
                                        114.344715,
                                        22.755192
                                    ],
                                    [
                                        114.343194,
                                        22.755235
                                    ],
                                    [
                                        114.342985,
                                        22.754963
                                    ],
                                    [
                                        114.342362,
                                        22.754498
                                    ],
                                    [
                                        114.341842,
                                        22.754503
                                    ],
                                    [
                                        114.341343,
                                        22.754918
                                    ],
                                    [
                                        114.340675,
                                        22.754196
                                    ],
                                    [
                                        114.340514,
                                        22.753572
                                    ],
                                    [
                                        114.340176,
                                        22.753058
                                    ],
                                    [
                                        114.339891,
                                        22.75234
                                    ],
                                    [
                                        114.339768,
                                        22.751687
                                    ],
                                    [
                                        114.339576,
                                        22.751067
                                    ],
                                    [
                                        114.339319,
                                        22.750716
                                    ],
                                    [
                                        114.339077,
                                        22.749821
                                    ],
                                    [
                                        114.338868,
                                        22.749662
                                    ],
                                    [
                                        114.338257,
                                        22.749074
                                    ],
                                    [
                                        114.337502,
                                        22.747968
                                    ],
                                    [
                                        114.337367,
                                        22.747414
                                    ],
                                    [
                                        114.337705,
                                        22.746538
                                    ],
                                    [
                                        114.337995,
                                        22.746395
                                    ],
                                    [
                                        114.340075,
                                        22.746462
                                    ],
                                    [
                                        114.340525,
                                        22.743939
                                    ],
                                    [
                                        114.339925,
                                        22.742922
                                    ],
                                    [
                                        114.339903,
                                        22.741448
                                    ],
                                    [
                                        114.339045,
                                        22.740993
                                    ],
                                    [
                                        114.33897,
                                        22.740023
                                    ],
                                    [
                                        114.338626,
                                        22.736004
                                    ],
                                    [
                                        114.339099,
                                        22.734817
                                    ],
                                    [
                                        114.34088,
                                        22.733906
                                    ],
                                    [
                                        114.340915,
                                        22.732479
                                    ],
                                    [
                                        114.340923,
                                        22.732164
                                    ],
                                    [
                                        114.341019,
                                        22.729262
                                    ],
                                    [
                                        114.340708,
                                        22.726996
                                    ],
                                    [
                                        114.340601,
                                        22.726465
                                    ],
                                    [
                                        114.346013,
                                        22.72621
                                    ],
                                    [
                                        114.34936,
                                        22.717541
                                    ],
                                    [
                                        114.347837,
                                        22.713958
                                    ],
                                    [
                                        114.346717,
                                        22.713617
                                    ],
                                    [
                                        114.34543,
                                        22.712964
                                    ],
                                    [
                                        114.344443,
                                        22.713459
                                    ],
                                    [
                                        114.342511,
                                        22.712568
                                    ],
                                    [
                                        114.341203,
                                        22.712548
                                    ],
                                    [
                                        114.340344,
                                        22.711737
                                    ],
                                    [
                                        114.339765,
                                        22.711321
                                    ],
                                    [
                                        114.338971,
                                        22.711202
                                    ],
                                    [
                                        114.338027,
                                        22.710985
                                    ],
                                    [
                                        114.336094,
                                        22.711235
                                    ],
                                    [
                                        114.333303,
                                        22.711176
                                    ],
                                    [
                                        114.330643,
                                        22.710681
                                    ],
                                    [
                                        114.328754,
                                        22.710562
                                    ],
                                    [
                                        114.328754,
                                        22.709978
                                    ],
                                    [
                                        114.328859,
                                        22.708663
                                    ],
                                    [
                                        114.328829,
                                        22.708354
                                    ],
                                    [
                                        114.328915,
                                        22.707998
                                    ],
                                    [
                                        114.328946,
                                        22.707414
                                    ],
                                    [
                                        114.328701,
                                        22.706726
                                    ],
                                    [
                                        114.328593,
                                        22.706194
                                    ],
                                    [
                                        114.328433,
                                        22.705404
                                    ],
                                    [
                                        114.328358,
                                        22.705087
                                    ],
                                    [
                                        114.328261,
                                        22.704637
                                    ],
                                    [
                                        114.328084,
                                        22.704439
                                    ],
                                    [
                                        114.327467,
                                        22.704775
                                    ],
                                    [
                                        114.326837,
                                        22.705107
                                    ],
                                    [
                                        114.326053,
                                        22.70427
                                    ],
                                    [
                                        114.325778,
                                        22.704469
                                    ],
                                    [
                                        114.325215,
                                        22.704574
                                    ],
                                    [
                                        114.325076,
                                        22.704612
                                    ],
                                    [
                                        114.324294,
                                        22.704577
                                    ],
                                    [
                                        114.323916,
                                        22.704563
                                    ],
                                    [
                                        114.324101,
                                        22.703473
                                    ],
                                    [
                                        114.323913,
                                        22.70325
                                    ],
                                    [
                                        114.323805,
                                        22.703112
                                    ],
                                    [
                                        114.323693,
                                        22.702998
                                    ],
                                    [
                                        114.323602,
                                        22.702894
                                    ],
                                    [
                                        114.32351,
                                        22.702751
                                    ],
                                    [
                                        114.323371,
                                        22.702562
                                    ],
                                    [
                                        114.323269,
                                        22.702473
                                    ],
                                    [
                                        114.322534,
                                        22.702939
                                    ],
                                    [
                                        114.321358,
                                        22.703577
                                    ],
                                    [
                                        114.321232,
                                        22.703431
                                    ],
                                    [
                                        114.320604,
                                        22.702328
                                    ],
                                    [
                                        114.322685,
                                        22.700894
                                    ],
                                    [
                                        114.323487,
                                        22.700408
                                    ],
                                    [
                                        114.323331,
                                        22.700116
                                    ],
                                    [
                                        114.323388,
                                        22.699088
                                    ],
                                    [
                                        114.323243,
                                        22.698766
                                    ],
                                    [
                                        114.323194,
                                        22.697846
                                    ],
                                    [
                                        114.323173,
                                        22.697711
                                    ],
                                    [
                                        114.32305,
                                        22.696627
                                    ],
                                    [
                                        114.32298,
                                        22.695915
                                    ],
                                    [
                                        114.322814,
                                        22.694514
                                    ],
                                    [
                                        114.322787,
                                        22.69421
                                    ],
                                    [
                                        114.322733,
                                        22.693593
                                    ],
                                    [
                                        114.322632,
                                        22.692702
                                    ],
                                    [
                                        114.32264,
                                        22.69259
                                    ],
                                    [
                                        114.322628,
                                        22.692344
                                    ],
                                    [
                                        114.322562,
                                        22.691786
                                    ],
                                    [
                                        114.322589,
                                        22.690529
                                    ],
                                    [
                                        114.322668,
                                        22.690101
                                    ],
                                    [
                                        114.322757,
                                        22.689156
                                    ],
                                    [
                                        114.322873,
                                        22.68835
                                    ],
                                    [
                                        114.32077,
                                        22.689835
                                    ],
                                    [
                                        114.318569,
                                        22.691192
                                    ],
                                    [
                                        114.317959,
                                        22.690053
                                    ],
                                    [
                                        114.317122,
                                        22.688469
                                    ],
                                    [
                                        114.316919,
                                        22.688128
                                    ],
                                    [
                                        114.316099,
                                        22.686662
                                    ],
                                    [
                                        114.31253,
                                        22.686059
                                    ],
                                    [
                                        114.310287,
                                        22.685796
                                    ],
                                    [
                                        114.308299,
                                        22.685837
                                    ],
                                    [
                                        114.306354,
                                        22.685859
                                    ],
                                    [
                                        114.303999,
                                        22.685875
                                    ],
                                    [
                                        114.302412,
                                        22.685838
                                    ],
                                    [
                                        114.302221,
                                        22.685299
                                    ],
                                    [
                                        114.302079,
                                        22.684381
                                    ],
                                    [
                                        114.301167,
                                        22.683579
                                    ],
                                    [
                                        114.301087,
                                        22.683487
                                    ],
                                    [
                                        114.299557,
                                        22.681707
                                    ],
                                    [
                                        114.298999,
                                        22.681222
                                    ],
                                    [
                                        114.297208,
                                        22.680678
                                    ],
                                    [
                                        114.296553,
                                        22.680727
                                    ],
                                    [
                                        114.295458,
                                        22.681212
                                    ],
                                    [
                                        114.294482,
                                        22.68143
                                    ],
                                    [
                                        114.293913,
                                        22.681608
                                    ],
                                    [
                                        114.293366,
                                        22.68143
                                    ],
                                    [
                                        114.293227,
                                        22.680826
                                    ],
                                    [
                                        114.292336,
                                        22.680183
                                    ],
                                    [
                                        114.29136,
                                        22.679628
                                    ],
                                    [
                                        114.290952,
                                        22.678589
                                    ],
                                    [
                                        114.290545,
                                        22.677609
                                    ],
                                    [
                                        114.289751,
                                        22.677104
                                    ],
                                    [
                                        114.288452,
                                        22.67751
                                    ],
                                    [
                                        114.287626,
                                        22.67747
                                    ],
                                    [
                                        114.285973,
                                        22.678242
                                    ],
                                    [
                                        114.285082,
                                        22.678084
                                    ],
                                    [
                                        114.284267,
                                        22.677381
                                    ],
                                    [
                                        114.283816,
                                        22.676797
                                    ],
                                    [
                                        114.283913,
                                        22.675965
                                    ],
                                    [
                                        114.283162,
                                        22.675391
                                    ],
                                    [
                                        114.282217,
                                        22.675649
                                    ],
                                    [
                                        114.281273,
                                        22.675629
                                    ],
                                    [
                                        114.27793,
                                        22.675029
                                    ],
                                    [
                                        114.276746,
                                        22.674817
                                    ],
                                    [
                                        114.276166,
                                        22.674045
                                    ],
                                    [
                                        114.275308,
                                        22.673847
                                    ],
                                    [
                                        114.274793,
                                        22.673827
                                    ],
                                    [
                                        114.273355,
                                        22.673491
                                    ],
                                    [
                                        114.273162,
                                        22.672936
                                    ],
                                    [
                                        114.272755,
                                        22.672075
                                    ],
                                    [
                                        114.271939,
                                        22.670619
                                    ],
                                    [
                                        114.272422,
                                        22.669837
                                    ],
                                    [
                                        114.272251,
                                        22.66955
                                    ],
                                    [
                                        114.271671,
                                        22.668926
                                    ],
                                    [
                                        114.270773,
                                        22.668202
                                    ],
                                    [
                                        114.270854,
                                        22.667489
                                    ],
                                    [
                                        114.271234,
                                        22.66693
                                    ],
                                    [
                                        114.269953,
                                        22.666593
                                    ],
                                    [
                                        114.269562,
                                        22.666192
                                    ],
                                    [
                                        114.269132,
                                        22.665717
                                    ],
                                    [
                                        114.26924,
                                        22.665261
                                    ],
                                    [
                                        114.268011,
                                        22.664653
                                    ],
                                    [
                                        114.268022,
                                        22.664192
                                    ],
                                    [
                                        114.267276,
                                        22.663059
                                    ],
                                    [
                                        114.267002,
                                        22.662029
                                    ],
                                    [
                                        114.267194,
                                        22.661565
                                    ],
                                    [
                                        114.267625,
                                        22.660524
                                    ],
                                    [
                                        114.267281,
                                        22.659712
                                    ],
                                    [
                                        114.267389,
                                        22.657534
                                    ],
                                    [
                                        114.268118,
                                        22.656187
                                    ],
                                    [
                                        114.269789,
                                        22.653829
                                    ],
                                    [
                                        114.269225,
                                        22.653397
                                    ],
                                    [
                                        114.267542,
                                        22.652623
                                    ],
                                    [
                                        114.266212,
                                        22.651683
                                    ],
                                    [
                                        114.264323,
                                        22.650538
                                    ],
                                    [
                                        114.263474,
                                        22.649634
                                    ],
                                    [
                                        114.262618,
                                        22.648949
                                    ],
                                    [
                                        114.262244,
                                        22.648789
                                    ],
                                    [
                                        114.2614,
                                        22.64865
                                    ],
                                    [
                                        114.260339,
                                        22.647179
                                    ],
                                    [
                                        114.260286,
                                        22.646415
                                    ],
                                    [
                                        114.259533,
                                        22.644137
                                    ],
                                    [
                                        114.259534,
                                        22.643075
                                    ],
                                    [
                                        114.259332,
                                        22.642496
                                    ],
                                    [
                                        114.258586,
                                        22.64147
                                    ],
                                    [
                                        114.257972,
                                        22.640807
                                    ],
                                    [
                                        114.258381,
                                        22.639178
                                    ],
                                    [
                                        114.259059,
                                        22.637586
                                    ],
                                    [
                                        114.258926,
                                        22.636551
                                    ],
                                    [
                                        114.258966,
                                        22.635561
                                    ],
                                    [
                                        114.258779,
                                        22.634914
                                    ],
                                    [
                                        114.258704,
                                        22.634184
                                    ],
                                    [
                                        114.259034,
                                        22.633895
                                    ],
                                    [
                                        114.259874,
                                        22.633456
                                    ],
                                    [
                                        114.261192,
                                        22.632463
                                    ],
                                    [
                                        114.263099,
                                        22.631229
                                    ],
                                    [
                                        114.263838,
                                        22.630181
                                    ],
                                    [
                                        114.265214,
                                        22.629217
                                    ],
                                    [
                                        114.266111,
                                        22.628416
                                    ],
                                    [
                                        114.266186,
                                        22.628304
                                    ],
                                    [
                                        114.26633,
                                        22.626272
                                    ],
                                    [
                                        114.265836,
                                        22.625268
                                    ],
                                    [
                                        114.265313,
                                        22.622558
                                    ],
                                    [
                                        114.262981,
                                        22.62044
                                    ],
                                    [
                                        114.259886,
                                        22.61887
                                    ],
                                    [
                                        114.257604,
                                        22.619494
                                    ],
                                    [
                                        114.25583,
                                        22.619738
                                    ],
                                    [
                                        114.254828,
                                        22.620104
                                    ],
                                    [
                                        114.253901,
                                        22.620145
                                    ],
                                    [
                                        114.252971,
                                        22.62031
                                    ],
                                    [
                                        114.251749,
                                        22.62028
                                    ],
                                    [
                                        114.250923,
                                        22.620356
                                    ],
                                    [
                                        114.249385,
                                        22.620321
                                    ],
                                    [
                                        114.249024,
                                        22.620229
                                    ],
                                    [
                                        114.247923,
                                        22.619456
                                    ],
                                    [
                                        114.247395,
                                        22.619163
                                    ],
                                    [
                                        114.246916,
                                        22.619022
                                    ],
                                    [
                                        114.245188,
                                        22.618002
                                    ],
                                    [
                                        114.244774,
                                        22.617587
                                    ],
                                    [
                                        114.244227,
                                        22.616791
                                    ],
                                    [
                                        114.243485,
                                        22.61607
                                    ],
                                    [
                                        114.240838,
                                        22.615646
                                    ],
                                    [
                                        114.238144,
                                        22.612844
                                    ],
                                    [
                                        114.237106,
                                        22.611877
                                    ],
                                    [
                                        114.237059,
                                        22.611833
                                    ],
                                    [
                                        114.237005,
                                        22.611783
                                    ],
                                    [
                                        114.236966,
                                        22.611743
                                    ],
                                    [
                                        114.236921,
                                        22.611697
                                    ],
                                    [
                                        114.236354,
                                        22.610845
                                    ],
                                    [
                                        114.236243,
                                        22.610733
                                    ],
                                    [
                                        114.236218,
                                        22.610707
                                    ],
                                    [
                                        114.23475,
                                        22.609375
                                    ],
                                    [
                                        114.234422,
                                        22.608837
                                    ],
                                    [
                                        114.234108,
                                        22.607879
                                    ],
                                    [
                                        114.234683,
                                        22.60739
                                    ],
                                    [
                                        114.234844,
                                        22.607082
                                    ],
                                    [
                                        114.235398,
                                        22.605182
                                    ],
                                    [
                                        114.235492,
                                        22.603747
                                    ],
                                    [
                                        114.234721,
                                        22.602414
                                    ],
                                    [
                                        114.233167,
                                        22.601657
                                    ],
                                    [
                                        114.232992,
                                        22.600732
                                    ],
                                    [
                                        114.231546,
                                        22.599246
                                    ],
                                    [
                                        114.230905,
                                        22.598836
                                    ],
                                    [
                                        114.230714,
                                        22.59849
                                    ],
                                    [
                                        114.230543,
                                        22.596066
                                    ],
                                    [
                                        114.230533,
                                        22.595981
                                    ],
                                    [
                                        114.230524,
                                        22.595874
                                    ],
                                    [
                                        114.230512,
                                        22.595447
                                    ],
                                    [
                                        114.230527,
                                        22.595295
                                    ],
                                    [
                                        114.23053,
                                        22.595254
                                    ],
                                    [
                                        114.23036,
                                        22.594836
                                    ],
                                    [
                                        114.229555,
                                        22.593733
                                    ],
                                    [
                                        114.229379,
                                        22.593304
                                    ],
                                    [
                                        114.229064,
                                        22.592108
                                    ],
                                    [
                                        114.229104,
                                        22.591294
                                    ],
                                    [
                                        114.228935,
                                        22.590752
                                    ],
                                    [
                                        114.227488,
                                        22.589779
                                    ],
                                    [
                                        114.227003,
                                        22.589155
                                    ],
                                    [
                                        114.224916,
                                        22.585863
                                    ],
                                    [
                                        114.224769,
                                        22.585529
                                    ],
                                    [
                                        114.224643,
                                        22.584645
                                    ],
                                    [
                                        114.224496,
                                        22.584437
                                    ],
                                    [
                                        114.222286,
                                        22.583734
                                    ],
                                    [
                                        114.221412,
                                        22.583187
                                    ],
                                    [
                                        114.220844,
                                        22.582522
                                    ],
                                    [
                                        114.219509,
                                        22.581654
                                    ],
                                    [
                                        114.219184,
                                        22.581691
                                    ],
                                    [
                                        114.218763,
                                        22.581919
                                    ],
                                    [
                                        114.218891,
                                        22.583076
                                    ],
                                    [
                                        114.219527,
                                        22.58458
                                    ],
                                    [
                                        114.219593,
                                        22.585003
                                    ],
                                    [
                                        114.219352,
                                        22.585877
                                    ],
                                    [
                                        114.219037,
                                        22.587972
                                    ],
                                    [
                                        114.219105,
                                        22.588596
                                    ],
                                    [
                                        114.219021,
                                        22.588915
                                    ],
                                    [
                                        114.218556,
                                        22.589512
                                    ],
                                    [
                                        114.217754,
                                        22.590079
                                    ],
                                    [
                                        114.217635,
                                        22.590298
                                    ],
                                    [
                                        114.217485,
                                        22.591033
                                    ],
                                    [
                                        114.216721,
                                        22.59246
                                    ],
                                    [
                                        114.216158,
                                        22.593137
                                    ],
                                    [
                                        114.215775,
                                        22.593767
                                    ],
                                    [
                                        114.213677,
                                        22.59607
                                    ],
                                    [
                                        114.213704,
                                        22.596583
                                    ],
                                    [
                                        114.214085,
                                        22.59829
                                    ],
                                    [
                                        114.214031,
                                        22.598876
                                    ],
                                    [
                                        114.213842,
                                        22.599288
                                    ],
                                    [
                                        114.213228,
                                        22.599614
                                    ],
                                    [
                                        114.212641,
                                        22.599632
                                    ],
                                    [
                                        114.211343,
                                        22.599338
                                    ],
                                    [
                                        114.210086,
                                        22.598889
                                    ],
                                    [
                                        114.209512,
                                        22.598772
                                    ],
                                    [
                                        114.208871,
                                        22.599357
                                    ],
                                    [
                                        114.207583,
                                        22.601157
                                    ],
                                    [
                                        114.206973,
                                        22.601653
                                    ],
                                    [
                                        114.205452,
                                        22.601953
                                    ],
                                    [
                                        114.204079,
                                        22.601417
                                    ],
                                    [
                                        114.203151,
                                        22.601184
                                    ],
                                    [
                                        114.202343,
                                        22.601505
                                    ],
                                    [
                                        114.201067,
                                        22.602186
                                    ],
                                    [
                                        114.200081,
                                        22.602383
                                    ],
                                    [
                                        114.198867,
                                        22.60304
                                    ],
                                    [
                                        114.198742,
                                        22.60325
                                    ],
                                    [
                                        114.198788,
                                        22.603977
                                    ],
                                    [
                                        114.198702,
                                        22.604842
                                    ],
                                    [
                                        114.198901,
                                        22.605669
                                    ],
                                    [
                                        114.199242,
                                        22.606371
                                    ],
                                    [
                                        114.200202,
                                        22.607034
                                    ],
                                    [
                                        114.200348,
                                        22.607492
                                    ],
                                    [
                                        114.200355,
                                        22.60774
                                    ],
                                    [
                                        114.199882,
                                        22.609093
                                    ],
                                    [
                                        114.199861,
                                        22.609124
                                    ],
                                    [
                                        114.199765,
                                        22.609247
                                    ],
                                    [
                                        114.199502,
                                        22.6096
                                    ],
                                    [
                                        114.199387,
                                        22.609757
                                    ],
                                    [
                                        114.196861,
                                        22.613296
                                    ],
                                    [
                                        114.192406,
                                        22.61619
                                    ],
                                    [
                                        114.192145,
                                        22.616449
                                    ],
                                    [
                                        114.19169,
                                        22.616084
                                    ],
                                    [
                                        114.188777,
                                        22.615241
                                    ],
                                    [
                                        114.187194,
                                        22.61518
                                    ],
                                    [
                                        114.187185,
                                        22.61518
                                    ],
                                    [
                                        114.187096,
                                        22.615183
                                    ],
                                    [
                                        114.187,
                                        22.615187
                                    ],
                                    [
                                        114.186902,
                                        22.61519
                                    ],
                                    [
                                        114.184766,
                                        22.615289
                                    ],
                                    [
                                        114.183195,
                                        22.614909
                                    ],
                                    [
                                        114.182252,
                                        22.615341
                                    ],
                                    [
                                        114.181786,
                                        22.615914
                                    ],
                                    [
                                        114.181628,
                                        22.61599
                                    ],
                                    [
                                        114.17745,
                                        22.615527
                                    ],
                                    [
                                        114.177174,
                                        22.615588
                                    ],
                                    [
                                        114.176014,
                                        22.614284
                                    ],
                                    [
                                        114.175914,
                                        22.613807
                                    ],
                                    [
                                        114.175158,
                                        22.61219
                                    ],
                                    [
                                        114.173934,
                                        22.610991
                                    ],
                                    [
                                        114.172673,
                                        22.610358
                                    ],
                                    [
                                        114.17063,
                                        22.610244
                                    ],
                                    [
                                        114.167471,
                                        22.609519
                                    ],
                                    [
                                        114.16693,
                                        22.609288
                                    ],
                                    [
                                        114.166184,
                                        22.608646
                                    ],
                                    [
                                        114.166038,
                                        22.608519
                                    ],
                                    [
                                        114.165449,
                                        22.608013
                                    ],
                                    [
                                        114.165302,
                                        22.607886
                                    ],
                                    [
                                        114.164561,
                                        22.607248
                                    ],
                                    [
                                        114.164414,
                                        22.607122
                                    ],
                                    [
                                        114.163972,
                                        22.606755
                                    ],
                                    [
                                        114.163908,
                                        22.606709
                                    ],
                                    [
                                        114.163815,
                                        22.606642
                                    ],
                                    [
                                        114.163782,
                                        22.606619
                                    ],
                                    [
                                        114.163752,
                                        22.606596
                                    ],
                                    [
                                        114.163696,
                                        22.606555
                                    ],
                                    [
                                        114.16362,
                                        22.606499
                                    ],
                                    [
                                        114.163541,
                                        22.60644
                                    ],
                                    [
                                        114.163465,
                                        22.606384
                                    ],
                                    [
                                        114.161638,
                                        22.605271
                                    ],
                                    [
                                        114.161572,
                                        22.604487
                                    ],
                                    [
                                        114.160886,
                                        22.603346
                                    ],
                                    [
                                        114.160279,
                                        22.601884
                                    ],
                                    [
                                        114.159944,
                                        22.601389
                                    ],
                                    [
                                        114.159579,
                                        22.601232
                                    ],
                                    [
                                        114.159134,
                                        22.601195
                                    ],
                                    [
                                        114.157929,
                                        22.601334
                                    ],
                                    [
                                        114.154824,
                                        22.601445
                                    ],
                                    [
                                        114.154747,
                                        22.60145
                                    ],
                                    [
                                        114.154631,
                                        22.601454
                                    ],
                                    [
                                        114.15425,
                                        22.601428
                                    ],
                                    [
                                        114.153528,
                                        22.600911
                                    ],
                                    [
                                        114.152438,
                                        22.600394
                                    ],
                                    [
                                        114.152247,
                                        22.600358
                                    ],
                                    [
                                        114.151339,
                                        22.600002
                                    ],
                                    [
                                        114.150262,
                                        22.599342
                                    ],
                                    [
                                        114.146624,
                                        22.596017
                                    ],
                                    [
                                        114.146597,
                                        22.595994
                                    ],
                                    [
                                        114.146478,
                                        22.59589
                                    ],
                                    [
                                        114.146399,
                                        22.595822
                                    ],
                                    [
                                        114.146363,
                                        22.595791
                                    ],
                                    [
                                        114.146251,
                                        22.595698
                                    ],
                                    [
                                        114.146147,
                                        22.595613
                                    ],
                                    [
                                        114.146049,
                                        22.595533
                                    ],
                                    [
                                        114.14601,
                                        22.595499
                                    ],
                                    [
                                        114.146004,
                                        22.595483
                                    ],
                                    [
                                        114.145768,
                                        22.594911
                                    ],
                                    [
                                        114.145823,
                                        22.594669
                                    ],
                                    [
                                        114.145873,
                                        22.594481
                                    ],
                                    [
                                        114.145945,
                                        22.594116
                                    ],
                                    [
                                        114.145958,
                                        22.593844
                                    ],
                                    [
                                        114.145959,
                                        22.593802
                                    ],
                                    [
                                        114.145957,
                                        22.592811
                                    ],
                                    [
                                        114.145693,
                                        22.592358
                                    ],
                                    [
                                        114.145053,
                                        22.591772
                                    ],
                                    [
                                        114.144299,
                                        22.591268
                                    ],
                                    [
                                        114.143284,
                                        22.591405
                                    ],
                                    [
                                        114.141934,
                                        22.591243
                                    ],
                                    [
                                        114.141456,
                                        22.591084
                                    ],
                                    [
                                        114.139994,
                                        22.590331
                                    ],
                                    [
                                        114.13979,
                                        22.590095
                                    ],
                                    [
                                        114.139319,
                                        22.589018
                                    ],
                                    [
                                        114.139069,
                                        22.588748
                                    ],
                                    [
                                        114.138444,
                                        22.58874
                                    ],
                                    [
                                        114.136787,
                                        22.588331
                                    ],
                                    [
                                        114.135606,
                                        22.588144
                                    ],
                                    [
                                        114.13528,
                                        22.588108
                                    ],
                                    [
                                        114.134236,
                                        22.588814
                                    ],
                                    [
                                        114.13388,
                                        22.589161
                                    ],
                                    [
                                        114.133204,
                                        22.588735
                                    ],
                                    [
                                        114.133097,
                                        22.588299
                                    ],
                                    [
                                        114.131852,
                                        22.587407
                                    ],
                                    [
                                        114.130822,
                                        22.586694
                                    ],
                                    [
                                        114.13049,
                                        22.587318
                                    ],
                                    [
                                        114.130275,
                                        22.587676
                                    ],
                                    [
                                        114.129869,
                                        22.588308
                                    ],
                                    [
                                        114.129348,
                                        22.588701
                                    ],
                                    [
                                        114.128704,
                                        22.588944
                                    ],
                                    [
                                        114.12602,
                                        22.588761
                                    ],
                                    [
                                        114.12493,
                                        22.588682
                                    ],
                                    [
                                        114.124796,
                                        22.588661
                                    ],
                                    [
                                        114.124542,
                                        22.588289
                                    ],
                                    [
                                        114.123719,
                                        22.58773
                                    ],
                                    [
                                        114.123564,
                                        22.587968
                                    ],
                                    [
                                        114.123462,
                                        22.587963
                                    ],
                                    [
                                        114.12343,
                                        22.588161
                                    ],
                                    [
                                        114.123467,
                                        22.588929
                                    ],
                                    [
                                        114.123263,
                                        22.588939
                                    ],
                                    [
                                        114.122856,
                                        22.588973
                                    ],
                                    [
                                        114.122662,
                                        22.588988
                                    ],
                                    [
                                        114.122209,
                                        22.589007
                                    ],
                                    [
                                        114.122192,
                                        22.589041
                                    ],
                                    [
                                        114.122051,
                                        22.589317
                                    ],
                                    [
                                        114.121915,
                                        22.589584
                                    ],
                                    [
                                        114.121722,
                                        22.590666
                                    ],
                                    [
                                        114.121215,
                                        22.590506
                                    ],
                                    [
                                        114.119978,
                                        22.590116
                                    ],
                                    [
                                        114.119948,
                                        22.590107
                                    ],
                                    [
                                        114.119849,
                                        22.590075
                                    ],
                                    [
                                        114.119557,
                                        22.589983
                                    ],
                                    [
                                        114.117447,
                                        22.591251
                                    ],
                                    [
                                        114.115691,
                                        22.590902
                                    ],
                                    [
                                        114.115508,
                                        22.590837
                                    ],
                                    [
                                        114.115069,
                                        22.590714
                                    ],
                                    [
                                        114.114983,
                                        22.590702
                                    ],
                                    [
                                        114.11497,
                                        22.5907
                                    ],
                                    [
                                        114.114877,
                                        22.590688
                                    ],
                                    [
                                        114.114778,
                                        22.590676
                                    ],
                                    [
                                        114.114131,
                                        22.590493
                                    ],
                                    [
                                        114.112937,
                                        22.589878
                                    ],
                                    [
                                        114.112879,
                                        22.589847
                                    ],
                                    [
                                        114.112811,
                                        22.589811
                                    ],
                                    [
                                        114.112766,
                                        22.589787
                                    ],
                                    [
                                        114.112738,
                                        22.589772
                                    ],
                                    [
                                        114.112708,
                                        22.589755
                                    ],
                                    [
                                        114.112689,
                                        22.589744
                                    ],
                                    [
                                        114.112562,
                                        22.589674
                                    ],
                                    [
                                        114.112519,
                                        22.589649
                                    ],
                                    [
                                        114.112218,
                                        22.589464
                                    ],
                                    [
                                        114.111573,
                                        22.589357
                                    ],
                                    [
                                        114.111561,
                                        22.589353
                                    ],
                                    [
                                        114.111392,
                                        22.589314
                                    ],
                                    [
                                        114.111385,
                                        22.589313
                                    ],
                                    [
                                        114.110447,
                                        22.589194
                                    ],
                                    [
                                        114.108022,
                                        22.589015
                                    ],
                                    [
                                        114.107486,
                                        22.588193
                                    ],
                                    [
                                        114.106724,
                                        22.588183
                                    ],
                                    [
                                        114.105994,
                                        22.588302
                                    ],
                                    [
                                        114.105881,
                                        22.588793
                                    ],
                                    [
                                        114.105741,
                                        22.589396
                                    ],
                                    [
                                        114.105077,
                                        22.590145
                                    ],
                                    [
                                        114.103704,
                                        22.591266
                                    ],
                                    [
                                        114.103553,
                                        22.591365
                                    ],
                                    [
                                        114.103542,
                                        22.591372
                                    ],
                                    [
                                        114.103222,
                                        22.591579
                                    ],
                                    [
                                        114.10306,
                                        22.591685
                                    ],
                                    [
                                        114.102247,
                                        22.592214
                                    ],
                                    [
                                        114.100931,
                                        22.5927
                                    ],
                                    [
                                        114.100366,
                                        22.592807
                                    ],
                                    [
                                        114.099939,
                                        22.593058
                                    ],
                                    [
                                        114.099735,
                                        22.593308
                                    ],
                                    [
                                        114.099539,
                                        22.594177
                                    ],
                                    [
                                        114.097775,
                                        22.596069
                                    ],
                                    [
                                        114.096739,
                                        22.597389
                                    ],
                                    [
                                        114.095172,
                                        22.598901
                                    ],
                                    [
                                        114.093411,
                                        22.600147
                                    ],
                                    [
                                        114.09222,
                                        22.600078
                                    ],
                                    [
                                        114.09147,
                                        22.599906
                                    ],
                                    [
                                        114.090674,
                                        22.599398
                                    ],
                                    [
                                        114.089843,
                                        22.598586
                                    ],
                                    [
                                        114.089668,
                                        22.598512
                                    ],
                                    [
                                        114.089056,
                                        22.599067
                                    ],
                                    [
                                        114.086078,
                                        22.600389
                                    ],
                                    [
                                        114.085266,
                                        22.600967
                                    ],
                                    [
                                        114.083804,
                                        22.601219
                                    ],
                                    [
                                        114.082876,
                                        22.601197
                                    ],
                                    [
                                        114.081164,
                                        22.600857
                                    ],
                                    [
                                        114.079411,
                                        22.599596
                                    ],
                                    [
                                        114.078856,
                                        22.599039
                                    ],
                                    [
                                        114.077292,
                                        22.598071
                                    ],
                                    [
                                        114.076329,
                                        22.597851
                                    ],
                                    [
                                        114.075523,
                                        22.598098
                                    ],
                                    [
                                        114.075471,
                                        22.598105
                                    ],
                                    [
                                        114.075417,
                                        22.598111
                                    ],
                                    [
                                        114.075369,
                                        22.59811
                                    ],
                                    [
                                        114.075334,
                                        22.598101
                                    ],
                                    [
                                        114.075331,
                                        22.598095
                                    ],
                                    [
                                        114.075242,
                                        22.597386
                                    ],
                                    [
                                        114.075216,
                                        22.597212
                                    ],
                                    [
                                        114.075214,
                                        22.597194
                                    ],
                                    [
                                        114.07531,
                                        22.596547
                                    ],
                                    [
                                        114.075364,
                                        22.596361
                                    ],
                                    [
                                        114.075951,
                                        22.595047
                                    ],
                                    [
                                        114.076325,
                                        22.594627
                                    ],
                                    [
                                        114.076341,
                                        22.594601
                                    ],
                                    [
                                        114.076365,
                                        22.59456
                                    ],
                                    [
                                        114.076384,
                                        22.594524
                                    ],
                                    [
                                        114.076405,
                                        22.594494
                                    ],
                                    [
                                        114.076425,
                                        22.59446
                                    ],
                                    [
                                        114.07644,
                                        22.594435
                                    ],
                                    [
                                        114.076481,
                                        22.594279
                                    ],
                                    [
                                        114.076291,
                                        22.594081
                                    ],
                                    [
                                        114.073605,
                                        22.592416
                                    ],
                                    [
                                        114.071592,
                                        22.592746
                                    ],
                                    [
                                        114.071481,
                                        22.59281
                                    ],
                                    [
                                        114.069936,
                                        22.595511
                                    ],
                                    [
                                        114.069009,
                                        22.596463
                                    ],
                                    [
                                        114.067664,
                                        22.597117
                                    ],
                                    [
                                        114.067363,
                                        22.597109
                                    ],
                                    [
                                        114.066202,
                                        22.596646
                                    ],
                                    [
                                        114.065562,
                                        22.596626
                                    ],
                                    [
                                        114.064083,
                                        22.59802
                                    ],
                                    [
                                        114.063924,
                                        22.598431
                                    ],
                                    [
                                        114.063854,
                                        22.598612
                                    ],
                                    [
                                        114.063791,
                                        22.598803
                                    ],
                                    [
                                        114.063784,
                                        22.598878
                                    ],
                                    [
                                        114.063757,
                                        22.598993
                                    ],
                                    [
                                        114.063457,
                                        22.599291
                                    ],
                                    [
                                        114.062467,
                                        22.599253
                                    ],
                                    [
                                        114.062247,
                                        22.599373
                                    ],
                                    [
                                        114.061853,
                                        22.598742
                                    ],
                                    [
                                        114.062586,
                                        22.597345
                                    ],
                                    [
                                        114.062999,
                                        22.59699
                                    ],
                                    [
                                        114.063059,
                                        22.596938
                                    ],
                                    [
                                        114.063117,
                                        22.596888
                                    ],
                                    [
                                        114.063147,
                                        22.596863
                                    ],
                                    [
                                        114.063206,
                                        22.596811
                                    ],
                                    [
                                        114.063234,
                                        22.596787
                                    ],
                                    [
                                        114.063264,
                                        22.596762
                                    ],
                                    [
                                        114.063444,
                                        22.596606
                                    ],
                                    [
                                        114.063002,
                                        22.596181
                                    ],
                                    [
                                        114.062863,
                                        22.596046
                                    ],
                                    [
                                        114.062768,
                                        22.595954
                                    ],
                                    [
                                        114.062628,
                                        22.59582
                                    ],
                                    [
                                        114.062515,
                                        22.595676
                                    ],
                                    [
                                        114.06216,
                                        22.595911
                                    ],
                                    [
                                        114.061274,
                                        22.597528
                                    ],
                                    [
                                        114.060797,
                                        22.598017
                                    ],
                                    [
                                        114.060896,
                                        22.598109
                                    ],
                                    [
                                        114.060419,
                                        22.601391
                                    ],
                                    [
                                        114.059131,
                                        22.6021
                                    ],
                                    [
                                        114.058156,
                                        22.602929
                                    ],
                                    [
                                        114.05864,
                                        22.6038
                                    ],
                                    [
                                        114.05929,
                                        22.605355
                                    ],
                                    [
                                        114.059363,
                                        22.605517
                                    ],
                                    [
                                        114.059369,
                                        22.605532
                                    ],
                                    [
                                        114.059431,
                                        22.605671
                                    ],
                                    [
                                        114.059442,
                                        22.605694
                                    ],
                                    [
                                        114.059511,
                                        22.605847
                                    ],
                                    [
                                        114.059674,
                                        22.606696
                                    ],
                                    [
                                        114.059678,
                                        22.606731
                                    ],
                                    [
                                        114.059698,
                                        22.606888
                                    ],
                                    [
                                        114.059703,
                                        22.607008
                                    ],
                                    [
                                        114.059708,
                                        22.60714
                                    ],
                                    [
                                        114.059707,
                                        22.607202
                                    ],
                                    [
                                        114.058998,
                                        22.610544
                                    ],
                                    [
                                        114.058955,
                                        22.610733
                                    ],
                                    [
                                        114.058508,
                                        22.612672
                                    ],
                                    [
                                        114.057571,
                                        22.613713
                                    ],
                                    [
                                        114.056786,
                                        22.614329
                                    ],
                                    [
                                        114.056638,
                                        22.614542
                                    ],
                                    [
                                        114.056503,
                                        22.616412
                                    ],
                                    [
                                        114.056499,
                                        22.616464
                                    ],
                                    [
                                        114.056489,
                                        22.616605
                                    ],
                                    [
                                        114.056485,
                                        22.616657
                                    ],
                                    [
                                        114.056399,
                                        22.617849
                                    ],
                                    [
                                        114.056256,
                                        22.617977
                                    ],
                                    [
                                        114.056314,
                                        22.618653
                                    ],
                                    [
                                        114.056558,
                                        22.619366
                                    ],
                                    [
                                        114.0565,
                                        22.621129
                                    ],
                                    [
                                        114.056206,
                                        22.621466
                                    ],
                                    [
                                        114.055569,
                                        22.621907
                                    ],
                                    [
                                        114.05551,
                                        22.621949
                                    ],
                                    [
                                        114.055412,
                                        22.622019
                                    ],
                                    [
                                        114.055352,
                                        22.622062
                                    ],
                                    [
                                        114.054651,
                                        22.622566
                                    ],
                                    [
                                        114.054286,
                                        22.622151
                                    ],
                                    [
                                        114.054699,
                                        22.61959
                                    ],
                                    [
                                        114.054713,
                                        22.619507
                                    ],
                                    [
                                        114.05473,
                                        22.619399
                                    ],
                                    [
                                        114.054744,
                                        22.619315
                                    ],
                                    [
                                        114.054961,
                                        22.617968
                                    ],
                                    [
                                        114.054852,
                                        22.617801
                                    ],
                                    [
                                        114.054646,
                                        22.61782
                                    ],
                                    [
                                        114.05353,
                                        22.618426
                                    ],
                                    [
                                        114.053512,
                                        22.618919
                                    ],
                                    [
                                        114.053508,
                                        22.619007
                                    ],
                                    [
                                        114.053505,
                                        22.619112
                                    ],
                                    [
                                        114.053501,
                                        22.619201
                                    ],
                                    [
                                        114.053388,
                                        22.621898
                                    ],
                                    [
                                        114.053632,
                                        22.622387
                                    ],
                                    [
                                        114.053516,
                                        22.622681
                                    ],
                                    [
                                        114.053544,
                                        22.623343
                                    ],
                                    [
                                        114.053552,
                                        22.623537
                                    ],
                                    [
                                        114.053613,
                                        22.624212
                                    ],
                                    [
                                        114.053613,
                                        22.6243
                                    ],
                                    [
                                        114.053617,
                                        22.624406
                                    ],
                                    [
                                        114.053526,
                                        22.624831
                                    ],
                                    [
                                        114.052937,
                                        22.625125
                                    ],
                                    [
                                        114.052808,
                                        22.625188
                                    ],
                                    [
                                        114.052764,
                                        22.625212
                                    ],
                                    [
                                        114.052149,
                                        22.625696
                                    ],
                                    [
                                        114.051207,
                                        22.626231
                                    ],
                                    [
                                        114.051001,
                                        22.626673
                                    ],
                                    [
                                        114.050993,
                                        22.626738
                                    ],
                                    [
                                        114.050988,
                                        22.626773
                                    ],
                                    [
                                        114.050987,
                                        22.626778
                                    ],
                                    [
                                        114.050961,
                                        22.626848
                                    ],
                                    [
                                        114.050967,
                                        22.626921
                                    ],
                                    [
                                        114.050967,
                                        22.62693
                                    ],
                                    [
                                        114.051121,
                                        22.627065
                                    ],
                                    [
                                        114.051467,
                                        22.628944
                                    ],
                                    [
                                        114.052428,
                                        22.628986
                                    ],
                                    [
                                        114.052878,
                                        22.629162
                                    ],
                                    [
                                        114.053025,
                                        22.629486
                                    ],
                                    [
                                        114.052864,
                                        22.630044
                                    ],
                                    [
                                        114.053157,
                                        22.630538
                                    ],
                                    [
                                        114.053119,
                                        22.632252
                                    ],
                                    [
                                        114.052667,
                                        22.632253
                                    ],
                                    [
                                        114.052676,
                                        22.632673
                                    ],
                                    [
                                        114.052152,
                                        22.6327
                                    ],
                                    [
                                        114.05211,
                                        22.633512
                                    ],
                                    [
                                        114.052066,
                                        22.63388
                                    ],
                                    [
                                        114.05204,
                                        22.633933
                                    ],
                                    [
                                        114.05201,
                                        22.634203
                                    ],
                                    [
                                        114.051985,
                                        22.634307
                                    ],
                                    [
                                        114.051967,
                                        22.634393
                                    ],
                                    [
                                        114.051947,
                                        22.634577
                                    ],
                                    [
                                        114.051963,
                                        22.634618
                                    ],
                                    [
                                        114.051994,
                                        22.634718
                                    ],
                                    [
                                        114.052009,
                                        22.634761
                                    ],
                                    [
                                        114.052211,
                                        22.635359
                                    ],
                                    [
                                        114.052226,
                                        22.635416
                                    ],
                                    [
                                        114.052274,
                                        22.635543
                                    ],
                                    [
                                        114.052279,
                                        22.635557
                                    ],
                                    [
                                        114.052301,
                                        22.635594
                                    ],
                                    [
                                        114.053326,
                                        22.635513
                                    ],
                                    [
                                        114.054861,
                                        22.635216
                                    ],
                                    [
                                        114.054893,
                                        22.635209
                                    ],
                                    [
                                        114.054918,
                                        22.635203
                                    ],
                                    [
                                        114.05505,
                                        22.635171
                                    ],
                                    [
                                        114.055068,
                                        22.635167
                                    ],
                                    [
                                        114.055107,
                                        22.635157
                                    ],
                                    [
                                        114.055848,
                                        22.634971
                                    ],
                                    [
                                        114.056022,
                                        22.635741
                                    ],
                                    [
                                        114.056031,
                                        22.635778
                                    ],
                                    [
                                        114.056021,
                                        22.635839
                                    ],
                                    [
                                        114.056084,
                                        22.636149
                                    ],
                                    [
                                        114.056132,
                                        22.636238
                                    ],
                                    [
                                        114.056178,
                                        22.636525
                                    ],
                                    [
                                        114.055173,
                                        22.638259
                                    ],
                                    [
                                        114.055134,
                                        22.638318
                                    ],
                                    [
                                        114.055067,
                                        22.638421
                                    ],
                                    [
                                        114.055027,
                                        22.638479
                                    ],
                                    [
                                        114.054946,
                                        22.638594
                                    ],
                                    [
                                        114.054919,
                                        22.638639
                                    ],
                                    [
                                        114.054187,
                                        22.640229
                                    ],
                                    [
                                        114.054601,
                                        22.641386
                                    ],
                                    [
                                        114.054853,
                                        22.641784
                                    ],
                                    [
                                        114.055216,
                                        22.642062
                                    ],
                                    [
                                        114.055648,
                                        22.642136
                                    ],
                                    [
                                        114.055936,
                                        22.642338
                                    ],
                                    [
                                        114.055175,
                                        22.646325
                                    ],
                                    [
                                        114.05509,
                                        22.646407
                                    ],
                                    [
                                        114.055,
                                        22.64644
                                    ],
                                    [
                                        114.054987,
                                        22.646445
                                    ],
                                    [
                                        114.054912,
                                        22.646479
                                    ],
                                    [
                                        114.054823,
                                        22.646518
                                    ],
                                    [
                                        114.053395,
                                        22.647382
                                    ],
                                    [
                                        114.050995,
                                        22.647235
                                    ],
                                    [
                                        114.050926,
                                        22.647231
                                    ],
                                    [
                                        114.050801,
                                        22.647223
                                    ],
                                    [
                                        114.050732,
                                        22.647219
                                    ],
                                    [
                                        114.050231,
                                        22.647168
                                    ],
                                    [
                                        114.050093,
                                        22.647427
                                    ],
                                    [
                                        114.05113,
                                        22.650226
                                    ],
                                    [
                                        114.051279,
                                        22.650283
                                    ],
                                    [
                                        114.052191,
                                        22.649878
                                    ],
                                    [
                                        114.052245,
                                        22.649855
                                    ],
                                    [
                                        114.052369,
                                        22.649799
                                    ],
                                    [
                                        114.052422,
                                        22.649776
                                    ],
                                    [
                                        114.054703,
                                        22.649052
                                    ],
                                    [
                                        114.054792,
                                        22.649026
                                    ],
                                    [
                                        114.054889,
                                        22.648998
                                    ],
                                    [
                                        114.054973,
                                        22.648974
                                    ],
                                    [
                                        114.054973,
                                        22.648998
                                    ],
                                    [
                                        114.054968,
                                        22.64905
                                    ],
                                    [
                                        114.054674,
                                        22.65594
                                    ],
                                    [
                                        114.054668,
                                        22.656067
                                    ],
                                    [
                                        114.054665,
                                        22.656134
                                    ],
                                    [
                                        114.054541,
                                        22.658865
                                    ],
                                    [
                                        114.054537,
                                        22.658921
                                    ],
                                    [
                                        114.054534,
                                        22.658983
                                    ],
                                    [
                                        114.054532,
                                        22.659059
                                    ],
                                    [
                                        114.054532,
                                        22.659084
                                    ],
                                    [
                                        114.05453,
                                        22.659115
                                    ],
                                    [
                                        114.054518,
                                        22.659526
                                    ],
                                    [
                                        114.055476,
                                        22.659986
                                    ],
                                    [
                                        114.056012,
                                        22.66041
                                    ],
                                    [
                                        114.056179,
                                        22.660836
                                    ],
                                    [
                                        114.056206,
                                        22.660903
                                    ],
                                    [
                                        114.056221,
                                        22.660943
                                    ],
                                    [
                                        114.056241,
                                        22.660999
                                    ],
                                    [
                                        114.056247,
                                        22.661018
                                    ],
                                    [
                                        114.056279,
                                        22.661117
                                    ],
                                    [
                                        114.056282,
                                        22.661127
                                    ],
                                    [
                                        114.05648,
                                        22.661822
                                    ],
                                    [
                                        114.056509,
                                        22.662651
                                    ],
                                    [
                                        114.056107,
                                        22.66325
                                    ],
                                    [
                                        114.055788,
                                        22.663537
                                    ],
                                    [
                                        114.054826,
                                        22.663812
                                    ],
                                    [
                                        114.054297,
                                        22.664535
                                    ],
                                    [
                                        114.05418,
                                        22.664877
                                    ],
                                    [
                                        114.05417,
                                        22.665906
                                    ],
                                    [
                                        114.054287,
                                        22.666102
                                    ],
                                    [
                                        114.057502,
                                        22.665613
                                    ],
                                    [
                                        114.057609,
                                        22.665597
                                    ],
                                    [
                                        114.05768,
                                        22.665651
                                    ],
                                    [
                                        114.057763,
                                        22.665715
                                    ],
                                    [
                                        114.058056,
                                        22.665581
                                    ],
                                    [
                                        114.058127,
                                        22.665512
                                    ],
                                    [
                                        114.058342,
                                        22.66538
                                    ],
                                    [
                                        114.058457,
                                        22.665324
                                    ],
                                    [
                                        114.058697,
                                        22.665222
                                    ],
                                    [
                                        114.059344,
                                        22.664862
                                    ],
                                    [
                                        114.059376,
                                        22.664848
                                    ],
                                    [
                                        114.059422,
                                        22.664842
                                    ],
                                    [
                                        114.059445,
                                        22.664863
                                    ],
                                    [
                                        114.059487,
                                        22.664911
                                    ],
                                    [
                                        114.059506,
                                        22.664931
                                    ],
                                    [
                                        114.061344,
                                        22.667141
                                    ],
                                    [
                                        114.061784,
                                        22.667831
                                    ],
                                    [
                                        114.061801,
                                        22.667854
                                    ],
                                    [
                                        114.061815,
                                        22.667879
                                    ],
                                    [
                                        114.062364,
                                        22.668739
                                    ],
                                    [
                                        114.062908,
                                        22.669373
                                    ],
                                    [
                                        114.062889,
                                        22.669779
                                    ],
                                    [
                                        114.062032,
                                        22.671031
                                    ],
                                    [
                                        114.061965,
                                        22.671808
                                    ],
                                    [
                                        114.062087,
                                        22.672131
                                    ],
                                    [
                                        114.062822,
                                        22.672595
                                    ],
                                    [
                                        114.063267,
                                        22.673626
                                    ],
                                    [
                                        114.063285,
                                        22.673662
                                    ],
                                    [
                                        114.063305,
                                        22.673702
                                    ],
                                    [
                                        114.063328,
                                        22.673749
                                    ],
                                    [
                                        114.063362,
                                        22.673795
                                    ],
                                    [
                                        114.063386,
                                        22.673828
                                    ],
                                    [
                                        114.063412,
                                        22.673863
                                    ],
                                    [
                                        114.063884,
                                        22.674477
                                    ],
                                    [
                                        114.064062,
                                        22.674497
                                    ],
                                    [
                                        114.064353,
                                        22.674318
                                    ],
                                    [
                                        114.064244,
                                        22.673993
                                    ],
                                    [
                                        114.064956,
                                        22.672757
                                    ],
                                    [
                                        114.065053,
                                        22.672589
                                    ],
                                    [
                                        114.065624,
                                        22.671598
                                    ],
                                    [
                                        114.065796,
                                        22.671549
                                    ],
                                    [
                                        114.067445,
                                        22.67271
                                    ],
                                    [
                                        114.067941,
                                        22.673284
                                    ],
                                    [
                                        114.068335,
                                        22.67408
                                    ],
                                    [
                                        114.068425,
                                        22.674252
                                    ],
                                    [
                                        114.068811,
                                        22.674739
                                    ],
                                    [
                                        114.068861,
                                        22.674776
                                    ],
                                    [
                                        114.068877,
                                        22.674787
                                    ],
                                    [
                                        114.068916,
                                        22.674782
                                    ],
                                    [
                                        114.068954,
                                        22.674781
                                    ],
                                    [
                                        114.068983,
                                        22.674789
                                    ],
                                    [
                                        114.069016,
                                        22.674807
                                    ],
                                    [
                                        114.069043,
                                        22.674831
                                    ],
                                    [
                                        114.069055,
                                        22.674855
                                    ],
                                    [
                                        114.06909,
                                        22.674934
                                    ],
                                    [
                                        114.06931,
                                        22.674967
                                    ],
                                    [
                                        114.069845,
                                        22.674714
                                    ],
                                    [
                                        114.071332,
                                        22.673732
                                    ],
                                    [
                                        114.072573,
                                        22.673127
                                    ],
                                    [
                                        114.074028,
                                        22.673443
                                    ],
                                    [
                                        114.074259,
                                        22.673578
                                    ],
                                    [
                                        114.074952,
                                        22.674514
                                    ],
                                    [
                                        114.075259,
                                        22.674791
                                    ],
                                    [
                                        114.075982,
                                        22.675238
                                    ],
                                    [
                                        114.076531,
                                        22.675208
                                    ],
                                    [
                                        114.078723,
                                        22.674374
                                    ],
                                    [
                                        114.079317,
                                        22.67281
                                    ],
                                    [
                                        114.080369,
                                        22.671554
                                    ],
                                    [
                                        114.080377,
                                        22.671439
                                    ],
                                    [
                                        114.080376,
                                        22.671357
                                    ],
                                    [
                                        114.080374,
                                        22.671283
                                    ],
                                    [
                                        114.080361,
                                        22.671246
                                    ],
                                    [
                                        114.080356,
                                        22.671231
                                    ],
                                    [
                                        114.080333,
                                        22.671169
                                    ],
                                    [
                                        114.080227,
                                        22.670664
                                    ],
                                    [
                                        114.080407,
                                        22.670262
                                    ],
                                    [
                                        114.081396,
                                        22.669651
                                    ],
                                    [
                                        114.081301,
                                        22.668325
                                    ],
                                    [
                                        114.082558,
                                        22.665455
                                    ],
                                    [
                                        114.083299,
                                        22.664465
                                    ],
                                    [
                                        114.084305,
                                        22.664299
                                    ],
                                    [
                                        114.085356,
                                        22.663403
                                    ],
                                    [
                                        114.08518,
                                        22.662807
                                    ],
                                    [
                                        114.085232,
                                        22.662034
                                    ],
                                    [
                                        114.085686,
                                        22.660524
                                    ],
                                    [
                                        114.085907,
                                        22.66031
                                    ],
                                    [
                                        114.088963,
                                        22.658829
                                    ],
                                    [
                                        114.089207,
                                        22.658874
                                    ],
                                    [
                                        114.091623,
                                        22.661387
                                    ],
                                    [
                                        114.0918,
                                        22.661458
                                    ],
                                    [
                                        114.092616,
                                        22.663402
                                    ],
                                    [
                                        114.093156,
                                        22.664131
                                    ],
                                    [
                                        114.093371,
                                        22.664149
                                    ],
                                    [
                                        114.093491,
                                        22.66431
                                    ],
                                    [
                                        114.093581,
                                        22.6644
                                    ],
                                    [
                                        114.093609,
                                        22.664427
                                    ],
                                    [
                                        114.093648,
                                        22.66445
                                    ],
                                    [
                                        114.093715,
                                        22.66449
                                    ],
                                    [
                                        114.093738,
                                        22.664514
                                    ],
                                    [
                                        114.094686,
                                        22.665401
                                    ],
                                    [
                                        114.095056,
                                        22.665503
                                    ],
                                    [
                                        114.098206,
                                        22.667684
                                    ],
                                    [
                                        114.098393,
                                        22.667899
                                    ],
                                    [
                                        114.100106,
                                        22.668366
                                    ],
                                    [
                                        114.100601,
                                        22.668648
                                    ],
                                    [
                                        114.100033,
                                        22.672236
                                    ],
                                    [
                                        114.100285,
                                        22.673588
                                    ],
                                    [
                                        114.100116,
                                        22.675353
                                    ],
                                    [
                                        114.100056,
                                        22.675492
                                    ],
                                    [
                                        114.099615,
                                        22.675802
                                    ],
                                    [
                                        114.096868,
                                        22.68055
                                    ],
                                    [
                                        114.096725,
                                        22.681242
                                    ],
                                    [
                                        114.095934,
                                        22.682647
                                    ],
                                    [
                                        114.095292,
                                        22.683517
                                    ],
                                    [
                                        114.095095,
                                        22.684332
                                    ],
                                    [
                                        114.095142,
                                        22.684789
                                    ],
                                    [
                                        114.096653,
                                        22.687477
                                    ],
                                    [
                                        114.097189,
                                        22.687782
                                    ],
                                    [
                                        114.099782,
                                        22.688076
                                    ],
                                    [
                                        114.099816,
                                        22.688079
                                    ],
                                    [
                                        114.099975,
                                        22.688094
                                    ],
                                    [
                                        114.100009,
                                        22.688098
                                    ],
                                    [
                                        114.101119,
                                        22.688194
                                    ],
                                    [
                                        114.101168,
                                        22.688201
                                    ],
                                    [
                                        114.101226,
                                        22.688218
                                    ],
                                    [
                                        114.101299,
                                        22.688246
                                    ],
                                    [
                                        114.101305,
                                        22.688248
                                    ],
                                    [
                                        114.101507,
                                        22.688319
                                    ],
                                    [
                                        114.101592,
                                        22.688366
                                    ],
                                    [
                                        114.101673,
                                        22.688417
                                    ],
                                    [
                                        114.101904,
                                        22.688573
                                    ],
                                    [
                                        114.101933,
                                        22.688685
                                    ],
                                    [
                                        114.101933,
                                        22.688783
                                    ],
                                    [
                                        114.101912,
                                        22.688839
                                    ],
                                    [
                                        114.101878,
                                        22.688862
                                    ],
                                    [
                                        114.101874,
                                        22.688865
                                    ],
                                    [
                                        114.101856,
                                        22.688876
                                    ],
                                    [
                                        114.101712,
                                        22.688972
                                    ],
                                    [
                                        114.100222,
                                        22.689959
                                    ],
                                    [
                                        114.099826,
                                        22.689839
                                    ],
                                    [
                                        114.098641,
                                        22.690086
                                    ],
                                    [
                                        114.098575,
                                        22.6901
                                    ],
                                    [
                                        114.098539,
                                        22.690114
                                    ],
                                    [
                                        114.09853,
                                        22.690117
                                    ],
                                    [
                                        114.098478,
                                        22.690152
                                    ],
                                    [
                                        114.098464,
                                        22.690161
                                    ],
                                    [
                                        114.098404,
                                        22.690196
                                    ],
                                    [
                                        114.098372,
                                        22.690213
                                    ],
                                    [
                                        114.097719,
                                        22.690611
                                    ],
                                    [
                                        114.097594,
                                        22.690697
                                    ],
                                    [
                                        114.097572,
                                        22.690736
                                    ],
                                    [
                                        114.097453,
                                        22.690941
                                    ],
                                    [
                                        114.097356,
                                        22.69111
                                    ],
                                    [
                                        114.097286,
                                        22.691233
                                    ],
                                    [
                                        114.09728,
                                        22.691269
                                    ],
                                    [
                                        114.097257,
                                        22.691398
                                    ],
                                    [
                                        114.09725,
                                        22.691424
                                    ],
                                    [
                                        114.097241,
                                        22.691459
                                    ],
                                    [
                                        114.096276,
                                        22.692095
                                    ],
                                    [
                                        114.095901,
                                        22.69256
                                    ],
                                    [
                                        114.095654,
                                        22.692976
                                    ],
                                    [
                                        114.095439,
                                        22.693313
                                    ],
                                    [
                                        114.095214,
                                        22.693511
                                    ],
                                    [
                                        114.094935,
                                        22.693611
                                    ],
                                    [
                                        114.094796,
                                        22.693759
                                    ],
                                    [
                                        114.094549,
                                        22.693947
                                    ],
                                    [
                                        114.094216,
                                        22.694126
                                    ],
                                    [
                                        114.093895,
                                        22.694205
                                    ],
                                    [
                                        114.094023,
                                        22.694541
                                    ],
                                    [
                                        114.094048,
                                        22.694907
                                    ],
                                    [
                                        114.093969,
                                        22.695899
                                    ],
                                    [
                                        114.093591,
                                        22.697649
                                    ],
                                    [
                                        114.093575,
                                        22.699018
                                    ],
                                    [
                                        114.093571,
                                        22.699078
                                    ],
                                    [
                                        114.093566,
                                        22.699142
                                    ],
                                    [
                                        114.093557,
                                        22.699211
                                    ],
                                    [
                                        114.093549,
                                        22.699271
                                    ],
                                    [
                                        114.093367,
                                        22.699799
                                    ],
                                    [
                                        114.093441,
                                        22.700177
                                    ],
                                    [
                                        114.094134,
                                        22.700632
                                    ],
                                    [
                                        114.095061,
                                        22.701651
                                    ],
                                    [
                                        114.095964,
                                        22.702884
                                    ],
                                    [
                                        114.097269,
                                        22.704052
                                    ],
                                    [
                                        114.097685,
                                        22.704279
                                    ],
                                    [
                                        114.098844,
                                        22.704654
                                    ],
                                    [
                                        114.099643,
                                        22.704489
                                    ],
                                    [
                                        114.100629,
                                        22.704484
                                    ],
                                    [
                                        114.100804,
                                        22.704652
                                    ],
                                    [
                                        114.104043,
                                        22.70553
                                    ],
                                    [
                                        114.104164,
                                        22.707141
                                    ],
                                    [
                                        114.104601,
                                        22.708195
                                    ],
                                    [
                                        114.106494,
                                        22.7098
                                    ],
                                    [
                                        114.106458,
                                        22.71076
                                    ],
                                    [
                                        114.106906,
                                        22.711829
                                    ],
                                    [
                                        114.109278,
                                        22.714109
                                    ],
                                    [
                                        114.109182,
                                        22.715416
                                    ],
                                    [
                                        114.109226,
                                        22.716563
                                    ],
                                    [
                                        114.109422,
                                        22.717408
                                    ],
                                    [
                                        114.109586,
                                        22.71747
                                    ],
                                    [
                                        114.110381,
                                        22.718443
                                    ],
                                    [
                                        114.112437,
                                        22.720018
                                    ],
                                    [
                                        114.112969,
                                        22.720772
                                    ],
                                    [
                                        114.113366,
                                        22.72103
                                    ],
                                    [
                                        114.113924,
                                        22.721152
                                    ],
                                    [
                                        114.114177,
                                        22.721454
                                    ],
                                    [
                                        114.11459,
                                        22.722321
                                    ],
                                    [
                                        114.115443,
                                        22.722982
                                    ],
                                    [
                                        114.117636,
                                        22.723253
                                    ],
                                    [
                                        114.117602,
                                        22.72315
                                    ],
                                    [
                                        114.119696,
                                        22.7196
                                    ],
                                    [
                                        114.121241,
                                        22.718681
                                    ],
                                    [
                                        114.121553,
                                        22.718003
                                    ],
                                    [
                                        114.121889,
                                        22.717515
                                    ],
                                    [
                                        114.12203,
                                        22.7165
                                    ],
                                    [
                                        114.121978,
                                        22.716257
                                    ],
                                    [
                                        114.123011,
                                        22.71568
                                    ],
                                    [
                                        114.123559,
                                        22.715202
                                    ],
                                    [
                                        114.123856,
                                        22.715117
                                    ],
                                    [
                                        114.124559,
                                        22.715217
                                    ],
                                    [
                                        114.125068,
                                        22.715924
                                    ],
                                    [
                                        114.125081,
                                        22.715949
                                    ],
                                    [
                                        114.125085,
                                        22.715949
                                    ],
                                    [
                                        114.125689,
                                        22.716788
                                    ],
                                    [
                                        114.127541,
                                        22.716924
                                    ],
                                    [
                                        114.129516,
                                        22.716763
                                    ],
                                    [
                                        114.12981,
                                        22.716658
                                    ],
                                    [
                                        114.129998,
                                        22.71646
                                    ],
                                    [
                                        114.130194,
                                        22.716042
                                    ],
                                    [
                                        114.130641,
                                        22.714844
                                    ],
                                    [
                                        114.131077,
                                        22.714112
                                    ],
                                    [
                                        114.131449,
                                        22.713685
                                    ],
                                    [
                                        114.131754,
                                        22.713484
                                    ],
                                    [
                                        114.135335,
                                        22.712101
                                    ],
                                    [
                                        114.136174,
                                        22.712677
                                    ],
                                    [
                                        114.137297,
                                        22.714499
                                    ],
                                    [
                                        114.13717,
                                        22.715703
                                    ],
                                    [
                                        114.137308,
                                        22.716326
                                    ],
                                    [
                                        114.138019,
                                        22.71634
                                    ],
                                    [
                                        114.139418,
                                        22.716152
                                    ],
                                    [
                                        114.144664,
                                        22.714183
                                    ],
                                    [
                                        114.144529,
                                        22.710493
                                    ],
                                    [
                                        114.143147,
                                        22.709684
                                    ],
                                    [
                                        114.1431,
                                        22.709372
                                    ],
                                    [
                                        114.143182,
                                        22.708897
                                    ],
                                    [
                                        114.143837,
                                        22.707638
                                    ],
                                    [
                                        114.144572,
                                        22.706727
                                    ],
                                    [
                                        114.144788,
                                        22.706575
                                    ],
                                    [
                                        114.145736,
                                        22.706417
                                    ],
                                    [
                                        114.145977,
                                        22.706166
                                    ],
                                    [
                                        114.146016,
                                        22.705977
                                    ],
                                    [
                                        114.145939,
                                        22.705493
                                    ],
                                    [
                                        114.145449,
                                        22.704262
                                    ],
                                    [
                                        114.144627,
                                        22.70275
                                    ],
                                    [
                                        114.144565,
                                        22.702251
                                    ],
                                    [
                                        114.144658,
                                        22.701695
                                    ],
                                    [
                                        114.145058,
                                        22.701176
                                    ],
                                    [
                                        114.146706,
                                        22.700361
                                    ],
                                    [
                                        114.147643,
                                        22.700151
                                    ],
                                    [
                                        114.148346,
                                        22.700095
                                    ],
                                    [
                                        114.149416,
                                        22.699733
                                    ],
                                    [
                                        114.149881,
                                        22.699452
                                    ],
                                    [
                                        114.150604,
                                        22.697374
                                    ],
                                    [
                                        114.151939,
                                        22.695352
                                    ],
                                    [
                                        114.15206,
                                        22.694601
                                    ],
                                    [
                                        114.152656,
                                        22.693153
                                    ],
                                    [
                                        114.152914,
                                        22.692108
                                    ],
                                    [
                                        114.15287,
                                        22.691841
                                    ],
                                    [
                                        114.151782,
                                        22.690136
                                    ],
                                    [
                                        114.158826,
                                        22.685945
                                    ],
                                    [
                                        114.159504,
                                        22.685514
                                    ],
                                    [
                                        114.160101,
                                        22.685006
                                    ],
                                    [
                                        114.161121,
                                        22.685228
                                    ],
                                    [
                                        114.161626,
                                        22.685275
                                    ],
                                    [
                                        114.163618,
                                        22.682723
                                    ],
                                    [
                                        114.164345,
                                        22.682341
                                    ],
                                    [
                                        114.164397,
                                        22.682314
                                    ],
                                    [
                                        114.164516,
                                        22.682251
                                    ],
                                    [
                                        114.164568,
                                        22.682223
                                    ],
                                    [
                                        114.167437,
                                        22.680697
                                    ],
                                    [
                                        114.168139,
                                        22.679841
                                    ],
                                    [
                                        114.168155,
                                        22.679804
                                    ],
                                    [
                                        114.168169,
                                        22.679694
                                    ],
                                    [
                                        114.168176,
                                        22.679651
                                    ],
                                    [
                                        114.168231,
                                        22.678779
                                    ],
                                    [
                                        114.166518,
                                        22.678713
                                    ],
                                    [
                                        114.166337,
                                        22.678352
                                    ],
                                    [
                                        114.166861,
                                        22.676661
                                    ],
                                    [
                                        114.167137,
                                        22.675043
                                    ],
                                    [
                                        114.167535,
                                        22.674458
                                    ],
                                    [
                                        114.167595,
                                        22.673681
                                    ],
                                    [
                                        114.167435,
                                        22.672918
                                    ],
                                    [
                                        114.167419,
                                        22.672873
                                    ],
                                    [
                                        114.167396,
                                        22.672744
                                    ],
                                    [
                                        114.167391,
                                        22.672729
                                    ],
                                    [
                                        114.16639,
                                        22.670761
                                    ],
                                    [
                                        114.166207,
                                        22.670672
                                    ],
                                    [
                                        114.164741,
                                        22.667501
                                    ],
                                    [
                                        114.164463,
                                        22.666418
                                    ],
                                    [
                                        114.163901,
                                        22.665376
                                    ],
                                    [
                                        114.163768,
                                        22.665286
                                    ],
                                    [
                                        114.163489,
                                        22.665302
                                    ],
                                    [
                                        114.163094,
                                        22.665767
                                    ],
                                    [
                                        114.162621,
                                        22.667102
                                    ],
                                    [
                                        114.162151,
                                        22.667311
                                    ],
                                    [
                                        114.161211,
                                        22.668081
                                    ],
                                    [
                                        114.160496,
                                        22.668848
                                    ],
                                    [
                                        114.157725,
                                        22.668181
                                    ],
                                    [
                                        114.155467,
                                        22.668934
                                    ],
                                    [
                                        114.155333,
                                        22.668839
                                    ],
                                    [
                                        114.155308,
                                        22.668561
                                    ],
                                    [
                                        114.155456,
                                        22.668209
                                    ],
                                    [
                                        114.15394,
                                        22.663956
                                    ],
                                    [
                                        114.153983,
                                        22.663856
                                    ],
                                    [
                                        114.154538,
                                        22.663574
                                    ],
                                    [
                                        114.154696,
                                        22.663324
                                    ],
                                    [
                                        114.154707,
                                        22.663069
                                    ],
                                    [
                                        114.154585,
                                        22.662639
                                    ],
                                    [
                                        114.153877,
                                        22.661592
                                    ],
                                    [
                                        114.153621,
                                        22.661344
                                    ],
                                    [
                                        114.153563,
                                        22.660691
                                    ],
                                    [
                                        114.155026,
                                        22.660259
                                    ],
                                    [
                                        114.155639,
                                        22.661701
                                    ],
                                    [
                                        114.156153,
                                        22.663953
                                    ],
                                    [
                                        114.156532,
                                        22.664114
                                    ],
                                    [
                                        114.157018,
                                        22.664172
                                    ],
                                    [
                                        114.15703,
                                        22.663952
                                    ],
                                    [
                                        114.157153,
                                        22.66162
                                    ],
                                    [
                                        114.157386,
                                        22.661499
                                    ],
                                    [
                                        114.15796,
                                        22.661687
                                    ],
                                    [
                                        114.159027,
                                        22.66288
                                    ],
                                    [
                                        114.159506,
                                        22.663949
                                    ],
                                    [
                                        114.159911,
                                        22.665109
                                    ],
                                    [
                                        114.160192,
                                        22.665319
                                    ],
                                    [
                                        114.160829,
                                        22.664996
                                    ],
                                    [
                                        114.161311,
                                        22.663942
                                    ],
                                    [
                                        114.162696,
                                        22.661043
                                    ],
                                    [
                                        114.162065,
                                        22.659776
                                    ],
                                    [
                                        114.161079,
                                        22.659039
                                    ],
                                    [
                                        114.160849,
                                        22.6574
                                    ],
                                    [
                                        114.162519,
                                        22.656814
                                    ],
                                    [
                                        114.164252,
                                        22.657161
                                    ],
                                    [
                                        114.164531,
                                        22.657467
                                    ],
                                    [
                                        114.16459,
                                        22.658312
                                    ],
                                    [
                                        114.164204,
                                        22.659129
                                    ],
                                    [
                                        114.164576,
                                        22.660369
                                    ],
                                    [
                                        114.164448,
                                        22.661333
                                    ],
                                    [
                                        114.164502,
                                        22.661609
                                    ],
                                    [
                                        114.164724,
                                        22.661696
                                    ],
                                    [
                                        114.165153,
                                        22.661685
                                    ],
                                    [
                                        114.16562,
                                        22.661997
                                    ],
                                    [
                                        114.167052,
                                        22.662559
                                    ],
                                    [
                                        114.167755,
                                        22.662591
                                    ],
                                    [
                                        114.168066,
                                        22.662451
                                    ],
                                    [
                                        114.168266,
                                        22.662192
                                    ],
                                    [
                                        114.168619,
                                        22.660499
                                    ],
                                    [
                                        114.170123,
                                        22.659246
                                    ],
                                    [
                                        114.17032,
                                        22.658599
                                    ],
                                    [
                                        114.170544,
                                        22.658249
                                    ],
                                    [
                                        114.170083,
                                        22.657957
                                    ],
                                    [
                                        114.16932,
                                        22.656774
                                    ],
                                    [
                                        114.169383,
                                        22.656448
                                    ],
                                    [
                                        114.169988,
                                        22.655716
                                    ],
                                    [
                                        114.172525,
                                        22.654395
                                    ],
                                    [
                                        114.176169,
                                        22.65421
                                    ],
                                    [
                                        114.179126,
                                        22.656136
                                    ],
                                    [
                                        114.180171,
                                        22.658011
                                    ],
                                    [
                                        114.181173,
                                        22.659663
                                    ],
                                    [
                                        114.181272,
                                        22.660422
                                    ],
                                    [
                                        114.181956,
                                        22.662294
                                    ],
                                    [
                                        114.182089,
                                        22.662996
                                    ],
                                    [
                                        114.182795,
                                        22.663902
                                    ],
                                    [
                                        114.183192,
                                        22.664439
                                    ],
                                    [
                                        114.184654,
                                        22.664516
                                    ],
                                    [
                                        114.185831,
                                        22.664724
                                    ],
                                    [
                                        114.187214,
                                        22.665888
                                    ],
                                    [
                                        114.187518,
                                        22.66629
                                    ],
                                    [
                                        114.187511,
                                        22.666377
                                    ],
                                    [
                                        114.186705,
                                        22.667102
                                    ],
                                    [
                                        114.186447,
                                        22.66755
                                    ],
                                    [
                                        114.18625,
                                        22.668149
                                    ],
                                    [
                                        114.186337,
                                        22.668324
                                    ],
                                    [
                                        114.18653,
                                        22.66967
                                    ],
                                    [
                                        114.185804,
                                        22.669994
                                    ],
                                    [
                                        114.186556,
                                        22.672213
                                    ],
                                    [
                                        114.18719,
                                        22.673238
                                    ],
                                    [
                                        114.187496,
                                        22.673556
                                    ],
                                    [
                                        114.189243,
                                        22.674841
                                    ],
                                    [
                                        114.18973,
                                        22.675115
                                    ],
                                    [
                                        114.190299,
                                        22.67527
                                    ],
                                    [
                                        114.190655,
                                        22.67556
                                    ],
                                    [
                                        114.19085,
                                        22.675897
                                    ],
                                    [
                                        114.190842,
                                        22.676648
                                    ],
                                    [
                                        114.190988,
                                        22.677005
                                    ],
                                    [
                                        114.195357,
                                        22.680077
                                    ],
                                    [
                                        114.195892,
                                        22.680986
                                    ],
                                    [
                                        114.196545,
                                        22.681804
                                    ],
                                    [
                                        114.197154,
                                        22.682361
                                    ],
                                    [
                                        114.197147,
                                        22.682854
                                    ],
                                    [
                                        114.196847,
                                        22.683234
                                    ],
                                    [
                                        114.195786,
                                        22.683707
                                    ],
                                    [
                                        114.19349,
                                        22.68444
                                    ],
                                    [
                                        114.192619,
                                        22.683729
                                    ],
                                    [
                                        114.191051,
                                        22.687939
                                    ],
                                    [
                                        114.191484,
                                        22.688715
                                    ],
                                    [
                                        114.191919,
                                        22.688959
                                    ],
                                    [
                                        114.193566,
                                        22.688735
                                    ],
                                    [
                                        114.194237,
                                        22.688357
                                    ],
                                    [
                                        114.195101,
                                        22.688044
                                    ],
                                    [
                                        114.197115,
                                        22.68815
                                    ],
                                    [
                                        114.197192,
                                        22.689611
                                    ],
                                    [
                                        114.198956,
                                        22.694086
                                    ],
                                    [
                                        114.198971,
                                        22.695011
                                    ],
                                    [
                                        114.198791,
                                        22.695485
                                    ],
                                    [
                                        114.198709,
                                        22.696192
                                    ],
                                    [
                                        114.197955,
                                        22.696101
                                    ],
                                    [
                                        114.197501,
                                        22.696191
                                    ],
                                    [
                                        114.197299,
                                        22.696436
                                    ],
                                    [
                                        114.197233,
                                        22.696843
                                    ],
                                    [
                                        114.198435,
                                        22.699272
                                    ],
                                    [
                                        114.198773,
                                        22.700326
                                    ],
                                    [
                                        114.199291,
                                        22.700874
                                    ],
                                    [
                                        114.199489,
                                        22.702032
                                    ],
                                    [
                                        114.199048,
                                        22.704365
                                    ],
                                    [
                                        114.199089,
                                        22.705527
                                    ],
                                    [
                                        114.198924,
                                        22.706362
                                    ],
                                    [
                                        114.198686,
                                        22.706742
                                    ],
                                    [
                                        114.198374,
                                        22.706926
                                    ],
                                    [
                                        114.197144,
                                        22.707299
                                    ],
                                    [
                                        114.196843,
                                        22.707604
                                    ],
                                    [
                                        114.196552,
                                        22.708384
                                    ],
                                    [
                                        114.196802,
                                        22.709424
                                    ],
                                    [
                                        114.196718,
                                        22.710233
                                    ],
                                    [
                                        114.199984,
                                        22.713006
                                    ],
                                    [
                                        114.200553,
                                        22.713039
                                    ],
                                    [
                                        114.201431,
                                        22.713529
                                    ],
                                    [
                                        114.201651,
                                        22.713713
                                    ],
                                    [
                                        114.202665,
                                        22.715164
                                    ],
                                    [
                                        114.203307,
                                        22.715608
                                    ],
                                    [
                                        114.203974,
                                        22.715709
                                    ],
                                    [
                                        114.205027,
                                        22.715604
                                    ],
                                    [
                                        114.205865,
                                        22.715328
                                    ],
                                    [
                                        114.206294,
                                        22.714338
                                    ],
                                    [
                                        114.206418,
                                        22.714189
                                    ],
                                    [
                                        114.206637,
                                        22.714125
                                    ],
                                    [
                                        114.207385,
                                        22.714283
                                    ],
                                    [
                                        114.208066,
                                        22.714666
                                    ],
                                    [
                                        114.209268,
                                        22.719031
                                    ],
                                    [
                                        114.208904,
                                        22.719362
                                    ],
                                    [
                                        114.208664,
                                        22.719816
                                    ],
                                    [
                                        114.208487,
                                        22.72058
                                    ],
                                    [
                                        114.208524,
                                        22.721305
                                    ],
                                    [
                                        114.208419,
                                        22.72254
                                    ],
                                    [
                                        114.208417,
                                        22.722622
                                    ],
                                    [
                                        114.208415,
                                        22.722731
                                    ],
                                    [
                                        114.208409,
                                        22.722815
                                    ],
                                    [
                                        114.208249,
                                        22.724265
                                    ],
                                    [
                                        114.208651,
                                        22.726544
                                    ],
                                    [
                                        114.208505,
                                        22.727979
                                    ],
                                    [
                                        114.208574,
                                        22.728564
                                    ],
                                    [
                                        114.208524,
                                        22.729243
                                    ],
                                    [
                                        114.208599,
                                        22.729431
                                    ],
                                    [
                                        114.209476,
                                        22.730652
                                    ],
                                    [
                                        114.209675,
                                        22.731138
                                    ],
                                    [
                                        114.210144,
                                        22.731532
                                    ],
                                    [
                                        114.210352,
                                        22.731828
                                    ],
                                    [
                                        114.210606,
                                        22.731977
                                    ],
                                    [
                                        114.211423,
                                        22.732057
                                    ],
                                    [
                                        114.211514,
                                        22.732134
                                    ],
                                    [
                                        114.21174,
                                        22.732561
                                    ],
                                    [
                                        114.211923,
                                        22.73344
                                    ],
                                    [
                                        114.212125,
                                        22.733727
                                    ],
                                    [
                                        114.213692,
                                        22.734362
                                    ],
                                    [
                                        114.213932,
                                        22.734607
                                    ],
                                    [
                                        114.215673,
                                        22.735569
                                    ],
                                    [
                                        114.215361,
                                        22.737329
                                    ],
                                    [
                                        114.215196,
                                        22.737831
                                    ],
                                    [
                                        114.215581,
                                        22.738727
                                    ],
                                    [
                                        114.215561,
                                        22.739414
                                    ],
                                    [
                                        114.213284,
                                        22.741607
                                    ],
                                    [
                                        114.212504,
                                        22.742948
                                    ],
                                    [
                                        114.211856,
                                        22.743583
                                    ],
                                    [
                                        114.211385,
                                        22.743751
                                    ],
                                    [
                                        114.209993,
                                        22.743941
                                    ],
                                    [
                                        114.209129,
                                        22.744223
                                    ],
                                    [
                                        114.208744,
                                        22.744488
                                    ],
                                    [
                                        114.208337,
                                        22.745776
                                    ],
                                    [
                                        114.209205,
                                        22.74676
                                    ],
                                    [
                                        114.20923,
                                        22.747212
                                    ],
                                    [
                                        114.209349,
                                        22.748448
                                    ],
                                    [
                                        114.209972,
                                        22.749209
                                    ],
                                    [
                                        114.210497,
                                        22.750159
                                    ],
                                    [
                                        114.210044,
                                        22.750864
                                    ],
                                    [
                                        114.209738,
                                        22.751153
                                    ],
                                    [
                                        114.206483,
                                        22.752432
                                    ],
                                    [
                                        114.205503,
                                        22.75259
                                    ],
                                    [
                                        114.205079,
                                        22.751223
                                    ],
                                    [
                                        114.204213,
                                        22.750954
                                    ],
                                    [
                                        114.204125,
                                        22.751052
                                    ],
                                    [
                                        114.203114,
                                        22.755138
                                    ],
                                    [
                                        114.203289,
                                        22.755273
                                    ],
                                    [
                                        114.203645,
                                        22.755191
                                    ],
                                    [
                                        114.203818,
                                        22.755241
                                    ],
                                    [
                                        114.205702,
                                        22.756442
                                    ],
                                    [
                                        114.206077,
                                        22.756471
                                    ],
                                    [
                                        114.20657,
                                        22.757246
                                    ],
                                    [
                                        114.206528,
                                        22.757676
                                    ],
                                    [
                                        114.206308,
                                        22.758054
                                    ],
                                    [
                                        114.205649,
                                        22.758644
                                    ],
                                    [
                                        114.204373,
                                        22.759126
                                    ],
                                    [
                                        114.204002,
                                        22.759123
                                    ],
                                    [
                                        114.203637,
                                        22.758979
                                    ],
                                    [
                                        114.203182,
                                        22.758591
                                    ],
                                    [
                                        114.202514,
                                        22.758605
                                    ],
                                    [
                                        114.201884,
                                        22.759161
                                    ],
                                    [
                                        114.200411,
                                        22.759981
                                    ],
                                    [
                                        114.199785,
                                        22.760472
                                    ],
                                    [
                                        114.199743,
                                        22.760567
                                    ],
                                    [
                                        114.200427,
                                        22.763267
                                    ],
                                    [
                                        114.201064,
                                        22.764771
                                    ],
                                    [
                                        114.200402,
                                        22.765649
                                    ],
                                    [
                                        114.199003,
                                        22.765893
                                    ],
                                    [
                                        114.198644,
                                        22.76586
                                    ],
                                    [
                                        114.198035,
                                        22.765686
                                    ],
                                    [
                                        114.197572,
                                        22.765336
                                    ],
                                    [
                                        114.197414,
                                        22.765051
                                    ],
                                    [
                                        114.197095,
                                        22.764936
                                    ],
                                    [
                                        114.196709,
                                        22.765049
                                    ],
                                    [
                                        114.196424,
                                        22.765367
                                    ],
                                    [
                                        114.196073,
                                        22.765535
                                    ],
                                    [
                                        114.195593,
                                        22.765665
                                    ],
                                    [
                                        114.195069,
                                        22.765639
                                    ],
                                    [
                                        114.193571,
                                        22.765218
                                    ],
                                    [
                                        114.192399,
                                        22.764612
                                    ],
                                    [
                                        114.190419,
                                        22.764177
                                    ],
                                    [
                                        114.188947,
                                        22.763693
                                    ],
                                    [
                                        114.188804,
                                        22.763662
                                    ],
                                    [
                                        114.188759,
                                        22.763653
                                    ],
                                    [
                                        114.188106,
                                        22.76357
                                    ],
                                    [
                                        114.186944,
                                        22.76375
                                    ],
                                    [
                                        114.186402,
                                        22.764195
                                    ],
                                    [
                                        114.185677,
                                        22.764547
                                    ],
                                    [
                                        114.185023,
                                        22.76517
                                    ],
                                    [
                                        114.18354,
                                        22.764617
                                    ],
                                    [
                                        114.182574,
                                        22.764813
                                    ],
                                    [
                                        114.182051,
                                        22.765277
                                    ],
                                    [
                                        114.182341,
                                        22.766757
                                    ],
                                    [
                                        114.182225,
                                        22.767893
                                    ],
                                    [
                                        114.182219,
                                        22.767928
                                    ],
                                    [
                                        114.182239,
                                        22.767996
                                    ],
                                    [
                                        114.182291,
                                        22.76807
                                    ],
                                    [
                                        114.18264,
                                        22.768418
                                    ],
                                    [
                                        114.183226,
                                        22.768659
                                    ],
                                    [
                                        114.184708,
                                        22.768646
                                    ],
                                    [
                                        114.185063,
                                        22.768474
                                    ],
                                    [
                                        114.185262,
                                        22.768229
                                    ],
                                    [
                                        114.186155,
                                        22.768128
                                    ],
                                    [
                                        114.187035,
                                        22.768525
                                    ],
                                    [
                                        114.187144,
                                        22.768568
                                    ],
                                    [
                                        114.187216,
                                        22.768595
                                    ],
                                    [
                                        114.187603,
                                        22.768871
                                    ],
                                    [
                                        114.187804,
                                        22.769858
                                    ],
                                    [
                                        114.188004,
                                        22.770389
                                    ],
                                    [
                                        114.187111,
                                        22.771704
                                    ],
                                    [
                                        114.185983,
                                        22.772022
                                    ],
                                    [
                                        114.185754,
                                        22.772804
                                    ],
                                    [
                                        114.184239,
                                        22.772915
                                    ],
                                    [
                                        114.182947,
                                        22.773716
                                    ],
                                    [
                                        114.182704,
                                        22.77463
                                    ],
                                    [
                                        114.182654,
                                        22.775487
                                    ],
                                    [
                                        114.181694,
                                        22.776316
                                    ],
                                    [
                                        114.181446,
                                        22.776411
                                    ],
                                    [
                                        114.181077,
                                        22.77624
                                    ],
                                    [
                                        114.180856,
                                        22.775955
                                    ],
                                    [
                                        114.180833,
                                        22.775713
                                    ],
                                    [
                                        114.181079,
                                        22.774684
                                    ],
                                    [
                                        114.181107,
                                        22.774057
                                    ],
                                    [
                                        114.181844,
                                        22.773062
                                    ],
                                    [
                                        114.182121,
                                        22.772297
                                    ],
                                    [
                                        114.182213,
                                        22.772253
                                    ],
                                    [
                                        114.182096,
                                        22.771994
                                    ],
                                    [
                                        114.181583,
                                        22.771576
                                    ],
                                    [
                                        114.181261,
                                        22.771584
                                    ],
                                    [
                                        114.180655,
                                        22.771974
                                    ],
                                    [
                                        114.179626,
                                        22.772984
                                    ],
                                    [
                                        114.17951,
                                        22.7733
                                    ],
                                    [
                                        114.179489,
                                        22.773846
                                    ],
                                    [
                                        114.17987,
                                        22.775384
                                    ],
                                    [
                                        114.180027,
                                        22.77714
                                    ],
                                    [
                                        114.179477,
                                        22.778284
                                    ],
                                    [
                                        114.179344,
                                        22.779162
                                    ],
                                    [
                                        114.179917,
                                        22.779257
                                    ],
                                    [
                                        114.180694,
                                        22.779167
                                    ],
                                    [
                                        114.183259,
                                        22.779696
                                    ],
                                    [
                                        114.183457,
                                        22.779868
                                    ],
                                    [
                                        114.183546,
                                        22.780314
                                    ],
                                    [
                                        114.185334,
                                        22.781811
                                    ],
                                    [
                                        114.185788,
                                        22.783283
                                    ],
                                    [
                                        114.186706,
                                        22.78401
                                    ],
                                    [
                                        114.188868,
                                        22.784922
                                    ],
                                    [
                                        114.18943,
                                        22.785466
                                    ],
                                    [
                                        114.189992,
                                        22.785734
                                    ],
                                    [
                                        114.192375,
                                        22.785745
                                    ],
                                    [
                                        114.193274,
                                        22.785556
                                    ],
                                    [
                                        114.19559,
                                        22.785765
                                    ],
                                    [
                                        114.196659,
                                        22.78568
                                    ],
                                    [
                                        114.196963,
                                        22.785983
                                    ],
                                    [
                                        114.197646,
                                        22.787161
                                    ],
                                    [
                                        114.198151,
                                        22.787487
                                    ],
                                    [
                                        114.202444,
                                        22.788342
                                    ],
                                    [
                                        114.202651,
                                        22.788601
                                    ],
                                    [
                                        114.203198,
                                        22.788944
                                    ],
                                    [
                                        114.204632,
                                        22.789039
                                    ],
                                    [
                                        114.205419,
                                        22.789196
                                    ],
                                    [
                                        114.207241,
                                        22.789782
                                    ],
                                    [
                                        114.210163,
                                        22.792634
                                    ],
                                    [
                                        114.21134,
                                        22.795993
                                    ],
                                    [
                                        114.212665,
                                        22.798202
                                    ],
                                    [
                                        114.213021,
                                        22.798959
                                    ],
                                    [
                                        114.213011,
                                        22.799152
                                    ],
                                    [
                                        114.211851,
                                        22.80027
                                    ],
                                    [
                                        114.212934,
                                        22.802489
                                    ],
                                    [
                                        114.213611,
                                        22.803548
                                    ],
                                    [
                                        114.214144,
                                        22.805063
                                    ],
                                    [
                                        114.215069,
                                        22.80636
                                    ],
                                    [
                                        114.215644,
                                        22.807741
                                    ],
                                    [
                                        114.216091,
                                        22.808173
                                    ],
                                    [
                                        114.218057,
                                        22.809351
                                    ],
                                    [
                                        114.219442,
                                        22.808875
                                    ],
                                    [
                                        114.220551,
                                        22.808241
                                    ],
                                    [
                                        114.220808,
                                        22.808622
                                    ],
                                    [
                                        114.221171,
                                        22.808926
                                    ],
                                    [
                                        114.222782,
                                        22.809886
                                    ],
                                    [
                                        114.223659,
                                        22.810616
                                    ],
                                    [
                                        114.224021,
                                        22.811373
                                    ],
                                    [
                                        114.224255,
                                        22.812783
                                    ],
                                    [
                                        114.22563,
                                        22.813647
                                    ],
                                    [
                                        114.225816,
                                        22.813691
                                    ],
                                    [
                                        114.227821,
                                        22.813473
                                    ],
                                    [
                                        114.229201,
                                        22.812513
                                    ],
                                    [
                                        114.228938,
                                        22.810479
                                    ],
                                    [
                                        114.229266,
                                        22.809016
                                    ],
                                    [
                                        114.230915,
                                        22.807552
                                    ],
                                    [
                                        114.231769,
                                        22.807101
                                    ],
                                    [
                                        114.231872,
                                        22.806421
                                    ],
                                    [
                                        114.232559,
                                        22.804898
                                    ],
                                    [
                                        114.233243,
                                        22.800722
                                    ],
                                    [
                                        114.233862,
                                        22.799471
                                    ],
                                    [
                                        114.234169,
                                        22.798129
                                    ],
                                    [
                                        114.234149,
                                        22.797508
                                    ],
                                    [
                                        114.233852,
                                        22.796341
                                    ],
                                    [
                                        114.23381,
                                        22.794675
                                    ],
                                    [
                                        114.233809,
                                        22.793951
                                    ],
                                    [
                                        114.234111,
                                        22.793387
                                    ],
                                    [
                                        114.234917,
                                        22.792992
                                    ],
                                    [
                                        114.239933,
                                        22.792083
                                    ],
                                    [
                                        114.240752,
                                        22.791476
                                    ],
                                    [
                                        114.242437,
                                        22.791239
                                    ],
                                    [
                                        114.243597,
                                        22.791788
                                    ],
                                    [
                                        114.244474,
                                        22.791535
                                    ],
                                    [
                                        114.245501,
                                        22.790654
                                    ],
                                    [
                                        114.246572,
                                        22.787516
                                    ],
                                    [
                                        114.250427,
                                        22.783308
                                    ],
                                    [
                                        114.250322,
                                        22.782541
                                    ],
                                    [
                                        114.250586,
                                        22.781891
                                    ],
                                    [
                                        114.250812,
                                        22.78166
                                    ],
                                    [
                                        114.252221,
                                        22.781231
                                    ],
                                    [
                                        114.252829,
                                        22.781285
                                    ],
                                    [
                                        114.25334,
                                        22.781607
                                    ],
                                    [
                                        114.254133,
                                        22.782807
                                    ],
                                    [
                                        114.254463,
                                        22.782921
                                    ],
                                    [
                                        114.255534,
                                        22.782889
                                    ],
                                    [
                                        114.258339,
                                        22.782774
                                    ],
                                    [
                                        114.26,
                                        22.781997
                                    ],
                                    [
                                        114.261434,
                                        22.781774
                                    ],
                                    [
                                        114.264113,
                                        22.784457
                                    ],
                                    [
                                        114.264813,
                                        22.784598
                                    ],
                                    [
                                        114.267798,
                                        22.787309
                                    ],
                                    [
                                        114.268134,
                                        22.787754
                                    ],
                                    [
                                        114.268184,
                                        22.787945
                                    ],
                                    [
                                        114.269311,
                                        22.788931
                                    ],
                                    [
                                        114.26875,
                                        22.790144
                                    ],
                                    [
                                        114.268149,
                                        22.791081
                                    ],
                                    [
                                        114.268186,
                                        22.791429
                                    ],
                                    [
                                        114.26847,
                                        22.792097
                                    ],
                                    [
                                        114.269375,
                                        22.792545
                                    ],
                                    [
                                        114.269559,
                                        22.792525
                                    ],
                                    [
                                        114.272312,
                                        22.793201
                                    ],
                                    [
                                        114.273034,
                                        22.793738
                                    ],
                                    [
                                        114.273333,
                                        22.793856
                                    ],
                                    [
                                        114.27451,
                                        22.794021
                                    ],
                                    [
                                        114.275103,
                                        22.794343
                                    ],
                                    [
                                        114.275975,
                                        22.795273
                                    ],
                                    [
                                        114.276061,
                                        22.795459
                                    ],
                                    [
                                        114.276039,
                                        22.795951
                                    ],
                                    [
                                        114.275626,
                                        22.796736
                                    ],
                                    [
                                        114.275767,
                                        22.797321
                                    ],
                                    [
                                        114.275779,
                                        22.797343
                                    ],
                                    [
                                        114.275807,
                                        22.797376
                                    ],
                                    [
                                        114.27587,
                                        22.797451
                                    ],
                                    [
                                        114.275909,
                                        22.797448
                                    ],
                                    [
                                        114.275946,
                                        22.797445
                                    ],
                                    [
                                        114.275967,
                                        22.797451
                                    ],
                                    [
                                        114.278228,
                                        22.798312
                                    ],
                                    [
                                        114.278841,
                                        22.798432
                                    ],
                                    [
                                        114.279601,
                                        22.798917
                                    ],
                                    [
                                        114.280069,
                                        22.799618
                                    ],
                                    [
                                        114.28287,
                                        22.802379
                                    ],
                                    [
                                        114.282928,
                                        22.803605
                                    ],
                                    [
                                        114.282765,
                                        22.804252
                                    ],
                                    [
                                        114.282749,
                                        22.804744
                                    ],
                                    [
                                        114.282974,
                                        22.805287
                                    ],
                                    [
                                        114.283531,
                                        22.806037
                                    ],
                                    [
                                        114.283981,
                                        22.806892
                                    ],
                                    [
                                        114.284716,
                                        22.807968
                                    ],
                                    [
                                        114.284813,
                                        22.808258
                                    ],
                                    [
                                        114.286905,
                                        22.807198
                                    ],
                                    [
                                        114.288575,
                                        22.807386
                                    ],
                                    [
                                        114.289132,
                                        22.807895
                                    ],
                                    [
                                        114.290333,
                                        22.808063
                                    ],
                                    [
                                        114.291627,
                                        22.808597
                                    ],
                                    [
                                        114.291893,
                                        22.808234
                                    ],
                                    [
                                        114.292779,
                                        22.807528
                                    ],
                                    [
                                        114.29328,
                                        22.807287
                                    ],
                                    [
                                        114.294006,
                                        22.806743
                                    ],
                                    [
                                        114.294851,
                                        22.806381
                                    ],
                                    [
                                        114.294507,
                                        22.805691
                                    ],
                                    [
                                        114.294636,
                                        22.805039
                                    ],
                                    [
                                        114.294319,
                                        22.80342
                                    ],
                                    [
                                        114.295479,
                                        22.802789
                                    ],
                                    [
                                        114.298379,
                                        22.802204
                                    ],
                                    [
                                        114.298517,
                                        22.802322
                                    ],
                                    [
                                        114.305353,
                                        22.801708
                                    ],
                                    [
                                        114.305759,
                                        22.801544
                                    ],
                                    [
                                        114.306119,
                                        22.8026
                                    ],
                                    [
                                        114.307991,
                                        22.803456
                                    ],
                                    [
                                        114.308345,
                                        22.803564
                                    ],
                                    [
                                        114.309594,
                                        22.803497
                                    ],
                                    [
                                        114.311147,
                                        22.803571
                                    ],
                                    [
                                        114.312575,
                                        22.802887
                                    ],
                                    [
                                        114.313002,
                                        22.802266
                                    ],
                                    [
                                        114.313064,
                                        22.801725
                                    ],
                                    [
                                        114.312978,
                                        22.800879
                                    ],
                                    [
                                        114.313078,
                                        22.800563
                                    ],
                                    [
                                        114.314468,
                                        22.800142
                                    ],
                                    [
                                        114.315858,
                                        22.800906
                                    ],
                                    [
                                        114.316454,
                                        22.801409
                                    ],
                                    [
                                        114.316957,
                                        22.802398
                                    ],
                                    [
                                        114.31705,
                                        22.802808
                                    ],
                                    [
                                        114.318241,
                                        22.804665
                                    ],
                                    [
                                        114.318554,
                                        22.805768
                                    ],
                                    [
                                        114.318549,
                                        22.806559
                                    ],
                                    [
                                        114.318676,
                                        22.806788
                                    ],
                                    [
                                        114.318947,
                                        22.806851
                                    ],
                                    [
                                        114.320654,
                                        22.806509
                                    ],
                                    [
                                        114.324065,
                                        22.804828
                                    ],
                                    [
                                        114.327505,
                                        22.805271
                                    ],
                                    [
                                        114.328204,
                                        22.805621
                                    ],
                                    [
                                        114.329309,
                                        22.806348
                                    ],
                                    [
                                        114.329946,
                                        22.807393
                                    ],
                                    [
                                        114.330114,
                                        22.808594
                                    ],
                                    [
                                        114.330515,
                                        22.809268
                                    ],
                                    [
                                        114.332687,
                                        22.809183
                                    ],
                                    [
                                        114.332731,
                                        22.809181
                                    ],
                                    [
                                        114.332881,
                                        22.809175
                                    ],
                                    [
                                        114.332925,
                                        22.809173
                                    ],
                                    [
                                        114.333015,
                                        22.80917
                                    ],
                                    [
                                        114.333075,
                                        22.809167
                                    ],
                                    [
                                        114.333209,
                                        22.809162
                                    ],
                                    [
                                        114.333269,
                                        22.80916
                                    ],
                                    [
                                        114.335301,
                                        22.808987
                                    ],
                                    [
                                        114.337324,
                                        22.809485
                                    ],
                                    [
                                        114.339674,
                                        22.809607
                                    ],
                                    [
                                        114.340041,
                                        22.809748
                                    ],
                                    [
                                        114.340395,
                                        22.810018
                                    ],
                                    [
                                        114.341594,
                                        22.809898
                                    ],
                                    [
                                        114.342076,
                                        22.809573
                                    ],
                                    [
                                        114.342774,
                                        22.808844
                                    ],
                                    [
                                        114.343148,
                                        22.808668
                                    ],
                                    [
                                        114.345332,
                                        22.808506
                                    ],
                                    [
                                        114.346376,
                                        22.808992
                                    ],
                                    [
                                        114.347873,
                                        22.809191
                                    ],
                                    [
                                        114.348067,
                                        22.809052
                                    ],
                                    [
                                        114.34859,
                                        22.808225
                                    ],
                                    [
                                        114.349321,
                                        22.807413
                                    ],
                                    [
                                        114.34959,
                                        22.806772
                                    ],
                                    [
                                        114.349788,
                                        22.806552
                                    ],
                                    [
                                        114.350237,
                                        22.80643
                                    ],
                                    [
                                        114.350822,
                                        22.806592
                                    ],
                                    [
                                        114.352342,
                                        22.806703
                                    ],
                                    [
                                        114.353164,
                                        22.806624
                                    ],
                                    [
                                        114.353296,
                                        22.806495
                                    ],
                                    [
                                        114.353505,
                                        22.80582
                                    ],
                                    [
                                        114.353514,
                                        22.805312
                                    ],
                                    [
                                        114.353367,
                                        22.804583
                                    ],
                                    [
                                        114.353137,
                                        22.80401
                                    ],
                                    [
                                        114.352827,
                                        22.803745
                                    ],
                                    [
                                        114.351616,
                                        22.803384
                                    ],
                                    [
                                        114.351196,
                                        22.802929
                                    ],
                                    [
                                        114.350159,
                                        22.799478
                                    ],
                                    [
                                        114.35,
                                        22.799331
                                    ],
                                    [
                                        114.350013,
                                        22.799137
                                    ],
                                    [
                                        114.350726,
                                        22.797559
                                    ],
                                    [
                                        114.35171,
                                        22.797232
                                    ],
                                    [
                                        114.351839,
                                        22.796458
                                    ],
                                    [
                                        114.351959,
                                        22.795332
                                    ],
                                    [
                                        114.351846,
                                        22.792257
                                    ],
                                    [
                                        114.351121,
                                        22.789689
                                    ],
                                    [
                                        114.349697,
                                        22.789193
                                    ],
                                    [
                                        114.348201,
                                        22.78838
                                    ],
                                    [
                                        114.347484,
                                        22.788209
                                    ],
                                    [
                                        114.346499,
                                        22.78813
                                    ],
                                    [
                                        114.34565,
                                        22.787514
                                    ],
                                    [
                                        114.345607,
                                        22.787459
                                    ],
                                    [
                                        114.345504,
                                        22.787388
                                    ],
                                    [
                                        114.345294,
                                        22.78723
                                    ],
                                    [
                                        114.344259,
                                        22.785606
                                    ],
                                    [
                                        114.342751,
                                        22.784436
                                    ],
                                    [
                                        114.342622,
                                        22.783969
                                    ],
                                    [
                                        114.342607,
                                        22.783698
                                    ],
                                    [
                                        114.342733,
                                        22.783653
                                    ],
                                    [
                                        114.343671,
                                        22.782562
                                    ],
                                    [
                                        114.344063,
                                        22.781829
                                    ],
                                    [
                                        114.34418,
                                        22.781511
                                    ],
                                    [
                                        114.344389,
                                        22.779814
                                    ],
                                    [
                                        114.345104,
                                        22.778971
                                    ],
                                    [
                                        114.346293,
                                        22.777904
                                    ],
                                    [
                                        114.347839,
                                        22.77742
                                    ],
                                    [
                                        114.348184,
                                        22.777481
                                    ],
                                    [
                                        114.34951,
                                        22.778385
                                    ],
                                    [
                                        114.350001,
                                        22.778523
                                    ],
                                    [
                                        114.350441,
                                        22.778522
                                    ],
                                    [
                                        114.354111,
                                        22.778147
                                    ],
                                    [
                                        114.35428,
                                        22.778053
                                    ],
                                    [
                                        114.355212,
                                        22.776987
                                    ],
                                    [
                                        114.356504,
                                        22.774301
                                    ],
                                    [
                                        114.356472,
                                        22.773488
                                    ],
                                    [
                                        114.356223,
                                        22.772795
                                    ],
                                    [
                                        114.356196,
                                        22.772481
                                    ],
                                    [
                                        114.356228,
                                        22.772059
                                    ],
                                    [
                                        114.356363,
                                        22.771748
                                    ],
                                    [
                                        114.356577,
                                        22.768719
                                    ],
                                    [
                                        114.356215,
                                        22.767092
                                    ],
                                    [
                                        114.355826,
                                        22.76637
                                    ],
                                    [
                                        114.355784,
                                        22.765796
                                    ]
                                ]
                            ]
                        ]
                    },
                    "properties": {
                        "name": "龙岗区",
                        "cp": [
                            114.251372,
                            22.721511
                        ]
                    }
                },
                {
                    "type": "Feature",
                    "id": "440309",
                    "geometry": {
                        "type": "Polygon",
                        "coordinates": [
                            [
                                [
                                    114.113366,
                                    22.72103
                                ],
                                [
                                    114.112969,
                                    22.720772
                                ],
                                [
                                    114.112437,
                                    22.720018
                                ],
                                [
                                    114.110381,
                                    22.718443
                                ],
                                [
                                    114.109586,
                                    22.71747
                                ],
                                [
                                    114.109422,
                                    22.717408
                                ],
                                [
                                    114.109226,
                                    22.716563
                                ],
                                [
                                    114.109182,
                                    22.715416
                                ],
                                [
                                    114.109278,
                                    22.714109
                                ],
                                [
                                    114.106906,
                                    22.711829
                                ],
                                [
                                    114.106458,
                                    22.71076
                                ],
                                [
                                    114.106494,
                                    22.7098
                                ],
                                [
                                    114.104601,
                                    22.708195
                                ],
                                [
                                    114.104164,
                                    22.707141
                                ],
                                [
                                    114.104043,
                                    22.70553
                                ],
                                [
                                    114.100804,
                                    22.704652
                                ],
                                [
                                    114.100629,
                                    22.704484
                                ],
                                [
                                    114.099643,
                                    22.704489
                                ],
                                [
                                    114.098844,
                                    22.704654
                                ],
                                [
                                    114.097685,
                                    22.704279
                                ],
                                [
                                    114.097269,
                                    22.704052
                                ],
                                [
                                    114.095964,
                                    22.702884
                                ],
                                [
                                    114.095061,
                                    22.701651
                                ],
                                [
                                    114.094134,
                                    22.700632
                                ],
                                [
                                    114.093441,
                                    22.700177
                                ],
                                [
                                    114.093367,
                                    22.699799
                                ],
                                [
                                    114.093549,
                                    22.699271
                                ],
                                [
                                    114.093557,
                                    22.699211
                                ],
                                [
                                    114.093566,
                                    22.699142
                                ],
                                [
                                    114.093571,
                                    22.699078
                                ],
                                [
                                    114.093575,
                                    22.699018
                                ],
                                [
                                    114.093591,
                                    22.697649
                                ],
                                [
                                    114.093969,
                                    22.695899
                                ],
                                [
                                    114.094048,
                                    22.694907
                                ],
                                [
                                    114.094023,
                                    22.694541
                                ],
                                [
                                    114.093895,
                                    22.694205
                                ],
                                [
                                    114.094216,
                                    22.694126
                                ],
                                [
                                    114.094549,
                                    22.693947
                                ],
                                [
                                    114.094796,
                                    22.693759
                                ],
                                [
                                    114.094935,
                                    22.693611
                                ],
                                [
                                    114.095214,
                                    22.693511
                                ],
                                [
                                    114.095439,
                                    22.693313
                                ],
                                [
                                    114.095654,
                                    22.692976
                                ],
                                [
                                    114.095901,
                                    22.69256
                                ],
                                [
                                    114.096276,
                                    22.692095
                                ],
                                [
                                    114.097241,
                                    22.691459
                                ],
                                [
                                    114.09725,
                                    22.691424
                                ],
                                [
                                    114.097257,
                                    22.691398
                                ],
                                [
                                    114.09728,
                                    22.691269
                                ],
                                [
                                    114.097286,
                                    22.691233
                                ],
                                [
                                    114.097356,
                                    22.69111
                                ],
                                [
                                    114.097453,
                                    22.690941
                                ],
                                [
                                    114.097572,
                                    22.690736
                                ],
                                [
                                    114.097594,
                                    22.690697
                                ],
                                [
                                    114.097719,
                                    22.690611
                                ],
                                [
                                    114.098372,
                                    22.690213
                                ],
                                [
                                    114.098404,
                                    22.690196
                                ],
                                [
                                    114.098464,
                                    22.690161
                                ],
                                [
                                    114.098478,
                                    22.690152
                                ],
                                [
                                    114.09853,
                                    22.690117
                                ],
                                [
                                    114.098539,
                                    22.690114
                                ],
                                [
                                    114.098575,
                                    22.6901
                                ],
                                [
                                    114.098641,
                                    22.690086
                                ],
                                [
                                    114.099826,
                                    22.689839
                                ],
                                [
                                    114.100222,
                                    22.689959
                                ],
                                [
                                    114.101712,
                                    22.688972
                                ],
                                [
                                    114.101856,
                                    22.688876
                                ],
                                [
                                    114.101874,
                                    22.688865
                                ],
                                [
                                    114.101878,
                                    22.688862
                                ],
                                [
                                    114.101912,
                                    22.688839
                                ],
                                [
                                    114.101933,
                                    22.688783
                                ],
                                [
                                    114.101933,
                                    22.688685
                                ],
                                [
                                    114.101904,
                                    22.688573
                                ],
                                [
                                    114.101673,
                                    22.688417
                                ],
                                [
                                    114.101592,
                                    22.688366
                                ],
                                [
                                    114.101507,
                                    22.688319
                                ],
                                [
                                    114.101305,
                                    22.688248
                                ],
                                [
                                    114.101299,
                                    22.688246
                                ],
                                [
                                    114.101226,
                                    22.688218
                                ],
                                [
                                    114.101168,
                                    22.688201
                                ],
                                [
                                    114.101119,
                                    22.688194
                                ],
                                [
                                    114.100009,
                                    22.688098
                                ],
                                [
                                    114.099975,
                                    22.688094
                                ],
                                [
                                    114.099816,
                                    22.688079
                                ],
                                [
                                    114.099782,
                                    22.688076
                                ],
                                [
                                    114.097189,
                                    22.687782
                                ],
                                [
                                    114.096653,
                                    22.687477
                                ],
                                [
                                    114.095142,
                                    22.684789
                                ],
                                [
                                    114.095095,
                                    22.684332
                                ],
                                [
                                    114.095292,
                                    22.683517
                                ],
                                [
                                    114.095934,
                                    22.682647
                                ],
                                [
                                    114.096725,
                                    22.681242
                                ],
                                [
                                    114.096868,
                                    22.68055
                                ],
                                [
                                    114.099615,
                                    22.675802
                                ],
                                [
                                    114.100056,
                                    22.675492
                                ],
                                [
                                    114.100116,
                                    22.675353
                                ],
                                [
                                    114.100285,
                                    22.673588
                                ],
                                [
                                    114.100033,
                                    22.672236
                                ],
                                [
                                    114.100601,
                                    22.668648
                                ],
                                [
                                    114.100106,
                                    22.668366
                                ],
                                [
                                    114.098393,
                                    22.667899
                                ],
                                [
                                    114.098206,
                                    22.667684
                                ],
                                [
                                    114.095056,
                                    22.665503
                                ],
                                [
                                    114.094686,
                                    22.665401
                                ],
                                [
                                    114.093738,
                                    22.664514
                                ],
                                [
                                    114.093715,
                                    22.66449
                                ],
                                [
                                    114.093648,
                                    22.66445
                                ],
                                [
                                    114.093609,
                                    22.664427
                                ],
                                [
                                    114.093581,
                                    22.6644
                                ],
                                [
                                    114.093491,
                                    22.66431
                                ],
                                [
                                    114.093371,
                                    22.664149
                                ],
                                [
                                    114.093156,
                                    22.664131
                                ],
                                [
                                    114.092616,
                                    22.663402
                                ],
                                [
                                    114.0918,
                                    22.661458
                                ],
                                [
                                    114.091623,
                                    22.661387
                                ],
                                [
                                    114.089207,
                                    22.658874
                                ],
                                [
                                    114.088963,
                                    22.658829
                                ],
                                [
                                    114.085907,
                                    22.66031
                                ],
                                [
                                    114.085686,
                                    22.660524
                                ],
                                [
                                    114.085232,
                                    22.662034
                                ],
                                [
                                    114.08518,
                                    22.662807
                                ],
                                [
                                    114.085356,
                                    22.663403
                                ],
                                [
                                    114.084305,
                                    22.664299
                                ],
                                [
                                    114.083299,
                                    22.664465
                                ],
                                [
                                    114.082558,
                                    22.665455
                                ],
                                [
                                    114.081301,
                                    22.668325
                                ],
                                [
                                    114.081396,
                                    22.669651
                                ],
                                [
                                    114.080407,
                                    22.670262
                                ],
                                [
                                    114.080227,
                                    22.670664
                                ],
                                [
                                    114.080333,
                                    22.671169
                                ],
                                [
                                    114.080356,
                                    22.671231
                                ],
                                [
                                    114.080361,
                                    22.671246
                                ],
                                [
                                    114.080374,
                                    22.671283
                                ],
                                [
                                    114.080376,
                                    22.671357
                                ],
                                [
                                    114.080377,
                                    22.671439
                                ],
                                [
                                    114.080369,
                                    22.671554
                                ],
                                [
                                    114.079317,
                                    22.67281
                                ],
                                [
                                    114.078723,
                                    22.674374
                                ],
                                [
                                    114.076531,
                                    22.675208
                                ],
                                [
                                    114.075982,
                                    22.675238
                                ],
                                [
                                    114.075259,
                                    22.674791
                                ],
                                [
                                    114.074952,
                                    22.674514
                                ],
                                [
                                    114.074259,
                                    22.673578
                                ],
                                [
                                    114.074028,
                                    22.673443
                                ],
                                [
                                    114.072573,
                                    22.673127
                                ],
                                [
                                    114.071332,
                                    22.673732
                                ],
                                [
                                    114.069845,
                                    22.674714
                                ],
                                [
                                    114.06931,
                                    22.674967
                                ],
                                [
                                    114.06909,
                                    22.674934
                                ],
                                [
                                    114.069055,
                                    22.674855
                                ],
                                [
                                    114.069043,
                                    22.674831
                                ],
                                [
                                    114.069016,
                                    22.674807
                                ],
                                [
                                    114.068983,
                                    22.674789
                                ],
                                [
                                    114.068954,
                                    22.674781
                                ],
                                [
                                    114.068916,
                                    22.674782
                                ],
                                [
                                    114.068877,
                                    22.674787
                                ],
                                [
                                    114.068861,
                                    22.674776
                                ],
                                [
                                    114.068811,
                                    22.674739
                                ],
                                [
                                    114.068425,
                                    22.674252
                                ],
                                [
                                    114.068335,
                                    22.67408
                                ],
                                [
                                    114.067941,
                                    22.673284
                                ],
                                [
                                    114.067445,
                                    22.67271
                                ],
                                [
                                    114.065796,
                                    22.671549
                                ],
                                [
                                    114.065624,
                                    22.671598
                                ],
                                [
                                    114.065053,
                                    22.672589
                                ],
                                [
                                    114.064956,
                                    22.672757
                                ],
                                [
                                    114.064244,
                                    22.673993
                                ],
                                [
                                    114.064353,
                                    22.674318
                                ],
                                [
                                    114.064062,
                                    22.674497
                                ],
                                [
                                    114.063884,
                                    22.674477
                                ],
                                [
                                    114.063412,
                                    22.673863
                                ],
                                [
                                    114.063386,
                                    22.673828
                                ],
                                [
                                    114.063362,
                                    22.673795
                                ],
                                [
                                    114.063328,
                                    22.673749
                                ],
                                [
                                    114.063305,
                                    22.673702
                                ],
                                [
                                    114.063285,
                                    22.673662
                                ],
                                [
                                    114.063267,
                                    22.673626
                                ],
                                [
                                    114.062822,
                                    22.672595
                                ],
                                [
                                    114.062087,
                                    22.672131
                                ],
                                [
                                    114.061965,
                                    22.671808
                                ],
                                [
                                    114.062032,
                                    22.671031
                                ],
                                [
                                    114.062889,
                                    22.669779
                                ],
                                [
                                    114.062908,
                                    22.669373
                                ],
                                [
                                    114.062364,
                                    22.668739
                                ],
                                [
                                    114.061815,
                                    22.667879
                                ],
                                [
                                    114.061801,
                                    22.667854
                                ],
                                [
                                    114.061784,
                                    22.667831
                                ],
                                [
                                    114.061344,
                                    22.667141
                                ],
                                [
                                    114.059506,
                                    22.664931
                                ],
                                [
                                    114.059487,
                                    22.664911
                                ],
                                [
                                    114.059445,
                                    22.664863
                                ],
                                [
                                    114.059422,
                                    22.664842
                                ],
                                [
                                    114.059376,
                                    22.664848
                                ],
                                [
                                    114.059344,
                                    22.664862
                                ],
                                [
                                    114.058697,
                                    22.665222
                                ],
                                [
                                    114.058457,
                                    22.665324
                                ],
                                [
                                    114.058342,
                                    22.66538
                                ],
                                [
                                    114.058127,
                                    22.665512
                                ],
                                [
                                    114.058056,
                                    22.665581
                                ],
                                [
                                    114.057763,
                                    22.665715
                                ],
                                [
                                    114.05768,
                                    22.665651
                                ],
                                [
                                    114.057609,
                                    22.665597
                                ],
                                [
                                    114.057502,
                                    22.665613
                                ],
                                [
                                    114.054287,
                                    22.666102
                                ],
                                [
                                    114.05417,
                                    22.665906
                                ],
                                [
                                    114.05418,
                                    22.664877
                                ],
                                [
                                    114.054297,
                                    22.664535
                                ],
                                [
                                    114.054826,
                                    22.663812
                                ],
                                [
                                    114.055788,
                                    22.663537
                                ],
                                [
                                    114.056107,
                                    22.66325
                                ],
                                [
                                    114.056509,
                                    22.662651
                                ],
                                [
                                    114.05648,
                                    22.661822
                                ],
                                [
                                    114.056282,
                                    22.661127
                                ],
                                [
                                    114.056279,
                                    22.661117
                                ],
                                [
                                    114.056247,
                                    22.661018
                                ],
                                [
                                    114.056241,
                                    22.660999
                                ],
                                [
                                    114.056221,
                                    22.660943
                                ],
                                [
                                    114.056206,
                                    22.660903
                                ],
                                [
                                    114.056179,
                                    22.660836
                                ],
                                [
                                    114.056012,
                                    22.66041
                                ],
                                [
                                    114.055476,
                                    22.659986
                                ],
                                [
                                    114.054518,
                                    22.659526
                                ],
                                [
                                    114.05453,
                                    22.659115
                                ],
                                [
                                    114.054532,
                                    22.659084
                                ],
                                [
                                    114.054532,
                                    22.659059
                                ],
                                [
                                    114.054534,
                                    22.658983
                                ],
                                [
                                    114.054537,
                                    22.658921
                                ],
                                [
                                    114.054541,
                                    22.658865
                                ],
                                [
                                    114.054665,
                                    22.656134
                                ],
                                [
                                    114.054668,
                                    22.656067
                                ],
                                [
                                    114.054674,
                                    22.65594
                                ],
                                [
                                    114.054968,
                                    22.64905
                                ],
                                [
                                    114.054973,
                                    22.648998
                                ],
                                [
                                    114.054973,
                                    22.648974
                                ],
                                [
                                    114.054889,
                                    22.648998
                                ],
                                [
                                    114.054792,
                                    22.649026
                                ],
                                [
                                    114.054703,
                                    22.649052
                                ],
                                [
                                    114.052422,
                                    22.649776
                                ],
                                [
                                    114.052369,
                                    22.649799
                                ],
                                [
                                    114.052245,
                                    22.649855
                                ],
                                [
                                    114.052191,
                                    22.649878
                                ],
                                [
                                    114.051279,
                                    22.650283
                                ],
                                [
                                    114.05113,
                                    22.650226
                                ],
                                [
                                    114.050093,
                                    22.647427
                                ],
                                [
                                    114.050231,
                                    22.647168
                                ],
                                [
                                    114.050732,
                                    22.647219
                                ],
                                [
                                    114.050801,
                                    22.647223
                                ],
                                [
                                    114.050926,
                                    22.647231
                                ],
                                [
                                    114.050995,
                                    22.647235
                                ],
                                [
                                    114.053395,
                                    22.647382
                                ],
                                [
                                    114.054823,
                                    22.646518
                                ],
                                [
                                    114.054912,
                                    22.646479
                                ],
                                [
                                    114.054987,
                                    22.646445
                                ],
                                [
                                    114.055,
                                    22.64644
                                ],
                                [
                                    114.05509,
                                    22.646407
                                ],
                                [
                                    114.055175,
                                    22.646325
                                ],
                                [
                                    114.055936,
                                    22.642338
                                ],
                                [
                                    114.055648,
                                    22.642136
                                ],
                                [
                                    114.055216,
                                    22.642062
                                ],
                                [
                                    114.054853,
                                    22.641784
                                ],
                                [
                                    114.054601,
                                    22.641386
                                ],
                                [
                                    114.054187,
                                    22.640229
                                ],
                                [
                                    114.054919,
                                    22.638639
                                ],
                                [
                                    114.054946,
                                    22.638594
                                ],
                                [
                                    114.055027,
                                    22.638479
                                ],
                                [
                                    114.055067,
                                    22.638421
                                ],
                                [
                                    114.055134,
                                    22.638318
                                ],
                                [
                                    114.055173,
                                    22.638259
                                ],
                                [
                                    114.056178,
                                    22.636525
                                ],
                                [
                                    114.056132,
                                    22.636238
                                ],
                                [
                                    114.056084,
                                    22.636149
                                ],
                                [
                                    114.056021,
                                    22.635839
                                ],
                                [
                                    114.056031,
                                    22.635778
                                ],
                                [
                                    114.056022,
                                    22.635741
                                ],
                                [
                                    114.055848,
                                    22.634971
                                ],
                                [
                                    114.055107,
                                    22.635157
                                ],
                                [
                                    114.055068,
                                    22.635167
                                ],
                                [
                                    114.05505,
                                    22.635171
                                ],
                                [
                                    114.054918,
                                    22.635203
                                ],
                                [
                                    114.054893,
                                    22.635209
                                ],
                                [
                                    114.054861,
                                    22.635216
                                ],
                                [
                                    114.053326,
                                    22.635513
                                ],
                                [
                                    114.052301,
                                    22.635594
                                ],
                                [
                                    114.052279,
                                    22.635557
                                ],
                                [
                                    114.052274,
                                    22.635543
                                ],
                                [
                                    114.052226,
                                    22.635416
                                ],
                                [
                                    114.052211,
                                    22.635359
                                ],
                                [
                                    114.052009,
                                    22.634761
                                ],
                                [
                                    114.051994,
                                    22.634718
                                ],
                                [
                                    114.051963,
                                    22.634618
                                ],
                                [
                                    114.051947,
                                    22.634577
                                ],
                                [
                                    114.051967,
                                    22.634393
                                ],
                                [
                                    114.051985,
                                    22.634307
                                ],
                                [
                                    114.05201,
                                    22.634203
                                ],
                                [
                                    114.05204,
                                    22.633933
                                ],
                                [
                                    114.052066,
                                    22.63388
                                ],
                                [
                                    114.05211,
                                    22.633512
                                ],
                                [
                                    114.052152,
                                    22.6327
                                ],
                                [
                                    114.052676,
                                    22.632673
                                ],
                                [
                                    114.052667,
                                    22.632253
                                ],
                                [
                                    114.053119,
                                    22.632252
                                ],
                                [
                                    114.053157,
                                    22.630538
                                ],
                                [
                                    114.052864,
                                    22.630044
                                ],
                                [
                                    114.053025,
                                    22.629486
                                ],
                                [
                                    114.052878,
                                    22.629162
                                ],
                                [
                                    114.052428,
                                    22.628986
                                ],
                                [
                                    114.051467,
                                    22.628944
                                ],
                                [
                                    114.051121,
                                    22.627065
                                ],
                                [
                                    114.050967,
                                    22.62693
                                ],
                                [
                                    114.050967,
                                    22.626921
                                ],
                                [
                                    114.050961,
                                    22.626848
                                ],
                                [
                                    114.050987,
                                    22.626778
                                ],
                                [
                                    114.050988,
                                    22.626773
                                ],
                                [
                                    114.050993,
                                    22.626738
                                ],
                                [
                                    114.051001,
                                    22.626673
                                ],
                                [
                                    114.051207,
                                    22.626231
                                ],
                                [
                                    114.052149,
                                    22.625696
                                ],
                                [
                                    114.052764,
                                    22.625212
                                ],
                                [
                                    114.052808,
                                    22.625188
                                ],
                                [
                                    114.052937,
                                    22.625125
                                ],
                                [
                                    114.053526,
                                    22.624831
                                ],
                                [
                                    114.053617,
                                    22.624406
                                ],
                                [
                                    114.053613,
                                    22.6243
                                ],
                                [
                                    114.053613,
                                    22.624212
                                ],
                                [
                                    114.053552,
                                    22.623537
                                ],
                                [
                                    114.053544,
                                    22.623343
                                ],
                                [
                                    114.053516,
                                    22.622681
                                ],
                                [
                                    114.053632,
                                    22.622387
                                ],
                                [
                                    114.053388,
                                    22.621898
                                ],
                                [
                                    114.053501,
                                    22.619201
                                ],
                                [
                                    114.053505,
                                    22.619112
                                ],
                                [
                                    114.053508,
                                    22.619007
                                ],
                                [
                                    114.053512,
                                    22.618919
                                ],
                                [
                                    114.05353,
                                    22.618426
                                ],
                                [
                                    114.054646,
                                    22.61782
                                ],
                                [
                                    114.054852,
                                    22.617801
                                ],
                                [
                                    114.054961,
                                    22.617968
                                ],
                                [
                                    114.054744,
                                    22.619315
                                ],
                                [
                                    114.05473,
                                    22.619399
                                ],
                                [
                                    114.054713,
                                    22.619507
                                ],
                                [
                                    114.054699,
                                    22.61959
                                ],
                                [
                                    114.054286,
                                    22.622151
                                ],
                                [
                                    114.054651,
                                    22.622566
                                ],
                                [
                                    114.055352,
                                    22.622062
                                ],
                                [
                                    114.055412,
                                    22.622019
                                ],
                                [
                                    114.05551,
                                    22.621949
                                ],
                                [
                                    114.055569,
                                    22.621907
                                ],
                                [
                                    114.056206,
                                    22.621466
                                ],
                                [
                                    114.0565,
                                    22.621129
                                ],
                                [
                                    114.056558,
                                    22.619366
                                ],
                                [
                                    114.056314,
                                    22.618653
                                ],
                                [
                                    114.056256,
                                    22.617977
                                ],
                                [
                                    114.056399,
                                    22.617849
                                ],
                                [
                                    114.056485,
                                    22.616657
                                ],
                                [
                                    114.056489,
                                    22.616605
                                ],
                                [
                                    114.056499,
                                    22.616464
                                ],
                                [
                                    114.056503,
                                    22.616412
                                ],
                                [
                                    114.056638,
                                    22.614542
                                ],
                                [
                                    114.056786,
                                    22.614329
                                ],
                                [
                                    114.057571,
                                    22.613713
                                ],
                                [
                                    114.058508,
                                    22.612672
                                ],
                                [
                                    114.058955,
                                    22.610733
                                ],
                                [
                                    114.058998,
                                    22.610544
                                ],
                                [
                                    114.059707,
                                    22.607202
                                ],
                                [
                                    114.059708,
                                    22.60714
                                ],
                                [
                                    114.059703,
                                    22.607008
                                ],
                                [
                                    114.059698,
                                    22.606888
                                ],
                                [
                                    114.059678,
                                    22.606731
                                ],
                                [
                                    114.059674,
                                    22.606696
                                ],
                                [
                                    114.059511,
                                    22.605847
                                ],
                                [
                                    114.059442,
                                    22.605694
                                ],
                                [
                                    114.059431,
                                    22.605671
                                ],
                                [
                                    114.059369,
                                    22.605532
                                ],
                                [
                                    114.059363,
                                    22.605517
                                ],
                                [
                                    114.05929,
                                    22.605355
                                ],
                                [
                                    114.05864,
                                    22.6038
                                ],
                                [
                                    114.058156,
                                    22.602929
                                ],
                                [
                                    114.059131,
                                    22.6021
                                ],
                                [
                                    114.060419,
                                    22.601391
                                ],
                                [
                                    114.060896,
                                    22.598109
                                ],
                                [
                                    114.060797,
                                    22.598017
                                ],
                                [
                                    114.061274,
                                    22.597528
                                ],
                                [
                                    114.06216,
                                    22.595911
                                ],
                                [
                                    114.062515,
                                    22.595676
                                ],
                                [
                                    114.062628,
                                    22.59582
                                ],
                                [
                                    114.062768,
                                    22.595954
                                ],
                                [
                                    114.062863,
                                    22.596046
                                ],
                                [
                                    114.063002,
                                    22.596181
                                ],
                                [
                                    114.063444,
                                    22.596606
                                ],
                                [
                                    114.063264,
                                    22.596762
                                ],
                                [
                                    114.063234,
                                    22.596787
                                ],
                                [
                                    114.063206,
                                    22.596811
                                ],
                                [
                                    114.063147,
                                    22.596863
                                ],
                                [
                                    114.063117,
                                    22.596888
                                ],
                                [
                                    114.063059,
                                    22.596938
                                ],
                                [
                                    114.062999,
                                    22.59699
                                ],
                                [
                                    114.062586,
                                    22.597345
                                ],
                                [
                                    114.061853,
                                    22.598742
                                ],
                                [
                                    114.062247,
                                    22.599373
                                ],
                                [
                                    114.062467,
                                    22.599253
                                ],
                                [
                                    114.063457,
                                    22.599291
                                ],
                                [
                                    114.063757,
                                    22.598993
                                ],
                                [
                                    114.063784,
                                    22.598878
                                ],
                                [
                                    114.063791,
                                    22.598803
                                ],
                                [
                                    114.063854,
                                    22.598612
                                ],
                                [
                                    114.063924,
                                    22.598431
                                ],
                                [
                                    114.064083,
                                    22.59802
                                ],
                                [
                                    114.065562,
                                    22.596626
                                ],
                                [
                                    114.066202,
                                    22.596646
                                ],
                                [
                                    114.067363,
                                    22.597109
                                ],
                                [
                                    114.067664,
                                    22.597117
                                ],
                                [
                                    114.069009,
                                    22.596463
                                ],
                                [
                                    114.069936,
                                    22.595511
                                ],
                                [
                                    114.071481,
                                    22.59281
                                ],
                                [
                                    114.071592,
                                    22.592746
                                ],
                                [
                                    114.070783,
                                    22.591517
                                ],
                                [
                                    114.070446,
                                    22.591161
                                ],
                                [
                                    114.069677,
                                    22.590484
                                ],
                                [
                                    114.068388,
                                    22.589547
                                ],
                                [
                                    114.067792,
                                    22.58822
                                ],
                                [
                                    114.06676,
                                    22.587997
                                ],
                                [
                                    114.066427,
                                    22.587767
                                ],
                                [
                                    114.066242,
                                    22.586446
                                ],
                                [
                                    114.066307,
                                    22.585671
                                ],
                                [
                                    114.065572,
                                    22.585862
                                ],
                                [
                                    114.063838,
                                    22.586057
                                ],
                                [
                                    114.06212,
                                    22.586478
                                ],
                                [
                                    114.059393,
                                    22.587531
                                ],
                                [
                                    114.058831,
                                    22.587359
                                ],
                                [
                                    114.058132,
                                    22.586926
                                ],
                                [
                                    114.05771,
                                    22.586392
                                ],
                                [
                                    114.056656,
                                    22.586093
                                ],
                                [
                                    114.056562,
                                    22.586066
                                ],
                                [
                                    114.056469,
                                    22.58604
                                ],
                                [
                                    114.056376,
                                    22.586014
                                ],
                                [
                                    114.054641,
                                    22.585291
                                ],
                                [
                                    114.053877,
                                    22.584813
                                ],
                                [
                                    114.053742,
                                    22.584621
                                ],
                                [
                                    114.053533,
                                    22.582237
                                ],
                                [
                                    114.053343,
                                    22.58208
                                ],
                                [
                                    114.052556,
                                    22.581747
                                ],
                                [
                                    114.047516,
                                    22.582406
                                ],
                                [
                                    114.046389,
                                    22.58322
                                ],
                                [
                                    114.045654,
                                    22.584044
                                ],
                                [
                                    114.045318,
                                    22.584165
                                ],
                                [
                                    114.043538,
                                    22.584099
                                ],
                                [
                                    114.043095,
                                    22.583957
                                ],
                                [
                                    114.042057,
                                    22.583859
                                ],
                                [
                                    114.041096,
                                    22.583906
                                ],
                                [
                                    114.040419,
                                    22.58373
                                ],
                                [
                                    114.039465,
                                    22.583224
                                ],
                                [
                                    114.038943,
                                    22.583044
                                ],
                                [
                                    114.038205,
                                    22.58297
                                ],
                                [
                                    114.036416,
                                    22.582982
                                ],
                                [
                                    114.034303,
                                    22.582628
                                ],
                                [
                                    114.031997,
                                    22.581307
                                ],
                                [
                                    114.030323,
                                    22.580562
                                ],
                                [
                                    114.030141,
                                    22.580561
                                ],
                                [
                                    114.029117,
                                    22.581175
                                ],
                                [
                                    114.028061,
                                    22.581459
                                ],
                                [
                                    114.025531,
                                    22.581602
                                ],
                                [
                                    114.024271,
                                    22.581551
                                ],
                                [
                                    114.023509,
                                    22.581647
                                ],
                                [
                                    114.023942,
                                    22.582409
                                ],
                                [
                                    114.025217,
                                    22.587389
                                ],
                                [
                                    114.025873,
                                    22.589005
                                ],
                                [
                                    114.026285,
                                    22.589584
                                ],
                                [
                                    114.026292,
                                    22.589599
                                ],
                                [
                                    114.026376,
                                    22.589756
                                ],
                                [
                                    114.026421,
                                    22.590284
                                ],
                                [
                                    114.026399,
                                    22.590391
                                ],
                                [
                                    114.026382,
                                    22.590474
                                ],
                                [
                                    114.026377,
                                    22.590494
                                ],
                                [
                                    114.026359,
                                    22.590581
                                ],
                                [
                                    114.026338,
                                    22.590684
                                ],
                                [
                                    114.026043,
                                    22.591936
                                ],
                                [
                                    114.025394,
                                    22.592158
                                ],
                                [
                                    114.024737,
                                    22.592527
                                ],
                                [
                                    114.023901,
                                    22.593347
                                ],
                                [
                                    114.023741,
                                    22.593626
                                ],
                                [
                                    114.023207,
                                    22.595146
                                ],
                                [
                                    114.023648,
                                    22.597158
                                ],
                                [
                                    114.023488,
                                    22.598572
                                ],
                                [
                                    114.02318,
                                    22.599946
                                ],
                                [
                                    114.0219,
                                    22.602357
                                ],
                                [
                                    114.020835,
                                    22.601864
                                ],
                                [
                                    114.018987,
                                    22.602043
                                ],
                                [
                                    114.016785,
                                    22.602591
                                ],
                                [
                                    114.016653,
                                    22.602624
                                ],
                                [
                                    114.016612,
                                    22.602649
                                ],
                                [
                                    114.016603,
                                    22.602655
                                ],
                                [
                                    114.016244,
                                    22.603213
                                ],
                                [
                                    114.016152,
                                    22.603383
                                ],
                                [
                                    114.016128,
                                    22.603427
                                ],
                                [
                                    114.016122,
                                    22.603437
                                ],
                                [
                                    114.016068,
                                    22.603538
                                ],
                                [
                                    114.016049,
                                    22.603604
                                ],
                                [
                                    114.015751,
                                    22.604353
                                ],
                                [
                                    114.014363,
                                    22.605729
                                ],
                                [
                                    114.013299,
                                    22.605877
                                ],
                                [
                                    114.012861,
                                    22.60622
                                ],
                                [
                                    114.009301,
                                    22.611084
                                ],
                                [
                                    114.009109,
                                    22.611618
                                ],
                                [
                                    114.009081,
                                    22.613109
                                ],
                                [
                                    114.008801,
                                    22.615906
                                ],
                                [
                                    114.00682,
                                    22.619112
                                ],
                                [
                                    114.006139,
                                    22.618996
                                ],
                                [
                                    114.00555,
                                    22.619095
                                ],
                                [
                                    114.005187,
                                    22.619412
                                ],
                                [
                                    114.004881,
                                    22.619692
                                ],
                                [
                                    114.004319,
                                    22.620244
                                ],
                                [
                                    114.003937,
                                    22.621497
                                ],
                                [
                                    114.003532,
                                    22.621876
                                ],
                                [
                                    114.002811,
                                    22.622221
                                ],
                                [
                                    114.002651,
                                    22.622427
                                ],
                                [
                                    114.002546,
                                    22.622906
                                ],
                                [
                                    114.002572,
                                    22.623404
                                ],
                                [
                                    114.001924,
                                    22.625431
                                ],
                                [
                                    114.001737,
                                    22.625719
                                ],
                                [
                                    114.001034,
                                    22.625759
                                ],
                                [
                                    114.000318,
                                    22.625416
                                ],
                                [
                                    113.999205,
                                    22.625095
                                ],
                                [
                                    113.998849,
                                    22.62513
                                ],
                                [
                                    113.998131,
                                    22.625504
                                ],
                                [
                                    113.997366,
                                    22.626346
                                ],
                                [
                                    113.996565,
                                    22.626636
                                ],
                                [
                                    113.994856,
                                    22.626509
                                ],
                                [
                                    113.994424,
                                    22.626065
                                ],
                                [
                                    113.993918,
                                    22.62578
                                ],
                                [
                                    113.993775,
                                    22.625834
                                ],
                                [
                                    113.993612,
                                    22.626172
                                ],
                                [
                                    113.993333,
                                    22.626867
                                ],
                                [
                                    113.99316,
                                    22.628119
                                ],
                                [
                                    113.992449,
                                    22.629798
                                ],
                                [
                                    113.992622,
                                    22.630623
                                ],
                                [
                                    113.992521,
                                    22.631096
                                ],
                                [
                                    113.992403,
                                    22.631213
                                ],
                                [
                                    113.991814,
                                    22.631423
                                ],
                                [
                                    113.991225,
                                    22.631951
                                ],
                                [
                                    113.990491,
                                    22.633009
                                ],
                                [
                                    113.989989,
                                    22.634041
                                ],
                                [
                                    113.988879,
                                    22.634984
                                ],
                                [
                                    113.98684,
                                    22.636179
                                ],
                                [
                                    113.985958,
                                    22.63645
                                ],
                                [
                                    113.984501,
                                    22.63625
                                ],
                                [
                                    113.983618,
                                    22.636411
                                ],
                                [
                                    113.982771,
                                    22.63685
                                ],
                                [
                                    113.98236,
                                    22.63724
                                ],
                                [
                                    113.982116,
                                    22.637298
                                ],
                                [
                                    113.981226,
                                    22.63703
                                ],
                                [
                                    113.980253,
                                    22.636939
                                ],
                                [
                                    113.980019,
                                    22.637006
                                ],
                                [
                                    113.97845,
                                    22.636974
                                ],
                                [
                                    113.978029,
                                    22.637098
                                ],
                                [
                                    113.976192,
                                    22.637281
                                ],
                                [
                                    113.975398,
                                    22.636576
                                ],
                                [
                                    113.974731,
                                    22.636126
                                ],
                                [
                                    113.973666,
                                    22.636373
                                ],
                                [
                                    113.973279,
                                    22.637076
                                ],
                                [
                                    113.972302,
                                    22.637453
                                ],
                                [
                                    113.971469,
                                    22.63831
                                ],
                                [
                                    113.970044,
                                    22.640537
                                ],
                                [
                                    113.969882,
                                    22.640661
                                ],
                                [
                                    113.969638,
                                    22.640681
                                ],
                                [
                                    113.969014,
                                    22.640517
                                ],
                                [
                                    113.967455,
                                    22.64042
                                ],
                                [
                                    113.966626,
                                    22.640839
                                ],
                                [
                                    113.966593,
                                    22.641749
                                ],
                                [
                                    113.966726,
                                    22.642334
                                ],
                                [
                                    113.967523,
                                    22.643478
                                ],
                                [
                                    113.968736,
                                    22.644282
                                ],
                                [
                                    113.968547,
                                    22.645765
                                ],
                                [
                                    113.967964,
                                    22.647886
                                ],
                                [
                                    113.967852,
                                    22.648885
                                ],
                                [
                                    113.967084,
                                    22.650781
                                ],
                                [
                                    113.967535,
                                    22.651476
                                ],
                                [
                                    113.967492,
                                    22.65207
                                ],
                                [
                                    113.967321,
                                    22.652624
                                ],
                                [
                                    113.967492,
                                    22.652822
                                ],
                                [
                                    113.96908,
                                    22.652743
                                ],
                                [
                                    113.969767,
                                    22.653258
                                ],
                                [
                                    113.970411,
                                    22.653733
                                ],
                                [
                                    113.970282,
                                    22.655159
                                ],
                                [
                                    113.970454,
                                    22.655555
                                ],
                                [
                                    113.970454,
                                    22.655991
                                ],
                                [
                                    113.972385,
                                    22.657179
                                ],
                                [
                                    113.972642,
                                    22.657456
                                ],
                                [
                                    113.972084,
                                    22.658446
                                ],
                                [
                                    113.972428,
                                    22.659199
                                ],
                                [
                                    113.972642,
                                    22.659397
                                ],
                                [
                                    113.972556,
                                    22.659991
                                ],
                                [
                                    113.972943,
                                    22.660545
                                ],
                                [
                                    113.973329,
                                    22.661099
                                ],
                                [
                                    113.973028,
                                    22.661495
                                ],
                                [
                                    113.972814,
                                    22.662129
                                ],
                                [
                                    113.972814,
                                    22.662723
                                ],
                                [
                                    113.973286,
                                    22.662961
                                ],
                                [
                                    113.973458,
                                    22.663317
                                ],
                                [
                                    113.973114,
                                    22.663713
                                ],
                                [
                                    113.973415,
                                    22.664228
                                ],
                                [
                                    113.972857,
                                    22.664822
                                ],
                                [
                                    113.971355,
                                    22.666604
                                ],
                                [
                                    113.97057,
                                    22.668277
                                ],
                                [
                                    113.969981,
                                    22.669534
                                ],
                                [
                                    113.968308,
                                    22.670524
                                ],
                                [
                                    113.96805,
                                    22.670802
                                ],
                                [
                                    113.967793,
                                    22.672346
                                ],
                                [
                                    113.96702,
                                    22.67298
                                ],
                                [
                                    113.967492,
                                    22.67393
                                ],
                                [
                                    113.968479,
                                    22.675039
                                ],
                                [
                                    113.968866,
                                    22.676662
                                ],
                                [
                                    113.969752,
                                    22.677137
                                ],
                                [
                                    113.970712,
                                    22.677652
                                ],
                                [
                                    113.970347,
                                    22.678325
                                ],
                                [
                                    113.969789,
                                    22.678721
                                ],
                                [
                                    113.97039,
                                    22.679256
                                ],
                                [
                                    113.971034,
                                    22.679691
                                ],
                                [
                                    113.972471,
                                    22.680345
                                ],
                                [
                                    113.97275,
                                    22.680167
                                ],
                                [
                                    113.974576,
                                    22.680425
                                ],
                                [
                                    113.974232,
                                    22.682563
                                ],
                                [
                                    113.974608,
                                    22.683288
                                ],
                                [
                                    113.974919,
                                    22.683889
                                ],
                                [
                                    113.975627,
                                    22.68486
                                ],
                                [
                                    113.975477,
                                    22.686325
                                ],
                                [
                                    113.973889,
                                    22.686127
                                ],
                                [
                                    113.97449,
                                    22.688007
                                ],
                                [
                                    113.97537,
                                    22.689215
                                ],
                                [
                                    113.97434,
                                    22.69064
                                ],
                                [
                                    113.975756,
                                    22.691907
                                ],
                                [
                                    113.975455,
                                    22.692224
                                ],
                                [
                                    113.974919,
                                    22.692541
                                ],
                                [
                                    113.974533,
                                    22.693234
                                ],
                                [
                                    113.975436,
                                    22.693736
                                ],
                                [
                                    113.975911,
                                    22.693715
                                ],
                                [
                                    113.976829,
                                    22.693412
                                ],
                                [
                                    113.978288,
                                    22.693709
                                ],
                                [
                                    113.978545,
                                    22.695057
                                ],
                                [
                                    113.97597,
                                    22.695215
                                ],
                                [
                                    113.975627,
                                    22.696126
                                ],
                                [
                                    113.977858,
                                    22.697472
                                ],
                                [
                                    113.978288,
                                    22.696245
                                ],
                                [
                                    113.98009,
                                    22.696482
                                ],
                                [
                                    113.979918,
                                    22.697353
                                ],
                                [
                                    113.980047,
                                    22.698422
                                ],
                                [
                                    113.97979,
                                    22.698937
                                ],
                                [
                                    113.978803,
                                    22.698779
                                ],
                                [
                                    113.978588,
                                    22.699175
                                ],
                                [
                                    113.978373,
                                    22.699333
                                ],
                                [
                                    113.97803,
                                    22.69957
                                ],
                                [
                                    113.97803,
                                    22.699966
                                ],
                                [
                                    113.977215,
                                    22.699808
                                ],
                                [
                                    113.976743,
                                    22.700046
                                ],
                                [
                                    113.976142,
                                    22.699768
                                ],
                                [
                                    113.975026,
                                    22.699531
                                ],
                                [
                                    113.974769,
                                    22.699887
                                ],
                                [
                                    113.974769,
                                    22.700402
                                ],
                                [
                                    113.976786,
                                    22.700441
                                ],
                                [
                                    113.976957,
                                    22.701154
                                ],
                                [
                                    113.975883,
                                    22.701351
                                ],
                                [
                                    113.976441,
                                    22.702024
                                ],
                                [
                                    113.975799,
                                    22.702816
                                ],
                                [
                                    113.973652,
                                    22.701945
                                ],
                                [
                                    113.973781,
                                    22.70337
                                ],
                                [
                                    113.975454,
                                    22.703647
                                ],
                                [
                                    113.975454,
                                    22.703964
                                ],
                                [
                                    113.97627,
                                    22.706419
                                ],
                                [
                                    113.976742,
                                    22.707171
                                ],
                                [
                                    113.976742,
                                    22.707685
                                ],
                                [
                                    113.976399,
                                    22.707804
                                ],
                                [
                                    113.976956,
                                    22.708636
                                ],
                                [
                                    113.976871,
                                    22.709111
                                ],
                                [
                                    113.977428,
                                    22.709111
                                ],
                                [
                                    113.977729,
                                    22.709823
                                ],
                                [
                                    113.978072,
                                    22.710219
                                ],
                                [
                                    113.978201,
                                    22.710417
                                ],
                                [
                                    113.977986,
                                    22.710971
                                ],
                                [
                                    113.977986,
                                    22.711723
                                ],
                                [
                                    113.977859,
                                    22.712198
                                ],
                                [
                                    113.977257,
                                    22.712753
                                ],
                                [
                                    113.977323,
                                    22.71284
                                ],
                                [
                                    113.977371,
                                    22.712924
                                ],
                                [
                                    113.977452,
                                    22.713028
                                ],
                                [
                                    113.977586,
                                    22.713142
                                ],
                                [
                                    113.977698,
                                    22.713216
                                ],
                                [
                                    113.97779,
                                    22.713256
                                ],
                                [
                                    113.978004,
                                    22.71329
                                ],
                                [
                                    113.978112,
                                    22.71333
                                ],
                                [
                                    113.978331,
                                    22.713449
                                ],
                                [
                                    113.978536,
                                    22.713657
                                ],
                                [
                                    113.978669,
                                    22.713736
                                ],
                                [
                                    113.978745,
                                    22.71377
                                ],
                                [
                                    113.978932,
                                    22.71378
                                ],
                                [
                                    113.978997,
                                    22.713805
                                ],
                                [
                                    113.979115,
                                    22.713993
                                ],
                                [
                                    113.979394,
                                    22.714092
                                ],
                                [
                                    113.979431,
                                    22.714122
                                ],
                                [
                                    113.979469,
                                    22.714176
                                ],
                                [
                                    113.979517,
                                    22.714305
                                ],
                                [
                                    113.979663,
                                    22.714523
                                ],
                                [
                                    113.979919,
                                    22.714815
                                ],
                                [
                                    113.98,
                                    22.714889
                                ],
                                [
                                    113.980188,
                                    22.714963
                                ],
                                [
                                    113.980338,
                                    22.715037
                                ],
                                [
                                    113.980402,
                                    22.715087
                                ],
                                [
                                    113.980433,
                                    22.715177
                                ],
                                [
                                    113.980531,
                                    22.715598
                                ],
                                [
                                    113.980599,
                                    22.715751
                                ],
                                [
                                    113.980749,
                                    22.71592
                                ],
                                [
                                    113.980884,
                                    22.716024
                                ],
                                [
                                    113.980953,
                                    22.716123
                                ],
                                [
                                    113.981071,
                                    22.716454
                                ],
                                [
                                    113.981286,
                                    22.716716
                                ],
                                [
                                    113.981393,
                                    22.716786
                                ],
                                [
                                    113.981517,
                                    22.71685
                                ],
                                [
                                    113.981668,
                                    22.716889
                                ],
                                [
                                    113.981796,
                                    22.716889
                                ],
                                [
                                    113.981914,
                                    22.71687
                                ],
                                [
                                    113.982049,
                                    22.716805
                                ],
                                [
                                    113.982251,
                                    22.716652
                                ],
                                [
                                    113.982403,
                                    22.716405
                                ],
                                [
                                    113.982595,
                                    22.716414
                                ],
                                [
                                    113.982691,
                                    22.716449
                                ],
                                [
                                    113.982986,
                                    22.716746
                                ],
                                [
                                    113.983094,
                                    22.716835
                                ],
                                [
                                    113.983452,
                                    22.716963
                                ],
                                [
                                    113.983639,
                                    22.717052
                                ],
                                [
                                    113.984048,
                                    22.717191
                                ],
                                [
                                    113.984111,
                                    22.71722
                                ],
                                [
                                    113.984278,
                                    22.717507
                                ],
                                [
                                    113.984369,
                                    22.717616
                                ],
                                [
                                    113.984508,
                                    22.717849
                                ],
                                [
                                    113.984557,
                                    22.717958
                                ],
                                [
                                    113.984643,
                                    22.718061
                                ],
                                [
                                    113.984712,
                                    22.718096
                                ],
                                [
                                    113.984917,
                                    22.718137
                                ],
                                [
                                    113.985084,
                                    22.718201
                                ],
                                [
                                    113.985277,
                                    22.71835
                                ],
                                [
                                    113.985422,
                                    22.718464
                                ],
                                [
                                    113.985631,
                                    22.718647
                                ],
                                [
                                    113.985851,
                                    22.718864
                                ],
                                [
                                    113.985953,
                                    22.719023
                                ],
                                [
                                    113.986039,
                                    22.719181
                                ],
                                [
                                    113.986097,
                                    22.71933
                                ],
                                [
                                    113.986097,
                                    22.719468
                                ],
                                [
                                    113.986146,
                                    22.719527
                                ],
                                [
                                    113.986222,
                                    22.719572
                                ],
                                [
                                    113.986419,
                                    22.719785
                                ],
                                [
                                    113.986548,
                                    22.719963
                                ],
                                [
                                    113.986853,
                                    22.720558
                                ],
                                [
                                    113.986945,
                                    22.720771
                                ],
                                [
                                    113.987068,
                                    22.720934
                                ],
                                [
                                    113.987202,
                                    22.721018
                                ],
                                [
                                    113.987241,
                                    22.721083
                                ],
                                [
                                    113.987256,
                                    22.72131
                                ],
                                [
                                    113.98739,
                                    22.721889
                                ],
                                [
                                    113.987936,
                                    22.722731
                                ],
                                [
                                    113.987948,
                                    22.722804
                                ],
                                [
                                    113.98799,
                                    22.722952
                                ],
                                [
                                    113.988033,
                                    22.72316
                                ],
                                [
                                    113.988044,
                                    22.723294
                                ],
                                [
                                    113.98865,
                                    22.72364
                                ],
                                [
                                    113.988854,
                                    22.723754
                                ],
                                [
                                    113.989074,
                                    22.723798
                                ],
                                [
                                    113.989267,
                                    22.723818
                                ],
                                [
                                    113.989595,
                                    22.723996
                                ],
                                [
                                    113.989776,
                                    22.7241
                                ],
                                [
                                    113.990216,
                                    22.724372
                                ],
                                [
                                    113.990416,
                                    22.724476
                                ],
                                [
                                    113.990678,
                                    22.724575
                                ],
                                [
                                    113.990699,
                                    22.724743
                                ],
                                [
                                    113.990683,
                                    22.724926
                                ],
                                [
                                    113.990705,
                                    22.72506
                                ],
                                [
                                    113.990822,
                                    22.725208
                                ],
                                [
                                    113.990989,
                                    22.725436
                                ],
                                [
                                    113.991048,
                                    22.72553
                                ],
                                [
                                    113.991166,
                                    22.72564
                                ],
                                [
                                    113.991321,
                                    22.725704
                                ],
                                [
                                    113.991552,
                                    22.725788
                                ],
                                [
                                    113.991596,
                                    22.725799
                                ],
                                [
                                    113.991772,
                                    22.725897
                                ],
                                [
                                    113.991841,
                                    22.725956
                                ],
                                [
                                    113.991891,
                                    22.726119
                                ],
                                [
                                    113.991907,
                                    22.726189
                                ],
                                [
                                    113.991966,
                                    22.726327
                                ],
                                [
                                    113.992029,
                                    22.726431
                                ],
                                [
                                    113.992099,
                                    22.726541
                                ],
                                [
                                    113.992222,
                                    22.726695
                                ],
                                [
                                    113.992349,
                                    22.726794
                                ],
                                [
                                    113.992531,
                                    22.726884
                                ],
                                [
                                    113.992696,
                                    22.726944
                                ],
                                [
                                    113.992922,
                                    22.726953
                                ],
                                [
                                    113.992964,
                                    22.727032
                                ],
                                [
                                    113.993159,
                                    22.727408
                                ],
                                [
                                    113.993345,
                                    22.72765
                                ],
                                [
                                    113.993839,
                                    22.728156
                                ],
                                [
                                    113.994236,
                                    22.728437
                                ],
                                [
                                    113.994456,
                                    22.7286
                                ],
                                [
                                    113.994595,
                                    22.728684
                                ],
                                [
                                    113.994751,
                                    22.728788
                                ],
                                [
                                    113.994884,
                                    22.728912
                                ],
                                [
                                    113.994987,
                                    22.729179
                                ],
                                [
                                    113.995046,
                                    22.729283
                                ],
                                [
                                    113.995114,
                                    22.729348
                                ],
                                [
                                    113.995238,
                                    22.729418
                                ],
                                [
                                    113.995393,
                                    22.729491
                                ],
                                [
                                    113.995507,
                                    22.729601
                                ],
                                [
                                    113.995598,
                                    22.729783
                                ],
                                [
                                    113.995662,
                                    22.729869
                                ],
                                [
                                    113.995764,
                                    22.729922
                                ],
                                [
                                    113.995882,
                                    22.729957
                                ],
                                [
                                    113.996409,
                                    22.730076
                                ],
                                [
                                    113.996504,
                                    22.730135
                                ],
                                [
                                    113.996908,
                                    22.730318
                                ],
                                [
                                    113.997037,
                                    22.730463
                                ],
                                [
                                    113.997407,
                                    22.731001
                                ],
                                [
                                    113.997476,
                                    22.731115
                                ],
                                [
                                    113.997529,
                                    22.731219
                                ],
                                [
                                    113.997583,
                                    22.731293
                                ],
                                [
                                    113.997729,
                                    22.731388
                                ],
                                [
                                    113.998019,
                                    22.731502
                                ],
                                [
                                    113.998206,
                                    22.731619
                                ],
                                [
                                    113.998362,
                                    22.731783
                                ],
                                [
                                    113.99848,
                                    22.731966
                                ],
                                [
                                    113.998774,
                                    22.732376
                                ],
                                [
                                    113.999109,
                                    22.732693
                                ],
                                [
                                    113.999209,
                                    22.732786
                                ],
                                [
                                    113.999408,
                                    22.732975
                                ],
                                [
                                    113.999668,
                                    22.733224
                                ],
                                [
                                    113.999861,
                                    22.733309
                                ],
                                [
                                    114.000184,
                                    22.733367
                                ],
                                [
                                    114.000569,
                                    22.733586
                                ],
                                [
                                    114.00095,
                                    22.733654
                                ],
                                [
                                    114.001042,
                                    22.733779
                                ],
                                [
                                    114.001397,
                                    22.734124
                                ],
                                [
                                    114.001627,
                                    22.734358
                                ],
                                [
                                    114.001678,
                                    22.734425
                                ],
                                [
                                    114.001796,
                                    22.734534
                                ],
                                [
                                    114.001968,
                                    22.734629
                                ],
                                [
                                    114.002112,
                                    22.734687
                                ],
                                [
                                    114.002231,
                                    22.734693
                                ],
                                [
                                    114.002306,
                                    22.734717
                                ],
                                [
                                    114.002327,
                                    22.734791
                                ],
                                [
                                    114.002408,
                                    22.734964
                                ],
                                [
                                    114.002564,
                                    22.735183
                                ],
                                [
                                    114.002762,
                                    22.735429
                                ],
                                [
                                    114.003099,
                                    22.735949
                                ],
                                [
                                    114.003351,
                                    22.736366
                                ],
                                [
                                    114.003463,
                                    22.736534
                                ],
                                [
                                    114.003534,
                                    22.736577
                                ],
                                [
                                    114.003781,
                                    22.736656
                                ],
                                [
                                    114.003973,
                                    22.736781
                                ],
                                [
                                    114.004182,
                                    22.736899
                                ],
                                [
                                    114.004666,
                                    22.737028
                                ],
                                [
                                    114.005063,
                                    22.737118
                                ],
                                [
                                    114.005229,
                                    22.737123
                                ],
                                [
                                    114.005369,
                                    22.737033
                                ],
                                [
                                    114.005648,
                                    22.736884
                                ],
                                [
                                    114.00598,
                                    22.736726
                                ],
                                [
                                    114.006189,
                                    22.736653
                                ],
                                [
                                    114.006175,
                                    22.736559
                                ],
                                [
                                    114.006179,
                                    22.735971
                                ],
                                [
                                    114.007399,
                                    22.735896
                                ],
                                [
                                    114.008754,
                                    22.735813
                                ],
                                [
                                    114.008346,
                                    22.736224
                                ],
                                [
                                    114.008343,
                                    22.736621
                                ],
                                [
                                    114.008507,
                                    22.738831
                                ],
                                [
                                    114.009204,
                                    22.739939
                                ],
                                [
                                    114.00898,
                                    22.741988
                                ],
                                [
                                    114.008996,
                                    22.742088
                                ],
                                [
                                    114.008989,
                                    22.742131
                                ],
                                [
                                    114.008883,
                                    22.742281
                                ],
                                [
                                    114.008862,
                                    22.742339
                                ],
                                [
                                    114.008866,
                                    22.742404
                                ],
                                [
                                    114.008862,
                                    22.742577
                                ],
                                [
                                    114.008831,
                                    22.742784
                                ],
                                [
                                    114.00875,
                                    22.742902
                                ],
                                [
                                    114.008617,
                                    22.743036
                                ],
                                [
                                    114.008467,
                                    22.743229
                                ],
                                [
                                    114.008462,
                                    22.743367
                                ],
                                [
                                    114.008557,
                                    22.74361
                                ],
                                [
                                    114.008655,
                                    22.743719
                                ],
                                [
                                    114.008762,
                                    22.743861
                                ],
                                [
                                    114.008809,
                                    22.743941
                                ],
                                [
                                    114.008869,
                                    22.744019
                                ],
                                [
                                    114.008666,
                                    22.744198
                                ],
                                [
                                    114.008542,
                                    22.744296
                                ],
                                [
                                    114.008355,
                                    22.744431
                                ],
                                [
                                    114.008241,
                                    22.744519
                                ],
                                [
                                    114.007807,
                                    22.744861
                                ],
                                [
                                    114.008104,
                                    22.745107
                                ],
                                [
                                    114.008097,
                                    22.745238
                                ],
                                [
                                    114.007985,
                                    22.745144
                                ],
                                [
                                    114.007893,
                                    22.745134
                                ],
                                [
                                    114.007673,
                                    22.745233
                                ],
                                [
                                    114.007523,
                                    22.745233
                                ],
                                [
                                    114.007378,
                                    22.745272
                                ],
                                [
                                    114.007141,
                                    22.745282
                                ],
                                [
                                    114.006896,
                                    22.745738
                                ],
                                [
                                    114.006751,
                                    22.746088
                                ],
                                [
                                    114.00666,
                                    22.746212
                                ],
                                [
                                    114.006589,
                                    22.746346
                                ],
                                [
                                    114.006536,
                                    22.74639
                                ],
                                [
                                    114.006348,
                                    22.746406
                                ],
                                [
                                    114.006177,
                                    22.746514
                                ],
                                [
                                    114.006052,
                                    22.746629
                                ],
                                [
                                    114.005345,
                                    22.747271
                                ],
                                [
                                    114.004767,
                                    22.747787
                                ],
                                [
                                    114.004156,
                                    22.748172
                                ],
                                [
                                    114.003963,
                                    22.748341
                                ],
                                [
                                    114.003812,
                                    22.748529
                                ],
                                [
                                    114.003743,
                                    22.748681
                                ],
                                [
                                    114.005164,
                                    22.749908
                                ],
                                [
                                    114.006169,
                                    22.750806
                                ],
                                [
                                    114.006142,
                                    22.750938
                                ],
                                [
                                    114.005783,
                                    22.751365
                                ],
                                [
                                    114.005772,
                                    22.751464
                                ],
                                [
                                    114.005702,
                                    22.751558
                                ],
                                [
                                    114.005569,
                                    22.75156
                                ],
                                [
                                    114.005465,
                                    22.751594
                                ],
                                [
                                    114.005324,
                                    22.751589
                                ],
                                [
                                    114.005179,
                                    22.75162
                                ],
                                [
                                    114.005071,
                                    22.751703
                                ],
                                [
                                    114.004991,
                                    22.751787
                                ],
                                [
                                    114.0049,
                                    22.751906
                                ],
                                [
                                    114.004803,
                                    22.751866
                                ],
                                [
                                    114.004711,
                                    22.751976
                                ],
                                [
                                    114.004626,
                                    22.751828
                                ],
                                [
                                    114.004594,
                                    22.751744
                                ],
                                [
                                    114.004556,
                                    22.751713
                                ],
                                [
                                    114.004486,
                                    22.751709
                                ],
                                [
                                    114.004421,
                                    22.751713
                                ],
                                [
                                    114.004315,
                                    22.751744
                                ],
                                [
                                    114.004223,
                                    22.751758
                                ],
                                [
                                    114.004143,
                                    22.751729
                                ],
                                [
                                    114.004099,
                                    22.751678
                                ],
                                [
                                    114.004089,
                                    22.75162
                                ],
                                [
                                    114.004105,
                                    22.751574
                                ],
                                [
                                    114.004159,
                                    22.751536
                                ],
                                [
                                    114.004309,
                                    22.751471
                                ],
                                [
                                    114.004465,
                                    22.751378
                                ],
                                [
                                    114.004641,
                                    22.751259
                                ],
                                [
                                    114.004734,
                                    22.751156
                                ],
                                [
                                    114.004814,
                                    22.750968
                                ],
                                [
                                    114.004831,
                                    22.750868
                                ],
                                [
                                    114.004809,
                                    22.750844
                                ],
                                [
                                    114.004337,
                                    22.750612
                                ],
                                [
                                    114.004203,
                                    22.750324
                                ],
                                [
                                    114.002577,
                                    22.751105
                                ],
                                [
                                    114.002153,
                                    22.751368
                                ],
                                [
                                    114.001879,
                                    22.751451
                                ],
                                [
                                    114.001627,
                                    22.75157
                                ],
                                [
                                    114.001455,
                                    22.75162
                                ],
                                [
                                    114.001209,
                                    22.751649
                                ],
                                [
                                    114.000881,
                                    22.751758
                                ],
                                [
                                    114.000715,
                                    22.751981
                                ],
                                [
                                    114.000162,
                                    22.752426
                                ],
                                [
                                    114.000012,
                                    22.752684
                                ],
                                [
                                    113.999888,
                                    22.75303
                                ],
                                [
                                    113.999798,
                                    22.753491
                                ],
                                [
                                    113.999696,
                                    22.75371
                                ],
                                [
                                    113.999621,
                                    22.753739
                                ],
                                [
                                    113.998709,
                                    22.753764
                                ],
                                [
                                    113.998285,
                                    22.753884
                                ],
                                [
                                    113.997673,
                                    22.754132
                                ],
                                [
                                    113.997571,
                                    22.754116
                                ],
                                [
                                    113.997039,
                                    22.753849
                                ],
                                [
                                    113.996858,
                                    22.753667
                                ],
                                [
                                    113.996628,
                                    22.753341
                                ],
                                [
                                    113.996457,
                                    22.753286
                                ],
                                [
                                    113.995931,
                                    22.753306
                                ],
                                [
                                    113.995394,
                                    22.753459
                                ],
                                [
                                    113.995099,
                                    22.753646
                                ],
                                [
                                    113.994718,
                                    22.753741
                                ],
                                [
                                    113.994069,
                                    22.753622
                                ],
                                [
                                    113.993581,
                                    22.753469
                                ],
                                [
                                    113.992932,
                                    22.753623
                                ],
                                [
                                    113.992326,
                                    22.75398
                                ],
                                [
                                    113.992867,
                                    22.754726
                                ],
                                [
                                    113.993087,
                                    22.755271
                                ],
                                [
                                    113.993194,
                                    22.755617
                                ],
                                [
                                    113.993226,
                                    22.755824
                                ],
                                [
                                    113.993167,
                                    22.756309
                                ],
                                [
                                    113.993055,
                                    22.756627
                                ],
                                [
                                    113.992985,
                                    22.756894
                                ],
                                [
                                    113.992953,
                                    22.75721
                                ],
                                [
                                    113.992788,
                                    22.757714
                                ],
                                [
                                    113.992976,
                                    22.758229
                                ],
                                [
                                    113.993249,
                                    22.758521
                                ],
                                [
                                    113.993624,
                                    22.759064
                                ],
                                [
                                    113.994312,
                                    22.758773
                                ],
                                [
                                    113.994961,
                                    22.758658
                                ],
                                [
                                    113.995427,
                                    22.758679
                                ],
                                [
                                    113.995696,
                                    22.758762
                                ],
                                [
                                    113.99628,
                                    22.758649
                                ],
                                [
                                    113.996559,
                                    22.758565
                                ],
                                [
                                    113.996736,
                                    22.758664
                                ],
                                [
                                    113.99731,
                                    22.759089
                                ],
                                [
                                    113.998159,
                                    22.760439
                                ],
                                [
                                    113.99832,
                                    22.760711
                                ],
                                [
                                    113.998508,
                                    22.76092
                                ],
                                [
                                    113.998632,
                                    22.760984
                                ],
                                [
                                    113.999324,
                                    22.761237
                                ],
                                [
                                    113.99971,
                                    22.761479
                                ],
                                [
                                    113.999887,
                                    22.761701
                                ],
                                [
                                    114.000112,
                                    22.762062
                                ],
                                [
                                    114.000638,
                                    22.762344
                                ],
                                [
                                    114.001474,
                                    22.762558
                                ],
                                [
                                    114.002483,
                                    22.762973
                                ],
                                [
                                    114.002617,
                                    22.763472
                                ],
                                [
                                    114.002695,
                                    22.763616
                                ],
                                [
                                    114.002836,
                                    22.763504
                                ],
                                [
                                    114.002991,
                                    22.763472
                                ],
                                [
                                    114.003629,
                                    22.763661
                                ],
                                [
                                    114.004752,
                                    22.764075
                                ],
                                [
                                    114.004846,
                                    22.764113
                                ],
                                [
                                    114.005029,
                                    22.764167
                                ],
                                [
                                    114.005101,
                                    22.76417
                                ],
                                [
                                    114.005281,
                                    22.764154
                                ],
                                [
                                    114.005504,
                                    22.764141
                                ],
                                [
                                    114.005566,
                                    22.764135
                                ],
                                [
                                    114.006286,
                                    22.764137
                                ],
                                [
                                    114.006567,
                                    22.764125
                                ],
                                [
                                    114.006909,
                                    22.763632
                                ],
                                [
                                    114.006956,
                                    22.763491
                                ],
                                [
                                    114.007022,
                                    22.763375
                                ],
                                [
                                    114.007218,
                                    22.763083
                                ],
                                [
                                    114.007281,
                                    22.762999
                                ],
                                [
                                    114.007377,
                                    22.762859
                                ],
                                [
                                    114.007419,
                                    22.762781
                                ],
                                [
                                    114.007491,
                                    22.762642
                                ],
                                [
                                    114.007583,
                                    22.762421
                                ],
                                [
                                    114.007638,
                                    22.762301
                                ],
                                [
                                    114.007691,
                                    22.762198
                                ],
                                [
                                    114.007726,
                                    22.762151
                                ],
                                [
                                    114.007961,
                                    22.761838
                                ],
                                [
                                    114.008249,
                                    22.761542
                                ],
                                [
                                    114.008411,
                                    22.761417
                                ],
                                [
                                    114.008506,
                                    22.761352
                                ],
                                [
                                    114.008551,
                                    22.761334
                                ],
                                [
                                    114.008627,
                                    22.761336
                                ],
                                [
                                    114.008753,
                                    22.761364
                                ],
                                [
                                    114.009062,
                                    22.76151
                                ],
                                [
                                    114.009334,
                                    22.761672
                                ],
                                [
                                    114.00953,
                                    22.761773
                                ],
                                [
                                    114.009742,
                                    22.761857
                                ],
                                [
                                    114.009878,
                                    22.761889
                                ],
                                [
                                    114.010029,
                                    22.761942
                                ],
                                [
                                    114.010106,
                                    22.761962
                                ],
                                [
                                    114.01026,
                                    22.762001
                                ],
                                [
                                    114.01041,
                                    22.762027
                                ],
                                [
                                    114.010628,
                                    22.762079
                                ],
                                [
                                    114.010741,
                                    22.762116
                                ],
                                [
                                    114.010885,
                                    22.762143
                                ],
                                [
                                    114.011006,
                                    22.762162
                                ],
                                [
                                    114.011159,
                                    22.762156
                                ],
                                [
                                    114.011297,
                                    22.762132
                                ],
                                [
                                    114.012651,
                                    22.761798
                                ],
                                [
                                    114.012793,
                                    22.761763
                                ],
                                [
                                    114.012931,
                                    22.761725
                                ],
                                [
                                    114.013048,
                                    22.761665
                                ],
                                [
                                    114.013201,
                                    22.761582
                                ],
                                [
                                    114.013367,
                                    22.761484
                                ],
                                [
                                    114.013555,
                                    22.761401
                                ],
                                [
                                    114.013659,
                                    22.761324
                                ],
                                [
                                    114.013756,
                                    22.761243
                                ],
                                [
                                    114.013858,
                                    22.76113
                                ],
                                [
                                    114.013958,
                                    22.760987
                                ],
                                [
                                    114.014016,
                                    22.760883
                                ],
                                [
                                    114.014074,
                                    22.76078
                                ],
                                [
                                    114.014152,
                                    22.760671
                                ],
                                [
                                    114.014221,
                                    22.760612
                                ],
                                [
                                    114.014296,
                                    22.760566
                                ],
                                [
                                    114.014375,
                                    22.760534
                                ],
                                [
                                    114.014446,
                                    22.760524
                                ],
                                [
                                    114.017251,
                                    22.760294
                                ],
                                [
                                    114.017888,
                                    22.76024
                                ],
                                [
                                    114.017997,
                                    22.760315
                                ],
                                [
                                    114.018079,
                                    22.760411
                                ],
                                [
                                    114.018221,
                                    22.76059
                                ],
                                [
                                    114.018243,
                                    22.760616
                                ],
                                [
                                    114.01856,
                                    22.760925
                                ],
                                [
                                    114.018624,
                                    22.761021
                                ],
                                [
                                    114.018651,
                                    22.761078
                                ],
                                [
                                    114.018799,
                                    22.761329
                                ],
                                [
                                    114.018822,
                                    22.761357
                                ],
                                [
                                    114.018863,
                                    22.761394
                                ],
                                [
                                    114.018919,
                                    22.761404
                                ],
                                [
                                    114.020914,
                                    22.7615
                                ],
                                [
                                    114.020972,
                                    22.761516
                                ],
                                [
                                    114.021146,
                                    22.761534
                                ],
                                [
                                    114.021284,
                                    22.761557
                                ],
                                [
                                    114.021424,
                                    22.761581
                                ],
                                [
                                    114.021512,
                                    22.761587
                                ],
                                [
                                    114.021689,
                                    22.761624
                                ],
                                [
                                    114.021903,
                                    22.761677
                                ],
                                [
                                    114.02207,
                                    22.761719
                                ],
                                [
                                    114.022272,
                                    22.761766
                                ],
                                [
                                    114.022473,
                                    22.761816
                                ],
                                [
                                    114.022599,
                                    22.761856
                                ],
                                [
                                    114.022728,
                                    22.761909
                                ],
                                [
                                    114.022874,
                                    22.761968
                                ],
                                [
                                    114.022987,
                                    22.762014
                                ],
                                [
                                    114.02309,
                                    22.762065
                                ],
                                [
                                    114.023174,
                                    22.762112
                                ],
                                [
                                    114.023259,
                                    22.762177
                                ],
                                [
                                    114.023355,
                                    22.762272
                                ],
                                [
                                    114.023444,
                                    22.762369
                                ],
                                [
                                    114.023575,
                                    22.762496
                                ],
                                [
                                    114.023677,
                                    22.762579
                                ],
                                [
                                    114.023774,
                                    22.762647
                                ],
                                [
                                    114.023861,
                                    22.762702
                                ],
                                [
                                    114.023964,
                                    22.762757
                                ],
                                [
                                    114.024097,
                                    22.762812
                                ],
                                [
                                    114.024305,
                                    22.762859
                                ],
                                [
                                    114.024533,
                                    22.762889
                                ],
                                [
                                    114.024681,
                                    22.762917
                                ],
                                [
                                    114.025011,
                                    22.763125
                                ],
                                [
                                    114.025494,
                                    22.763426
                                ],
                                [
                                    114.025643,
                                    22.763483
                                ],
                                [
                                    114.025706,
                                    22.763521
                                ],
                                [
                                    114.025813,
                                    22.763573
                                ],
                                [
                                    114.025844,
                                    22.763589
                                ],
                                [
                                    114.025859,
                                    22.763603
                                ],
                                [
                                    114.025894,
                                    22.76366
                                ],
                                [
                                    114.025933,
                                    22.763761
                                ],
                                [
                                    114.025952,
                                    22.763838
                                ],
                                [
                                    114.025979,
                                    22.763955
                                ],
                                [
                                    114.026015,
                                    22.764125
                                ],
                                [
                                    114.026039,
                                    22.764214
                                ],
                                [
                                    114.026099,
                                    22.764416
                                ],
                                [
                                    114.026142,
                                    22.764568
                                ],
                                [
                                    114.026172,
                                    22.76469
                                ],
                                [
                                    114.026196,
                                    22.76477
                                ],
                                [
                                    114.026213,
                                    22.764838
                                ],
                                [
                                    114.026217,
                                    22.764913
                                ],
                                [
                                    114.026213,
                                    22.765021
                                ],
                                [
                                    114.026174,
                                    22.765119
                                ],
                                [
                                    114.026137,
                                    22.765182
                                ],
                                [
                                    114.026118,
                                    22.765271
                                ],
                                [
                                    114.026107,
                                    22.765352
                                ],
                                [
                                    114.026121,
                                    22.765439
                                ],
                                [
                                    114.026162,
                                    22.765525
                                ],
                                [
                                    114.026222,
                                    22.765632
                                ],
                                [
                                    114.026316,
                                    22.765808
                                ],
                                [
                                    114.026426,
                                    22.765971
                                ],
                                [
                                    114.026515,
                                    22.766076
                                ],
                                [
                                    114.026636,
                                    22.766214
                                ],
                                [
                                    114.026736,
                                    22.766314
                                ],
                                [
                                    114.026835,
                                    22.766408
                                ],
                                [
                                    114.026915,
                                    22.766482
                                ],
                                [
                                    114.026984,
                                    22.766533
                                ],
                                [
                                    114.027079,
                                    22.766567
                                ],
                                [
                                    114.027185,
                                    22.766594
                                ],
                                [
                                    114.027308,
                                    22.766601
                                ],
                                [
                                    114.027382,
                                    22.766598
                                ],
                                [
                                    114.027438,
                                    22.766579
                                ],
                                [
                                    114.027542,
                                    22.766516
                                ],
                                [
                                    114.028085,
                                    22.766112
                                ],
                                [
                                    114.02814,
                                    22.766073
                                ],
                                [
                                    114.028158,
                                    22.766031
                                ],
                                [
                                    114.028381,
                                    22.765494
                                ],
                                [
                                    114.028493,
                                    22.765399
                                ],
                                [
                                    114.028622,
                                    22.765278
                                ],
                                [
                                    114.028739,
                                    22.76517
                                ],
                                [
                                    114.028816,
                                    22.765097
                                ],
                                [
                                    114.028933,
                                    22.765018
                                ],
                                [
                                    114.029042,
                                    22.764946
                                ],
                                [
                                    114.029164,
                                    22.764897
                                ],
                                [
                                    114.029321,
                                    22.764862
                                ],
                                [
                                    114.029494,
                                    22.764821
                                ],
                                [
                                    114.029806,
                                    22.764751
                                ],
                                [
                                    114.02999,
                                    22.764694
                                ],
                                [
                                    114.030091,
                                    22.764662
                                ],
                                [
                                    114.030222,
                                    22.764606
                                ],
                                [
                                    114.030355,
                                    22.76453
                                ],
                                [
                                    114.030449,
                                    22.764469
                                ],
                                [
                                    114.030556,
                                    22.764412
                                ],
                                [
                                    114.030611,
                                    22.764389
                                ],
                                [
                                    114.030664,
                                    22.764352
                                ],
                                [
                                    114.031002,
                                    22.764244
                                ],
                                [
                                    114.031117,
                                    22.764366
                                ],
                                [
                                    114.031283,
                                    22.764568
                                ],
                                [
                                    114.031416,
                                    22.764734
                                ],
                                [
                                    114.031564,
                                    22.764935
                                ],
                                [
                                    114.03167,
                                    22.765077
                                ],
                                [
                                    114.031808,
                                    22.765249
                                ],
                                [
                                    114.031905,
                                    22.765369
                                ],
                                [
                                    114.032149,
                                    22.766042
                                ],
                                [
                                    114.032122,
                                    22.766111
                                ],
                                [
                                    114.032122,
                                    22.766179
                                ],
                                [
                                    114.032126,
                                    22.766258
                                ],
                                [
                                    114.032131,
                                    22.76629
                                ],
                                [
                                    114.032173,
                                    22.766297
                                ],
                                [
                                    114.032271,
                                    22.766299
                                ],
                                [
                                    114.033993,
                                    22.766623
                                ],
                                [
                                    114.034044,
                                    22.766653
                                ],
                                [
                                    114.034171,
                                    22.766665
                                ],
                                [
                                    114.035217,
                                    22.766759
                                ],
                                [
                                    114.035273,
                                    22.766768
                                ],
                                [
                                    114.035306,
                                    22.766755
                                ],
                                [
                                    114.035342,
                                    22.766701
                                ],
                                [
                                    114.035398,
                                    22.766587
                                ],
                                [
                                    114.035428,
                                    22.766486
                                ],
                                [
                                    114.035454,
                                    22.766338
                                ],
                                [
                                    114.035502,
                                    22.766177
                                ],
                                [
                                    114.035574,
                                    22.76598
                                ],
                                [
                                    114.035668,
                                    22.765792
                                ],
                                [
                                    114.035719,
                                    22.765644
                                ],
                                [
                                    114.035779,
                                    22.765511
                                ],
                                [
                                    114.035837,
                                    22.765403
                                ],
                                [
                                    114.035912,
                                    22.765277
                                ],
                                [
                                    114.035992,
                                    22.765147
                                ],
                                [
                                    114.036066,
                                    22.765061
                                ],
                                [
                                    114.036152,
                                    22.764977
                                ],
                                [
                                    114.036237,
                                    22.76492
                                ],
                                [
                                    114.036342,
                                    22.76485
                                ],
                                [
                                    114.036434,
                                    22.764784
                                ],
                                [
                                    114.036545,
                                    22.764723
                                ],
                                [
                                    114.036748,
                                    22.764624
                                ],
                                [
                                    114.036832,
                                    22.764583
                                ],
                                [
                                    114.036932,
                                    22.764556
                                ],
                                [
                                    114.037063,
                                    22.764496
                                ],
                                [
                                    114.037206,
                                    22.764429
                                ],
                                [
                                    114.03737,
                                    22.764378
                                ],
                                [
                                    114.037532,
                                    22.764329
                                ],
                                [
                                    114.037693,
                                    22.764299
                                ],
                                [
                                    114.03781,
                                    22.76427
                                ],
                                [
                                    114.038108,
                                    22.764267
                                ],
                                [
                                    114.039295,
                                    22.764256
                                ],
                                [
                                    114.039418,
                                    22.764228
                                ],
                                [
                                    114.039507,
                                    22.764218
                                ],
                                [
                                    114.039629,
                                    22.764227
                                ],
                                [
                                    114.039765,
                                    22.764255
                                ],
                                [
                                    114.039847,
                                    22.764284
                                ],
                                [
                                    114.03992,
                                    22.764333
                                ],
                                [
                                    114.040021,
                                    22.764396
                                ],
                                [
                                    114.040196,
                                    22.764522
                                ],
                                [
                                    114.040351,
                                    22.764635
                                ],
                                [
                                    114.040452,
                                    22.764712
                                ],
                                [
                                    114.040547,
                                    22.764791
                                ],
                                [
                                    114.040644,
                                    22.764876
                                ],
                                [
                                    114.040737,
                                    22.764968
                                ],
                                [
                                    114.040874,
                                    22.7651
                                ],
                                [
                                    114.040989,
                                    22.765217
                                ],
                                [
                                    114.041068,
                                    22.765325
                                ],
                                [
                                    114.041174,
                                    22.765478
                                ],
                                [
                                    114.041242,
                                    22.765586
                                ],
                                [
                                    114.04135,
                                    22.765753
                                ],
                                [
                                    114.041458,
                                    22.76594
                                ],
                                [
                                    114.041509,
                                    22.766067
                                ],
                                [
                                    114.041578,
                                    22.766182
                                ],
                                [
                                    114.041644,
                                    22.766298
                                ],
                                [
                                    114.041737,
                                    22.766415
                                ],
                                [
                                    114.041824,
                                    22.766523
                                ],
                                [
                                    114.04189,
                                    22.766615
                                ],
                                [
                                    114.041961,
                                    22.766679
                                ],
                                [
                                    114.042035,
                                    22.766719
                                ],
                                [
                                    114.042163,
                                    22.766781
                                ],
                                [
                                    114.042354,
                                    22.766841
                                ],
                                [
                                    114.042472,
                                    22.766875
                                ],
                                [
                                    114.042628,
                                    22.766935
                                ],
                                [
                                    114.042832,
                                    22.767023
                                ],
                                [
                                    114.043013,
                                    22.767092
                                ],
                                [
                                    114.043153,
                                    22.767133
                                ],
                                [
                                    114.043298,
                                    22.767164
                                ],
                                [
                                    114.043446,
                                    22.767203
                                ],
                                [
                                    114.043597,
                                    22.767235
                                ],
                                [
                                    114.043746,
                                    22.76727
                                ],
                                [
                                    114.043912,
                                    22.767323
                                ],
                                [
                                    114.044084,
                                    22.767399
                                ],
                                [
                                    114.044182,
                                    22.767444
                                ],
                                [
                                    114.044287,
                                    22.767496
                                ],
                                [
                                    114.044498,
                                    22.767566
                                ],
                                [
                                    114.044564,
                                    22.767585
                                ],
                                [
                                    114.045348,
                                    22.769556
                                ],
                                [
                                    114.045389,
                                    22.769644
                                ],
                                [
                                    114.04545,
                                    22.769788
                                ],
                                [
                                    114.045579,
                                    22.77
                                ],
                                [
                                    114.045716,
                                    22.770238
                                ],
                                [
                                    114.045852,
                                    22.77041
                                ],
                                [
                                    114.046397,
                                    22.771096
                                ],
                                [
                                    114.046442,
                                    22.771153
                                ],
                                [
                                    114.046543,
                                    22.771248
                                ],
                                [
                                    114.046668,
                                    22.77132
                                ],
                                [
                                    114.046831,
                                    22.771383
                                ],
                                [
                                    114.046936,
                                    22.771425
                                ],
                                [
                                    114.047062,
                                    22.771453
                                ],
                                [
                                    114.047256,
                                    22.771533
                                ],
                                [
                                    114.047434,
                                    22.771614
                                ],
                                [
                                    114.047523,
                                    22.771656
                                ],
                                [
                                    114.047579,
                                    22.771664
                                ],
                                [
                                    114.048442,
                                    22.771793
                                ],
                                [
                                    114.048558,
                                    22.77182
                                ],
                                [
                                    114.048627,
                                    22.771822
                                ],
                                [
                                    114.048727,
                                    22.771774
                                ],
                                [
                                    114.049394,
                                    22.771449
                                ],
                                [
                                    114.04961,
                                    22.771343
                                ],
                                [
                                    114.049714,
                                    22.771255
                                ],
                                [
                                    114.049761,
                                    22.77118
                                ],
                                [
                                    114.049776,
                                    22.770753
                                ],
                                [
                                    114.049822,
                                    22.769493
                                ],
                                [
                                    114.049825,
                                    22.769414
                                ],
                                [
                                    114.049805,
                                    22.769344
                                ],
                                [
                                    114.049775,
                                    22.769276
                                ],
                                [
                                    114.0497,
                                    22.769161
                                ],
                                [
                                    114.049621,
                                    22.769067
                                ],
                                [
                                    114.04953,
                                    22.76898
                                ],
                                [
                                    114.04945,
                                    22.768915
                                ],
                                [
                                    114.049337,
                                    22.768808
                                ],
                                [
                                    114.049171,
                                    22.76871
                                ],
                                [
                                    114.049009,
                                    22.768617
                                ],
                                [
                                    114.048873,
                                    22.768544
                                ],
                                [
                                    114.048766,
                                    22.768517
                                ],
                                [
                                    114.048728,
                                    22.768496
                                ],
                                [
                                    114.048711,
                                    22.768457
                                ],
                                [
                                    114.048714,
                                    22.768403
                                ],
                                [
                                    114.048761,
                                    22.767959
                                ],
                                [
                                    114.048794,
                                    22.767755
                                ],
                                [
                                    114.048821,
                                    22.76755
                                ],
                                [
                                    114.048886,
                                    22.767306
                                ],
                                [
                                    114.048925,
                                    22.767047
                                ],
                                [
                                    114.04898,
                                    22.766856
                                ],
                                [
                                    114.049007,
                                    22.766771
                                ],
                                [
                                    114.049044,
                                    22.766571
                                ],
                                [
                                    114.049077,
                                    22.766407
                                ],
                                [
                                    114.049122,
                                    22.766261
                                ],
                                [
                                    114.049155,
                                    22.766109
                                ],
                                [
                                    114.049175,
                                    22.766034
                                ],
                                [
                                    114.049263,
                                    22.765863
                                ],
                                [
                                    114.049309,
                                    22.765789
                                ],
                                [
                                    114.049372,
                                    22.765707
                                ],
                                [
                                    114.049476,
                                    22.76563
                                ],
                                [
                                    114.049566,
                                    22.765562
                                ],
                                [
                                    114.0497,
                                    22.765509
                                ],
                                [
                                    114.04981,
                                    22.765479
                                ],
                                [
                                    114.049922,
                                    22.765445
                                ],
                                [
                                    114.050104,
                                    22.765391
                                ],
                                [
                                    114.050227,
                                    22.765339
                                ],
                                [
                                    114.050327,
                                    22.765292
                                ],
                                [
                                    114.05039,
                                    22.765272
                                ],
                                [
                                    114.050636,
                                    22.765169
                                ],
                                [
                                    114.050729,
                                    22.765088
                                ],
                                [
                                    114.052127,
                                    22.763382
                                ],
                                [
                                    114.052208,
                                    22.763282
                                ],
                                [
                                    114.052232,
                                    22.76316
                                ],
                                [
                                    114.05223,
                                    22.763032
                                ],
                                [
                                    114.052171,
                                    22.762728
                                ],
                                [
                                    114.052154,
                                    22.762313
                                ],
                                [
                                    114.052153,
                                    22.762279
                                ],
                                [
                                    114.052135,
                                    22.762121
                                ],
                                [
                                    114.052121,
                                    22.762005
                                ],
                                [
                                    114.052089,
                                    22.761908
                                ],
                                [
                                    114.052051,
                                    22.761717
                                ],
                                [
                                    114.052015,
                                    22.761609
                                ],
                                [
                                    114.051984,
                                    22.761533
                                ],
                                [
                                    114.051955,
                                    22.761418
                                ],
                                [
                                    114.051938,
                                    22.761307
                                ],
                                [
                                    114.051919,
                                    22.761184
                                ],
                                [
                                    114.051911,
                                    22.761056
                                ],
                                [
                                    114.051893,
                                    22.76097
                                ],
                                [
                                    114.051875,
                                    22.760904
                                ],
                                [
                                    114.05184,
                                    22.760849
                                ],
                                [
                                    114.051806,
                                    22.760817
                                ],
                                [
                                    114.05172,
                                    22.760765
                                ],
                                [
                                    114.050434,
                                    22.760014
                                ],
                                [
                                    114.050359,
                                    22.759961
                                ],
                                [
                                    114.05024,
                                    22.759907
                                ],
                                [
                                    114.050104,
                                    22.759859
                                ],
                                [
                                    114.050039,
                                    22.759839
                                ],
                                [
                                    114.049916,
                                    22.759826
                                ],
                                [
                                    114.049849,
                                    22.759806
                                ],
                                [
                                    114.049801,
                                    22.759785
                                ],
                                [
                                    114.049745,
                                    22.759741
                                ],
                                [
                                    114.049634,
                                    22.759587
                                ],
                                [
                                    114.048886,
                                    22.758558
                                ],
                                [
                                    114.048841,
                                    22.758539
                                ],
                                [
                                    114.048808,
                                    22.758501
                                ],
                                [
                                    114.048764,
                                    22.758421
                                ],
                                [
                                    114.048713,
                                    22.758287
                                ],
                                [
                                    114.048677,
                                    22.758171
                                ],
                                [
                                    114.048661,
                                    22.758057
                                ],
                                [
                                    114.048648,
                                    22.757913
                                ],
                                [
                                    114.048612,
                                    22.757763
                                ],
                                [
                                    114.048594,
                                    22.757684
                                ],
                                [
                                    114.048575,
                                    22.75755
                                ],
                                [
                                    114.048554,
                                    22.757401
                                ],
                                [
                                    114.048547,
                                    22.757308
                                ],
                                [
                                    114.048537,
                                    22.757186
                                ],
                                [
                                    114.048542,
                                    22.757101
                                ],
                                [
                                    114.048565,
                                    22.75704
                                ],
                                [
                                    114.048609,
                                    22.756996
                                ],
                                [
                                    114.048702,
                                    22.756946
                                ],
                                [
                                    114.048778,
                                    22.756896
                                ],
                                [
                                    114.04908,
                                    22.756686
                                ],
                                [
                                    114.049385,
                                    22.756464
                                ],
                                [
                                    114.049532,
                                    22.75639
                                ],
                                [
                                    114.049657,
                                    22.75637
                                ],
                                [
                                    114.052503,
                                    22.755863
                                ],
                                [
                                    114.053493,
                                    22.755685
                                ],
                                [
                                    114.053577,
                                    22.755772
                                ],
                                [
                                    114.053634,
                                    22.75585
                                ],
                                [
                                    114.053679,
                                    22.755914
                                ],
                                [
                                    114.053707,
                                    22.755989
                                ],
                                [
                                    114.053751,
                                    22.756076
                                ],
                                [
                                    114.053789,
                                    22.756178
                                ],
                                [
                                    114.053831,
                                    22.756258
                                ],
                                [
                                    114.053886,
                                    22.756318
                                ],
                                [
                                    114.053964,
                                    22.756365
                                ],
                                [
                                    114.054028,
                                    22.756389
                                ],
                                [
                                    114.054094,
                                    22.756397
                                ],
                                [
                                    114.054187,
                                    22.756419
                                ],
                                [
                                    114.054284,
                                    22.756441
                                ],
                                [
                                    114.05437,
                                    22.756466
                                ],
                                [
                                    114.054442,
                                    22.756481
                                ],
                                [
                                    114.054543,
                                    22.756487
                                ],
                                [
                                    114.054617,
                                    22.756509
                                ],
                                [
                                    114.054705,
                                    22.75654
                                ],
                                [
                                    114.054826,
                                    22.756588
                                ],
                                [
                                    114.054954,
                                    22.756624
                                ],
                                [
                                    114.055036,
                                    22.756653
                                ],
                                [
                                    114.055129,
                                    22.756682
                                ],
                                [
                                    114.055242,
                                    22.756716
                                ],
                                [
                                    114.055391,
                                    22.756744
                                ],
                                [
                                    114.055482,
                                    22.756757
                                ],
                                [
                                    114.05556,
                                    22.756763
                                ],
                                [
                                    114.055998,
                                    22.756722
                                ],
                                [
                                    114.056459,
                                    22.75668
                                ],
                                [
                                    114.056494,
                                    22.756676
                                ],
                                [
                                    114.056509,
                                    22.756633
                                ],
                                [
                                    114.056846,
                                    22.755682
                                ],
                                [
                                    114.056974,
                                    22.755416
                                ],
                                [
                                    114.057022,
                                    22.755315
                                ],
                                [
                                    114.057098,
                                    22.755091
                                ],
                                [
                                    114.057143,
                                    22.754957
                                ],
                                [
                                    114.057197,
                                    22.75484
                                ],
                                [
                                    114.057233,
                                    22.754771
                                ],
                                [
                                    114.057303,
                                    22.754689
                                ],
                                [
                                    114.057397,
                                    22.754598
                                ],
                                [
                                    114.057539,
                                    22.754509
                                ],
                                [
                                    114.057676,
                                    22.754415
                                ],
                                [
                                    114.057803,
                                    22.754345
                                ],
                                [
                                    114.057926,
                                    22.754266
                                ],
                                [
                                    114.058071,
                                    22.754181
                                ],
                                [
                                    114.058207,
                                    22.754081
                                ],
                                [
                                    114.058347,
                                    22.753986
                                ],
                                [
                                    114.058443,
                                    22.753936
                                ],
                                [
                                    114.05856,
                                    22.753907
                                ],
                                [
                                    114.058634,
                                    22.753861
                                ],
                                [
                                    114.058681,
                                    22.753835
                                ],
                                [
                                    114.058736,
                                    22.753836
                                ],
                                [
                                    114.058803,
                                    22.753851
                                ],
                                [
                                    114.058938,
                                    22.75387
                                ],
                                [
                                    114.058972,
                                    22.753889
                                ],
                                [
                                    114.05907,
                                    22.753954
                                ],
                                [
                                    114.059213,
                                    22.754047
                                ],
                                [
                                    114.059324,
                                    22.754142
                                ],
                                [
                                    114.059392,
                                    22.754206
                                ],
                                [
                                    114.059455,
                                    22.754273
                                ],
                                [
                                    114.059507,
                                    22.754341
                                ],
                                [
                                    114.059544,
                                    22.754417
                                ],
                                [
                                    114.059599,
                                    22.754531
                                ],
                                [
                                    114.059644,
                                    22.754653
                                ],
                                [
                                    114.059698,
                                    22.754842
                                ],
                                [
                                    114.059716,
                                    22.754912
                                ],
                                [
                                    114.059742,
                                    22.754999
                                ],
                                [
                                    114.059778,
                                    22.755046
                                ],
                                [
                                    114.05985,
                                    22.755077
                                ],
                                [
                                    114.059922,
                                    22.755076
                                ],
                                [
                                    114.063438,
                                    22.755992
                                ],
                                [
                                    114.06375,
                                    22.756212
                                ],
                                [
                                    114.063845,
                                    22.756221
                                ],
                                [
                                    114.064131,
                                    22.756096
                                ],
                                [
                                    114.064579,
                                    22.755902
                                ],
                                [
                                    114.064607,
                                    22.755848
                                ],
                                [
                                    114.064652,
                                    22.755723
                                ],
                                [
                                    114.064666,
                                    22.755642
                                ],
                                [
                                    114.064673,
                                    22.755583
                                ],
                                [
                                    114.064679,
                                    22.755502
                                ],
                                [
                                    114.064683,
                                    22.755446
                                ],
                                [
                                    114.064658,
                                    22.755398
                                ],
                                [
                                    114.064583,
                                    22.755322
                                ],
                                [
                                    114.064512,
                                    22.755237
                                ],
                                [
                                    114.064609,
                                    22.75259
                                ],
                                [
                                    114.064619,
                                    22.752446
                                ],
                                [
                                    114.064619,
                                    22.752383
                                ],
                                [
                                    114.064613,
                                    22.752232
                                ],
                                [
                                    114.064591,
                                    22.752077
                                ],
                                [
                                    114.064574,
                                    22.752008
                                ],
                                [
                                    114.06455,
                                    22.751906
                                ],
                                [
                                    114.064517,
                                    22.751794
                                ],
                                [
                                    114.064473,
                                    22.751687
                                ],
                                [
                                    114.064431,
                                    22.751614
                                ],
                                [
                                    114.064377,
                                    22.751554
                                ],
                                [
                                    114.064296,
                                    22.751506
                                ],
                                [
                                    114.064222,
                                    22.751468
                                ],
                                [
                                    114.064109,
                                    22.751434
                                ],
                                [
                                    114.064018,
                                    22.751425
                                ],
                                [
                                    114.063758,
                                    22.751373
                                ],
                                [
                                    114.063613,
                                    22.751345
                                ],
                                [
                                    114.063425,
                                    22.749578
                                ],
                                [
                                    114.066188,
                                    22.747981
                                ],
                                [
                                    114.069001,
                                    22.749662
                                ],
                                [
                                    114.070795,
                                    22.749124
                                ],
                                [
                                    114.072388,
                                    22.746395
                                ],
                                [
                                    114.07249,
                                    22.742293
                                ],
                                [
                                    114.074815,
                                    22.740887
                                ],
                                [
                                    114.075767,
                                    22.742283
                                ],
                                [
                                    114.079498,
                                    22.745324
                                ],
                                [
                                    114.081242,
                                    22.745996
                                ],
                                [
                                    114.080996,
                                    22.747182
                                ],
                                [
                                    114.080992,
                                    22.747244
                                ],
                                [
                                    114.081002,
                                    22.74733
                                ],
                                [
                                    114.081007,
                                    22.747404
                                ],
                                [
                                    114.081007,
                                    22.747481
                                ],
                                [
                                    114.081028,
                                    22.747547
                                ],
                                [
                                    114.081055,
                                    22.747597
                                ],
                                [
                                    114.082147,
                                    22.748631
                                ],
                                [
                                    114.082218,
                                    22.748736
                                ],
                                [
                                    114.082408,
                                    22.748972
                                ],
                                [
                                    114.082523,
                                    22.749114
                                ],
                                [
                                    114.082675,
                                    22.749226
                                ],
                                [
                                    114.082864,
                                    22.74936
                                ],
                                [
                                    114.083127,
                                    22.749543
                                ],
                                [
                                    114.083236,
                                    22.749618
                                ],
                                [
                                    114.083355,
                                    22.749739
                                ],
                                [
                                    114.083443,
                                    22.749834
                                ],
                                [
                                    114.083591,
                                    22.749936
                                ],
                                [
                                    114.083756,
                                    22.750094
                                ],
                                [
                                    114.083926,
                                    22.750215
                                ],
                                [
                                    114.084178,
                                    22.750398
                                ],
                                [
                                    114.084295,
                                    22.750496
                                ],
                                [
                                    114.084361,
                                    22.750544
                                ],
                                [
                                    114.084394,
                                    22.750565
                                ],
                                [
                                    114.084421,
                                    22.750563
                                ],
                                [
                                    114.084506,
                                    22.750493
                                ],
                                [
                                    114.084751,
                                    22.750303
                                ],
                                [
                                    114.084996,
                                    22.750087
                                ],
                                [
                                    114.085196,
                                    22.749894
                                ],
                                [
                                    114.085368,
                                    22.749744
                                ],
                                [
                                    114.085538,
                                    22.749641
                                ],
                                [
                                    114.085741,
                                    22.749508
                                ],
                                [
                                    114.085875,
                                    22.749409
                                ],
                                [
                                    114.085999,
                                    22.7493
                                ],
                                [
                                    114.086133,
                                    22.749186
                                ],
                                [
                                    114.086316,
                                    22.749043
                                ],
                                [
                                    114.086426,
                                    22.748954
                                ],
                                [
                                    114.086507,
                                    22.748875
                                ],
                                [
                                    114.086578,
                                    22.748854
                                ],
                                [
                                    114.08668,
                                    22.74884
                                ],
                                [
                                    114.086843,
                                    22.748829
                                ],
                                [
                                    114.086973,
                                    22.748818
                                ],
                                [
                                    114.087141,
                                    22.748815
                                ],
                                [
                                    114.087313,
                                    22.748822
                                ],
                                [
                                    114.087575,
                                    22.748843
                                ],
                                [
                                    114.087782,
                                    22.74887
                                ],
                                [
                                    114.087979,
                                    22.748912
                                ],
                                [
                                    114.088118,
                                    22.748948
                                ],
                                [
                                    114.088299,
                                    22.749022
                                ],
                                [
                                    114.088475,
                                    22.749099
                                ],
                                [
                                    114.088645,
                                    22.749184
                                ],
                                [
                                    114.088786,
                                    22.749234
                                ],
                                [
                                    114.088878,
                                    22.74927
                                ],
                                [
                                    114.088969,
                                    22.749301
                                ],
                                [
                                    114.089907,
                                    22.749535
                                ],
                                [
                                    114.089949,
                                    22.749545
                                ],
                                [
                                    114.090025,
                                    22.749501
                                ],
                                [
                                    114.090212,
                                    22.74936
                                ],
                                [
                                    114.091846,
                                    22.748521
                                ],
                                [
                                    114.092829,
                                    22.748016
                                ],
                                [
                                    114.092845,
                                    22.747971
                                ],
                                [
                                    114.092834,
                                    22.747926
                                ],
                                [
                                    114.092779,
                                    22.74785
                                ],
                                [
                                    114.092726,
                                    22.747793
                                ],
                                [
                                    114.092629,
                                    22.747721
                                ],
                                [
                                    114.092541,
                                    22.747674
                                ],
                                [
                                    114.092408,
                                    22.747633
                                ],
                                [
                                    114.091896,
                                    22.74721
                                ],
                                [
                                    114.091696,
                                    22.746968
                                ],
                                [
                                    114.092149,
                                    22.746049
                                ],
                                [
                                    114.096174,
                                    22.746427
                                ],
                                [
                                    114.096843,
                                    22.746579
                                ],
                                [
                                    114.098468,
                                    22.747191
                                ],
                                [
                                    114.09868,
                                    22.746904
                                ],
                                [
                                    114.098831,
                                    22.746476
                                ],
                                [
                                    114.098743,
                                    22.745294
                                ],
                                [
                                    114.098016,
                                    22.743354
                                ],
                                [
                                    114.098099,
                                    22.743135
                                ],
                                [
                                    114.100281,
                                    22.741275
                                ],
                                [
                                    114.100827,
                                    22.739117
                                ],
                                [
                                    114.101036,
                                    22.73781
                                ],
                                [
                                    114.100824,
                                    22.73654
                                ],
                                [
                                    114.099404,
                                    22.735648
                                ],
                                [
                                    114.102837,
                                    22.731379
                                ],
                                [
                                    114.104202,
                                    22.731652
                                ],
                                [
                                    114.104377,
                                    22.731608
                                ],
                                [
                                    114.105225,
                                    22.730965
                                ],
                                [
                                    114.107179,
                                    22.723001
                                ],
                                [
                                    114.10812,
                                    22.722709
                                ],
                                [
                                    114.110533,
                                    22.72243
                                ],
                                [
                                    114.111273,
                                    22.721954
                                ],
                                [
                                    114.111759,
                                    22.721434
                                ],
                                [
                                    114.113366,
                                    22.72103
                                ]
                            ]
                        ]
                    },
                    "properties": {
                        "name": "龙华区",
                        "cp": [
                            114.044346,
                            22.691963
                        ]
                    }
                }
            ]
        }
    );
}));